//////////////////////////////////////////////////////////////////////////////////
//                                                                              //
//	$Revision: 1 $								//
//										//
//	Name       : SwiMPApiCm.h						//
//                                                                              //
//	Purpose    : SWI MP API							//
//                                                                              //
//	Note       : The contents of this header file are specific to the       //
//                   MP 7XX API and do not concern the AirCard 7XX API          //
//					                                        //
//	Copyright (c) 2003 Sierra Wireless, Inc.  All rights reserved		//
//                                                                              //
//////////////////////////////////////////////////////////////////////////////////
#ifndef _SWI_MP_API_
#define _SWI_MP_API_

#ifdef __cplusplus
extern "C" {
#endif

#include "SwiRcodes.h"
#include "SwiStructsMp.h"
#include "SwiApiCm.h"

//////////////////////////////////////////////////////////////////////////////////
//
// Name:	SwiStopAllMpNotif - to stop the modem from sending MP notifications
//
// Purpose:	This function is used to stop the modem from sending all MP notifications.
//
//			A request is sent to the modem.  The modem's response indicates that
//			the request is being processed.
//
//			The caller must specify the amount of time to wait for the modem
//			to respond to the request.    
//			
// Parameters:
//
//			timeout[IN]:		response timeout value in milliseconds
//
// Return:	SWI_RCODE_OK - the request has been received by the modem
//			SWI_RCODE_REQUEST_TIMEOUT  - the  request has timed out
//			See SWI_RCODE for other error return codes
//
// Notes:	None
//
//////////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiStopAllMpNotif(U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:	SwiSwitchMode - switch between data link modes
//
// Purpose:	This function is used to switch the method in which the API
//			communicates with the modem.
//
//			A request is sent to the modem.  The modem's response indicates a 
//			success or failure.
//			
// Parameters:
//		
//			eMode[IN]:		stores the data link mode to switch to
//
// Return:	SWI_RCODE_OK - the request was successful
//			SWI_RCODE_REQUEST_TIMEOUT  - the  request has timed out
//			See SWI_RCODE for other error return codes
//
// Notes:	None
//
//////////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiSwitchMode(SWI_TYPE_SwitchMode eMode);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:	SwiGetSwitchMode - get the current data link mode
//
// Purpose:	This function is used to get the current method that the API
//			uses to communicate with the modem.
//
//			A request is sent to the modem.  The modem's response sucess or 
//			failure.
//			
// Parameters:
//
//			eMode[OUT]:		stores the current data link mode
//
// Return:	SWI_RCODE_OK - the request is successful
//			SWI_RCODE_REQUEST_TIMEOUT  - the  request has timed out
//			See SWI_RCODE for other error return codes
//
// Notes:	None
//
//////////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiGetSwitchMode(SWI_TYPE_SwitchMode *eMode);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:	SwiGetExternalDigitalIOConfig - Get external digital input/output configuration
//
// Purpose:	The host software uses function to retrieve the current 
//			configuration of the specified external digital I/O.  A notification 
//			(SWI_STRUCT_EXT_DIO_Notif) returns the current logic level of all the I/O's.
//			
//			A request is sent to the modem.  The modem's response indicates that
//			the request is being processed.
//
//			The caller must specify the amount of time to wait for the modem
//			to respond to the request.    
//			
// Parameters:
//		
//			psDio[OUT]:			structure stores external digital I/O information retrieved
//
//			timeout[IN]:		response timeout value in milliseconds
//
// Return:	SWI_RCODE_OK - the request has been received by the modem
//			SWI_RCODE_REQUEST_TIMEOUT  - the  request has timed out
//			See SWI_RCODE for other error return codes
//
// Notes:	None
//
//////////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiGetExternalDigitalIOConfig(SWI_STRUCT_ExtDioCfg *psDio, U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:	SwiSetExternalDigitalIOConfig - Set external digital input/output configuration
//
// Purpose:	The host software uses function to configure an external 
//			digital I/O using the set request.  The set request configures only 
//			the specified I/O line.
//			
//			A request is sent to the modem.  The modem's response indicates that
//			the request is being processed.
//
//			The caller must specify the amount of time to wait for the modem
//			to respond to the request.    
//			
// Parameters:
//		
//			psDio[IN]:			structure stores external digital I/O information to set
//
//			timeout[IN]:		response timeout value in milliseconds
//
// Return:	SWI_RCODE_OK - the request has been received by the modem
//			SWI_RCODE_REQUEST_TIMEOUT  - the  request has timed out
//			See SWI_RCODE for other error return codes
//
// Notes:	None
//
//////////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiSetExternalDigitalIOConfig(SWI_STRUCT_ExtDioCfg *psDio, U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:	SwiGetExternalAnalogIOConfig - get external analog input configuration
//
// Purpose:	The host software uses this function to retrieve the current 
//			configuration of the specified external analog input.  The notification 
//			returns the current logic level of all the Input's.
//			
//			A request is sent to the modem.  The modem's response indicates that
//			the request is being processed.
//
//			The caller must specify the amount of time to wait for the modem
//			to respond to the request.    
//			
// Parameters:
//		
//			psAi[OUT]:			stores external analog input information retrieved
//
//			timeout[IN]:		response timeout value in milliseconds
//
// Return:	SWI_RCODE_OK - the request has been received by the modem
//			SWI_RCODE_REQUEST_TIMEOUT  - the  request has timed out
//			See SWI_RCODE for other error return codes
//
// Notes:	None
//
//////////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiGetExternalAnalogIOConfig(SWI_STRUCT_ExtAiCfg *psAi, U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:	SwiSetExternalAnalogIOConfig - set external analog input configuration
//
// Purpose:	The host software uses this to set the logic level of 
//			an external digital output using the set request.  The set request 
//			configures only the specified I/O line.
//			
//			A request is sent to the modem.  The modem's response indicates that
//			the request is being processed.
//
//			The caller must specify the amount of time to wait for the modem
//			to respond to the request.    
//			
// Parameters:
//		
//			psAi[IN]:			stores external analog input information to set
//
//			timeout[IN]:		response timeout value in milliseconds
//
// Return:	SWI_RCODE_OK - the request has been received by the modem
//			SWI_RCODE_REQUEST_TIMEOUT  - the  request has timed out
//			See SWI_RCODE for other error return codes
//
// Notes:	None
//
//////////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiSetExternalAnalogIOConfig(SWI_STRUCT_ExtAiCfg *psAi, U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:	SwiSetGPSCommand - send a GPS command to the GPS module
//
// Purpose:	This function is used to send GPS commands to the GPS module		
//
//			A request is sent to the modem.  The modem's response indicates that
//			the request is being processed.
//
//			The caller must specify the amount of time to wait for the modem
//			to respond to the request.    
//			
// Parameters:
//		
//			sGpsCommand[IN]:	stores the GPS command to be sent to the GPS module
//
//			timeout[IN]:		response timeout value in milliseconds
//
// Return:	SWI_RCODE_OK - the request has been received by the modem
//			SWI_RCODE_REQUEST_TIMEOUT  - the  request has timed out
//			See SWI_RCODE for other error return codes
//
// Notes:	None
//
//////////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiSetGPSCommand (SWI_STRUCT_GpsCommand sGpsCommand, U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:	SwiSetGpsReset - Reset the GPS module
//
// Purpose:	This function is used to send a GPS reset command to the GPS module		
//
//			A request is sent to the modem.  The modem's response indicates that
//			the request is being processed.
//
//			The caller must specify the amount of time to wait for the modem
//			to respond to the request.    
//			
// Parameters:
//
//			timeout[IN]:		response timeout value in milliseconds
//
// Return:	SWI_RCODE_OK - the request has been received by the modem
//			SWI_RCODE_REQUEST_TIMEOUT  - the  request has timed out
//			See SWI_RCODE for other error return codes
//
// Notes:	None
//
//////////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiSetGpsReset (U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:	SwiGetMpProductRevision - Get the Product Revision
//
// Purpose:	This function is used to get the product revision information from the modem	
//
//			A request is sent to the modem.  The modem's response indicates that
//			the request is being processed.
//
//			The caller must specify the amount of time to wait for the modem
//			to respond to the request.    
//			
// Parameters:
//
//			psMpRevision[OUT]:	stores product revision information
//
//			timeout[IN]:		response timeout value in milliseconds
//
// Return:	SWI_RCODE_OK - the request has been received by the modem
//			SWI_RCODE_REQUEST_TIMEOUT  - the  request has timed out
//			See SWI_RCODE for other error return codes
//
// Notes:	None
//
//////////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiGetMpProductRevision (SWI_STRUCT_MpRevision *psMPRevision, U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:	SwiGetMPDataCount - Get the Data Counter
//
// Purpose:	This function is used to get data counter information.  Proper
//			information must be set in 'pMPDataCount' before passing the
//			structure into the function for data retrieval.  Refer to comments
//			for SWI_STRUCT_MpDataCount for more information.
//
//			A request is sent to the modem.  The modem's response indicates that
//			the request is being processed.
//
//			The caller must specify the amount of time to wait for the modem
//			to respond to the request.    
//			
// Parameters:
//
//			psMPDataCount[OUT]:	stores data counter information retrieved
//
//			timeout[IN]:		response timeout value in milliseconds
//
// Return:	SWI_RCODE_OK - the request has been received by the modem
//			SWI_RCODE_REQUEST_TIMEOUT  - the  request has timed out
//			See SWI_RCODE for other error return codes
//
// Notes:	None
//
//////////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiGetMpDataCount (SWI_STRUCT_MpDataCount *pMPDataCount, U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:	SwiClearMPByteCount - Reset the Byte Counter
//
// Purpose:	This function is used to clear the total byte counter statistics.  User
//			must set the appropriate values for nYear, nMonth, nDay, nHour, 
//			nMinute, and nSecond in sMpDataCount before passing it into this
//			function.
//
//			A request is sent to the modem.  The modem's response indicates that
//			the request is being processed.
//
//			The caller must specify the amount of time to wait for the modem
//			to respond to the request.    
//			
// Parameters:
//
//			sMpDataCount[IN]:	stores reset information
//
//			timeout[IN]:		response timeout value in milliseconds
//
// Return:	SWI_RCODE_OK - the request has been received by the modem
//			SWI_RCODE_REQUEST_TIMEOUT  - the  request has timed out
//			See SWI_RCODE for other error return codes
//
// Notes:	None
//
//////////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiClearMpByteCount (SWI_STRUCT_MpDataCount sMpDataCount, U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:	SwiResetMpTrafficStatistics - Reset the session byte counter
//
// Purpose:	This function is used to reset session byte counter.
//
//			A request is sent to the modem.  The modem's response indicates that
//			the request is being processed.
//
//			The caller must specify the amount of time to wait for the modem
//			to respond to the request.    
//			
// Parameters:
//
//			timeout[IN]:		response timeout value in milliseconds
//
// Return:	SWI_RCODE_OK - the request has been received by the modem
//			SWI_RCODE_REQUEST_TIMEOUT  - the  request has timed out
//			See SWI_RCODE for other error return codes
//
// Notes:	None
//
//////////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiResetMpTrafficStatistics (U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:	SwiGetMpIgnitionSense - get the delay time between loss of ignition sense
//									and powering off the modem
//
// Purpose:	Used by host software to retrieve the 'time delay' value, ie. the 
//			'time delay' between lost of ignition sense and modem power-off.
//			
//			A request is sent to the modem.  The modem's response indicates that
//			the request is being processed.
//
//			The caller must specify the amount of time to wait for the modem
//			to respond to the request.    
//			
// Parameters:
//
//			nDelay[OUT]:		stores the time delay value
//
//			timeout[IN]:		response timeout value in milliseconds
//
// Return:	SWI_RCODE_OK - the request has been received by the modem
//			SWI_RCODE_REQUEST_TIMEOUT  - the  request has timed out
//			See SWI_RCODE for other error return codes
//
// Notes:	None
//
//////////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiGetMpIgnitionSense(U32* nDelay, U32 timeout);


//////////////////////////////////////////////////////////////////////////////////
//
// Name:	SwiSetMpIgnitionSense - set a delay time between loss of ignition sense
//									and powering off the modem
//
// Purpose:	The host software uses this function to specify a delay time 
//			(in minutes) between loss of ignition sense and powering-off the modem.  
//			This allows the modem to continue operation for a limited period after 
//			the vehicle ignition is switched off.  This setting is stored in 
//			non-volatile memory.
//
//			The notification (SWI_NOTIFY_MPIgnSense) first informs the host software when the 
//			ignition is turned off.  When the shutdown time approaches, other notifications are 
//			sent to the host software indicating that the MP750 will soon be shutdown.
//
//			If the ignition sense (accessory power) is turned on again before the 
//			power down time has expired, the timer is stopped and MP750 will not shutdown.  
//			In addition, if a set request is sent after the delay timer has started, 
//			but not yet expired, the MP750 continues with the current timer value.  
//			The new timer value is used when the ignition is turned back on.
//			
//			A request is sent to the modem.  The modem's response indicates that
//			the request is being processed.
//
//			The caller must specify the amount of time to wait for the modem
//			to respond to the request.    
//			
// Parameters:
//
//			nDelay[IN]:		delay time in minutes between loss of ignition sense and
//							powering-off the modem
//
//			timeout[IN]:	response timeout value in milliseconds
//
// Return:	SWI_RCODE_OK - the request has been received by the modem
//			SWI_RCODE_REQUEST_TIMEOUT  - the  request has timed out
//			See SWI_RCODE for other error return codes
//
// Notes:	None
//
//////////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiSetMpIgnitionSense (U32 nDelay, U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:	SwiGetMpNetworkConf - Get network configuration
//
// Purpose:	The host software uses this function to retrieve the network configuration 
//			stored on the MP750.
//			
//			A request is sent to the modem.  The modem's response indicates that
//			the request is being processed.
//
//			The caller must specify the amount of time to wait for the modem
//			to respond to the request.    
//			
// Parameters:
//
//			sNetworkConf[OUT]:	stores network configuration information retrieved
//
//			timeout[IN]:		response timeout value in milliseconds
//
// Return:	SWI_RCODE_OK - the request has been received by the modem
//			SWI_RCODE_REQUEST_TIMEOUT  - the  request has timed out
//			See SWI_RCODE for other error return codes
//
// Notes:	None
//
//////////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiGetMpNetworkConf(SWI_STRUCT_MpNetworkConf *sNetworkConf, U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:	SwiSetMpNetworkConf - Set network configuration
//
// Purpose:	The host software uses this function to set the network configuration 
//			stored on the MP750.
//			
//
//			A request is sent to the modem.  The modem's response indicates that
//			the request is being processed.
//
//			The caller must specify the amount of time to wait for the modem
//			to respond to the request.    
//			
// Parameters:
//
//			sNetworkConf[IN]:	stores the network configuration information to set 
//
//			timeout[IN]:		response timeout value in milliseconds
//
// Return:	SWI_RCODE_OK - the request has been received by the modem
//			SWI_RCODE_REQUEST_TIMEOUT  - the  request has timed out
//			See SWI_RCODE for other error return codes
//
// Notes:	None
//
//////////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiSetMpNetworkConf(SWI_STRUCT_MpNetworkConf sNetworkConf, U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:	SwiGetMpFwVersion - retrieves the MP firmware version
//
// Purpose:	This function is used to retrieve the firmware version of your MP750.
//
//			A request is sent to the modem.  The modem's response indicates that
//			the request is being processed.
//
//			The caller must specify the amount of time to wait for the modem
//			to respond to the request.    
//			
// Parameters:
//
//			sVersion[OUT]:		structure which stores the firmware version
//
//			timeout[IN]:		response timeout value in milliseconds
//
// Return:	SWI_RCODE_OK - the request has been received by the modem
//			SWI_RCODE_REQUEST_TIMEOUT  - the  request has timed out
//			See SWI_RCODE for other error return codes
//
// Notes:	None
//
//////////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiGetMpFwVersion(SWI_STRUCT_MpFwVersion* sVersion, U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:	SwiGetMpFwBuildDate - retrieves the MP firmware build date
//
// Purpose:	This function is used to retrieve the MP firmware build date.
//
//			A request is sent to the modem.  The modem's response indicates that
//			the request is being processed.
//
//			The caller must specify the amount of time to wait for the modem
//			to respond to the request.    
//			
// Parameters:
//
//			sBuildDate[OUT]:	structure which stores the firmware build date
//
//			timeout[IN]:		response timeout value in milliseconds
//
// Return:	SWI_RCODE_OK - the request has been received by the modem
//			SWI_RCODE_REQUEST_TIMEOUT  - the  request has timed out
//			See SWI_RCODE for other error return codes
//
// Notes:	None
//
//////////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiGetMpFwBuildDate(SWI_STRUCT_MpFwBuildDate* sBuildDate, U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:	SwiGetMpBootLoaderVersion - retrieves the MP boot loader version
//
// Purpose:	This function is used to retrieve the MP boot loader version
//
//			A request is sent to the modem.  The modem's response indicates that
//			the request is being processed.
//
//			The caller must specify the amount of time to wait for the modem
//			to respond to the request.    
//			
// Parameters:
//
//			sVersion[OUT]:		structure which stores the boot loader version
//
//			timeout[IN]:		response timeout value in milliseconds
//
// Return:	SWI_RCODE_OK - the request has been received by the modem
//			SWI_RCODE_REQUEST_TIMEOUT  - the  request has timed out
//			See SWI_RCODE for other error return codes
//
// Notes:	None
//
//////////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiGetMpBootLoaderVersion(SWI_STRUCT_MpBootLoaderVersion* sVersion, U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:	SwiGetMpHwVersion - retrieves the MP hardware version
//
// Purpose:	This function is used to retrieve the MP hardware version.
//
//			A request is sent to the modem.  The modem's response indicates that
//			the request is being processed.
//
//			The caller must specify the amount of time to wait for the modem
//			to respond to the request.    
//			
// Parameters:
//
//			sVersion[OUT]:		structure which stores the hardware version
//
//			timeout[IN]:		response timeout value in milliseconds
//
// Return:	SWI_RCODE_OK - the request has been received by the modem
//			SWI_RCODE_REQUEST_TIMEOUT  - the  request has timed out
//			See SWI_RCODE for other error return codes
//
// Notes:	None
//
//////////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiGetMpHwVersion(SWI_STRUCT_MpHwVersion* sVersion, U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:	SwiGetMpHwBuildDate - retrieves the MP hardware build date
//
// Purpose:	This function is used to retrieve the MP hardware build date.
//
//			A request is sent to the modem.  The modem's response indicates that
//			the request is being processed.
//
//			The caller must specify the amount of time to wait for the modem
//			to respond to the request.    
//			
// Parameters:
//
//			sVersion[OUT]:		structure which stores the hardware build date
//
//			timeout[IN]:		response timeout value in milliseconds
//
// Return:	SWI_RCODE_OK - the request has been received by the modem
//			SWI_RCODE_REQUEST_TIMEOUT  - the  request has timed out
//			See SWI_RCODE for other error return codes
//
// Notes:	None
//
//////////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiGetMpHwBuildDate(SWI_STRUCT_MpHwBuildDate* sVersion, U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:	SwiGetMpBatchNumber - retrieves the MP batch number
//
// Purpose:	This function is used to retrieve the MP batch number.
//
//			A request is sent to the modem.  The modem's response indicates that
//			the request is being processed.
//
//			The caller must specify the amount of time to wait for the modem
//			to respond to the request.    
//			
// Parameters:
//
//			sNumber[OUT]:		structure which stores the batch number
//
//			timeout[IN]:		response timeout value in milliseconds
//
// Return:	SWI_RCODE_OK - the request has been received by the modem
//			SWI_RCODE_REQUEST_TIMEOUT  - the  request has timed out
//			See SWI_RCODE for other error return codes
//
// Notes:	None
//
//////////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiGetMpBatchNumber(SWI_STRUCT_MpBatchNumber* sNumber, U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:	SwiGetMpFsn - retrieves the MP Fsn number
//
// Purpose:	This function is used to retrieve the MP Fsn number.
//
//			A request is sent to the modem.  The modem's response indicates that
//			the request is being processed.
//
//			The caller must specify the amount of time to wait for the modem
//			to respond to the request.    
//			
// Parameters:
//
//			sFsn[OUT]:			structure which stores the Fsn number
//
//			timeout[IN]:		response timeout value in milliseconds
//
// Return:	SWI_RCODE_OK - the request has been received by the modem
//			SWI_RCODE_REQUEST_TIMEOUT  - the  request has timed out
//			See SWI_RCODE for other error return codes
//
// Notes:	None
//
//////////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiGetMpFsn(SWI_STRUCT_MpFsn* sFsn, U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:	SwiGetMpDeviceName - retrieves the MP device name
//
// Purpose:	This function is used to retrieve the MP device name.
//
//			A request is sent to the modem.  The modem's response indicates that
//			the request is being processed.
//
//			The caller must specify the amount of time to wait for the modem
//			to respond to the request.    
//			
// Parameters:
//
//			sDeviceName[OUT]:	structure which stores the device name
//
//			timeout[IN]:		response timeout value in milliseconds
//
// Return:	SWI_RCODE_OK - the request has been received by the modem
//			SWI_RCODE_REQUEST_TIMEOUT  - the  request has timed out
//			See SWI_RCODE for other error return codes
//
// Notes:	None
//
//////////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiGetMpDeviceName(SWI_STRUCT_MpName* sDeviceName, U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:	SwiSetMpDeviceName - sets the MP device name
//
// Purpose:	This function is used to set the MP device name.
//			It takes in a properly populated SWI_STRUCT_MP_Name structure and 
//			sets the MP name to the modem with it.	
//
//			A request is sent to the modem.  The modem's response indicates that
//			the request is being processed.
//
//			The caller must specify the amount of time to wait for the modem
//			to respond to the request.    
//			
// Parameters:
//
//			sDeviceName[OUT]:	structure which stores the device name
//
//			timeout[IN]:		response timeout value in milliseconds
//
// Return:	SWI_RCODE_OK - the request has been received by the modem
//			SWI_RCODE_REQUEST_TIMEOUT  - the  request has timed out
//			See SWI_RCODE for other error return codes
//
// Notes:	None
//
//////////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiSetMpDeviceName(SWI_STRUCT_MpName sDeviceName, U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:	SwiGetMpCnxSetup - retrieve MP profile data
//
// Purpose:	This function is used to retrieve MP profile information.
//
//			A request is sent to the modem.  The modem's response indicates that
//			the request is being processed.
//
//			The caller must specify the amount of time to wait for the modem
//			to respond to the request.    
//			
// Parameters:
//
//			sProfile[OUT]:		stores the requested profile information
//
//			timeout[IN]:		response timeout value in milliseconds
//
// Return:	SWI_RCODE_OK - the request has been received by the modem
//			SWI_RCODE_REQUEST_TIMEOUT  - the  request has timed out
//			See SWI_RCODE for other error return codes
//
// Notes:	None
//
//////////////////////////////////////////////////////////////////////////////////
SWI_API	SWI_RCODE SwiGetMpCnxSetup(SWI_STRUCT_MpConnectionSetup* sProfile, U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:	SwiSetMpCnxSetup - set MP profile data
//
// Purpose:	This function is used to set MP profile information.
//
//			A request is sent to the modem.  The modem's response indicates that
//			the request is being processed.
//
//			The caller must specify the amount of time to wait for the modem
//			to respond to the request.    
//			
// Parameters:
//
//			sProfile[OUT]:		stores the profile information to be set
//
//			timeout[IN]:		response timeout value in milliseconds
//
// Return:	SWI_RCODE_OK - the request has been received by the modem
//			SWI_RCODE_REQUEST_TIMEOUT  - the  request has timed out
//			See SWI_RCODE for other error return codes
//
// Notes:	None
//
//////////////////////////////////////////////////////////////////////////////////
SWI_API	SWI_RCODE SwiSetMpCnxSetup(SWI_STRUCT_MpConnectionSetup sProfile, U32 timeout);


SWI_API	SWI_RCODE SwiGetMp555CnxSetup(SWI_STRUCT_Mp555ConnectionSetup* sProfile, U32 timeout);

SWI_API	SWI_RCODE SwiSetMp555CnxSetup(SWI_STRUCT_Mp555ConnectionSetup sProfile, U32 timeout);


//////////////////////////////////////////////////////////////////////////////////
//
// Name:	SwiMpConnect
//
// Purpose:	There are two cases involved with this function:
// 1)		USB case:	If using USB then this function creates an actual
//						data connection.
//
// 2)		Serial case:If using serial then this function will test the
//						connection to see if it is valid.  The user must invoke
//						dial-up networking to create the actual data connection.   
//			
//			A request is sent to the modem.  The modem's response indicates that
//			the request is being processed.
//
//			The caller must specify the amount of time to wait for the modem
//			to respond to the request.    
//			
// Parameters:
//
//			sConnect[IN]:	stores connection information needed to create a data
//							connection
//
//			timeout[IN]:	response timeout value in milliseconds
//
// Return:	SWI_RCODE_OK - the request has been received by the modem
//			SWI_RCODE_REQUEST_TIMEOUT  - the  request has timed out
//			See SWI_RCODE for other error return codes
//
// Notes:	None
//
//////////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiMpConnect(SWI_STRUCT_MpConnect sConnect, U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:	SwiMpDisconnect
//
// Purpose:	Disconnect from an active data connection.
//			
//			Note: USB only function
//
//			A request is sent to the modem.  The modem's response indicates that
//			the request is being processed.
//
//			The caller must specify the amount of time to wait for the modem
//			to respond to the request.    
//			
// Parameters:
//
//			timeout[IN]:		response timeout value in milliseconds
//
// Return:	SWI_RCODE_OK - the request has been received by the modem
//			SWI_RCODE_REQUEST_TIMEOUT  - the  request has timed out
//			See SWI_RCODE for other error return codes
//
// Notes:	None
//
//////////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiMpDisconnect(U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:	SwiGetMpStartupCfg - Get MP startup configuration
//
// Purpose:	Used to get UDP port information used by the MP modem.
//			
//			A request is sent to the modem.  The modem's response indicates that
//			the request is being processed.
//
//			The caller must specify the amount of time to wait for the modem
//			to respond to the request.    
//			
// Parameters:
//
//			sConfig[OUT]:		stores UDP port information retrieved
//
//			timeout[IN]:		response timeout value in milliseconds
//
// Return:	SWI_RCODE_OK - the request has been received by the modem
//			SWI_RCODE_REQUEST_TIMEOUT  - the  request has timed out
//			See SWI_RCODE for other error return codes
//
// Notes:	None
//
//////////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiGetMpStartupCfg(SWI_STRUCT_MpStartupConfig* sConfig, U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:	SwiSetMpStartupCfg - Set MP startup configuration
//
// Purpose:	Used to configure what UDP port to use on the MP modem.  The UDP settings
//			are used to send control and status messages to the MP when a data (dial-up)
//			connection is active.
//
//			The caller must specify the amount of time to wait for the modem
//			to respond to the request.    
//			
// Parameters:
//
//			sConfig[IN]:		stores UDP port information to set
//
//			timeout[IN]:		response timeout value in milliseconds
//
// Return:	SWI_RCODE_OK - the request has been received by the modem
//			SWI_RCODE_REQUEST_TIMEOUT  - the  request has timed out
//			See SWI_RCODE for other error return codes
//
// Notes:	None
//
//////////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiSetMpStartupCfg(SWI_STRUCT_MpStartupConfig sConfig, U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:	SwiGetMpActiveSetup - Get MP active setup
//
// Purpose:	Used to retrieve the index of the setup currently used to connect
//			with the network.  
//			
//			A request is sent to the modem.  The modem's response indicates that
//			the request is being processed.
//
//			The caller must specify the amount of time to wait for the modem
//			to respond to the request.    
//			
// Parameters:
//
//			sActive[OUT]:		stores the active setup (if any)
//
//			timeout[IN]:		response timeout value in milliseconds
//
// Return:	SWI_RCODE_OK - the request was successful
//			SWI_RCODE_REQUEST_TIMEOUT  - the  request has timed out
//			See SWI_RCODE for other error return codes
//
// Notes:	The result signals the connection status between the MP and the network.
//			This API call should only be made after SWI_NOTIFY_MP_Connect is
//			received.  Otherwise the value returned is unreliable.
//
//////////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiGetMpActiveSetup(SWI_STRUCT_MpActiveSetup* sActive, U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:	SwiGetMpManagerCfg 
//
// Purpose:	Used to retrieve MP manager configuration information  
//			
//			A request is sent to the modem.  The modem's response contains the
//			configuration settings.
//
//			The caller must specify the amount of time to wait for the modem
//			to respond to the request.    
//			
// Parameters:
//
//			sMpCfg[OUT]:	stores the MP Manager configuration
//
//			timeout[IN]:	response timeout value in milliseconds
//
// Return:	SWI_RCODE_OK - the request has been received by the modem
//			SWI_RCODE_REQUEST_TIMEOUT  - the  request has timed out
//			See SWI_RCODE for other error return codes
//
// Notes:	
//
//////////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiGetMpManagerCfg(SWI_STRUCT_MpManagerCfg &sMpCfg, U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:	SwiSetMpManagerCfg 
//
// Purpose:	Used to Set MP manager configuration information  
//
//			The caller must specify the amount of time to wait for the modem
//			to respond to the request.    
//			
// Parameters:
//
//			sMpCfg[IN]:	contains the MP Manager configuration
//
//			timeout[IN]:	response timeout value in milliseconds
//
// Return:	SWI_RCODE_OK - the request was successful
//			SWI_RCODE_REQUEST_TIMEOUT  - the  request has timed out
//			See SWI_RCODE for other error return codes
//
// Notes:	
//
//////////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiSetMpManagerCfg(SWI_STRUCT_MpManagerCfg sMpCfg, U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:	SwiStartMpRouter 
//
// Purpose:	Used to start MP manager router  
//			
//			A request is sent to begin routing MP manager data.   
//			
// Parameters:
//
//			sMpCfg[IN]:	contains the MP Manager routing configuration
//
// Return:	SWI_RCODE_OK - the request has been received by the modem
//			See SWI_RCODE for other error return codes
//
// Notes:	
//
//////////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiStartMpRouter(SWI_STRUCT_MpManagerCfg sMpCfg);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:	SwiStopMpRouter 
//
// Purpose:	Used to stop MP manager router  
//			
//			A request is sent to stop routing MP manager data.   
//			
// Parameters:
//
//			none
//
// Return:	SWI_RCODE_OK - the request has been received by the modem
//			See SWI_RCODE for other error return codes
//
// Notes:	
//
//////////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiStopMpRouter();

//////////////////////////////////////////////////////////////////////////////////
//
// Name:	SwiGetMpMtCfg 
//
// Purpose:	Used to retrieve MP Monitor and Tracking configuration  
//			
//			A request is sent to the modem.  The modem's response contains the
//			configuration settings.
//
//			The caller must specify the amount of time to wait for the modem
//			to respond to the request.    
//			
// Parameters:
//
//			sMpCfg[OUT]:	stores the MP MT configuration
//
//			timeout[IN]:	response timeout value in milliseconds
//
// Return:	SWI_RCODE_OK - the request has been received by the modem
//			SWI_RCODE_REQUEST_TIMEOUT  - the  request has timed out
//			See SWI_RCODE for other error return codes
//
// Notes:	
//
//////////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiGetMpMtCfg(SWI_STRUCT_MpMtCfg &sMpCfg, U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:	SwiSetMpMtCfg 
//
// Purpose:	Used to set MP Monitor and Tracking configuration 
//
//			The caller must specify the amount of time to wait for the modem
//			to respond to the request.    
//			
// Parameters:
//
//			sMpCfg[IN]:		contains the MP MT configuration
//
//			timeout[IN]:	response timeout value in milliseconds
//
// Return:	SWI_RCODE_OK - the request was successful
//			SWI_RCODE_REQUEST_TIMEOUT  - the  request has timed out
//			See SWI_RCODE for other error return codes
//
// Notes:	
//
//////////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiSetMpMtCfg(SWI_STRUCT_MpMtCfg sMpCfg, U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:	SwiGetMpCwCfg 
//
// Purpose:	Used to retrieve MP Watchdog configuration  
//			
//			A request is sent to the modem.  The modem's response contains the
//			configuration settings.
//
//			The caller must specify the amount of time to wait for the modem
//			to respond to the request.    
//			
// Parameters:
//
//			sMpCfg[OUT]:	stores the MP Watchdog configuration
//
//			timeout[IN]:	response timeout value in milliseconds
//
// Return:	SWI_RCODE_OK - the request has been received by the modem
//			SWI_RCODE_REQUEST_TIMEOUT  - the  request has timed out
//			See SWI_RCODE for other error return codes
//
// Notes:	
//
//////////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiGetMpCwCfg(SWI_STRUCT_MpCwCfg &sMpCfg, U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:	SwiSetMpMtCfg 
//
// Purpose:	Used to set MP Watchdog configuration 
//
//			The caller must specify the amount of time to wait for the modem
//			to respond to the request.    
//			
// Parameters:
//
//			sMpCfg[IN]:		contains the MP Watchdog configuration
//
//			timeout[IN]:	response timeout value in milliseconds
//
// Return:	SWI_RCODE_OK - the request was successful
//			SWI_RCODE_REQUEST_TIMEOUT  - the  request has timed out
//			See SWI_RCODE for other error return codes
//
// Notes:	
//
//////////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiSetMpCwCfg(SWI_STRUCT_MpCwCfg sMpCfg, U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:	SwiGetMpGpsInitCfg
//
// Purpose:	Used to retrieve MP GPS initialization string
//			
//			A request is sent to the modem.  The modem's response contains the
//			configuration settings.
//
//			The caller must specify the amount of time to wait for the modem
//			to respond to the request.    
//			
// Parameters:
//
//			sMpGpsInitCfg[OUT]:	stores the MP GPS initialization string
//
//			timeout[IN]:	response timeout value in milliseconds
//
// Return:	SWI_RCODE_OK - the request has been received by the modem
//			SWI_RCODE_REQUEST_TIMEOUT  - the  request has timed out
//			See SWI_RCODE for other error return codes
//
// Notes:	
//
//////////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiGetMpGpsInitCfg(SWI_STRUCT_MpGpsInitCfg &sMpGpsInitStr, U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:	SWI_STRUCT_MpGpsInitCfg 
//
// Purpose:	Used to set MP GPS initialization string
//
//			The caller must specify the amount of time to wait for the modem
//			to respond to the request.    
//			
// Parameters:
//
//			sMpGpsInitCfg[IN]:		contains the MP GPS initialization string
//
//			timeout[IN]:	response timeout value in milliseconds
//
// Return:	SWI_RCODE_OK - the request was successful
//			SWI_RCODE_REQUEST_TIMEOUT  - the  request has timed out
//			See SWI_RCODE for other error return codes
//
// Notes:	
//
//////////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiSetMpGpsInitCfg(SWI_STRUCT_MpGpsInitCfg sMpGpsInitStr, U32 timeout);

//////////////////////////////////////////////////////////////////////////////////
//
// Name:	SwiEnableMpNotif - to enable notifications
//
// Purpose:	This function is used to enable MP notifications in the list.  The list
//			consists of CWE or product specific objects to enable.
//
//			A request is sent to the modem.  The modem's response indicates that
//			the request is being processed.
//
//			The caller must specify the amount of time to wait for the modem
//			to respond to the request.    
//			
// Parameters:
//
//			psList[IN]:			list MP of notifications to enable
//
//			timeout[IN]:		response timeout value in milliseconds
//
// Return:	SWI_RCODE_OK - the request has been received by the modem
//			SWI_RCODE_REQUEST_TIMEOUT  - the  request has timed out
//			See SWI_RCODE for other error return codes
//
// Notes:	None
//
//////////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiEnableMpNotif(SWI_STRUCT_NotifList *psList, U32 timeout);

///////////////////////////////////////////////////////////////////////////////
//
// Name:	SwiGetMpWifiCfg
//
// Purpose:	This function is used to retrieve WIFI Access Point (WAP) 
//			configuration
//			
// Parameters:
//
//			sMpWifiCfg[OUT]:	WAP configuration
//
//			timeout[IN]:		response timeout value in milliseconds
//
// Return:	See SWI_RCODE for error return codes
//
// Notes:	None
//
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiGetMpWifiCfg(SWI_STRUCT_MpWifiCfg &sMpWifiCfg, U32 timeout);

///////////////////////////////////////////////////////////////////////////////
//
// Name:	SwiSetMpWifiCfg
//
// Purpose:	This function is used to set WIFI Access Point (WAP) 
//			configuration
//			
// Parameters:
//
//			sMpWifiCfg[OUT]:	WAP configuration
//
//			timeout[IN]:		response timeout value in milliseconds
//
// Return:	SWI_RCODE_OK indicates the modem has received the request 
//			successfully.  However, eResult must be evaluate to determine
//			if the operation actually succeeded.
//
//			See SWI_RCODE for additional error return codes
//
// Notes:	MP has to be unlocked at configuration level in order to modify
//			WAP configuration (see SwiSetMpUnlock).  MP has to be reset for the
//			changes to take effect.
//
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiSetMpWifiCfg(SWI_STRUCT_MpWifiCfg &sMpWifiCfg, U32 timeout);

///////////////////////////////////////////////////////////////////////////////
//
// Name:	SwiSetMpUnlock
//
// Purpose:	This function is used to unlock the MP to access various 
//			functionality
//			
// Parameters:
//
//			sMpUnlock[OUT]:	unlock information
//
//			timeout[IN]:	response timeout value in milliseconds
//
// Return:	SWI_RCODE_OK indicates the modem has received the request 
//			successfully.  However, eResult must be evaluate to determine
//			if the operation actually succeeded.
//
//			See SWI_RCODE for additional error return codes
//
// Notes:	See SWI_TYPE_MpUnlockLevel for list of lock levels
//
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiSetMpUnlock(SWI_STRUCT_MpUnlock &sMpUnlock, U32 timeout);

///////////////////////////////////////////////////////////////////////////////
//
// Name:	SwiSetMpUnlockCfg
//
// Purpose:	This function is used to set MP unlock configuration
//			
// Parameters:
//
//			sMpUnlock[OUT]:	unlock configuration
//
//			timeout[IN]:	response timeout value in milliseconds
//
// Return:	SWI_RCODE_OK indicates the modem has received the request 
//			successfully.  However, eResult must be evaluate to determine
//			if the operation actually succeeded.
//
//			See SWI_RCODE for additional error return codes
//
// Notes:	The MP has to be unlocked before configuration can be modified.
//			A same or higher order level unlock is required to modify a
//			specified level of unlock code.
//
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiSetMpUnlockCfg(SWI_STRUCT_MpUnlock &sMpUnlock, U32 timeout);

///////////////////////////////////////////////////////////////////////////////
//
// Name:	SwiGetMpFeatures
//
// Purpose:	This function is used to determine available features of the MP
//			
// Parameters:
//
//			sMpFeatures[OUT]:	available MP features
//
//			timeout[IN]:		response timeout value in milliseconds
//
// Return:	See SWI_RCODE for error return codes
//
// Notes:	See description of SWI_STRUCT_MpFeatures for list of available
//			features.
//
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiGetMpFeatures(SWI_STRUCT_MpFeatures &sMpFeatures, U32 timeout);

///////////////////////////////////////////////////////////////////////////////
//
// Name:	SwiGetMpFeatureCfg
//
// Purpose:	This function is used retrieve current programmable MP feature settings
//			
// Parameters:
//
//			sMpFeatureCfg[OUT]:	MP feature configuration
//
//			timeout[IN]:		response timeout value in milliseconds
//
// Return:	See SWI_RCODE for error return codes
//
// Notes:	See description of SWI_STRUCT_MpFeatureCfg for list of 
//			configurable features.
//
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiGetMpFeatureCfg(SWI_STRUCT_MpFeatureCfg &sMpFeatureCfg, U32 timeout);

///////////////////////////////////////////////////////////////////////////////
//
// Name:	SwiSetMpFeatureCfg
//
// Purpose:	This function is used configure programmable MP features
//			
// Parameters:
//
//			sMpFeatureCfg[IN/OUT]:	MP feature configuration/result
//
//			timeout[IN]:		response timeout value in milliseconds
//
// Return:	SWI_RCODE_OK indicates the modem has received the request 
//			successfully.  However, eResult must be evaluate to determine
//			if the operation actually succeeded.
//
//			See SWI_RCODE for additional error return codes
//
// Notes:	See description of SWI_STRUCT_MpFeatureCfg for list of 
//			configurable features.
//
///////////////////////////////////////////////////////////////////////////////
SWI_API SWI_RCODE SwiSetMpFeatureCfg(SWI_STRUCT_MpFeatureCfg &sMpFeatureCfg, U32 timeout);

#ifdef __cplusplus
} //extern "C" {
#endif

#endif  //_SWI_MP_API_