///////////////////////////////////////////////////////////////////////////////
//                                                                             
//	$Revision: 3 $
//
//	Name       : SwiDefinesCm.h
//
//	Purpose    : Command defines and enumerations common to both CDMA and GSM	
//
//	Copyright (c) 2008 Sierra Wireless, Inc.  All rights reserved
//
///////////////////////////////////////////////////////////////////////////////
#ifndef __SWI_DEFINES_CM_H
#define __SWI_DEFINES_CM_H

///////////////////////////////////////////////////////////////////////////////
///
/// Defines the Software/Firmware Power States.
///
/// \sa SWI_STRUCT_Power
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_Power
{
    SWI_TYPE_PowerFull = 0,  /*!< radio is on */
    SWI_TYPE_PowerOffline,   /*!< modem is in offline state */
    SWI_TYPE_PowerReset,     /*!< modem is reset */
    SWI_TYPE_PowerOff,       /*!< power off (used to indicate NDIS shutdown */
    SWI_TYPE_PowerSystemOff, /*!< close SWI because modem in S3, S4 or S5 
								  state */
    SWI_TYPE_RFPowerOff,     /*!< turn radio off */
    SWI_TYPE_PowerEject,     /*!< modem ejected */
};

///////////////////////////////////////////////////////////////////////////////
///
/// Defines the roaming states returned by the modem.
///
/// \sa SWI_STRUCT_GSM_NetworkStatus 
/// \sa SwiGetRoamingState 
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_RoamingState
{
    SWI_ROAMING_Home,     /*!< not roaming */
    SWI_ROAMING_Roaming,  /*!< roaming */
    SWI_ROAMING_NonPref,  /*!< no roaming information */
    SWI_ROAMING_None      /*!< unknown roaming state */
};

///////////////////////////////////////////////////////////////////////////////
// SMS
///////////////////////////////////////////////////////////////////////////////

///////////////////////////////////////////////////////////////////////////////
///
/// This is the enumeration of SMS address types
///
/// \sa SWI_STRUCT_SMS_RetrieveHeader 
/// \sa SWI_STRUCT_SMS_StoreHeader
/// \sa SWI_STRUCT_SMS_Deliver
/// \sa SWI_STRUCT_SMS_StatusReport
///
///////////////////////////////////////////////////////////////////////////////
enum  SWI_TYPE_SMS_Address
{
    SWI_SMS_ADDRESS_Unknown,            /*!< unknown address type */				
    SWI_SMS_ADDRESS_International,      /*!< international address type */
    SWI_SMS_ADDRESS_National,	        /*!< national address type */
    SWI_SMS_ADDRESS_NetworkSpecific,    /*!< network specific address type */
    SWI_SMS_ADDRESS_Subscriber,	        /*!< subscriber address type */	
    SWI_SMS_ADDRESS_Alphanumeric,       /*!< alphanumeric address type */
    SWI_SMS_ADDRESS_Abbreviated         /*!< abbreviated address type */
};

///////////////////////////////////////////////////////////////////////////////
///
/// This is the enumeration of SMS address numbering types
///
/// \sa SWI_STRUCT_SMS_RetrieveHeader 
/// \sa SWI_STRUCT_SMS_StoreHeader
/// \sa SWI_STRUCT_SMS_Deliver
/// \sa SWI_STRUCT_SMS_StatusReport
///
///////////////////////////////////////////////////////////////////////////////
enum  SWI_TYPE_SMS_AddressNumbering
{
    SWI_SMS_ADDNUMBERING_Unknown,         /*!< unknown numbering type */ 
    SWI_SMS_ADDNUMBERING_ISDN,            /*!< telephone numbering plan */ 
    SWI_SMS_ADDNUMBERING_DataNumbering,   /*!< X.121 numbering plan */
    SWI_SMS_ADDNUMBERING_Telex,           /*!< Telex numbering plan */ 
    SWI_SMS_ADDNUMBERING_TelexPrivate,    /*!< private Telex numbering plan */
    SWI_SMS_ADDNUMBERING_ERMES,           /*!< ERMES numbering plan */
    SWI_SMS_ADDNUMBERING_Abbreviated      /*!< abbreviated numbering plan */
};

///////////////////////////////////////////////////////////////////////////////
///
/// This is the enumeration of SMS protocol types
///
/// \sa SWI_STRUCT_SMS_RetrieveHeader 
/// \sa SWI_STRUCT_SMS_Deliver 
/// \sa SWI_STRUCT_SMS_StoreHeader 
///
///////////////////////////////////////////////////////////////////////////////
enum  SWI_TYPE_SMS_Protocol
{
    SWI_SMS_PROTOCOL_AppLayer = 0x00,	/*!< application layer protocol */ 
    SWI_SMS_PROTOCOL_Telematic = 0x20,  /*!< telematic interworking protocol 
											 (default) */
    SWI_SMS_PROTOCOL_SMFunctions = 0x40,/*!< SM functions */
    SWI_SMS_PROTOCOL_MEFunctions = 0x60,/*!< ME functions */
    SWI_SMS_PROTOCOL_SCSpecific = 0xC0,	/*!< SC specifics */
    SWI_SMS_PROTOCOL_RawData = 0xC1,	/*!< RAW data */
};

///////////////////////////////////////////////////////////////////////////////
///
/// This is the enumeration of SMS protocol id types
///
/// \sa SWI_STRUCT_SMS_RetrieveHeader 
/// \sa SWI_STRUCT_SMS_Deliver 
/// \sa SWI_STRUCT_SMS_StoreHeader 
///
///////////////////////////////////////////////////////////////////////////////
enum  SWI_TYPE_SMS_ProtocolId
{
    SWI_SMS_PROTOCOLID_Implicit,		/*!< device type is specific to SC */
    SWI_SMS_PROTOCOLID_Telex,			/*!< telex protocol */ 
    SWI_SMS_PROTOCOLID_Group3Fax,		/*!< group 3 FAX */ 
    SWI_SMS_PROTOCOLID_Group4Fax,		/*!< group 4 FAX */ 
    SWI_SMS_PROTOCOLID_Voice,			/*!< voice */
    SWI_SMS_PROTOCOLID_ERMES,			/*!< ERMES */
    SWI_SMS_PROTOCOLID_NationalPagingSystem, /*!< national paging system */
    SWI_SMS_PROTOCOLID_Videotex,		/*!< VideoTex (T.100 /T.101) */
    SWI_SMS_PROTOCOLID_TelexUnsecified,	/*!< teletex, carrier unspecified */ 
    SWI_SMS_PROTOCOLID_TelexPSPDN,		/*!< teletex, in PSPDN */
    SWI_SMS_PROTOCOLID_TelexCSPDN,		/*!< teletex, in CSPDN */
    SWI_SMS_PROTOCOLID_TelexAnalogPSTN,	/*!< teletex, in analog PSTN */ 
    SWI_SMS_PROTOCOLID_TelexDigitalPSTN,	/*!< teletex, in digital PSTN */ 
    SWI_SMS_PROTOCOLID_UCI,				/*!< universal computer interface */
    SWI_SMS_PROTOCOLID_MessageHandling,	/*!< message handling facility */ 
    SWI_SMS_PROTOCOLID_AnyPublicX400,	/*!< any public X.400 based message */
    SWI_SMS_PROTOCOLID_InternalMail,	/*!< internal mail */
    SWI_SMS_PROTOCOLID_Value1SC,		/*!< value #1 specific to the SC */ 
    SWI_SMS_PROTOCOLID_Value2SC,		/*!< value #2 specific to the SC */  
    SWI_SMS_PROTOCOLID_Value3SC,		/*!< value #3 specific to the SC */ 
    SWI_SMS_PROTOCOLID_Value4SC,		/*!< value #4 specific to the SC */ 
    SWI_SMS_PROTOCOLID_Value5SC,		/*!< value #5 specific to the SC */ 
    SWI_SMS_PROTOCOLID_Value6SC,		/*!< value #6 specific to the SC */ 
    SWI_SMS_PROTOCOLID_Value7SC,		/*!< value #7 specific to the SC */ 
    SWI_SMS_PROTOCOLID_GSMMobil			/*!< GSM mobile station */ 
};

///////////////////////////////////////////////////////////////////////////////
///
/// This is the enumeration of SMS coding schemes
///
/// \sa SWI_STRUCT_SMS_RetrieveHeader 
/// \sa SWI_STRUCT_SMS_Deliver 
/// \sa SWI_STRUCT_SMS_StoreHeader 
///
///////////////////////////////////////////////////////////////////////////////
enum  SWI_TYPE_SMS_CodingScheme
{
    SWI_SMS_CODINGSCHEME_Default,    /*!< 7 bit coding (default) */ 
    SWI_SMS_CODINGSCHEME_8bit,       /*!< 8 bit coding */  
    SWI_SMS_CODINGSCHEME_UCS2,       /*!< USC2 coding */ 
    SWI_SMS_CODINGSCHEME_Unknown     /*!< unknown coding */
};

///////////////////////////////////////////////////////////////////////////////
///
/// This is the enumeration of SMS coding class. 
///
/// \sa SWI_STRUCT_SMS_RetrieveHeader 
/// \sa SWI_STRUCT_SMS_Deliver 
/// \sa SWI_STRUCT_SMS_StoreHeader 
///
///////////////////////////////////////////////////////////////////////////////
enum  SWI_TYPE_SMS_CodingClass
{
    SWI_SMS_CODINGCLASS_Class0,   /*!< class 0 DCS class */
    SWI_SMS_CODINGCLASS_Class1,   /*!< class 1 DCS class */
    SWI_SMS_CODINGCLASS_Class2,   /*!< class 2 DCS class */
    SWI_SMS_CODINGCLASS_Class3,   /*!< class 3 DCS class */
    SWI_SMS_CODINGCLASS_NotGiven  /*!< default class */
};

///////////////////////////////////////////////////////////////////////////////
///
/// This is the enumeration of SMS coding compression. 
///
/// \sa SWI_STRUCT_SMS_RetrieveHeader 
/// \sa SWI_STRUCT_SMS_Deliver 
/// \sa SWI_STRUCT_SMS_StoreHeader 
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_SMS_CodingCompression 
{
    SWI_SMSCOMPRESSION_Uncompressed,    /*!< SMS text is uncompressed */
    SWI_SMSCOMPRESSION_Compressed       /*!< SMS text is compressed */
};

///////////////////////////////////////////////////////////////////////////////
///
/// This is the enumeration of SMS routing.
///
/// \sa SWI_STRUCT_GSM_SMS_Status 
/// \sa SWI_STRUCT_SMS_Param
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_SMS_Routing
{
    SWI_SMSROUTE_Gprs,          /*!< GPRS */ 
    SWI_SMSROUTE_Csn,           /*!< circuit switched */
    SWI_SMSROUTE_GprsPreferred, /*!< GPRS preferred */
    SWI_SMSROUTE_CsnPreferred   /*!< circuit switched preferred */
};

#endif // __SWI_DEFINES_CM_H