//////////////////////////////////////////////////////////////////////////////////
//                                                                              //
//	$Revision: 4 $																//
//																				//
//	Name       : SwiStructs.h													//
//                                                                              //
//	Purpose    : SWI CDMA 1xRtt specific enumerated types and structures				//
//					                                                            //
//	Copyright (c) 2003 Sierra Wireless, Inc.  All rights reserved			    //
//                                                                              //
//////////////////////////////////////////////////////////////////////////////////
#ifndef __SWI_STRUCTS_CDMA_H
#define __SWI_STRUCTS_CDMA_H

#include "SwiDataTypes.h"
#include "SwiStructsMp.h"
#include "SwiDefinesCm.h"

#define LENGTH_CallNumber				32		// Maximum Caller ID length
#define LENGTH_CallExtendedNumber		64		// Maximum Extended Caller ID length

#define MAX_SMSI_CALL_BACK				32		// Maximum SMS callback length
#define MAX_SMSI_TL_ADDRESS				50		// Maximum SMS address length

#define LENGTH_SectorId           16
#define LENGTH_WAPUri             128
#define LENGTH_HdrUati            16

// constants
#define LENGTH_MaxPPPString					33
#define LENGTH_DebugFormatString			40
#define LENGTH_DebugFileName				13
#define	SWI_PORT_NAME_SIZE					16	// length of COM port name
#define	SWI_FRIENDLY_NAME_SIZE				256	// maximum length of the instance ID 
// string for devices and ports
#define SWI_INSTANCE_ID_SIZE				256 // maximum length of the instance ID 
// string for devices and ports
#define SWI_SUFFIX_ID_SIZE					16	// maximum length for unique device and port prefixes


#define _CDMA_SWI_STRUCT_SMS_Status			SWI_STRUCT_SMS_Status
#define _CDMA_SWI_STRUCT_SMS_RetrieveSms	SWI_STRUCT_SMS_RetrieveSms
#define _CDMA_SWI_STRUCT_SMS_SendStatus		SWI_STRUCT_SMS_SendStatus
#define _CDMA_SWI_STRUCT_SMS_StoreSms		SWI_STRUCT_SMS_StoreSms
#define _CDMA_SWI_TYPE_CallType				SWI_TYPE_CallType
#define _CDMA_SWI_TYPE_CallState			SWI_TYPE_CallState
#define _CDMA_SWI_TYPE_CallError			SWI_TYPE_CallError
#define _CDMA_SWI_TYPE_Notify				SWI_TYPE_Notify
#define _CDMA_SwiNotifyVariant				SwiNotifyVariant
#define _CDMA_SWI_NOTIFY_HeartBeat			SWI_NOTIFY_HeartBeat
#define _CDMA_SWI_NOTIFY_Rssi				SWI_NOTIFY_Rssi
#define _CDMA_SWI_NOTIFY_SmsStatus			SWI_NOTIFY_SmsStatus
#define _CDMA_SWI_NOTIFY_SmsSendStatus		SWI_NOTIFY_SmsSendStatus
#define _CDMA_SWI_NOTIFY_HeadsetState		SWI_NOTIFY_HeadsetState
#define _CDMA_SWI_NOTIFY_Band				SWI_NOTIFY_Band
#define _CDMA_SWI_NOTIFY_TransmitAlert		SWI_NOTIFY_TransmitAlert
#define _CDMA_SWI_NOTIFY_Reset				SWI_NOTIFY_Reset
#define _CDMA_SWI_NOTIFY_Power				SWI_NOTIFY_Power
#define _CDMA_SWI_NOTIFY_Dhcp				SWI_NOTIFY_Dhcp
#define _CDMA_SWI_NOTIFY_PPP				SWI_NOTIFY_PPP
#define _CDMA_SWI_NOTIFY_Debug				SWI_NOTIFY_Debug
#define _CDMA_SWI_NOTIFY_Gps				SWI_NOTIFY_Gps
#define _CDMA_SWI_NOTIFY_ExtDio				SWI_NOTIFY_ExtDio
#define _CDMA_SWI_NOTIFY_ExtAi				SWI_NOTIFY_ExtAi
#define _CDMA_SWI_NOTIFY_GpsCommand			SWI_NOTIFY_GpsCommand
#define _CDMA_SWI_NOTIFY_MpByteCount		SWI_NOTIFY_MpByteCount
#define _CDMA_SWI_NOTIFY_MPIgnSense			SWI_NOTIFY_MPIgnSense
#define _CDMA_SWI_NOTIFY_RfDownload			SWI_NOTIFY_RfDownload
#define _CDMA_SWI_NOTIFY_SimSled			SWI_NOTIFY_SimSled
#define _CDMA_SWI_NOTIFY_BatteryStatus		SWI_NOTIFY_BatteryStatus
#define _CDMA_SWI_NOTIFY_MpShutdown			SWI_NOTIFY_MpShutdown
#define _CDMA_SWI_NOTIFY_MpConnect			SWI_NOTIFY_MpConnect
#define _CDMA_SWI_NOTIFY_MpStartupDiag		SWI_NOTIFY_MpStartupDiag
#define _CDMA_SWI_NOTIFY_MpDisconnect		SWI_NOTIFY_MpDisconnect
#define _CDMA_SWI_NOTIFY_END_MP				SWI_NOTIFY_END_MP
#define _CDMA_SWI_NOTIFY_AirServerChange	SWI_NOTIFY_AirServerChange
#define _CDMA_SWI_NOTIFY_LockServ			SWI_NOTIFY_LockServ
#define _CDMA_SWI_NOTIFY_END_NOTIFY			SWI_NOTIFY_END_NOTIFY
#define _CDMA_SWI_STRUCT_NotifList			SWI_STRUCT_NotifList

#define _CDMA_SWI_CALLBACK_EX				SWI_CALLBACK_EX

//////////////////////////////////////////////////////////////////////////////////
//
// Account management
// The activation account information for CDMA is
// stored in data structures. Multiple NAM account
// profiles are supported.
// The structures and data types following relate to
// managing accounts.
//
//////////////////////////////////////////////////////////////////////////////////

#pragma pack(push,1)

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_STRUCT_SidNid - SID/NID pair structure
//
// Purpose:     This structure is used as a member of 
//				SWI_STRUCT_HomeSidNid.
//
// Members:  	Sid				- SID value
//				Nid				- NID value
//
// Notes:	    None.
//
//////////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_SidNid
{
	U16 Sid;
	U16 Nid;
};

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_STRUCT_HomeSidNid - Home SID/NID pairs structure
//
// Purpose:     This structure is used to report (SwiPstGetHomeSidNid) or set
//              (SwiPstSetHomeSidNid) the home (non-roaming)
//              SID / NID table for an account profile.
//
// Members:  	SidNid				- SID NID pair array.  See
//									  SWI_STRUCT_SidNid for details
//
// Notes:	    The table supports twenty entries.
//
//////////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_HomeSidNid
{
	SWI_STRUCT_SidNid SidNid[20];
};

#pragma pack(pop)

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_TYPE_Commit_ErrorMask - Activation Commit error mask enumeration
//
// Purpose:     This identifies the possible bits in the
//				failure mask field returned by SwiPstLock
//
// Memnbers:	SWI_COMMIT_ERRMASK_NONE			- No error
//              SWI_COMMIT_ERRMASK_MDN			- MDN not set
//              SWI_COMMIT_ERRMASK_IMSI			- IMSI not set
//              SWI_COMMIT_ERRMASK_USERIDPW		- No User ID/Password
//              SWI_COMMIT_ERRMASK_DATE			- No Provisioning Date
//              SWI_COMMIT_ERRMASK_NAMORDER		- NAM profile index out of sequence
//												  (NAM 0 must always be provisioned
//												   first)
//
// Notes:	    None
//
//////////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_Commit_ErrorMask
{
	SWI_COMMIT_ERRMASK_NONE			= 0x00000000,
	SWI_COMMIT_ERRMASK_MDN			= 0x00000001,
	SWI_COMMIT_ERRMASK_IMSI			= 0x00000002,
	SWI_COMMIT_ERRMASK_USERIDPW		= 0x00000004,
	SWI_COMMIT_ERRMASK_DATE			= 0x00000008,
	SWI_COMMIT_ERRMASK_NAMORDER		= 0x00000010,
};

//////////////////////////////////////////////////////////////////////////////////
//
// SMS Messaging
//
// CDMA2000 1X modems can send and receive
// SMS messages. To handle SMS messages, there
// are many data types and structures involved.
// Most of these relate to header content. The
// details of the parameters in the SMS header are
// defined in the CDMA specification and are
// beyond the scope of this manual.
//
// Consult the documentation for a discussion of the SMS message handling process.
//
//////////////////////////////////////////////////////////////////////////////////

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_TYPE_SMS_ParamMask - SMS Parameter Mask enumeration
//
// Purpose:     This identifies the meanings of the bits in the
//				SWI_STRUCT_SMS_CdmaHeader parameter mask of available fields.
//
// Memnbers:	SWI_SMS_PARAMASK_NO_PARAMS		- No parameters set
//				SWI_SMS_PARAMASK_BEARER_REPLY	- Bearer Reply (TL Ack.)
//				SWI_SMS_PARAMASK_VALID_ABS		- Absolute Validity Time
//				SWI_SMS_PARAMASK_VALID_REL	   	- Relative Validity Time
//				SWI_SMS_PARAMASK_DEFER_ABS	   	- Absolute Delivery Deferral Time
//				SWI_SMS_PARAMASK_DEFER_REL	   	- Relative Delivery Deferral Time
//				SWI_SMS_PARAMASK_USER_RESP	   	- User Response	
//				SWI_SMS_PARAMASK_ADDRESS	   	- Address
//				SWI_SMS_PARAMASK_SUBADDR	   	- Sub Address
//				SWI_SMS_PARAMASK_USER_DATA	   	- Data Encoding
//				SWI_SMS_PARAMASK_PRIORITY	   	- Priority
//				SWI_SMS_PARAMASK_PRIVACY	   	- Privacy
//				SWI_SMS_PARAMASK_REPLY_OPT	   	- Reply Option (DAK & User Ack)
//				SWI_SMS_PARAMASK_NUM_OF_MSG	   	- Number of Messages
//				SWI_SMS_PARAMASK_ALERT		   	- Delivery Alert
//				SWI_SMS_PARAMASK_LANGUAGE	   	- Language
//				SWI_SMS_PARAMASK_CALL_BACK	   	- Call Back Number 
//				SWI_SMS_PARAMASK_MC_TIME_STAMP 	- Time Stamp 
//				SWI_SMS_PARAMASK_DISP_MODE	   	- Display Mode
//
// Notes:	    None
//
//////////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_SMS_ParamMask
{
	SWI_SMS_PARAMASK_NO_PARAMS,
	SWI_SMS_PARAMASK_BEARER_REPLY,
	SWI_SMS_PARAMASK_VALID_ABS,
	SWI_SMS_PARAMASK_VALID_REL		= 0x00000004,
	SWI_SMS_PARAMASK_DEFER_ABS		= 0x00000008,
	SWI_SMS_PARAMASK_DEFER_REL		= 0x00000010,
	SWI_SMS_PARAMASK_USER_RESP		= 0x00000020,
	SWI_SMS_PARAMASK_ADDRESS		= 0x00000040,
	SWI_SMS_PARAMASK_SUBADDR		= 0x00000080,
	SWI_SMS_PARAMASK_USER_DATA		= 0x00000100,
	SWI_SMS_PARAMASK_PRIORITY		= 0x00000200,
	SWI_SMS_PARAMASK_PRIVACY		= 0x00000400,
	SWI_SMS_PARAMASK_REPLY_OPT		= 0x00000800,
	SWI_SMS_PARAMASK_NUM_OF_MSG		= 0x00001000,
	SWI_SMS_PARAMASK_ALERT			= 0x00002000,
	SWI_SMS_PARAMASK_LANGUAGE		= 0x00004000,
	SWI_SMS_PARAMASK_CALL_BACK		= 0x00008000,
	SWI_SMS_PARAMASK_MC_TIME_STAMP	= 0x00010000,
	SWI_SMS_PARAMASK_DISP_MODE		= 0x00020000
};

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_TYPE_SMS_MsgCategory - SMS Message Category enumeration
//
// Purpose:     Defines the SMS category
//
// Members:  	SWI_SMS_MSGCAT_POINT_TO_POINT	- IS-637 SMS Point-to-Point Message 
//				SWI_SMS_MSGCAT_BROADCAST_MSG	- IS-637 SMS Broadcast Message  
//				SWI_SMS_MSGCAT_ACK_MSG			- IS-637 SMS Acknowledge Message
//
// Notes:	    None
//
//////////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_SMS_MsgCategory
{
	SWI_SMS_MSGCAT_POINT_TO_POINT,
	SWI_SMS_MSGCAT_BROADCAST_MSG, 
	SWI_SMS_MSGCAT_ACK_MSG		  
};

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_TYPE_SMS_Teleservice - SMS Message Teleservice Type enumeration
//
// Purpose:     Defines the SMS teleservice type.  
//				Refer to TIA/EIA-41-D Table 175 for further information.
//
// Members:  	SWI_SMS_TELESRV_CELL_PAGING		- SMSI_CPT_95: IS-95A Cellular Paging
//				SWI_SMS_TELESRV_CELL_MESSAGING	- SMSI_CMT_95: IS-95A Cellular Messaging
//				SWI_SMS_TELESRV_VOICE_MAIL_NOT	- SMSI_VMN_95: IS-95A Voice Mail Notification
//				SWI_SMS_TELESRV_CLI_ORDER		- SMSI_CMT_91_CLI: IS-91 Extended Protocol - CLI Order
//				SWI_SMS_TELESRV_VOICE_IND		- SMSI_CMT_91_VOICE_MAIL: IS-91 Extended Protocol -
//												  Voice Mail and Embedded Message Waiting Indicator 
//				SWI_SMS_TELESRV_SHORT_MSG		- SMSI_CMT_91_SHORT_MSG: IS-91 Extended Protocol - Short Message
//				SWI_SMS_TELESRV_ALERT_INFO		- SMSI_AWI_95: IS-95A Alert With Info
//				SWI_SMS_TELESRV_WAP				- SMSI_WAP:  WAP Message
//					  
// Notes:	    Refer to TIA/EIA-41-D Table 175 for further info
//
//////////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_SMS_Teleservice
{
	SWI_SMS_TELESRV_CELL_PAGING,
	SWI_SMS_TELESRV_CELL_MESSAGING,
	SWI_SMS_TELESRV_VOICE_MAIL_NOT,
	SWI_SMS_TELESRV_CLI_ORDER,
	SWI_SMS_TELESRV_VOICE_IND,
	SWI_SMS_TELESRV_SHORT_MSG,
	SWI_SMS_TELESRV_ALERT_INFO,
	SWI_SMS_TELESRV_WAP
};

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_TYPE_SMS_MsgIdType - SMS Message ID Type enumeration
//
// Purpose:     Defines the SMS Message ID Type
//
// Members:  	SWI_SMS_MSGIDTYPE_NOTUSED		- NOT USED
//				SWI_SMS_MSGIDTYPE_DELIVER		- Deliver (Regular MT SMS)
//				SWI_SMS_MSGIDTYPE_SUBMIT		- Submit (Regular MO SMS)
//				SWI_SMS_MSGIDTYPE_CANCEL		- Cancellation (MO Only.  
//												  Cancel previous SMS delivery)
//				SWI_SMS_MSGIDTYPE_DELIVERY_ACK	- Delivery Ack.  (MT Only)
//				SWI_SMS_MSGIDTYPE_USER_ACK		- User Acknowledgement (Either Directions)
//
// Notes:	    None
//
//////////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_SMS_MsgIdType
{
	SWI_SMS_MSGIDTYPE_NOTUSED,
	SWI_SMS_MSGIDTYPE_DELIVER,
	SWI_SMS_MSGIDTYPE_SUBMIT,
	SWI_SMS_MSGIDTYPE_CANCEL,
	SWI_SMS_MSGIDTYPE_DELIVERY_ACK,
	SWI_SMS_MSGIDTYPE_USER_ACK
};

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_TYPE_SMS_Priority - SMS Message Priority enumeration
//
// Purpose:     Defines the priority of the SMS Message.
//				
// Members:  	SWI_SMS_PRIORITY_NORMAL			- Normal	
// 				SWI_SMS_PRIORITY_INTERACTIVE	- Interactive	
//				SWI_SMS_PRIORITY_URGENT			- Urgent	
// 				SWI_SMS_PRIORITY_EMERGENCY		- Emergency
//
// Notes:	    None.
//
//////////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_SMS_Priority
{
	SWI_SMS_PRIORITY_NORMAL,
	SWI_SMS_PRIORITY_INTERACTIVE,
	SWI_SMS_PRIORITY_URGENT,
	SWI_SMS_PRIORITY_EMERGENCY
};

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_TYPE_SMS_Privacy - SMS Message Privacy enumeration
//
// Purpose:     Defines the privacy level of the SMS message
//
// Parameters: 	SWI_SMS_PRIVACY_NOT_RESTR		- Not restricted (Level 0)	
//				SWI_SMS_PRIVACY_RESTRICTED		- Restricted (Level 1)	
//				SWI_SMS_PRIVACY_CONFIDENTIAL	- Confidential (Level 2) 	
//				SWI_SMS_PRIVACY_SECRET			- Secret (Level 3)
//
// Notes:	    None
//
//////////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_SMS_Privacy
{
	SWI_SMS_PRIVACY_NOT_RESTR,
	SWI_SMS_PRIVACY_RESTRICTED,
	SWI_SMS_PRIVACY_CONFIDENTIAL,
	SWI_SMS_PRIVACY_SECRET
};

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_TYPE_SMS_Language - SMS Language type enumeration
//
// Purpose:     Defines the language used in the message body
//
// Members:  	SWI_SMS_LANGUAGE_UNSPECIFIED	- UNSPECIFIED	
//				SWI_SMS_LANGUAGE_ENGLISH		- ENGLISH	
//				SWI_SMS_LANGUAGE_FRENCH			- FRENCH	
//				SWI_SMS_LANGUAGE_SPANISH		- SPANISH	
//				SWI_SMS_LANGUAGE_JAPANESE		- JAPANESE	
//				SWI_SMS_LANGUAGE_KOREAN			- KOREAN	
//				SWI_SMS_LANGUAGE_CHINESE		- CHINESE	
//				SWI_SMS_LANGUAGE_HEBREW			- HEBREW
//
// Notes:	    None.
//
//////////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_SMS_Language
{
	SWI_SMS_LANGUAGE_UNSPECIFIED,
	SWI_SMS_LANGUAGE_ENGLISH,
	SWI_SMS_LANGUAGE_FRENCH,
	SWI_SMS_LANGUAGE_SPANISH,
	SWI_SMS_LANGUAGE_JAPANESE,
	SWI_SMS_LANGUAGE_KOREAN,
	SWI_SMS_LANGUAGE_CHINESE,
	SWI_SMS_LANGUAGE_HEBREW
};

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_TYPE_SMS_MsgDispMode - SMS Message Display Mode enumeration
//
// Purpose:     Specifies how the SMS message should be displayed
//
// Members:  	SWI_SMS_MSGDISPMODE_IMMEDIATE		- Immediate Display
//				SWI_SMS_MSGDISPMODE_DEFAULT			- Radio default setting
// 				SWI_SMS_MSGDISPMODE_USER_INVOKE		- User Invoke
//
// Notes:	    None
//
//////////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_SMS_MsgDispMode
{
	SWI_SMS_MSGDISPMODE_IMMEDIATE,
	SWI_SMS_MSGDISPMODE_DEFAULT,
	SWI_SMS_MSGDISPMODE_USER_INVOKE
};

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_TYPE_SMS_DataEncodeType - SMS Data Encoding enumeration
//
// Purpose:     This enumeration identifies the possible data encoding methods
//				used on the SMS message body.  
//
// Members: 	SWI_SMS_DATAENCODE_8bitAscii 	    - Octet, unspecified (i.e. Binary)
//	          SWI_SMS_DATAENCODE_IS91EP         -  varies
//	          SWI_SMS_DATAENCODE_7bitAscii      - Standard ascii, 7-bit 
//	          SWI_SMS_DATAENCODE_IA5            - 7-bit  encoding (  International Alphabet No. 5 same as ASCII )
//	          SWI_SMS_DATAENCODE_Unicode	      - Unicode
//	          SWI_SMS_DATAENCODE_Shift_Jis      -    /* 8 or 16-bit */ It's also known as SJIS or MS Kanji for Japanese support
//	          SWI_SMS_DATAENCODE_Korean         -    /* 8 or 16-bit */ Korean support
//	          SWI_SMS_DATAENCODE_LatinHebrew     -   /* 8 */ specific to the Hebrew script ISO-8859-8 and Windows-1255  
//	          SWI_SMS_DATAENCODE_Latin     		  	- Latin	      
//	          SWI_SMS_DATAENCODE_GSM7BitDefault   - /* 7-bit */ defined in ETSI GSM 03.38.
//            SWI_SMS_DATAENCODE_MAX32

//
// Notes:	    For a more complete list, see SMS standard TSB-58C.
//
//////////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_SMS_DataEncodeType
{
	SWI_SMS_DATAENCODE_8bitAscii = 0,	
	SWI_SMS_DATAENCODE_IS91EP,    
	SWI_SMS_DATAENCODE_7bitAscii,
	SWI_SMS_DATAENCODE_IA5,
	SWI_SMS_DATAENCODE_Unicode,
	SWI_SMS_DATAENCODE_Shift_Jis,
	SWI_SMS_DATAENCODE_Korean,
	SWI_SMS_DATAENCODE_LatinHebrew,    
	SWI_SMS_DATAENCODE_Latin, 		      
	SWI_SMS_DATAENCODE_GSM7BitDefault,
  SWI_SMS_DATAENCODE_MAX32 = 0x10000000
};

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_TYPE_SMS_ErrorClass - SMS Send Error Class enumeration
//
// Purpose:     This enumeration identifies the possible Error Class values
//				that may be returned with the notification SWI_NOTIFY_SmsSendStatus
//
// Members: 	SWI_SMS_ERRORCLASS_NoError	- No Error 
//				SWI_SMS_ERRORCLASS_Reserved	- Reserved (Ignore)
//				SWI_SMS_ERRORCLASS_Temporary
//											- Temporary.  A retry is recommended.
//				SWI_SMS_ERRORCLASS_Permanent
//											- Permanent.  A retry is not recommened.
//
// Notes:	    None
//
//////////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_SMS_ErrorClass
{
	SWI_SMS_ERRORCLASS_NoError,
	SWI_SMS_ERRORCLASS_Reserved,
	SWI_SMS_ERRORCLASS_Temporary,
	SWI_SMS_ERRORCLASS_Permanent
};

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_TYPE_SMS_CauseCode - SMS Send Cause Code enumeration
//
// Purpose:     This enumeration identifies the possible Cause Code values
//				that may be returned with the notification SWI_NOTIFY_SmsSendStatus
//
// Members: 	( Network problems )
//				SWI_SMS_CAUSECODE_AddressVacant 					
//				SWI_SMS_CAUSECODE_AddressTranslationFailure
//				SWI_SMS_CAUSECODE_NetworkResourceShortage
//				SWI_SMS_CAUSECODE_NetworkFailure
//				SWI_SMS_CAUSECODE_InvalidTeleserviceId
//				SWI_SMS_CAUSECODE_OtherNetworkProblem
//				SWI_SMS_CAUSECODE_OtherNetworkProblemMoreFirst		
//				SWI_SMS_CAUSECODE_OtherNetworkProblemMoreLast		
//				
//				( Terminal Problems )
//				SWI_SMS_CAUSECODE_NoPageResponse 					
//				SWI_SMS_CAUSECODE_DestinationBusy
//				SWI_SMS_CAUSECODE_NoAck
//				SWI_SMS_CAUSECODE_DestinationResourceShortage
//				SWI_SMS_CAUSECODE_SmsDeliveryPostponed
//				SWI_SMS_CAUSECODE_DestinationOutOfService
//				SWI_SMS_CAUSECODE_DestinationNoLongerAtThisAddress
//				SWI_SMS_CAUSECODE_OtherTerminalProblem
//				SWI_SMS_CAUSECODE_OtherTerminalProblemMoreFirst		
//				SWI_SMS_CAUSECODE_OtherTerminalProblemMoreLast		
//				SWI_SMS_CAUSECODE_SmsDeliveryPostponedMoreFirst		
//				SWI_SMS_CAUSECODE_SmsDeliveryPostponedMoreLast		
//				
//				( Radio Interface Problems )
//				SWI_SMS_CAUSECODE_Radio_If_Resource_Shortage		
//				SWI_SMS_CAUSECODE_RadioIfIncompatible
//				SWI_SMS_CAUSECODE_OtherRadioIfProblem
//				SWI_SMS_CAUSECODE_OtherRadioIfProblemMoreFirst		
//				SWI_SMS_CAUSECODE_OtherRadioIfProblemMoreLast		
//
//				( General Problems )
//				SWI_SMS_CAUSECODE_UnexpectedParmSize				
//				SWI_SMS_CAUSECODE_SmsOriginationDenied
//				SWI_SMS_CAUSECODE_SmsTerminationDenied
//				SWI_SMS_CAUSECODE_SupplServiceNotSupported
//				SWI_SMS_CAUSECODE_SmsNotSupported
//				SWI_SMS_CAUSECODE_Reserved101
//				SWI_SMS_CAUSECODE_MissingExpectedParm
//				SWI_SMS_CAUSECODE_MissingMandatoryParm
//				SWI_SMS_CAUSECODE_UnrecognizedParmValue
//				SWI_SMS_CAUSECODE_UnexpectedParmValue
//				SWI_SMS_CAUSECODE_UserDataSizeError
//				SWI_SMS_CAUSECODE_OtherGeneralProblems
//				SWI_SMS_CAUSECODE_OtherGeneralProblemsMoreFirst		
//				SWI_SMS_CAUSECODE_OtherGeneralProblemsMoreLast		
//				
//				( Internal SMS Cause Code (From the Mobile Station) )
//				SWI_SMS_CAUSECODE_DtcCallDisconnect  				
//				SWI_SMS_CAUSECODE_DtcCallError						
//				SWI_SMS_CAUSECODE_Ok								
//				SWI_SMS_CAUSECODE_WaitingForTlAck
//				SWI_SMS_CAUSECODE_OutOfResources
//				SWI_SMS_CAUSECODE_AccesTooLarge
//				SWI_SMS_CAUSECODE_DtcTooLarge
//				SWI_SMS_CAUSECODE_NetworkNotReady
//				SWI_SMS_CAUSECODE_PhoneNotReady
//				SWI_SMS_CAUSECODE_NotAllowedInAmps
//				SWI_SMS_CAUSECODE_CannotSendBroadcast
//				SWI_SMS_CAUSECODE_InvalidTransactionID
//				SWI_SMS_CAUSECODE_MsgNotSent
//				SWI_SMS_CAUSECODE_MsgBeingSent
//
// Notes:	    For detailed explanation of each of the codes, please refer to
//				the IS-41 SMS Standard.
//
//////////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_SMS_CauseCode
{
	// Network problems
	SWI_SMS_CAUSECODE_AddressVacant 					= 0x00,
	SWI_SMS_CAUSECODE_AddressTranslationFailure,
	SWI_SMS_CAUSECODE_NetworkResourceShortage,
	SWI_SMS_CAUSECODE_NetworkFailure,
	SWI_SMS_CAUSECODE_InvalidTeleserviceId,
	SWI_SMS_CAUSECODE_OtherNetworkProblem,
	SWI_SMS_CAUSECODE_OtherNetworkProblemMoreFirst		= 0x06,
	SWI_SMS_CAUSECODE_OtherNetworkProblemMoreLast		= 0x1F,

	// Terminal Problems
	SWI_SMS_CAUSECODE_NoPageResponse 					= 0x20,
	SWI_SMS_CAUSECODE_DestinationBusy,
	SWI_SMS_CAUSECODE_NoAck,
	SWI_SMS_CAUSECODE_DestinationResourceShortage,
	SWI_SMS_CAUSECODE_SmsDeliveryPostponed,
	SWI_SMS_CAUSECODE_DestinationOutOfService,
	SWI_SMS_CAUSECODE_DestinationNoLongerAtThisAddress,
	SWI_SMS_CAUSECODE_OtherTerminalProblem,
	SWI_SMS_CAUSECODE_OtherTerminalProblemMoreFirst		= 0x28,
	SWI_SMS_CAUSECODE_OtherTerminalProblemMoreLast		= 0x2F,
	SWI_SMS_CAUSECODE_SmsDeliveryPostponedMoreFirst		= 0x30,
	SWI_SMS_CAUSECODE_SmsDeliveryPostponedMoreLast		= 0x3F,

	// Radio Interface Problems
	SWI_SMS_CAUSECODE_Radio_If_Resource_Shortage		= 0x40,
	SWI_SMS_CAUSECODE_RadioIfIncompatible,
	SWI_SMS_CAUSECODE_OtherRadioIfProblem,
	SWI_SMS_CAUSECODE_OtherRadioIfProblemMoreFirst		= 0x43,
	SWI_SMS_CAUSECODE_OtherRadioIfProblemMoreLast		= 0x5F, 

	// General Problems
	SWI_SMS_CAUSECODE_UnexpectedParmSize				= 0x60,
	SWI_SMS_CAUSECODE_SmsOriginationDenied,
	SWI_SMS_CAUSECODE_SmsTerminationDenied,
	SWI_SMS_CAUSECODE_SupplServiceNotSupported,
	SWI_SMS_CAUSECODE_SmsNotSupported,
	SWI_SMS_CAUSECODE_Reserved101,
	SWI_SMS_CAUSECODE_MissingExpectedParm,
	SWI_SMS_CAUSECODE_MissingMandatoryParm,
	SWI_SMS_CAUSECODE_UnrecognizedParmValue,
	SWI_SMS_CAUSECODE_UnexpectedParmValue,
	SWI_SMS_CAUSECODE_UserDataSizeError,
	SWI_SMS_CAUSECODE_OtherGeneralProblems,
	SWI_SMS_CAUSECODE_OtherGeneralProblemsMoreFirst		= 0x6C,
	SWI_SMS_CAUSECODE_OtherGeneralProblemsMoreLast		= 0xFF,

	// Internal SMS Cause Code (From the Mobile Station)
	SWI_SMS_CAUSECODE_DtcCallDisconnect  				= 0x4000,
	SWI_SMS_CAUSECODE_DtcCallError						= 0x4001, 
	SWI_SMS_CAUSECODE_Ok								= 0x8000,
	SWI_SMS_CAUSECODE_WaitingForTlAck,
	SWI_SMS_CAUSECODE_OutOfResources,
	SWI_SMS_CAUSECODE_AccesTooLarge,
	SWI_SMS_CAUSECODE_DtcTooLarge,
	SWI_SMS_CAUSECODE_NetworkNotReady,
	SWI_SMS_CAUSECODE_PhoneNotReady,
	SWI_SMS_CAUSECODE_NotAllowedInAmps,
	SWI_SMS_CAUSECODE_CannotSendBroadcast,
	SWI_SMS_CAUSECODE_InvalidTransactionID,
	SWI_SMS_CAUSECODE_MsgNotSent,
	SWI_SMS_CAUSECODE_MsgBeingSent,
};

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_TYPE_PRI_SmsMask - SMS Support mask bit enumeration
//
// Purpose:     The enumerated mask bits identifies the SMS features
//				supported by the modem
//
// Members:  	SWI_PRI_SMS_MT				- Mobile Terminated (Incoming) SMS supported
//				SWI_PRI_SMS_MO				- Mobile Originated (Outgoing) SMS supported
//				SWI_PRI_SMS_ALL				- Internal Use
//				SWI_PRI_SMS_MASK_ENABLED	- Internal use
//
//////////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_PRI_SmsMask
{
	SWI_PRI_SMS_MT						= 0x0001,	
	SWI_PRI_SMS_MO						= 0x0002,	
	SWI_PRI_SMS_ALL						= 0xFFFF,

	SWI_PRI_SMS_MASK_ENABLED			= 0x8000	// Enabled bit (Internal use only)
};

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_STRUCT_CDMA_SMS_Status - status of SMS messages on the modem
//
// Purpose:     This structure reports the number of SMS
//				messages in each of the three buffers in the
//				modem: urgent, regular, and voice.
//
// Members: 	sizeStruct			- size of this structure
//
//				cntUrgentMsg		- urgent msg count
//
//				cntRegularMsg		- regular msg count
//
//				cntVoiceMsg			- voice msg count
//
//
// Notes:	    None
//
//////////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_CDMA_SMS_Status
{
	U32 sizeStruct;	   
	U32 cntUrgentMsg;  
	U32 cntRegularMsg; 
	U32 cntVoiceMsg;   
};

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_STRUCT_SMS_CdmaHeader - CDMA SMS Header
//
// Purpose:     A portion of SWI_STRUCT_CDMA_SMS_RetrieveSms,
//				this structure defines the header of incoming
//				SMS messages. Most of the data items are
//				defined in the CDMA specification and are not
//				explained here. The enumerated types are
//				described following this structure.
//
// Members:  	sizeStruct 			- size of this structure
//
//				eParamMask 			- Parameter Mask indicating which of the below fields
//									  are valid.  See SWI_TYPE_SMS_ParamMask.
//
//				eMsgCategory 		- Message Category
//									  See SWI_TYPE_SMS_MsgCategory
//
//				eTeleservice 		- Message Teleservice
//									  See SWI_TYPE_SMS_Teleservice
//
//				serviceCategory 	- Service Category (News, Restaraunts, etc.) 
//									  Refer to TIA/EIA-637 Section 3.4.3.2 for more detail.
//
//				tlAckReq 			- Indicates if the client needs to confirm 
//									  whether the message is received successfully or not.
//
//				eMsgIdType			- Message ID Type
//									  See SWI_TYPE_SMS_MsgIdType
//
//				addrDigitMode 		- Address Digit Mode
//
//				addrNumMode			- Address number mode
//
//				addrNumType			- Address number type
//
//				addrNumPlan			- Address number plan
//
//				addrLen				- Length of Address
//
//			 	szAddress			- Destination address if we are sending out a MO SMS
//									  Origination address if we are retrieving a MT SMS
//
//				subType 			- Sub address type
//
//				subOdd				- Sub Address Odd byte
//
//				subLen				- Length of the sub-address
//
//				szSubAddress		- Destination sub-address if we are sending out a MO SMS
//									  Origination sub-address if we are retrieving a MT SMS
//
//				callBackLen			- Length of the Callback number
//
//				szCallBack			- String containing the Call Back number with a 32 maximum characters
//
//				ePriority			- Message Priority	
//									  See SWI_TYPE_SMS_Priority
//
//				ePrivacy			- Message Privacy Level	
//									  See SWI_TYPE_SMS_Privacy
//
//				eLanguage			- Message Language	
//									  See SWI_TYPE_SMS_Language
//
//				user_ack_req 		- Specify whether user Acknowledgement is required
//									  True/False
//
//				dak_req				- Specify whether delivery acknowledge is required.
//
//				userResp			- User Response Code
//
//				szNumMsg 			- Number of Voice messages (SMSI_VMN_95) on the network
//
//				deliveryAlert 		- Alert on Delivery
//
//				dataEncoding 		- Message Body Data Encoding.
//									  Refer to SWI_TYPE_SMS_DataEncodeType.
//
//				ts_yr				- Time Stamp Year - the value is presented in decimal format.
//
//				ts_mon				- Time Stamp Month - the value is presented in hexadecimal format.  
//									  E.g. December will be interpreted as 0x12
//
//				ts_day				- Time Stamp Day- the value is presented in hexadecimal format.  
//									  E.g. 30th will be interpreted as 0x30.
//
//				ts_hrs				- Time Stamp Hour - the value is presented in hexadecimal format.   
//									  E.g. eleven o'clock is presented as 0x0x11.  
//									  Represented in 24-hour time.
//
//				ts_min				- Time Stamp Minute - the value is presented in hexadecimal format.
//									  E.g. thirty minute is presented as 0x30.
//
//				ts_sec				- Time Stamp Second - the value is presented in hexadecimal format. 
//									  E.g. thirty minute is presented as 0x30.
//
//				abVal_yr 			- Absolute Validity Year - the value is presented in decimal format.  
//
//				abVal_mon			- Absolute Validity Month - the value is presented in hexadecimal format.  
//									  E.g. December will be interpreted as 0x12.
//
//				abVal_day			- Absolute Validity Day- the value is presented in hexadecimal format.  
//									  E.g. 30th will be interpreted as 0x30.
//
//				abVal_hrs			- Absolute Validity Hour - the value is presented in hexadecimal format.   
//									  E.g. eleven o'clock is presented as 0x0x11.
//									  Represented in 24-hour time.
//
//				abVal_min			- Absolute Validity Minute - the value is presented in hexadecimal format.   
//									  Thus, thirty minute is presented as 0x30.
//
//				abVal_sec			- Absolute Validity Second - the value is presented in hexadecimal format.   
//									  E.g. thirty minute is presented as 0x30.
//
//				relVal_time			- Relative Validity Time of a SMS transmission.
//									  See TIA/EIA 637-A Section 4.5.6 for more detail.
//
//				abDef_yr 			- Absolute Delivery Deferral Year - the value is presented in decimal format.  
//
//				abDef_mon			- Absolute Delivery Deferral Month - the value is presented in hexadecimal format.  
//									  E.g. December will be interpreted as 0x12.
//
//				abDef_day			- Absolute Delivery Deferral Day - the value is presented in hexadecimal format.
//									  E.g. 30th will be interpreted as 0x30.
//
//				abDef_hrs			- Absolute Delivery Deferral Hour - the value is presented in hexadecimal format.
//									  E.g. eleven o'clock is presented as 0x0x11.  
//								  	  Represented in 24-hour time.
//
//				abDef_min			- Absolute Delivery Deferral Minute - the value is presented in hexadecimal format.
//									  E.g. thirty minute is presented as 0x30.
//
//				abDef_sec			- Absolute Delivery Deferral Second - the value is presented in hexadecimal format.
//									  E.g. thirty minute is presented as 0x30.
//
//				relDef_time 		- Relative Delivery Deferral Time of a SMS transmission.
//									  See Reference 1 Section 4.5.8 for more detail.
//
//				eMsgDispMode		- Message Display Mode:
//									  See SWI_TYPE_SMS_MsgDispMode
//
// Notes:	    
//
//////////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_SMS_CdmaHeader
{
    U32							sizeStruct;	
	SWI_TYPE_SMS_ParamMask		eParamMask;
	SWI_TYPE_SMS_MsgCategory	eMsgCategory;	
	SWI_TYPE_SMS_Teleservice	eTeleservice;    
	U16							serviceCategory;
	U8							tlAckReq;
	SWI_TYPE_SMS_MsgIdType		eMsgIdType;
	U8							addrDigitMode;
	U8							addrNumMode;
	U8							addrNumType;
	U8							addrNumPlan;
	U8							addrLen;
	WCHAR						szAddress[MAX_SMSI_TL_ADDRESS];
	U8							subType;
	U8							subOdd;
	U8							subLen;
	WCHAR						szSubAddress[MAX_SMSI_TL_ADDRESS];
	U8							callBackLen;
	WCHAR						szCallBack[MAX_SMSI_CALL_BACK];
	SWI_TYPE_SMS_Priority		ePriority; 
	SWI_TYPE_SMS_Privacy		ePrivacy;   
	SWI_TYPE_SMS_Language		eLanguage;    
	U8							user_ack_req;
	U8							dak_req;
	U8							userResp;
	WCHAR						szNumMsg[2];
	U8							deliveryAlert;
	SWI_TYPE_SMS_DataEncodeType	dataEncoding;
	U8							ts_yr;        
	U8							ts_mon;        
	U8							ts_day;        
	U8							ts_hrs;        
	U8							ts_min;
	U8							ts_sec;
	U8							abVal_yr;
	U8							abVal_mon;
	U8							abVal_day;
	U8							abVal_hrs;
	U8							abVal_min;
	U8							abVal_sec;
	U8							relVal_time;
	U8							abDef_yr;
	U8							abDef_mon;
	U8							abDef_day;
	U8							abDef_hrs;
	U8							abDef_min;
	U8							abDef_sec;
	U8							relDef_time;
	SWI_TYPE_SMS_MsgDispMode	eMsgDispMode;
};

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_STRUCT_CDMA_SMS_RetrieveSms - SMS Retrieve structure
//
// Purpose:     This structure is used to provide input to, and
//				receive output from the SwiRetrieveSMSMessage function.
//
// Members:  	sizeStruct			- size of this structure
//
//				sHeader 			- The SMS header for this message.
//
//				nSMSId 				- The message ID number assigned by
//									  the network.
//
//				cntRemainingSMS 	- The number of SMS
//									  messages remaining in the modem (all three
//									  queues combined).
//
//				pMessage 			- A pointer provided by the application
//									  in which to place the body of the SMS
//									  message.
//
//				sizeBuffer 			- The length in bytes of the buffer
//									  supplied to receive the body of the SMS message.
//									  This should be based on the maximum size of
//									  message supported by the network. The API
//									  currently supports up to 240 bytes, although
//									  most networks limit this to a lower value.
//									  retrievedStatus For future use; ignore.
//                    On return , this parameter will be set to the 
//                    no. of bytes copied into the pMessage buffer
//
// Notes:	    None
//
//////////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_CDMA_SMS_RetrieveSms
{
	U32								sizeStruct;
	bool							bUnreadSMS;			// Not used
	SWI_STRUCT_SMS_CdmaHeader		sHeader;
	U16                             nSMSId;
	U32                             cntRemainingSMS;
	U8                              *pMessage;
	U32                             sizeBuffer;
	U32								retrievedStatus;	// Not used
};

struct SWI_STRUCT_SMS_RetrieveVBSms
{
	U32								sizeStruct;
	bool							bUnreadSMS;			// Not used
	SWI_STRUCT_SMS_CdmaHeader		sHeader;
	U16                             nSMSId;
	U32                             cntRemainingSMS;
	WCHAR                           pMessage[1024];
	U32                             sizeBuffer;
	U32								retrievedStatus;	// Not used
};

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_STRUCT_CDMA_SMS_SendStatus - SMS Send Status notification data structure
//
// Purpose:     This data structure is used as a member of the notification
//				SWI_NOTIFY_SmsSendStatus.  Refer to the description of
//				SWI_NOTIFY_SmsSendStatus for more detail.
//
// Members:  	sizeStruct					- size of this structure
//				nMsgID	      				- Message ID of the corresponding SMS
//											  that had been sent
//				eErrorClass  				- Error type.  See
//											  SWI_TYPE_SMS_ErrorClass for details.
//				eCauseCode   				- Error cause code.  See
//											  SWI_TYPE_SMS_CauseCode for details.
//
// Notes:	    None.
//
//////////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_CDMA_SMS_SendStatus
{
    U32                             sizeStruct;    
	U32	                            nMsgID;	                  
	SWI_TYPE_SMS_ErrorClass		    eErrorClass;                      
	SWI_TYPE_SMS_CauseCode		    eCauseCode;                      
};


//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_STRUCT_CDMA_SMS_StoreSms - Structure used to store SMS
//
// Purpose:     This structure is used to provide input to the
//				SwiStoreCdmaSMSMessage function.
//
// Members:  	sizeStruct			- size of this structure
//
//				nSMSId 				- This is a unique identifer set by the
//									  application. The onus is on the application to
//									  ensure message IDs are not duplicated. This ID
//									  is used to report the status of sent messages via
//									  SWI_NOTIFY_SmsSendStatus.
//
//				sSMSHeader 			- The SMS header for this
//									  message, as described on page 52.
//
//				pMsgBody 			- The body of the SMS message. The
//									  true length is stored in another field (limited to
//									  240 bytes by the API).
//
//				sizeSMSBody 		- The length of the message body
//									  in bytes up to 240, or a lower limit imposed by
//									  your service provider.
//
//				bStoreStatus 		- For future use; ignore.
//
// Notes:	    None
//
//////////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_CDMA_SMS_StoreSms
{
	U32								sizeStruct;		
	U16								nSMSId; 		
	SWI_STRUCT_SMS_CdmaHeader		sSMSHeader;		
    U8                              *pMsgBody;		
    U32                             sizeSMSBody;   	
    U32                             bStoreStatus;	
};

struct SWI_STRUCT_SMS_StoreVBSms
{
	U32								sizeStruct;		
	U16								nSMSId; 		
	SWI_STRUCT_SMS_CdmaHeader		sSMSHeader;		
    WCHAR                           pMsgBody[1024];		
    U32                             sizeSMSBody;   	
    U32                             bStoreStatus;	
};

//////////////////////////////////////////////////////////////////////////////////
//
// Connection Management
//
//////////////////////////////////////////////////////////////////////////////////

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_TYPE_CDMA_CallType - Call Type enumeration
//
// Purpose:     The call type is used for various call management notifications.
//
// Members:  	SWI_CALL_TYPE_Voice			- Standard voice call and originating an
//											  OTASP call. Used by both AirCard 555 and
//											  SB555 products for originating a voice call.
//
//				SWI_CALL_TYPE_VoiceAlert	- Call waiting (Incoming only)
//
// 				SWI_CALL_TYPE_AsyncData		- Asynchronous Data.  Used by the AirCards
//											  for originating a QNC data call.
//
//				SWI_CALL_TYPE_PacketData	- Packet Data.  Used by the AirCards for
//											  originating a 1xRTT packet data connection.
//
//				SWI_CALL_TYPE_Fax			- Fax.  Standard G3 facsimile call.
//
// 				SWI_CALL_TYPE_Sms			- SMS.  Not used for application originated calls.
// 											  This indicates the connection being made is for
// 											  SMS transactions.
//
//				SWI_CALL_TYPE_Test			- Test (not used)
//
//				SWI_CALL_TYPE_Otapa			- OTAPA.  A call from a special number to
//											  update network settings in the modem.
//											  (Incoming only)
//
// 				SWI_CALL_TYPE_StandardOtasp	- Standard OTASP.  Not used in call origination
//											  or termination (answering). When OTASP is
//											  established a voice call may change to this type.
//
//				SWI_CALL_TYPE_NonstandardOtasp
//											- Nonstandard OTASP	(not used)
//
//				SWI_CALL_TYPE_E911			- E911.  An emergency mode call.
//
// 				SWI_CALL_TYPE_EVDO			- EVDO call 
//
//				SWI_CALL_TYPE_None			- Call Type None - (not used)
//
// Notes:	    None
//
//////////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_CDMA_CallType
{
	SWI_CALL_TYPE_Voice				= 0x0000,
	SWI_CALL_TYPE_VoiceAlert		= 0x0100,
	SWI_CALL_TYPE_AsyncData			= 0x0001,
	SWI_CALL_TYPE_PacketData		= 0x0101,
	SWI_CALL_TYPE_Fax				= 0x0201,
	SWI_CALL_TYPE_Sms				= 0x0002,
	SWI_CALL_TYPE_Test				= 0x0003,
/*	pre 3.1qc
	SWI_CALL_TYPE_Otapa				= 0x0004,
	SWI_CALL_TYPE_StandardOtasp		= 0x0005,
	SWI_CALL_TYPE_NonstandardOtasp	= 0x0006,
	SWI_CALL_TYPE_E911				= 0x0007,
*/
	SWI_CALL_TYPE_Otapa				= 0x0005,
	SWI_CALL_TYPE_StandardOtasp		= 0x0006,
	SWI_CALL_TYPE_NonstandardOtasp	= 0x0007,
	SWI_CALL_TYPE_E911				= 0x0008,
	SWI_CALL_TYPE_EVDO				= 0x0009,
	SWI_CALL_TYPE_None				= 0xffff
};

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_TYPE_CDMA_CallState - Call State enumeration
//
// Purpose:     This enumeration type identifies the elements of
//				a bit-mapped call state.  More than one bit can be
//				set at one time.
//
// Members:  	SWI_CALL_STATE_Idle			- No call
//				SWI_CALL_STATE_CnsAsyncData	- Async Data call
//				SWI_CALL_STATE_VoiceCall	- Voice call
//				SWI_CALL_STATE_Packet		- Packet 1xRtt call
// 
//				SWI_CALL_STATE_AtAsyncData	- Async Data call (via AT cmds)
//				SWI_CALL_STATE_AtVoiceCall 	- Voice call (via AT cmds)	
// 				SWI_CALL_STATE_AtPacket	   	- Packet 1xRtt call (via AT cmds)
//
//				SWI_CALL_STATE_Fax			- Fax call
// 				SWI_CALL_STATE_Sms			- SMS
//				SWI_CALL_STATE_OTA			- OTA
//				SWI_CALL_STATE_Test			- not used
// 				SWI_CALL_STATE_Cw			
//				SWI_CALL_STATE_NotUsed		- not used	
//
// 				SWI_CALL_STATE_Dormant		- Data connection is in dormant state
//
//				SWI_CALL_STATE_Emergency	- An emergency (E911) call
//
// Notes:	    For descriptions on the meaning of the various states,
//				see SWI_TYPE_CDMA_CallType.
//
//////////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_CDMA_CallState
{
	SWI_CALL_STATE_Idle				= 0x0000,
	SWI_CALL_STATE_CnsAsyncData		= 0x0001,
	SWI_CALL_STATE_VoiceCall		= 0x0002,
	SWI_CALL_STATE_Packet			= 0x0004,
	SWI_CALL_STATE_AtAsyncData		= 0x0010,
	SWI_CALL_STATE_AtVoiceCall		= 0x0020,
	SWI_CALL_STATE_AtPacket			= 0x0040,
	SWI_CALL_STATE_Fax				= 0x0080,
	SWI_CALL_STATE_Sms				= 0x0200,
	SWI_CALL_STATE_OTA				= 0x0400,
	SWI_CALL_STATE_Test				= 0x0800,
	SWI_CALL_STATE_Cw				= 0x1000,
	SWI_CALL_STATE_NotUsed			= 0x2000,
	SWI_CALL_STATE_Dormant			= 0x4000,
	SWI_CALL_STATE_Emergency		= 0x8000
};

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_TYPE_EndReason - Reason for call termination
//
// Purpose:     This reports the reason a call is disconnected
//
// Members:  	SWI_END_REASON_Offline		- Phone is offline
//
//				SWI_END_REASON_CdmaLockedUntilPowerCycle		
//											- Phone is CDMA locked until power-cycle
//
//    			SWI_END_REASON_NoService						
//											- Phone has no service
//
//				SWI_END_REASON_CallEndedAbnormally				
//											- Call has ended abnormally
//
//				SWI_END_REASON_ReceivedInterceptFromBs			
//											- Received intercept from BS (Orig. only)
//
//    			SWI_END_REASON_ReceivedReorderFromBs			
//											- Received release from BS (Orig. only)
//
//				SWI_END_REASON_ReceivedReleaseFromBsNoReason	
//											- Received release from BS - no reason given
//
//				SWI_END_REASON_ReceivedInterceptFromBsSoReject	
//											- Received release from BS - SO reject
//
//    			SWI_END_REASON_ReceivedIncomingCallFromBs		
//											- Received incoming call from BS
//
//				SWI_END_REASON_ReceivedAlertStopFromBs			
//											- Received alert stop from BS (incoming only)
//
//				SWI_END_REASON_ClientEndedCall					
//											- Client ended the call
//
//    			SWI_END_REASON_ReceivedEndActivation			
//											- Received end activation (OTASP call only)
//
//				SWI_END_REASON_McAborts						
//											- Obsolete
//
//				SWI_END_REASON_NdssFailure						
//											- NDSS failure
//
//    			SWI_END_REASON_MaxAccessProbesTransmitted		
//											- Max access probes transmitted
//
//				SWI_END_REASON_PersistenceTestFailure			
//											- Persistence test failure
//
//				SWI_END_REASON_RuimNotPresent					
//											- RUIM not present
//
//    			SWI_END_REASON_AccessAttemptAlreadyInProgress	
//											- Access attempt already in progress
//
//				SWI_END_REASON_AccessFailureReasonUnspecified	
//											- Access failure for reason other than the above reason
//
//				SWI_END_REASON_ReceivedRetryOrder				
//											- Received retry order (Orig. only)
//    
// Notes:	    None
//
//////////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_EndReason
{
	SWI_END_REASON_Offline,
	SWI_END_REASON_CdmaLockedUntilPowerCycle,
	SWI_END_REASON_NoService,
	SWI_END_REASON_CallEndedAbnormally,
	SWI_END_REASON_ReceivedInterceptFromBs,
	SWI_END_REASON_ReceivedReorderFromBs,
	SWI_END_REASON_ReceivedReleaseFromBsNoReason,
	SWI_END_REASON_ReceivedInterceptFromBsSoReject,
	SWI_END_REASON_ReceivedIncomingCallFromBs,
	SWI_END_REASON_ReceivedAlertStopFromBs,
	SWI_END_REASON_ClientEndedCall,
	SWI_END_REASON_ReceivedEndActivation,
	SWI_END_REASON_McAborts,
	SWI_END_REASON_NdssFailure,
	SWI_END_REASON_MaxAccessProbesTransmitted,
	SWI_END_REASON_PersistenceTestFailure,
	SWI_END_REASON_RuimNotPresent,
	SWI_END_REASON_AccessAttemptAlreadyInProgress,
	SWI_END_REASON_AccessFailureReasonUnspecified,
	SWI_END_REASON_ReceivedRetryOrder
};

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_TYPE_CallSource - Call Source (AT Cmds or API) enumeration
//
// Purpose:     This enumerates the call source options which identify if a call
//				was connected using AT commands or using the CnS
//				protocol (used by the API).
//
// Members:  	SWI_CALL_SOURCE_At			- AT Commands
//				SWI_CALL_SOURCE_Cns			- CNS (API)
// 	    
// Notes:	    None
//
//////////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_CallSource
{
	SWI_CALL_SOURCE_At,
	SWI_CALL_SOURCE_Cns
};

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_TYPE_PhoneKey - Dialpad keys enumeration
//
// Purpose:     This enumeration type identifies the dial pad keys.
//
// Members:  	SWI_PHONE_KEY_Pound			- '#' key, ASCII '#'                      
//				SWI_PHONE_KEY_Star			- '*' key, ASCII '*'                      
//     			SWI_PHONE_KEY_0				- '0' key, ASCII '0'                      
//				SWI_PHONE_KEY_1				- '1' key, ASCII '1'                      
//				SWI_PHONE_KEY_2				- '2' key, ASCII '2'                      
//     			SWI_PHONE_KEY_3				- '3' key, ASCII '3'                      
//				SWI_PHONE_KEY_4				- '4' key, ASCII '4'                      
//				SWI_PHONE_KEY_5				- '5' key, ASCII '5'                      
//     			SWI_PHONE_KEY_6				- '6' key, ASCII '6'                      
//				SWI_PHONE_KEY_7				- '7' key, ASCII '7'                      
//				SWI_PHONE_KEY_8				- '8' key, ASCII '8'                      
//     			SWI_PHONE_KEY_9				- '9' key, ASCII '9'                      
//				SWI_PHONE_KEY_Send			- Send key                                
//				SWI_PHONE_KEY_End			- End key or Power key (Based on Target)  
//     			SWI_PHONE_KEY_Clear			- Clear key                               
//				SWI_PHONE_KEY_Store			- Store key                               
//				SWI_PHONE_KEY_Up			- Up-arrow key was pressed                
//     			SWI_PHONE_KEY_Down			- Down-arrow key was pressed              
//				SWI_PHONE_KEY_Mute			- Mute Key                                
//				SWI_PHONE_KEY_Recall		- Recall key                              
//     
// Notes:	    Only digit keys 0-9, #, and * have any real use (i.e., DTMF tones
//				are played accordingly)
//
//				Command keys (Send, End, Recall, etc) have no effect and are not
//				used
//
//////////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_PhoneKey
{
	SWI_PHONE_KEY_Pound  = 0x23,
	SWI_PHONE_KEY_Star	= 0x2A,		
	SWI_PHONE_KEY_0		= 0x30,     
	SWI_PHONE_KEY_1		= 0x31,     
	SWI_PHONE_KEY_2		= 0x32,     
	SWI_PHONE_KEY_3		= 0x33,     
	SWI_PHONE_KEY_4		= 0x34,     
	SWI_PHONE_KEY_5		= 0x35,     
	SWI_PHONE_KEY_6		= 0x36,     
	SWI_PHONE_KEY_7		= 0x37,     
	SWI_PHONE_KEY_8		= 0x38,     
	SWI_PHONE_KEY_9		= 0x39,     
	SWI_PHONE_KEY_Send	= 0x50,     
	SWI_PHONE_KEY_End	= 0x51,     
	SWI_PHONE_KEY_Clear	= 0x52,     
	SWI_PHONE_KEY_Store	= 0x53,     
	SWI_PHONE_KEY_Up	= 0x54,     
	SWI_PHONE_KEY_Down	= 0x55,     
	SWI_PHONE_KEY_Mute	= 0x56,     
	SWI_PHONE_KEY_Recall = 0x57     
};

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_TYPE_FlashContext - Flash Context enumeration
//
// Purpose:     Values for use with the SwiSetCallFlashCmd function.
//
// Members:  	SWI_FLASH_CONTEXT_DontCare	- Dont Care This passes the call 
// 											  number to the call manager without checking that the 
// 											  flash command is valid in the present call state. Use
// 											  this context when you want manual control over
// 											  the flash command. If enabled, the [CallError]
// 											  notifications are sent if the flash is invoked in an
// 											  inappropriate call state.
//				SWI_FLASH_CONTEXT_CallWaiting
//											- Call Waiting This indicates to the call manager
//											  that the flash is for servicing a waiting call.
//											  When first invoked, it puts the current call on
//											  hold and connects the second call that is waiting.
//											  hold and connects the second call that is waiting.
//											  original call and holds the second call.
//     			SWI_FLASH_CONTEXT_ThreewaySetup		
//											- Threeway Setup This indicates to the call
//											  manager that the flash is for setting up a threeway
//											  call. A call number must be provided or
//											  else an error message will be returned as the
//											  response. This context sends two flashes to the
//											  base station, the first without a phone number
//											  and the second with a phone number.
//				SWI_FLASH_CONTEXT_ThreewayConnect
//											- Threeway Connect This indicates to the call
//											  manager that the flash is to connect all three
//											  parties. For this context, a call number must not
//											  be provided, otherwise an error message is
//											  returned as the response. Use the Don't Care
//											  flash context with an empty call number to
//											  disconnect the last connected party.
//				SWI_FLASH_CONTEXT_AnswerHold
//											- Answer Hold Not implemented.	 
//     			SWI_FLASH_CONTEXT_AnswerForward	
//											- Answer Forward Not implemented.	
//
// Notes:	    SWI_FLASH_CONTEXT_DontCare can be typically used for all
//				scenarios.
//
//////////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_FlashContext
{
	SWI_FLASH_CONTEXT_DontCare		    = 0x0000,
	SWI_FLASH_CONTEXT_CallWaiting	    = 0x0001,
	SWI_FLASH_CONTEXT_ThreewaySetup		= 0x0002,
	SWI_FLASH_CONTEXT_ThreewayConnect	= 0x0003,
	SWI_FLASH_CONTEXT_AnswerHold	    = 0x0004,
	SWI_FLASH_CONTEXT_AnswerForward		= 0x0005,
};

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_TYPE_AnswerState - Answer State enumeration
//
// Purpose:     The modes of operation the modem uses to
// 				determine how to answer the next incoming
// 				voice call.
//
// Parameters:  SWI_ANSWER_STATE_VoiceAsVoice     
//											- Answer voice as voice
//				SWI_ANSWER_STATE_VoiceAsFaxOnce,   
//											- Answer voice as fax once
//											  (for the next 10 minutes)
//				SWI_ANSWER_STATE_VoiceAsFaxAlways, 
//											- Answer voice as fax always 
//				SWI_ANSWER_STATE_VoiceAsModemOnce, 
//											- Answer voice as modem once
//											  (for the next 10 minutes)
//				SWI_ANSWER_STATE_VoiceAsModemAlways
//											- Answer voice as modem always
//
// Notes:	    None
//
//////////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_AnswerState 
{
	SWI_ANSWER_STATE_VoiceAsVoice,       
	SWI_ANSWER_STATE_VoiceAsFaxOnce,     
	SWI_ANSWER_STATE_VoiceAsFaxAlways,   
	SWI_ANSWER_STATE_VoiceAsModemOnce,   
	SWI_ANSWER_STATE_VoiceAsModemAlways  
};

//////////////////////////////////////////////////////////////////////////////////
//
// Service Status
//
//////////////////////////////////////////////////////////////////////////////////

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_STRUCT_ChannelNumber - Channel # notification data structure
//
// Purpose:     This data structure is used as a member of the notification
//				SWI_NOTIFY_ChannelNumber.  Refer to the description of
//				SWI_NOTIFY_ChannelNumber for more detail.
//
// Members:  	sizeStruct					- size of this structure
//				nChannelNumber				- Channel #
//
// Notes:	    Consult the reference for SwiGetChannelNumber
//				for details on the value nChannelNumber.
//
//////////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_ChannelNumber
{
    U32                     sizeStruct;
	U32						nChannelNumber;
};

/////////////////////////////////////////////////////////////////////////////////
//
// Name:	SWI_TYPE_ChannelState - channel state
//
// Purpose:	This enumerates the channel state
//
// Members:	SWI_CHANNEL_Aquired		- acquired
//
//			SWI_CHANNEL_Sleep		- sleep
//
//			SWI_CHANNEL_Scan		- scan
//
// Notes:	None
//
/////////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_ChannelState
{
	SWI_CHANNEL_Sleep	= 0,	// sleep
	SWI_CHANNEL_Aquired = 1,	// aquired 
	SWI_CHANNEL_Scan	= 5		// scan 
};

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_STRUCT_ChannelState - Channel State notification data structure
//
// Purpose:     This data structure is used as a member of the notification
//				SWI_NOTIFY_ChannelState.  Refer to the description of 
//				SWI_NOTIFY_ChannelState for more detail.
//
// Members:  	sizeStruct					- size of this structure
//				eChannelState				- Channel state.  See 
//											  SWI_TYPE_ChannelState for details.
//
// Notes:	    None.
//
//////////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_ChannelState
{
    U32                     sizeStruct;
	SWI_TYPE_ChannelState	eChannelState;
};

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_TYPE_TechBandClass - Bandclass enumeration
//
// Purpose:     The data enumerates as either cellular or PCS.
//
// Members:  	SWI_TECH_BANDCLASS_Cellular	- Cellular
//				SWI_TECH_BANDCLASS_Pcs		- PCS
//
// Notes:	    None.
//
//////////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_TechBandClass
{
	SWI_TECH_BANDCLASS_Cellular,
	SWI_TECH_BANDCLASS_Pcs
};

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_STRUCT_TechBandClass - Bandclass notification data structure
//
// Purpose:     This data structure is used as a member of the notification
//				SWI_NOTIFY_TechBandClass.  Refer to the description of
//				SWI_NOTIFY_TechBandClass for more detail.
//
// Members:  	sizeStruct					- size of this structure
//				eBandClass					- Bandclass.  See
//											  SWI_TYPE_TechBandClass for details.
//
// Notes:	    None.
//
//////////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_TechBandClass
{
    U32                     sizeStruct; 
	SWI_TYPE_TechBandClass	eBandClass;
};

/////////////////////////////////////////////////////////////////////////////////
//
// Name:	SWI_TYPE_ServiceIndication - service indication enumeration
//
// Purpose:	This enumeration contains the service indication states.
//
// Members:	SWI_SERVICE_INDICATION_None		- no service
//
//			SWI_SERVICE_INDICATION_Analog	- analog
//
//			SWI_SERVICE_INDICATION_Digital	- digital
//
// Notes:	None
//
/////////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_ServiceIndication 
{
	SWI_SERVICE_INDICATION_None,
	SWI_SERVICE_INDICATION_Analog,
	SWI_SERVICE_INDICATION_Digital
};

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_STRUCT_ServiceIndication - Service indication notification 
//											   data structure
//
// Purpose:     This data structure is used as a member of the notification
//				SWI_NOTIFY_ServiceIndication.  Refer to the description of 
//				SWI_NOTIFY_ServiceIndication for more detail.
//
// Members:  	sizeStruct					- size of this structure
//				eServiceIndicator			- Service indication.  See 
//											  SWI_TYPE_ServiceIndication for details.
//
// Notes:	    None.
//
//////////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_ServiceIndication
{
    U32						sizeStruct;
	SWI_TYPE_ServiceIndication	eServiceIndicator;
};

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_TYPE_PrevValue - Protocol Revision enumeration
//
// Purpose:     This enumerates the protocol revision 
//				supported by the serving base station.
//
// Members:  	SWI_PREV_VALUE_Jstd008	 	- Not supported
//				SWI_PREV_VALUE_Is95			- IS95
// 	    		SWI_PREV_VALUE_Is95A		- IS95A
// 	    		SWI_PREV_VALUE_MinIs95B		- Minimum IS95B
// 	    		SWI_PREV_VALUE_FullIs95B	- Full IS95B
// 	    		SWI_PREV_VALUE_Cdma2000Rev0	- CDMA 2000 Rev 0
// 	    		SWI_PREV_VALUE_Cdma2000Rev1	- CDMA 2000 Rev 1
// 	    
// Notes:	    Values of 6 or 7 (Cdma2000) indicate 1xRTT
//				coverage is availble. Value 1 (Jstd008) is not
//				supported.
//
//////////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_PrevValue
{
	SWI_PREV_VALUE_Jstd008			= 1,
	SWI_PREV_VALUE_Is95,
	SWI_PREV_VALUE_Is95A,
	SWI_PREV_VALUE_MinIs95B,
	SWI_PREV_VALUE_FullIs95B,
	SWI_PREV_VALUE_Cdma2000Rev0,
	SWI_PREV_VALUE_Cdma2000Rev1
};

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_STRUCT_Prev - Protocol Revision notification data structure
//
// Purpose:     This data structure is used as a member of the notification
//				SWI_NOTIFY_Prev.  Refer to the description of
//				SWI_NOTIFY_Prev for more detail.
//
// Members:  	sizeStruct					- size of this structure
//				eValue						- Protocal Revision value.  See
//											  SWI_TYPE_PrevValue for details.
//
// Notes:	    None.
//
//////////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_Prev
{
    U32                     sizeStruct;     
	SWI_TYPE_PrevValue		eValue;
};

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_STRUCT_RoamingStatus - Roaming State notification 
//										   data structure
//
// Purpose:     This data structure is used as a member of the notification
//				SWI_NOTIFY_RoamingStatus.  Refer to the description of 
//				SWI_NOTIFY_RoamingStatus for more detail.
//
// Members:  	sizeStruct					- size of this structure
//				eRoamingStatus				- Roaming status.  See 
//											  SWI_TYPE_RoamingState for details.
//
// Notes:	    None.
//
//////////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_RoamingStatus
{
    U32                     sizeStruct;     
	SWI_TYPE_RoamingState	eRoamingStatus;
};

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_TYPE_E911Mode - Emergency 911 mode enumeration
//
// Purpose:     This enumerates the Emergency 911 modes available
//
// Members:  	SWI_E911_MODE_Off			- E911 mode off
// 	    		SWI_E911_MODE_On			- E911 mode on
// 	    
// Notes:	    When in E911 mode, some modem functionality
//				may not be available. The modem can forced out
//				of E911 mode using SwiSetE911Mode.
//
//////////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_E911Mode
{
	SWI_E911_MODE_Off,
	SWI_E911_MODE_On
};

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_STRUCT_E911Mode - Emergency 911 notification data structure
//
// Purpose:     This data structure is used as a member of the notification
//				SWI_NOTIFY_E911Mode.  Refer to the description of
//				SWI_NOTIFY_E911Mode for more detail.
//
// Members:  	sizeStruct					- size of this structure
//				eMode						- Emergency 911 mode.  See
//											  SWI_TYPE_E911Mode for details.
//
// Notes:	    None.
//
//////////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_E911Mode
{
    U32                     sizeStruct;
	SWI_TYPE_E911Mode		eMode;
};

//////////////////////////////////////////////////////////////////////////////////
//
// Call Management
//
//////////////////////////////////////////////////////////////////////////////////

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_STRUCT_CallByteCounter - Byte Counter notification data structure
//
// Purpose:     This data structure is used as a member of the notification
//				SWI_NOTIFY_CallByteCounter.  Refer to the description of
//				SWI_NOTIFY_CallByteCounter for more detail.
//
// Members:  	sizeStruct					- size of this structure
//				nTxBytes					- bytes transmitted
//				nRxBytes					- bytes received
//
// Notes:	    The counters measure traffic over the local (host/
//				modem) interface. The counter resets when the
//				call is disconnected.
//
//////////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_CallByteCounter
{
    U32                     sizeStruct;     
    U32                     nTxBytes;
    U32                     nRxBytes;
};

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_STRUCT_CallConnecting - Call Connecting notification data structure
//
// Purpose:     This data structure is used as a member of the notification
//				SWI_NOTIFY_CallConnecting.  Refer to the description of
//				SWI_NOTIFY_CallConnecting for more detail.
//
// Members:  	sizeStruct					- size of this structure
//				eType						- Type of call being connected.
//											  See SWI_TYPE_CDMA_CallType for details.
//				eSource				  		- This indicates if the connection was
//											  requested by AT command or CnS (API)
//											- See SWI_TYPE_CallSource for details.
//				szNum			 			- Reports the standard caller ID of
//											  incoming calls (if available from 
//											  the network).
//											  Use SWI_NOTIFY_CallCallerID to determine
//											  CallerID prior to connecting.
//
// Notes:	    None.
//
//////////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_CallConnecting
{
    U32                     sizeStruct;
	SWI_TYPE_CDMA_CallType	eType;
	SWI_TYPE_CallSource		eSource;
    WCHAR					szNum[LENGTH_CallNumber + 1];   
};

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_STRUCT_CallConnected - Call Connected notification data structure
//
// Purpose:     This data structure is used as a member of the notification
//				SWI_NOTIFY_CallConnected.  Refer to the description of
//				SWI_NOTIFY_CallConnected for more detail.
//
// Members:  	sizeStruct					- size of this structure
//				eState						- Call State bit mask.  
//											  See SWI_TYPE_CDMA_CallState for details 
//				nSo							- The service option of the call. 
//											  This should be ignored. 
//
// Notes:	    None.
//
//////////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_CallConnected
{
    U32                     sizeStruct;
	SWI_TYPE_CDMA_CallState	eState;
	U32						nSo;
};

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_STRUCT_CallIncoming - Call Incoming notification data structure
//
// Purpose:     This data structure is used as a member of the notification
//				SWI_NOTIFY_CallIncoming.  Refer to the description of
//				SWI_NOTIFY_CallIncoming for more detail.
//
// Members:  	sizeStruct					- size of this structure
//				eType						- Call Incoming call type.  
//											  See SWI_TYPE_CDMA_CallType for details 
//
// Notes:	    None.
//
//////////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_CallIncoming
{
    U32                     sizeStruct;
	SWI_TYPE_CDMA_CallType	eType;
};

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_STRUCT_CallCallerID - Caller ID notification data structure
//
// Purpose:     This data structure is used as a member of the notification
//				SWI_NOTIFY_CallCallerID.  Refer to the description of
//				SWI_NOTIFY_CallCallerID for more detail.
//
// Members:  	sizeStruct					- size of this structure
//				szNum						- Caller ID string
//
// Notes:	    The Caller ID string is provided by the network.
//
//////////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_CallCallerID
{
    U32                     sizeStruct;     
    WCHAR					szNum[LENGTH_CallNumber + 1];   
};

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_STRUCT_CallExtendedCallerID - Extended Caller ID notification 
//				data structure
//
// Purpose:     This data structure is used as a member of the notification
//				SWI_NOTIFY_CallExtendedCallerID.  Refer to the description of
//				SWI_NOTIFY_CallExtendedCallerID for more detail.
//
// Members:  	sizeStruct					- size of this structure
//				szNum						- Extended Caller ID string
//
// Notes:	    The Extended Caller ID string is provided by the network.
//
//////////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_CallExtendedCallerID
{
    U32                     sizeStruct;   
    WCHAR					szNum[LENGTH_CallExtendedNumber + 1];   
};

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_STRUCT_CallDisconnected - Call Disconnected notification 
//				data structure
//
// Purpose:     This data structure is used as a member of the notification
//				SWI_NOTIFY_CallDisconnected.  Refer to the description of
//				SWI_NOTIFY_CallDisconnected for more detail.
//
// Members:  	sizeStruct					- size of this structure
//				eState						- Call State bit mask.  
//											  See SWI_TYPE_CDMA_CallState for details.
//				eReason						- The reason the call was disconnected.
//											  See SWI_TYPE_EndReason for details.
//
// Notes:	    None.
//
//////////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_CallDisconnected
{
    U32                     sizeStruct;    
	SWI_TYPE_CDMA_CallState		eState;
	SWI_TYPE_EndReason		eReason;
};

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_TYPE_CDMA_CallError - Call Error enumeration
//
// Purpose:     This enumerates the call errors provided by the notification
//				SWI_NOTIFY_CallError.
//
// Members:  	SW_CALL_ERROR_None			- No errors found
//
//				SW_CALL_ERROR_InvalidClientID
//											- Invalid client ID - null or not initialized
//
//				SW_CALL_ERROR_BadCallTypeParameter
//											- Bad call type parameter
//
//				SW_CALL_ERROR_BadServiceTypeParameter
//											- Bad service type parameter
//
//				SW_CALL_ERROR_BadServiceOptionParameter
//											- Bad service option parameter
//
//				SW_CALL_ERROR_ExpectingNumber
//											- Expecting a number to be provided via the number parameter
//
//				SW_CALL_ERROR_NumberLengthGreaterThanZeroBufferNull
//											- Number length is > 0, but number buffer points to NULL
//
//				SW_CALL_ERROR_InvalidDigitsNumberBuffer
//											- Invalid digits found in number buffer
//
//				SW_CALL_ERROR_OutOfRangeNumberLength
//											- Out of range value found in number length field
//
//				SW_CALL_ERROR_AlphaLengthGreaterThanZeroBufferNull
//											- Alpha length is > 0, but alpha buffer points to NULL
//
//				SW_CALL_ERROR_OutOfRangeAlphaLength
//											- Out of range value found in alpha length field
//
//				SW_CALL_ERROR_InvalidOtaspActivationCode
//											- Invalid OTASP activation code
//
//				SW_CALL_ERROR_PhoneOffline	- Phone is offline
//
//				SW_CALL_ERROR_PhoneCdmaLocked
//											- Phone is CDMA locked
//
//				SW_CALL_ERROR_ClientSendingFlasForUnsupportdFlashCall
//											- Client tried to send a flash while a call that not supporting flashes is in progress
//
//				SW_CALL_ERROR_DialedNumberNotPermitted
//											- Dialed number is not allowed under the current origination restriction
//
//				SW_CALL_ERROR_NonE911CallWhileE911PreferenceInEffect
//											- Client tried to originate a NONE E911 call while E911 mode preference is in effect
//
//				SW_CALL_ERROR_InvalidCmdWhilePhoneInUse
//											- Can't perform the command in question while phone is in-use
//
//				SW_CALL_ERROR_ServiceTypeNotSupportedByPhonePrl
//											- Client originated with service type that is currently not supported by the phone/PRL
//
//				SW_CALL_ERROR_ClientAnsweredWithWrongCallType
//											- Client answered with inappropriate call type relative to the type of the incoming call
//
//				SW_CALL_ERROR_CmdInvalidForCurrentState
//											- The command in question is invalid in the current call state 
//
//				SW_CALL_ERROR_CmdInvalidForCurrentPhoneServingState
//											- The command in question is invalid in the current Phone serving state 
//
//				SW_CALL_ERROR_NoServiceFoundForAutomatic
//											- no valid service found for origination with AUTOMATIC or CDMA_AUTOMATIC service type
//
//				SW_CALL_ERROR_ClientCannotAnswerIncomingCall
//											- Client is not allowed to answer the incoming call
//
//				SW_CALL_ERROR_BadPrivacyPref
//											- Bad privacy preference setting
//
//				SW_CALL_ERROR_NoAvailableCmdBuffers
//											- No available CM command buffers to queue the command
//
//				SW_CALL_ERROR_CommunicationProblemsWithMc
//											- Communication problems with MC 
//
//				SW_CALL_ERROR_Unspecified	- A problem other than the above was found
//				
// 	    
// Notes:	    None
//
//////////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_CDMA_CallError
{
	SW_CALL_ERROR_None,
	SW_CALL_ERROR_InvalidClientID,
	SW_CALL_ERROR_BadCallTypeParameter,
	SW_CALL_ERROR_BadServiceTypeParameter,
	SW_CALL_ERROR_BadServiceOptionParameter,
	SW_CALL_ERROR_ExpectingNumber,
	SW_CALL_ERROR_NumberLengthGreaterThanZeroBufferNull,
	SW_CALL_ERROR_InvalidDigitsNumberBuffer,
	SW_CALL_ERROR_OutOfRangeNumberLength,
	SW_CALL_ERROR_AlphaLengthGreaterThanZeroBufferNull,
	SW_CALL_ERROR_OutOfRangeAlphaLength,
	SW_CALL_ERROR_InvalidOtaspActivationCode,
	SW_CALL_ERROR_PhoneOffline,
	SW_CALL_ERROR_PhoneCdmaLocked,
	SW_CALL_ERROR_ClientSendingFlasForUnsupportdFlashCall,
	SW_CALL_ERROR_DialedNumberNotPermitted,
	SW_CALL_ERROR_NonE911CallWhileE911PreferenceInEffect,
	SW_CALL_ERROR_InvalidCmdWhilePhoneInUse,
	SW_CALL_ERROR_ServiceTypeNotSupportedByPhonePrl,
	SW_CALL_ERROR_ClientAnsweredWithWrongCallType,
	SW_CALL_ERROR_CmdInvalidForCurrentState,
	SW_CALL_ERROR_CmdInvalidForCurrentPhoneServingState,
	SW_CALL_ERROR_NoServiceFoundForAutomatic,
	SW_CALL_ERROR_ClientCannotAnswerIncomingCall,
	SW_CALL_ERROR_BadPrivacyPref,
	SW_CALL_ERROR_NoAvailableCmdBuffers,
	SW_CALL_ERROR_CommunicationProblemsWithMc,
	SW_CALL_ERROR_Unspecified
};

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_TYPE_CallCmd - Call Command enumeration
//
// Purpose:     This enumerates the call commands provided by the notification
//				SWI_NOTIFY_CallError.
//
// Members:  	SWI_CALL_CMD_None			- No command
//				SWI_CALL_CMD_Orig			- Call origination command
//				SWI_CALL_CMD_Answer	 		- Call answer command
//				SWI_CALL_CMD_End			- Call end command
//				SWI_CALL_CMD_Flash			- Flash command
//				SWI_CALL_CMD_PrivacyPref	- Privacy Pref. Command
//				SWI_CALL_CMD_InfoGet	 	- Info command
//				SWI_CALL_CMD_Hold			- Hold command
// 	    
// Notes:	    None
//
//////////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_CallCmd
{
	SWI_CALL_CMD_Orig,
	SWI_CALL_CMD_Answer,
	SWI_CALL_CMD_End,
	SWI_CALL_CMD_Flash,
	SWI_CALL_CMD_PrivacyPref,
	SWI_CALL_CMD_InfoGet,
	SWI_CALL_CMD_Hold,
	SWI_CALL_CMD_None = 0x00FF,
};

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_STRUCT_CallError - Call Error notification data structure
//
// Purpose:     This data structure is used as a member of the notification
//				SWI_NOTIFY_CallError.  Refer to the description of
//				SWI_NOTIFY_CallError for more detail.
//
// Members:  	sizeStruct					- size of this structure
//				eCmd						- The command or action being used
//											  when the error occured.
//										  	  See SWI_TYPE_CallCmd for details.
//				eError						- The nature of the error.
//											  See SWI_TYPE_CDMA_CallError for details.
//				eSource						- This indicates if the action was
//											  requested by AT command or CnS (API)
//											  See SWI_TYPE_CallSource for details.
//
// Notes:	    None.
//
//////////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_CallError
{
    U32							sizeStruct;    
	SWI_TYPE_CallCmd			eCmd;
	SWI_TYPE_CDMA_CallError		eError;
    SWI_TYPE_CallSource			eSource;
};

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_STRUCT_CallDormant - Dormant state notification data structure
//
// Purpose:     This data structure is used as a member of the notification
//				SWI_NOTIFY_CallDormant.  Refer to the description of
//				SWI_NOTIFY_CallDormant for more detail.
//
// Members:  	sizeStruct					- size of this structure
//				eState						- Call State bit mask.  
//											  See SWI_TYPE_CDMA_CallState for details
//				eReason						- Not Used.
//
// Notes:	    None.
//
//////////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_CallDormant
{
    U32							sizeStruct;
	SWI_TYPE_CDMA_CallState		eState;
	SWI_TYPE_EndReason			eReason;
};

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_TYPE_OTASPState - OTASP State enumeration
//
// Purpose:     This enumeration type identifies the available OTASP progress
//				states.
//
// Members:  	SWI_OTASP_STATE_PROG_START	- Programming started
//				SWI_OTASP_STATE_SPL_UNLOCK	- SPL unlock - required to access certain parameters
//				SWI_OTASP_STATE_AKEY_EXCHG	- AKey exchange - Authentication key has been exchanged
//				SWI_OTASP_STATE_SSD_UPDT	- Shared Secret Data has been updated
// 				SWI_OTASP_STATE_NAM_DL		- New NAM parameters have been downloaded
//				SWI_OTASP_STATE_MDN_DL		- New MDM has been downloaded  
//				SWI_OTASP_STATE_IMSI_DL		- IMSI has been downloaded  
// 				SWI_OTASP_STATE_PRL_DL		- PRL has been downloaded  
//				SWI_OTASP_STATE_COMMIT		- Newly downloaded parameters have been transferred to NV-RAM
//				SWI_OTASP_STATE_PROG_END	- Programming ended
//
// Notes:	    A successful OTASP session assumes no failures for any states,
//				and a successful commit.
//
//////////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_OTASPState
{
	SWI_OTASP_STATE_PROG_START		= 0x0000,
	SWI_OTASP_STATE_SPL_UNLOCK		= 0x0001,
	SWI_OTASP_STATE_AKEY_EXCHG		= 0x0002,
	SWI_OTASP_STATE_SSD_UPDT		= 0x0003,
	SWI_OTASP_STATE_NAM_DL			= 0x0004,
	SWI_OTASP_STATE_MDN_DL			= 0x0005,
	SWI_OTASP_STATE_IMSI_DL			= 0x0006,
	SWI_OTASP_STATE_PRL_DL			= 0x0007,
	SWI_OTASP_STATE_COMMIT			= 0x0008,
	SWI_OTASP_STATE_PROG_END		= 0x0009
};

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_STRUCT_OTASPState - OTASP State notification data structure
//
// Purpose:     This data structure is used as a member of the notification
//				SWI_NOTIFY_OTASPState.  Refer to the description of
//				SWI_NOTIFY_OTASPState for more detail.
//
// Members:  	sizeStruct					- size of this structure
//				eState						- The current stage in the OTASP
//											  process.
//										  	  SWI_TYPE_OTASPState for details.
//				nSuccess					- Indicates the success (1) or failure (0)
//											  of the stage indicated by eState.
//
// Notes:	    None.
//
//////////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_OTASPState
{
    U32                     sizeStruct;     
	SWI_TYPE_OTASPState		eState;
	U32						nSuccess;
};

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_TYPE_Privacy - Privacy state enumeration
//
// Purpose:     The data enumerates as privacy either on or off
//
// Members:  	SWI_PRIVACY_Off				- Privacy off
// 	    		SWI_PRIVACY_On				- Privacy on
// 	    
// Notes:	    None
//
//////////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_Privacy
{
	SWI_PRIVACY_Off,
	SWI_PRIVACY_On
};

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_STRUCT_CallPrivacy - Privacy notification data structure
//
// Purpose:     This data structure is used as a member of the notification
//				SWI_NOTIFY_CallPrivacy.  Refer to the description of
//				SWI_NOTIFY_CallPrivacy for more detail.
//
// Members:  	sizeStruct					- size of this structure
//				eMode						- Privacy state.  See
//											  SWI_TYPE_Privacy for details.
//
// Notes:	    None.
//
//////////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_CallPrivacy
{
    U32                     sizeStruct;     
	SWI_TYPE_Privacy		eMode;
};

//////////////////////////////////////////////////////////////////////////////////
//
// Modem Event data types
//
//////////////////////////////////////////////////////////////////////////////////

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_STRUCT_PowerSaveEnter - PowerSave (Enter) notification data structure
//
// Purpose:     This data structure is used as a member of the notification
//				SWI_NOTIFY_PowerSaveEnter.  Refer to the description of
//				SWI_NOTIFY_PowerSaveEnter for more detail.
//
// Members:  	sizeStruct					- size of this structure
//
// Notes:	    No data.
//
//////////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_PowerSaveEnter
{
	U32						sizeStruct; 
	// no data
};

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_STRUCT_PowerSaveExit - PowerSave (Exit) notification data structure
//
// Purpose:     This data structure is used as a member of the notification
//				SWI_NOTIFY_PowerSaveExit.  Refer to the description of
//				SWI_NOTIFY_PowerSaveExit for more detail.
//
// Members:  	sizeStruct					- size of this structure
//
// Notes:	    No data.
//
//////////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_PowerSaveExit
{
	U32						sizeStruct;
	// no data
};

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_TYPE_PRI_VoiceDataMask - Voice/Data Support mask bit enumeration
//
// Purpose:     The enumerated mask bits identifies the voice/data features
//				supported by the modem
//
// Members:  	SWI_PRI_DATA_1X				- 1x data calls supported
//				SWI_PRI_DATA_IS95			- IS95 (QNC/Fax/Dialup) data calls supported
//				SWI_PRI_DATA_AUTOCONNECT	- Internal use for Watcher only
//				SWI_PRI_VOICE				- Voice calls supported
//				SWI_PRI_VOICE				- Internal Use
//				SWI_PRI_VD_ALL				- Internal Use
//				SWI_PRI_VD_MASK_ENABLED		- Internal Use
//
// Notes:	    None.
//
//////////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_PRI_VoiceDataMask
{
	SWI_PRI_DATA_1X						= 0x0001,
	SWI_PRI_DATA_IS95					= 0x0002,	
	SWI_PRI_DATA_AUTOCONNECT			= 0x0004,	
#if FUTURE_USE												// { bits 4-7 reserved for future use }
	SWI_PRI_DATA_						= 0x0008,
	SWI_PRI_DATA_						= 0x0010,
	SWI_PRI_DATA_						= 0x0020,
	SWI_PRI_DATA_						= 0x0040,
#endif
	SWI_PRI_VOICE						= 0x0080,  
	SWI_PRI_VD_ALL						= 0xFFFF,
	SWI_PRI_VD_MASK_ENABLED				= 0x8000	// Enabled bit (Internal use only)
};

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_TYPE_CarrierID - Carrier ID enumeration
//
// Purpose:     The enumerated values identify the various
//				carriers a modem may be configured for
//
// Members:  	SWICARRIER_UNDEFINED		- Not defined
//				SWICARRIER_RESERVED			- (reserved)
//				SWICARRIER_AC555_GENERIC	- Generic
//				SWICARRIER_AC550_SPRINT		- Sprint
//				SWICARRIER_AC555_BELL		- Bell Mobility
//				SWICARRIER_AC555_TELUS		- Telus
//				SWICARRIER_AC555_VZW		- Verizon Wireless
//				SWICARRIER_AC555_WESTERNWIRELESS
//											- Western Wireless
//				SWICARRIER_AC555_SMARTCOM	- SmartCom
//				SWICARRIER_AC555_ALLTEL		- AllTel
//				SWICARRIER_AC555_USCELLULAR	- US Cellular
//				SWICARRIER_SB550T_SPRINT	- (Thera) Sprint
//				SWICARRIER_SB555T_BELL		- (Thera) Bell Mobility
//				SWICARRIER_SB555T_TELUS		- (Thera) Telus
//				SWICARRIER_SB555T_VZW		- (Thera) Verizon Wireless
//				SWICARRIER_AC555_CHINAUNICOM
//											- China Unicom
//				SWICARRIER_AC555_HUTCHISONTHAILAND
//											- Hutchison Thailand
//				SWICARRIER_AC555_MOVILNET	- MovilNet
//				SWICARRIER_AC555_TARJETAS_IUSACELL_MEXICO
//											- Iusacell Mexico
//				SWICARRIER_AC555_TELECOMNEWZEALAND
//											- Telecom NewZealand
//				SWICARRIER_AC555_RELIANCE	- Reliance
//				SWICARRIER_AC555_TELSTRA	- Telstra
//				SWICARRIER_AC555_MOBILITYCANADA
//											- Mobility Canada
//				SWICARRIER_AC555_VZW_PUERTO_RICO
//											- Verizon Wireless Puerto Rico
//				SWICARRIER_AC555_PELEPHONE	- Pelephone
//				SWICARRIER_AC555_BELL_CANADA
//											- Bell Canada
//				SWICARRIER_AC555_INDOSOL_INDONESIA
//											- Indosol
//				SWICARRIER_AC555_MIDWEST_WIRELESS
//											- MidWest Wireless
//        SWI_CARRIER_AC555_BELL_SOUTH_CHILE,
//        SWI_CARRIER_AC555_BELL_SOUTH_PANAMA,
//        SWI_CARRIER_AC555_TATA
//        
//
//
//
//
// Notes:	    The Carrier IDs no longer represent the Product type (AC555 vs AC580).
//            supported.  The SBXXX items are kept only for backwards compatibility.
//            (ie.  The AC580 for Verizon carrier ID will be SWI_CARRIER_AC555_VZW)
//
//////////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_CarrierID
{
	SWI_CARRIER_UNDEFINED						= -1,
	SWI_CARRIER_RESERVED						= 0,
	SWI_CARRIER_AC555_GENERIC,
	SWI_CARRIER_AC550_SPRINT,
	SWI_CARRIER_AC555_BELL,
	SWI_CARRIER_AC555_TELUS,
	SWI_CARRIER_AC555_VZW,
	SWI_CARRIER_AC555_WESTERNWIRELESS,
	SWI_CARRIER_AC555_SMARTCOM,
	SWI_CARRIER_AC555_ALLTEL,
	SWI_CARRIER_AC555_USCELLULAR,
	SWI_CARRIER_SB550T_SPRINT,
	SWI_CARRIER_SB555T_BELL,
	SWI_CARRIER_SB555T_TELUS,
	SWI_CARRIER_SB555T_VZW,
	SWI_CARRIER_AC555_CHINAUNICOM,
	SWI_CARRIER_AC555_HUTCHISONTHAILAND,
	SWI_CARRIER_AC555_MOVILNET,
	SWI_CARRIER_AC555_TARJETAS_IUSACELL_MEXICO,
	SWI_CARRIER_AC555_TELECOMNEWZEALAND,
	SWI_CARRIER_AC555_RELIANCE,
	SWI_CARRIER_AC555_TELSTRA,
	SWI_CARRIER_AC555_MOBILITYCANADA,
	SWI_CARRIER_AC555_VZW_PUERTO_RICO,
	SWI_CARRIER_AC555_PELEPHONE,
	SWI_CARRIER_AC555_BELL_CANADA,
	SWI_CARRIER_AC555_INDOSOL_INDONESIA,
	SWI_CARRIER_AC555_MIDWEST_WIRELESS,
	SWI_CARRIER_AC555_BELL_SOUTH_CHILE,
	SWI_CARRIER_AC555_BELL_SOUTH_PANAMA,
	SWI_CARRIER_AC555_TATA
};

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_TYPE_DistributorID - Distributor ID enumeration
//
// Purpose:     The enumerated values identify the various
//      				distributors a modem may be configured for
//
// Members:  	SWIDISTRIBUTOR_UNDEFINED		    - Not defined
//				    SWIDISTRIBUTOR_NONE	     		    - (reserved)
//				    SWIDISTRIBUTOR_SIERRA_WIRELESS  - SWIR
//				    SWIDISTRIBUTOR_EASTCOM          - Easter Communications
//            SWIDISTRIBUTOR_TONGFANG         - TSINGHUA TONGFANG
//            SWIDISTRIBUTOR_ZTE              - ZTE
//            SWIDISTRIBUTOR_CHINA_PUTIAN     - NANJING PUTIAN ZHONGYOU
//            SWIDISTRIBUTOR_NCL              - NCL Technology
//            SWIDISTRIBUTOR_SHANGHAI_BELL    - SHANGHAI BELL
//            SWIDISTRIBUTOR
//
// Notes: None
//////////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_DistributorID
{
	SWI_DISTRIBUTOR_UNDEFINED						= -1,
	SWI_DISTRIBUTOR_NONE    						= 0,
  SWI_DISTRIBUTOR_SIERRA_WIRELESS     = 1,
  SWI_DISTRIBUTOR_EASTCOM             = 2,
  SWI_DISTRIBUTOR_TONGFANG            = 3,
  SWI_DISTRIBUTOR_ZTE                 = 4,
  SWI_DISTRIBUTOR_CHINA_PUTIAN        = 5,
  SWI_DISTRIBUTOR_NCL                 = 6,
  SWI_DISTRIBUTOR_SHANGHAI_BELL       = 7,
};


//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_STRUCT_HdrNotificationStatus - HDR Notification status data structure
//
// Purpose:     This data structure is used to hold the status of HDR notifcations.
//
// Members:  	sizeStruct					- size of this structure
//            iHdrNotificationStatus - Mask of enabled notifications
//
// Notes:	    None.
//
//////////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_HdrNotificationStatus
{
  U32           sizeStruct;     
  U16						iHdrNotificationStatus;   
};

//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_STRUCT_Rssi_Ecio - RSSI and EcIo data structure
//
// Purpose:     This data structure is used to hold RSSI and EcIo data.
//
// Members:  	sizeStruct					- size of this structure
//            iCdmaRssi;          - Cdma RSSI
//            iCdmaEcio;          - Cdma EcIo
//            iHdrRssi;           - HDR RSSI
//            iHdrEcio;           - HDR EcIo
//
//
// Notes:	    None.
//
//////////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_Rssi_Ecio
{
    U32           sizeStruct;     
    U16						iCdmaRssi;   
    U16						iCdmaEcio;
    U16						iHdrRssi;
    U16						iHdrEcio;
};


enum SWI_TYPE_Hdr_Roam_Status
{
	SWI_HDR_ROAM_STATUS_NO_ROAMING	= 0x00000000,
	SWI_HDR_ROAM_STATUS_ROAMING_WITH_GAURANTEED_VALID_SIDS	= 0x00000001,
  SWI_HDR_ROAM_STATUS_ROAMING_WITHOUT_GAURANTEED_SIDS	= 0x00000002,
};

struct SWI_STRUCT_Hdr_Roam_Status
{
    U32           sizeStruct;     
    U16						iHdrRoamStatus;   
};

enum SWI_TYPE_Hdr_Srv_State
{
	SWI_HDR_SRV_STATE_NO_SERVICE			= 0x00000000,
	SWI_HDR_SRV_STATE_DIGITAL_SERVICE		= 0x00000002,
	SWI_HDR_SRV_STATE_DIGITAL_SERVICE_Rev0	= SWI_HDR_SRV_STATE_DIGITAL_SERVICE,
	SWI_HDR_SRV_STATE_DIGITAL_SERVICE_RevA	= 0x00000004,
};

struct SWI_STRUCT_Hdr_Srv_State
{
    U32           sizeStruct;     
    U16						iHdrSrvState;   
};

enum SWI_TYPE_Hdr_Hybr_Pref
{
	SWI_HDR_HYBR_PREF_MODE_OFF	= 0x00000000,
	SWI_HDR_HYBR_PREF_MODE_ON	  = 0x00000001,
};

struct SWI_STRUCT_Hdr_Hybr_Pref
{
    U32           sizeStruct;     
    U16						iHdrHybrPref;   
};

enum SWI_TYPE_Digital_Mode
{
	SWI_HDR_MODE_NO_SERVICE	    = 0x00000000,
	SWI_HDR_MODE_AMPS     	    = 0x00000001,
  SWI_HDR_MODE_CDMA     	    = 0x00000002,
  SWI_HDR_MODE_GSM      	    = 0x00000003,
  SWI_HDR_MODE_HDR      	    = 0x00000004,
  SWI_HDR_MODE_WCDMA    	    = 0x00000005,
  SWI_HDR_MODE_GPS    	      = 0x00000006,
};

struct SWI_STRUCT_Idle_Digital_Mode
{
    U32           sizeStruct;     
    U16						iPrevIdleDigitalMode;   
    U16						iCurrIdleDigitalMode;   
};

enum SWI_TYPE_DDTM_Pref
{
	SWI_HDR_DDTM_PREF_MODE_OFF  = 0x00000000,
	SWI_HDR_DDTM_PREF_MODE_ON   = 0x00000001,
  SWI_HDR_DDTM_PREF_MODE_NO_CHANGE = 0x00000002,
};

struct SWI_STRUCT_DDTM_Pref
{
    U32           sizeStruct;     
    U16						iDDTMPref;   
};

struct SWI_STRUCT_Hdr_PowerSave_Enter
{
    U32           sizeStruct;     
};

struct SWI_STRUCT_Hdr_PowerSave_Exit
{
    U32           sizeStruct;     
};


// RUIM -- For RUIM enabled products only
enum SWI_TYPE_RuimStatus
{
  SWI_RUIM_STATUS_OK = 0x0000,
  SWI_RUIM_STATUS_INIT_ERR,
  SWI_RUIM_STATUS_GENERAL_ERR,
  SWI_RUIM_STATUS_LOCKED,
  SWI_RUIM_STATUS_CHV1_BLOCKED,
  SWI_RUIM_STATUS_CHV2_BLOCKED,
  SWI_RUIM_STATUS_CHV1_REJECTED,
  SWI_RUIM_STATUS_CHV2_REJECTED,
  SWI_RUIM_STATUS_POLL_ERR,
  SWI_RUIM_STATUS_NO_SRV_ERR,
  SWI_RUIM_STATUS_ICCID_MISMATCH_ERR,
};

enum SWI_TYPE_RuimOpReq
{
	SWI_RUIM_OPREQ_NONE = 0x0000,
	SWI_RUIM_OPREQ_CHV1,
	SWI_RUIM_OPREQ_CHV2,
	SWI_RUIM_OPREQ_CHV_UNBLK1,
	SWI_RUIM_OPREQ_CHV_UNBLK2,
};

enum SWI_TYPE_RuimPrevOp
{
	SWI_RUIM_PREV_OP_NONE = 0x0000,
	SWI_RUIM_PREV_OP_CHV1CHG,
	SWI_RUIM_PREV_OP_CHV2CHG,
	SWI_RUIM_PREV_OP_CHV1VER,
	SWI_RUIM_PREV_OP_CHV2VER,
	SWI_RUIM_PREV_OP_UNBLK1,
	SWI_RUIM_PREV_OP_UNBLK2,
	SWI_RUIM_PREV_OP_CHV1_EN,
	SWI_RUIM_PREV_OP_CHV1_DIS
};

enum SWI_TYPE_RuimPrevOpRes
{
	SWI_RUIM_PREV_OP_FAIL = 0x0000,
	SWI_RUIM_PREV_OP_SUCCESS,
	SWI_RUIM_PREV_OP_FAIL_VER,
  SWI_RUIM_PREV_OP_FAIL_CHV_LEN,
  SWI_RUIM_PREV_OP_FAIL_UNBLK_LEN,
  SWI_RUIM_PREV_OP_FAIL_NO_SRV,  
	SWI_RUIM_PREV_OP_FAIL_EMERG
};

enum SWI_TYPE_RuimRetryPres
{
	SWI_RUIM_NO_RETRY_INFO = 0x0000,
	SWI_RUIM_RETRY_INFO
};

enum SWI_TYPE_RuimRetry
{
	SWI_RUIM_RETRY_CHV1 = 0x0000,
	SWI_RUIM_RETRY_CHV2,
	SWI_RUIM_RETRY_UNBLOCK_CHV1,
	SWI_RUIM_RETRY_UNBLOCK_CHV2
};

enum SWI_RUIM_CHV
{
	SWI_RUIM_CHV1 = 0x0001,
	SWI_RUIM_CHV2,
  SWI_RUIM_UNBLOCK_CHV1,
  SWI_RUIM_UNBLOCK_CHV2
};

struct SWI_STRUCT_RuimStatus
{
  U32                      sizeStruct;     //size of this structure
  U16                      nStatus;
  U16                      byActionReq;
  U16                      byPrevAction;
  U16                      byPrevActRes;
  U16                      byRetryPres;
  U16                      byRetry;
  U16                      byRetryNum;
};

//////////////////////////////////////////////////////////////////////////////////
//
//	Not Supported / Internal Use - START									
//
//////////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_ActivationStatus
{
	SWI_ACTIVATION_STATUS_False,
	SWI_ACTIVATION_STATUS_True
};

struct SWI_STRUCT_ActivationStatus
{
    U32                     sizeStruct;     
	SWI_TYPE_ActivationStatus eActivationStatus;
};

struct SWI_STRUCT_CallNotificationStatus
{
    U32                     sizeStruct;     
    U32                     nNotifyStatus;
};

struct SWI_STRUCT_Ecio
{
    U32                     sizeStruct;     
	U32						nEcio;
};

enum SWI_TYPE_V42BisEnabled
{
	SWI_V42_BIS_ENABLED_True,
	SWI_V42_BIS_ENABLED_False
};

struct SWI_STRUCT_V42BisEnabled
{
    U32                     sizeStruct;     
	SWI_TYPE_V42BisEnabled  eV42Bis;
};

enum SWI_TYPE_AuthenticationStatus
{
	SWI_AUTHENTICATION_STATUS_True,
	SWI_AUTHENTICATION_STATUS_False
};

struct SWI_STRUCT_AuthenticationStatus
{
    U32                     sizeStruct;     
	SWI_TYPE_AuthenticationStatus eAuthenticationStatus;
};

struct SWI_STRUCT_TechSid
{
    U32                     sizeStruct;     
	U32						nSid;
};

struct SWI_STRUCT_TechNid
{
    U32                     sizeStruct;     
	U32						nNid;
};

struct SWI_STRUCT_TechBsInfo
{
    U32                     sizeStruct;     
    U32						nLongitude;
    U32						nLatitude;
};

struct SWI_STRUCT_TechRegZone
{
    U32                     sizeStruct;     
	U32						nZoneID;
};

struct SWI_STRUCT_TechPacketZone
{
    U32                     sizeStruct;     
	U32						nZoneID;
};

enum SWI_TYPE_TechPcsBlock
{
	SWI_TECH_PCS_BLOCK_NoCoverage,
	SWI_TECH_PCS_BLOCK_A,
	SWI_TECH_PCS_BLOCK_B,
	SWI_TECH_PCS_BLOCK_C,
	SWI_TECH_PCS_BLOCK_D,
	SWI_TECH_PCS_BLOCK_E,
	SWI_TECH_PCS_BLOCK_F
};

struct SWI_STRUCT_TechPcsBlock
{
    U32                     sizeStruct;     
	SWI_TYPE_TechPcsBlock	ePcs;
};

enum SWI_TYPE_TechCellChannel
{
	SWI_TECH_CELL_CHANNEL_NoCoverage,
	SWI_TECH_CELL_CHANNEL_A,
	SWI_TECH_CELL_CHANNEL_B
};

struct SWI_STRUCT_TechCellChannel
{
    U32                     sizeStruct;     
	SWI_TYPE_TechCellChannel eChannel;
};


struct SWI_STRUCT_SystemTime
{
    U32                     sizeStruct;     
	SYSTEMTIME				time;
};


struct SWI_STRUCT_HIOTAStatus
{
    U32                     sizeStruct;     
	U32						nResult;
	U32						nMask;
};

enum SWI_TYPE_NamValue
{
	SWI_NAM_VALUE_0,
	SWI_NAM_VALUE_1,
	SWI_NAM_VALUE_2,
	SWI_NAM_VALUE_3,
	SWI_NAM_VALUE_Auto
};

struct SWI_STRUCT_ActiveNam
{
    U32                     sizeStruct;     
	SWI_TYPE_NamValue		eNamIndex;
};

enum SWI_TYPE_ModemTooHot
{
	SWI_MODEM_TOO_HOT_Disconnect	= 0x0011,
	SWI_MODEM_TOO_HOT_ShutdownModem = 0x0012
};

struct SWI_STRUCT_ModemTooHotIndication
{
    U32                     sizeStruct;     
	SWI_TYPE_ModemTooHot	eAction;
};

struct SWI_STRUCT_FlashBurn
{
	U32						sizeStruct;     
	U16						nSector;
};

enum SWI_TYPE_ExcessSPCFailures
{
	SWI_MODEM_RESET		= 0x0000,
	SWI_MODEM_FREEZE	= 0x0001
};

struct SWI_STRUCT_ExcessSPCFailures
{
	U32							sizeStruct;     
	SWI_TYPE_ExcessSPCFailures	eFailType;
};


struct SWI_STRUCT_Hdr_Acq 
{
    U32						sizeStruct;     
	I32						lAcquired;
};
struct SWI_STRUCT_Hdr_Rssi 
{
    U32						sizeStruct;     
	I32						iRssi;
};
struct SWI_STRUCT_Hdr_Uati 
{
    U32                     sizeStruct;     
    U8   					byUati[17];   
};

struct SWI_STRUCT_TechHdrNotificationStatus
{
  U32           sizeStruct;     
  U16						iTechHdrNotificationStatus;   
};

struct SWI_STRUCT_Tech_Hdr_Prev
{
    U32           sizeStruct;     
    U16						iHdrPRevMin;   
    U16						iHdrPRevMax;   
};

struct SWI_STRUCT_Tech_Hdr_Sector
{
    U32           sizeStruct; 
    U8				    szHdrSectorId[LENGTH_SectorId];   
    U16						iHdrSubnetMask;   
    U16           iHdrColorCode;
    U16           iHdrPnOffset;
};

enum SWI_TYPE_Tech_Hdr_At_State
{
	SWI_TECH_HDR_AT_STATE_INACTIVE    = 0x00000000,
	SWI_TECH_HDR_AT_STATE_ACQUISITION = 0x00000001,
  SWI_TECH_HDR_AT_STATE_SYNC        = 0x00000002,
  SWI_TECH_HDR_AT_STATE_IDLE        = 0x00000003,
  SWI_TECH_HDR_AT_STATE_ACCESS      = 0x00000004,
  SWI_TECH_HDR_AT_STATE_CONNECTED   = 0x00000005,
};

enum SWI_TYPE_Tech_Hdr_Session_State
{
	SWI_TECH_HDR_SESSION_STATE_CLOSE                    = 0x00000000,
	SWI_TECH_HDR_SESSION_STATE_ADDR_MGMT_PROTOCOL_SETUP = 0x00000001,
  SWI_TECH_HDR_SESSION_STATE_AT_INITIATED             = 0x00000002,
  SWI_TECH_HDR_SESSION_STATE_AN_INITIATED             = 0x00000003,
  SWI_TECH_HDR_SESSION_STATE_OPEN                     = 0x00000004,
};

struct SWI_STRUCT_Tech_Hdr_State
{
    U32           sizeStruct; 
    U16           iHdrAtState;
    U16           iHdrSessionState;
};

struct SWI_STRUCT_Tech_Hdr_Channel
{
    U32           sizeStruct; 
    U16           iHdrChannel;
};

struct SWI_STRUCT_Tech_Hdr_Session
{
    U32           sizeStruct; 
    U8            szHdrUati[LENGTH_HdrUati];
    U16           iHdrUatiColorCode;
    U32           iHdrRati;
    U16           iHdrSessionDuration;
    U32           iHdrSessionStart1;
    U32           iHdrSessionStart2;
    U32           iHdrSessionEnd1;
    U32           iHdrSessionEnd2;
};

enum SWI_TYPE_Tech_Hdr_An_Auth
{
	SWI_TECH_HDR_AN_AUTH_NOT_AUTHENTICATED            = 0x00000000,
	SWI_TECH_HDR_AN_AUTH_AUTHENTICATED                = 0x00000001,
  SWI_TECH_HDR_AN_AUTH_AUTHENTICATION_FAILED        = 0x00000002,
  SWI_TECH_HDR_AN_AUTH_AUTHENTICATION_DISABLED      = 0x00000003,
};

struct SWI_STRUCT_Tech_Hdr_An_Auth
{
    U32           sizeStruct; 
    U16           iHdrAnAuthS;
};

struct SWI_STRUCT_Tech_Hdr_Drc_Val
{
    U32           sizeStruct; 
    U16           iHdrDrcValue;
};

struct SWI_STRUCT_Tech_Hdr_Drc_Cover
{
    U32           sizeStruct; 
    U16           iHdrDrcCover;
};

struct SWI_STRUCT_Tech_Hdr_Rri
{
    U32           sizeStruct; 
    U16           iHdrRri;
};

struct SWI_STRUCT_Tech_Hdr_Stats
{
    U32           sizeStruct; 
    U16           iHdrRxAgc0;
    U16           iHdrRxAgc1;
    U16           iHdrTxTotal;
    U16           iHdrTxAdj;
    U16           iHdrc2i;
    U16           iHdrEcio;
    U16           iHdrRssi;
};

struct SWI_STRUCT_SwiApi_State
{
    U32           sizeStruct; 
    U8            lState;
};

//////////////////////////////////////////////////////////////////////////////////
//
//	Not Supported / Internal Use - END
//
//////////////////////////////////////////////////////////////////////////////////


enum SWI_TYPE_Notify_HdrMask
{
  CNS_HDR_RSSI_Mask = 0x0001,
  CNS_HDR_ROAM_STATUS_Mask = 0x0002,
  CNS_HDR_SRV_STATE_Mask = 0x0004,
  CNS_HDR_HYBR_PREF_Mask = 0x0008,
  CNS_IDLE_DIGITAL_MODE_Mask = 0x0010,
  CNS_DDTM_PREF_Mask = 0x0020,
  CNS_HDR_POWERSAVE_Mask = 0x0040,
};

enum SWI_TYPE_Notify_TechHdrMask
{
  CNS_TECH_HDR_PREV_Mask = 0x0001,
  CNS_TECH_HDR_SECTOR_Mask = 0x0002,
  CNS_TECH_HDR_STATE_Mask = 0x0004,
  CNS_TECH_HDR_CHANNEL_Mask = 0x0008,
  CNS_TECH_HDR_SESSION_Mask = 0x0010,
  CNS_TECH_HDR_AN_AUTH_Mask = 0x0020,
  CNS_TECH_HDR_DRC_VAL_Mask = 0x0040,
  CNS_TECH_HDR_DRC_COV_Mask = 0x0080,
  CNS_TECH_HDR_RRI_Mask = 0x0100,
  CNS_TECH_HDR_STATS_Mask = 0x0200,
};

typedef enum {
  NV_MODE_DIGITAL_PREF,     /* CDMA then Analog */
  NV_MODE_DIGITAL_ONLY,     /* CDMA only */
  NV_MODE_ANALOG_PREF,      /* Analog then CDMA */
  NV_MODE_ANALOG_ONLY,      /* Analog only */
  NV_MODE_AUTOMATIC,        /* Determine mode automatically */
  NV_MODE_E911,             /* Emergency mode */
  NV_MODE_HOME_ONLY,        /* Restrict to home only */
  NV_MODE_PCS_CDMA_ONLY,    /* Restrict to PCS home only */
  NV_MODE_CELL_CDMA_ONLY,   /* Restrict to cellular home only */
  NV_MODE_CDMA_ONLY,
  NV_MODE_HDR_ONLY,
  NV_MODE_CDMA_AMPS_ONLY,
  NV_MODE_GPS_ONLY,
  NV_MODE_GSM_ONLY,         /* Service is limited to GSM only */
  NV_MODE_WCDMA_ONLY,       /* Service is limited to WCDMA only */
  NV_MODE_ENUM_PAD = 0x7FFF /* Pad to 16 bits on ARM */
} nv_mode_enum_type;

typedef enum cm_mode_pref_e {

    CM_MODE_PREF_NONE=-1,     /* FOR INTERNAL USE OF CM ONLY! */

    /*- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -*/

    /* For compatibility with QXDM database, please do not change the following
       fix assigned values. If new values are added please also update the QXDM
       database */
    CM_MODE_PREF_ANALOG_ONLY=0, /* = NV_MODE_ANALOG_ONLY, */
        /* Service is limited to analog only */

    CM_MODE_PREF_DIGITAL_ONLY=1,/* = NV_MODE_DIGITAL_ONLY, */
        /* Service is limited to digital (CDMA or HDR) only */

    CM_MODE_PREF_AUTOMATIC=2,   /* = NV_MODE_AUTOMATIC, */
        /* Determine the mode automatically from the PRL order */

    CM_MODE_PREF_E911=3,        /* = NV_MODE_E911, */
        /* Emergency mode */

    CM_MODE_PREF_PCS_CDMA_ONLY=4, /* = NV_MODE_PCS_CDMA_ONLY */
        /* PCS mode - obsolete in SD 2.0 (use band preference) */

    CM_MODE_PREF_CELL_CDMA_ONLY=5, /*= NV_MODE_CELL_CDMA_ONLY, */
        /* Cellular mode - obsolete in SD 2.0 (use band preference) */

    /*- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -*/

    /* New for SD 2.0. For compatibility with QPST, do not change values or
    ** order. We start with NV_MODE_CELL_CDMA_ONLY+1 (i.e. 9).
    */
    CM_MODE_PREF_CDMA_ONLY = 9,
        /* Service is limited to CDMA only */

    CM_MODE_PREF_HDR_ONLY=10,
        /* Service is limited to HDR only */

    CM_MODE_PREF_CDMA_AMPS_ONLY=11,
        /* Service is limited to CDMA and AMPS only */

    CM_MODE_PREF_GPS_ONLY=12,
        /* Service is limited to GPS only */

    /*
    ** The following enums are the radio access technologies for
    ** WCDMA and GSM.
    */

    CM_MODE_PREF_GSM_ONLY=13,
        /* Service is limited to GSM only */

    CM_MODE_PREF_WCDMA_ONLY=14,
       /* Service is limited to WCMDA only */

    /*- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -*/

    CM_MODE_PREF_PERSISTENT,
        /* Return to persistent mode preference */

    CM_MODE_PREF_NO_CHANGE,
        /* Do not change the mode preference */

    /*- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -*/

    CM_MODE_PREF_MAX          /* FOR INTERNAL USE OF CM ONLY! */

#ifdef FEATURE_RPC
#error code not present
#endif /* FEATURE_RPC */

} cm_mode_pref_e_type;

// Enumeration of mode terms - i.e designate the mode span. (TBD)
enum SWI_TYPE_Mode_Term
{

	CNS_MODE_TERM_NONE=-1,      /* FOR INTERNAL USE OF CM ONLY! */


	CNS_MODE_TERM_PERMANENT,
	/* Permanent mode change */

	CNS_MODE_TERM_PWR_CYCLE,
	/* Until power cycle */

	CNS_MODE_TERM_1_CALL,
	/* Until end of next call or power-cycle */

	CNS_MODE_TERM_1_CALL_OR_TIME,
	/* Until end of next call, specified timeout or power-cycle */

	CNS_MODE_TERM_CM_1_CALL,
	CNS_MODE_TERM_CM_1_CALL_PLUS,
	CNS_MODE_TERM_CM_MO_SMS,
	/* Mode terms that are assigned automatically by call manager
	** when mode is forced on the fly during a call origination.
	**
	** CM unforce the mode back to it original settings at end of
	** call or some short time after end of call.
	**
	** NOTE! These mode term should NOT be used by clients
	** when changing the mode preference */


	CNS_MODE_TERM_MAX           /* FOR INTERNAL USE OF CM ONLY! */

};

// Enumeration of band preferences.
enum SWI_TYPE_Band_Pref
{
	CNS_BAND_PREF_NONE      = 0,
	/* Acquire no system */
	CNS_BAND_PREF_BC0_A     = 0x01,
	/* Acquire band class 0, A-Side systems only (US Cellular A 800 MHz) */
	CNS_BAND_PREF_BC0_B     = 0x02,
	/* Acquire band class 0, B-Side systems only (US Cellular B 800 MHz) */
	CNS_BAND_PREF_BC0       = 0x03,
	/* Acquire band class 0 systems only (US Cellular A/B 800 MHz) */
	CNS_BAND_PREF_BC1       = 0x04,
	/* Acquire band class 1 systems only (US PCS 1900 MHz) */
	CNS_BAND_PREF_BC3       = 0x10,
	/* Acquire band class 3 systems only (Japanese Cellular 800 MHz) */
	CNS_BAND_PREF_BC4       = 0x20,
	/* Acquire band class 4 systems only (Korean PCS 1800 MHz) */
	CNS_BAND_PREF_BC5       = 0x40,
	/* Acquire band class 5 systems only (450 MHz) */
	CNS_BAND_PREF_BC6       = 0x80,
	/* Acquire band class 6 systems only (IMT2000) */
	CNS_BAND_PREF_ANY       = 0xFFFF,
	/* Acquire any band class systems */
	CNS_BAND_PREF_NO_CHANGE = 0x10000,   
	/* Do not change the band preference */
	CNS_BAND_PREF_MAX

};

// Enumeration of system selection roam preferences.
enum SWI_TYPE_Roam_Pref
{
	CNS_ROAM_PREF_NONE=-1,   /* FOR INTERNAL USE OF CM ONLY! */

	CNS_ROAM_PREF_HOME     = 0x01,
	/* Acquire only systems for which the roaming indication is off */
	CNS_ROAM_PREF_AFFIL    = 0x03,
	/* Acquire only systems for which the roaming indication is off or
	** solid on - i.e. not flashing */
	CNS_ROAM_PREF_ANY      = 0xFF,
	/* Acquire systems regardless of their roaming indication */
	CNS_ROAM_PREF_NO_CHANGE,
	/* Do not change the roam preference */

	CNS_ROAM_PREF_MAX      /* FOR INTERNAL USE OF CM ONLY! */

};

struct SWI_STRUCT_DebugPacket
{
	U32						sizeStruct;						// size of this structure
	U32						nCommandCode;
	U32						nNumberMsg;
	U32						nDroppedMsg;
	U32						nTotalMsg;
	U32						nSeverityLevel;
	WCHAR					szFileName[LENGTH_DebugFileName + 1];
	U32						nLineNumber;
	WCHAR					szFormatString[LENGTH_DebugFormatString + 1];
	U32						nParameter1;
	U32						nParameter2;
	U32						nParameter3;
};

/////////////////////////////////////////////////////////////////////////////////
//
// Name:	SWI_TYPE_DEVICE_DLC - Device DLCI list 
//
// Purpose:	This is the enumeration of device DLCI channels supportred by MUX devices.
//
// Members:	SWI_DEVICE_DLC_ATPPP	- AT/PPP channel
//			SWI_DEVICE_DLC_DM - DM (Diagnostic monitoring) channel
//			SWI_DEVICE_DLC_CNS	- CNS (Control and Status, proprietory SW) Channel
//
// Notes:	None
//
///////////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_DEVICE_DLC 
{
	SWI_DEVICE_DLC_ATPPP	= 1,	// DLC for AT/PPP
	SWI_DEVICE_DLC_DM		= 2,    // DLC for DM
	SWI_DEVICE_DLC_CNS		= 3,	// DLC for CNS
	SWI_DEVICE_DLC_NMEA		= 4,	// DLC for NMEA
};

/////////////////////////////////////////////////////////////////////////////////
//
// Name:	SWI_SUBTYPE_DEVICE - Device type enumeration
//
// Purpose:	This is the enumeration of DLCI device type.
//
// Members:	SWI_DEVICE_MODEM	- Modem device type (For eg.AT/PPP is type modem) 
//			SWI_DEVICE_SERIAL	- Serial device type (For eg.DM is type Serial)
//			SWI_DEVICE_NETWORK	- NDIS device type (For eg.CNS can be type Network)
//
// Notes:	None
//
///////////////////////////////////////////////////////////////////////////////////
enum SWI_SUBTYPE_DEVICE 
{
	SWI_DEVICE_MODEM		= 0,	// Device type Modem
	SWI_DEVICE_SERIAL		= 1,    // Device type Serial
	SWI_DEVICE_NETWORK		= 2,	// device type Network
};

/////////////////////////////////////////////////////////////////////////////////
//
// Name:	SWI_TYPE_USB_DEVICE - USB Device list enumeration
//
// Purpose:	This is the enumeration of USB device list supported by MUX 27.010 drivers.
//
// Members:	SWI_USB_DEVICE_EM56XX	- EM56XX Non-Composite Device 
//			SWI_USB_DEVICE_EM86XX	- EM86XX Non-Composite Device
//			SWI_USB_DEVICE_MC57XX	- MC57XX Non-Composite Device
//
// Notes:	None
//
///////////////////////////////////////////////////////////////////////////////////

enum SWI_TYPE_USB_DEVICE 
{
	SWI_USB_DEVICE_EM56XX		= 0,	// EM56XX Non-Composite Device
	SWI_USB_DEVICE_EM86XX		= 1,    // EM86XX Non-Composite Device
	SWI_USB_DEVICE_MC57XX		= 2,	// EM57XX Non-Composite Device
	SWI_USB_DEVICE_MC5725		= 4,	// MC5725 Non-Composite Device
	SWI_USB_DEVICE_AC595		= 5,	// AC5895 Non-Composite Device
};

/////////////////////////////////////////////////////////////////////////////////
//
// Name:	SWI_DEVICE_STATE - Device mode state - MUX 27.010 driver specifications
//
// Purpose:	This is the enumeration of device state.
//
// Members:	SWI_DEVICE_STATE_UNKNOWN	- Device in unknown modem 
//			SWI_DEVICE_STATE_MUXMODE	- Device in MUX mode
//			SWI_DEVICE_STATE_NONMUX		- Device in Non-MUX mode
//			SWI_DEVICE_STATE_TRANSITION	- Device in transistioning mode
//			SWI_DEVICE_STATE_SYNCMODE	- Device in synchronous mode
//
// Notes:	None
//
///////////////////////////////////////////////////////////////////////////////////
enum SWI_DEVICE_STATE 
{
	SWI_DEVICE_STATE_UNKNOWN,	// Unknown mode
	SWI_DEVICE_STATE_MUXMODE,	// MUX mode
	SWI_DEVICE_STATE_NONMUX,	// Non-MUX mode
	SWI_DEVICE_STATE_TRANSITION,// Transition mode
	SWI_DEVICE_STATE_SYNCMODE	// Synchronizing mode
};

/////////////////////////////////////////////////////////////////////////////////
//
// Name:	SWI_STRUCT_Port_Info - Port and device information
//
// Purpose:	This structure contains DLCI Port requested and also device state information.
//
// Members:	Dlci		- Dlci value of the port. Use this information to query for 
//					Port/Device information. This is set value in the structure.
//					Fill this value in the structure when querying SWI_Get_Port_Info
//					using SwiGetDrvIntInfo().	
//			SubType		- Dlci type if modem or serial or network
//			Acquired	- Notifies if the port is acquired by some other application.
//			ProcessId	- If port is acquired by some one, use processid to determine 
//					who owns the port.
//			ThreadId	- ThreadID of the owned process of the port.
//			State		- Device mode state. DM/CNS/other PPP ports are available only 
//					id device is in MUX mode. Non-MUX mode only AT/PPP port is available.
//			InstanceSuffix	- Suffex of the port index. For eg. if there are multiple devices
//					or ports, devices will have to be appended with the index. (For eg.
//					Friendly name for two modem devices can be Sierra Wireless Modem Device
//					and Sierra Wireless Modem Device #2, 2 is the instance suffix.)
//			Name		- Name of the port. (for eg. Com4 name is \\.\COM4)
//			InstanceId	- Unique identifier of port.
//			FriendlyName	- Friendly name of the device. (See device manager for more info)
//
// Notes:	This structure is valid only for MUX 27.010 supported devices. 
//			Check error codes for more information.
//
///////////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_Port_Info
{
	SWI_TYPE_DEVICE_DLC		Dlci;		// Set only
	SWI_SUBTYPE_DEVICE		SubType;	// Get only

	struct{
		BOOLEAN					Acquired;	// Get only
		// owner
		PHANDLE					ProcessId;	// Get only
		PHANDLE					ThreadId;	// Get only
	} DeviceLock;

	struct{
		BOOLEAN					Acquired;	// Get only
		// owner
		PHANDLE					ProcessId;	// Get only
		PHANDLE					ThreadId;	// Get only
	} PortAcquired;

	SWI_TYPE_USB_DEVICE		DeviceType;	// Get only

	// state	
	SWI_DEVICE_STATE		State;		// Get only
	WCHAR					InstanceSuffix[SWI_SUFFIX_ID_SIZE]; // Get only
	WCHAR					Name[SWI_PORT_NAME_SIZE];	// Get only
	WCHAR					InstanceId[SWI_INSTANCE_ID_SIZE];	// Get only
	WCHAR					FriendlyName[SWI_FRIENDLY_NAME_SIZE];	// Get only
	BOOLEAN					bNDISSupported; // Get only
};

/////////////////////////////////////////////////////////////////////////////////
//
// Name:	SWI_DRV_VER_INFO - MUX driver information
//
// Purpose:	This structure contains MUX driver version information.
//
// Members:	MajorVersion	- Major version number of the MUX driver.	
//			MinorVersion	- Minor Vesion number of the MUX driver.
//			BuildNumber		- Build number of the MUX driver.
//
// Notes:	This structure is valid only for MUX 27.010 supported devices. 
//			Use this structure when querying SWI_Get_Version using SwiGetDrvIntInfo().
//
///////////////////////////////////////////////////////////////////////////////////
struct SWI_DRV_VER_INFO
{
	ULONG		MajorVersion;	// Get only
	ULONG		MinorVersion;	// Get only
	ULONG		BuildNumber;	// Get only
};

/////////////////////////////////////////////////////////////////////////////////
//
// Name:	SWI_TYPE_DRV_INT_Query - SW MUX Drv Interface Query command
//
// Purpose:	This is the enumeration of Query commands to get information from 
//			SW MUX Drviver interface. 
//
// Members:	SWI_Get_Version	- Version Information of the MUX Driver
//			SWI_Get_Port_Info - Port Information for the DLCI value set
//
// Notes:	None
//
///////////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_DRV_INT_Query 
{
	SWI_Get_Version = 1,	// Version Information of the MUX Driver
	SWI_Get_Port_Info,      // Port Information for the DLCI value set
};

/////////////////////////////////////////////////////////////////////////////////
//
// Name:	SWI_DRV_INT_QUERY - Generic structure for querying MUX 27.010 drivers
//
// Purpose:	This structure contains union for driver version and port information.
//			The information is returned based on the query type.
//
// Members:	eQueryType		- Fill in this information to query either Version or 
//							port information.	
//			FileVersion		- Fileversion information returned when SWI_Get_Version 
//							is used as query type.
//			PortInfo		- Port information returned when SWI_Get_Port_Info is 
//							used as query type.
//
// Notes:	This structure is valid only for MUX 27.010 supported devices. 
//			Make sure to set query type before calling SwiGetDrvIntInfo() API.
//			And if query type is SWI_Get_Port_Info, then make sure to set Dlci value 
//			for PortInfo structure.			
//
///////////////////////////////////////////////////////////////////////////////////
struct SWI_DRV_INT_QUERY
{
	SWI_TYPE_DRV_INT_Query eQueryType;
	union {
		SWI_DRV_VER_INFO		FileVersion;
		SWI_STRUCT_Port_Info	PortInfo;
	} uResult;
};

/////////////////////////////////////////////////////////////////////////////////
//
// Name:	SWI_NDIS_PREF_MODE - NDIS PREF Mode supported to get and set values
//
// Purpose:	This is the enumeration of NDIS Pref Mode.
//
// Members:	SWI_NDIS_PREF_ENABLED			- NDIS is enabled 
//			SWI_NDIS_PREF_DISABLED			- NDIS is disabled
//
// Notes:	NDIS when loaded aquires DATA & CNS port to talk to the modem. In some 
//			cases like Async data or fax calls, data call has to go thru DUN using
//			data channel and not over NDIS interface. In order for NDIS to release 
//			handle on data/cns even when NDIS driver is loaded, make use of Pref 
//			mode to disable/enable NDIS.
//
///////////////////////////////////////////////////////////////////////////////////
enum SWI_NDIS_PREF_MODE 
{
	SWI_NDIS_PREF_DISABLED,				// Get and Set
	SWI_NDIS_PREF_ENABLED,				// Get and Set	
};

/////////////////////////////////////////////////////////////////////////////////
//
// Name:	SWI_NDIS_MUX_MODE - Structure for querying MUX NDIS driver mode
//
// Purpose:	This structure contain values to determine NDIS supported and NDIS 
//			Pref mode stored in the modem. These values can be queried to determine
//			the current NDIS mode. 
//
// Members:	bNDISSupported	- This value will determine NDIS is supported for the
//								product or not. 	 
//			eNDISPrefMode	- This value will determine if NDIS is enabled or disabled 
//								This flag will have significance only if NDIS supported
//								flag is set to true.
//
// Notes:	NDIS driver is loaded by USB MUX drivers when NDIS supported and NDIS 
//			Pref mode are both set to true and device is in MUX mode. 			
//
///////////////////////////////////////////////////////////////////////////////////
struct SWI_NDIS_MUX_MODE
{
	BOOLEAN					bNDISSupported;
	SWI_NDIS_PREF_MODE		eNDISPrefMode;
};


/////////////////////////////////////////////////////////////////////////////////
//
// Name:	SWI_EMIOTA_EVENT_TYPE - Evnet type like stat session ,end session 
//
// Purpose:	This is the enumeration of Embedded IOTA event type.
//
// Members:	13 members see below for description
//
// Notes:	
//
///////////////////////////////////////////////////////////////////////////////////
enum SWI_EMIOTA_EVENT_TYPE 
{
	SWI_EMIOTA_SESSION_START,				    // 0:EM IOTA session started
	SWI_EMIOTA_SESSION_END,				      // 1:EM IOTA session end
};


/////////////////////////////////////////////////////////////////////////////////
//
// Name:	SWI_EMIOTA_EVENT_RESULT - Evnet type sucess or failure  
//
// Purpose:	This is the enumeration of Embedded IOTA event type result.
//
// Members:	SWI_EMIOTA_EVENT_RESULT_SUCCESS,				// event successfull
//          SWI_EMIOTA_EVENT_RESULT_FAILURE,				// event failed
//
//
// Notes:	
//
///////////////////////////////////////////////////////////////////////////////////
enum SWI_EMIOTA_EVENT_RESULT 
{
	SWI_EMIOTA_EVENT_RESULT_SUCCESS,				// 0:event successful
	SWI_EMIOTA_EVENT_RESULT_FAILURE,				// 1:event failed	
};



/////////////////////////////////////////////////////////////////////////////////
//
// Name:	SWI_EMIOTA_EVENT_FAIL_REASON - Evnet type failure reason. 
//
// Purpose:	This is the enumeration of Embedded IOTA event type failure reason.
//
// Members:	17 members see below for description
//
// Notes:	
//
///////////////////////////////////////////////////////////////////////////////////

enum SWI_EMIOTA_EVENT_FAIL_REASON 
{
	SWI_EMIOTA_STATUS_MIN = -1,		              // -1:IOTA status min
	SWI_EMIOTA_STATUS_SUCCESS ,		              // 0:IOTA status success
	SWI_EMIOTA_STATUS_ERROR_DISCONNECT,	        // 1:status error disconnect
	SWI_EMIOTA_STATUS_ERROR_NOT_ALLOWED,	      // 2:status error iota session is not allowed
	SWI_EMIOTA_STATUS_ERROR_ALREADY_ACTIVE,	    // 3:status error iota sesstion is already in progress
	SWI_EMIOTA_STATUS_ERROR_CLIENT_ABORT,	      // 4:status error client aborted iota session
	SWI_EMIOTA_STATUS_ERROR_HTTP,	              // 5:status error HTTP
	SWI_EMIOTA_STATUS_ERROR_MIME,	              // 6:status error MIME
	SWI_EMIOTA_STATUS_ERROR_XML,	              // 7:status error XML
	SWI_EMIOTA_STATUS_ERROR_MMC,	              // 8:status error MMC
	SWI_EMIOTA_STATUS_ERROR_NOT_TRUSTED,	      // 9:status error not trusted domain
	SWI_EMIOTA_STATUS_ERROR_SESSION_TIMEOUT,    // 10:status error session timed out
	SWI_EMIOTA_STATUS_ERROR_UNKNOWN,	          // 11:status error unknown
	SWI_EMIOTA_STATUS_ERROR_INTERNAL,	          // 12:status error internal
	SWI_EMIOTA_STATUS_ERROR_NO_SERVICE,	        // 13:status error no service
	SWI_EMIOTA_STATUS_ERROR_ACTIVE_DATA_CALL,	  // 14:status error user is in active data call
	SWI_EMIOTA_STATUS_ERROR_ACTIVE_VOICE_CALL,	// 15:status error user is in active voice call
	SWI_EMIOTA_STATUS_ERROR_NO_DIGITAL_SERVICE,	// 16:status error user is no digital service ( roaming  mode )
	SWI_EMIOTA_STATUS_MAX,	                    // 17:iota status max
};



/////////////////////////////////////////////////////////////////////////////////
//
// Name:	SWI_EMIOTA_EVENT_ERR_CODE - Evnet type failure error code
//
// Purpose:	This is the enumeration of Embedded IOTA event failure error code.
//
// Members:	24 members see below for description
//
// Notes:	
//
///////////////////////////////////////////////////////////////////////////////////

enum SWI_EMIOTA_EVENT_ERR_CODE 
{
	SWI_EMIOTA_ERR_MMC_DISCONNECT,      // 0:Normal Release (MMC "disconnect")
	SWI_EMIOTA_ERR_INVALID_VALREF,	    // 1:MMC_RESULT_INVALID_VALUEREF
	SWI_EMIOTA_ERR_CID_MISSING,				  // 2:MMC_RESULT_CID_MISSING
	SWI_EMIOTA_ERR_DLD_FAILED,	  			// 3:MMC_RESULT_DOWNLOAD_FAILED
	SWI_EMIOTA_ERR_RESERVED,			      // 4:reserved
	SWI_EMIOTA_ERR_INVALID_CONTENT,     // 5:MMC_RESULT_INVALID_CONTENT
	SWI_EMIOTA_ERR_USR_DENIED,		      // 6:MMC_RESULT_USER_DENIED
	SWI_EMIOTA_ERR_BAD_VALUE,		        // 7:MMC_RESULT_BAD_VALUE
	SWI_EMIOTA_ERR_TIMEOUT,             // 8:MMC_RESULT_TIMEOUT
	SWI_EMIOTA_ERR_NONEW_DOC, 			    // 9:MMC_RESULT_NEW_DOC_ARRIVED
	SWI_EMIOTA_ERR_DELETE_FAILED,		    // 10:MMC_RESULT_DELETE_FAILED
	SWI_EMIOTA_ERR_BAD_DATA,			      // 11:MMC_RESULT_BAD_DATA
	SWI_EMIOTA_ERR_DISPLAY_DISABLED,    // 12:MMC_RESULT_DISPLAY_DISABLED
	SWI_EMIOTA_ERR_WRITE_ONLY,		      // 13:MMC_RESULT_WRITE_ONLY
	SWI_EMIOTA_ERR_RESULT_ABORT,	      // 14:MMC_RESULT_ABORT
	SWI_EMIOTA_ERR_RESERVED1,			      // 15:reserved
	SWI_EMIOTA_ERR_BAD_OBJECT,		      // 16:MMC_RESULT_BAD_OBJECT
	SWI_EMIOTA_ERR_UNKNOWN_RESULT,      // 17:MMC_RESULT_UNKNOWN_ERROR
	SWI_EMIOTA_ERR_FILE_LOCKED,		      // 18:MMC_RESULT_FILE_LOCKED
	SWI_EMIOTA_ERR_FILE_OPEN, 		      // 19:MMC_RESULT_FILE_OPEN
	SWI_EMIOTA_ERR_CHECK_FAILED,	      // 20:MMC_RESULT_CHECK_FAILED
	SWI_EMIOTA_ERR_INVALID_SIZE,	      // 21:MMC_RESULT_INVALID_SIZE
	SWI_EMIOTA_ERR_INVALID_OFFSET,      // 22:MMC_RESULT_INVALID_OFFSET
	SWI_EMIOTA_ERR_DEVICE_BUSY,		      // 23:MMC_RESULT_DEVICE_BUSY
	SWI_EMIOTA_ERR_RESERVED2,			      // 24:reserved
	//For HTTP Error - actual HTTP error code so other than these error actual http
	// errror codes should be captured
};


//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_STRUCT_IOTA_State - Embedded ITOA notification data structure
//
// Purpose:     This data structure is used as a member of the notification
//				SWI_NOTIFY_IOTA_Status.  Refer to the description of
//				SWI_NOTIFY_IOTA_Status for more detail.
//
// Members:  	sizeStruct					- size of this structure
//				State						- Power state.  See
//											  SWIHW_TYPE_Power for details.
//
//
//////////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_IOTA_State
{
	U32			sizeStruct;					      // size of this structure
	U16			iEvent;						        // event type see SWI_EMIOTA_EVENT_TYPE for details
	U16			iEventStatus;						  // event success or failure see SWI_EMIOTA_EVENT_RESULT for details
	U16			iSessionEndFailureReason;	// Session end failure reason (future support) see SWI_EMIOTA_EVENT_FAIL_REASON for details
	U16			iSessionEndErrorCode;			// Session end error code (depends on Param 3 Session 
	//end failure reason) (future support) see SWI_EMIOTA_EVENT_ERR_CODE for details
	//For HTTP Error - actual HTTP error code MMC error //code see above

};


//////////////////////////////////////////////////////////////////////////////////
//
// Name:        SWI_STRUCT_IOTA_WAPPush - Embedded IOTA WAP URI notification data structure
//
// Purpose:     This data structure is used as a member of the notification
//				SWI_NOTIFY_IOTA_WAPPush.  Refer to the description of
//				SWI_NOTIFY_IOTA_WAPPush for more detail.
//
// Members:  	sizeStruct		- size of this structure
//				    szUri					- null terminated string contain the wap trigger.
//
//
//////////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_IOTA_WAPPush
{
	U32			sizeStruct;					// size of this structure
	U8 	    szWAPUri[128]; 	//null terminated URI contains wap trigger
};

struct SWI_STRUCT_MeidEsn
{
	U32						sizeStruct;     //size of this structure
	U16						nMeidEnabled;	// TRUE - MEID/pESN is used in the modem; FALSE - tESN is used in the modem
	U16						nMeidPresent;	// TRUE - MEID provisioned in the modem; FALSE - MEID has never been written
	U32						nMeidHigh;		// (high word of qword) 56 bits of MEID if MEID is provisioned; otherwise, all 0's
	U32						nMeidLow;		// (low word of qword) 56 bits of MEID if MEID is provisioned; otherwise, all 0's
	U32						nPEsn;			// 32 bits of pESN if MEID  is provisioned; otherwise, all 0's
	U16						nTEsnPresent;	// TRUE - tESN provisioned in the modem; FALSE - tESN has never been written
	U32						nEsn;			// 32 bits of tESN if tESN provisioned; otherwise, all 0's
};

typedef void (*SWAP_FUNCTION_TYPE)(U8*);

//typedef void (*SWI_FUNCTION_NOTIFY)(U8*, SwiNotifyVariant&);

#endif //__SWI_STRUCTS_CDMA_H
