///////////////////////////////////////////////////////////////////////////////
//                                                                              
//	$Revision: 49 $																
//																				
//	Name       : SwiStructsCm.h		                                        	
//                                                                              
//	Purpose    : Enumerated types and structures which are common to all		
//				 technologies.													
//					                                                            
//	Copyright (c) 2007 Sierra Wireless, Inc.  All rights reserved			    
//                                                                              
///////////////////////////////////////////////////////////////////////////////

#ifndef __SWI_STRUCTS_CM_H__
#define __SWI_STRUCTS_CM_H__

#include "SwiDatatypes.h"
#include "SwiStructsGsm.h"
#include "SwiStructsCdma.h"
#include "SwiStructsMp.h"

// constants
#define LENGTH_MaxPPPString			33
//#define LENGTH_DebugFileName		13
//#define LENGTH_IPAddress			16

#define LENGTH_UsbdVersion			85
#define LENGTH_UsbdBuildDate		9
#define LENGTH_BootBuildDate		9
#define NUMVALUE_WIMAX				80216
#define LENGTH_DriverName			100
	

#define LENGTH_TimeStamp			16
#define MAX_BAND_GROUPS				25
#define MAX_BAND_LIST				25 
#define LENGTH_MSIN					10

///////////////////////////////////////////////////////////////////////////////
//
//	API Management 
//
///////////////////////////////////////////////////////////////////////////////

#define MAX_AIR_SERVERS             50	/*!< Maximum number of air servers */
#define LENGTH_MacAddress			6	/*!< Maximum MAC address length */
#define LENGTH_ProductName			20	/*!< Maximum product name length */
#define LENGTH_ModemName			75	/*!< Maximum modem name length */
#define LENGTH_HardwareId			50	/*!< Maximum hardware ID length */
#define LENGTH_ProductString		15	/*!< Maximum product string length 
											 as returned by device information 
											 response */
#define LENGTH_CweHeaderProductType	5	/*!< Maximum CWE header product type
											 string length as returned by
											 device information response */

///////////////////////////////////////////////////////////////////////////////
///
/// An enumeration of supported device types.
///
///	Includes both GSM and CDMA PC cards, embedded devices, and MP line
///	of products.
///
///	\sa	SWI_STRUCT_AirServer
///	\sa See sample code, ConnectApi
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_Device
{
	SWI_DEVICE_None		= 0,	/*!< Unsupported device */
	// PC Cards
	SWI_DEVICE_AC550,			/*!< AirCard 550 (CDMA) */
	SWI_DEVICE_AC575,			/*!< AirCard 575 (CDMA) */
	SWI_DEVICE_AC580,			/*!< AirCard 580 (CDMA) */
	SWI_DEVICE_AC595,			/*!< AirCard 595 (CDMA) */
	SWI_DEVICE_AC597,			/*!< AirCard 597 (CDMA) */
	SWI_DEVICE_AC710	= 100,	/*!< AirCard 710 (GSM) */
	SWI_DEVICE_AC750,			/*!< AirCard 755 (GSM) */
	SWI_DEVICE_AC775,			/*!< AirCard 775 (GSM) */
	SWI_DEVICE_AC850,			/*!< AirCard 850 (GSM) */
	SWI_DEVICE_AC860,			/*!< AirCard 860 (GSM) */
	SWI_DEVICE_AC875,			/*!< AirCard 875 (GSM) */
	SWI_DEVICE_AC880,			/*!< AirCard 880 (GSM) */
	SWI_DEVICE_AC881,			/*!< AirCard 881 (GSM) */
	// Embedded Modules
	SWI_DEVICE_MC5720	= 200,	/*!< MC5720 (CDMA) */
	SWI_DEVICE_MC5725,			/*!< MC5725 (CDMA) */
	SWI_DEVICE_MC5727,			/*!< MC5727 (CDMA) */
	SWI_DEVICE_MC5728,			/*!< MC5728 (CDMA) */
	SWI_DEVICE_MC8755	= 300,	/*!< MC8775 (GSM) */
	SWI_DEVICE_MC8765,			/*!< MC8765 (GSM) */
	SWI_DEVICE_MC8775,			/*!< MC8775 (GSM) */
	SWI_DEVICE_MC8780,			/*!< MC8780 (GSM) */
	SWI_DEVICE_MC8781,			/*!< MC8781 (GSM) */
	SWI_DEVICE_MC8785,			/*!< MC8785 (GSM) */
	SWI_DEVICE_MC8790,			/*!< MC8790 (GSM) */
	SWI_DEVICE_MC8791,			/*!< MC8791 (GSM) */
	SWI_DEVICE_EM5625	= 400,	/*!< EM5625 (CDMA) */
	SWI_DEVICE_EM5725,			/*!< EM5725 (CDMA) */
	SWI_DEVICE_EM8780	= 500,	/*!< EM8780 (GSM) */
	SWI_DEVICE_EM8781,			/*!< EM8781 (GSM) */
	SWI_DEVICE_M81A,			/*!< M81A (GSM) */
	SWI_DEVICE_M81B,			/*!< M81B (GSM) */
	// MP
	SWI_DEVICE_MP555	= 600,	/*!< MP555 (CDMA) */
	SWI_DEVICE_MP595,			/*!< MP595 (CDMA) */
	SWI_DEVICE_MP750	= 700,	/*!< MP750 (GSM) */
	SWI_DEVICE_MP775,			/*!< MP775 (GSM) */
	SWI_DEVICE_MP875,			/*!< MP875 (GSM) */
	SWI_DEVICE_MP880,			/*!< MP880 (GSM) */
	SWI_DEVICE_MP881,			/*!< MP881 (GSM) */
	// ExpressCards
	SWI_DEVICE_AC597E	= 1000, /*!< AirCard 595E (CDMA) */
	SWI_DEVICE_AC598E,			/*!< AirCard 598E (CDMA) */
	SWI_DEVICE_AC875E	= 1100,	/*!< AirCard 875E (GSM) */
	SWI_DEVICE_AC880E,			/*!< AirCard 880E (GSM) */
	SWI_DEVICE_AC881E,			/*!< AirCard 881E (GSM) */
	SWI_DEVICE_AC885E,			/*!< AirCard 885E (GSM) */
	SWI_DEVICE_AC886E,			/*!< AirCard 886E (GSM) */
	// USB Modems
	SWI_DEVICE_AC595U	= 1200, /*!< AirCard 595U (CDMA) */
	SWI_DEVICE_COMPASS597,		/*!< Compass 598 (CDMA) */
	SWI_DEVICE_USB598,			/*!< Tiger 598 (CDMA) */
	SWI_DEVICE_USB11,			/*!< Tiger 11 (CDMA) */
	SWI_DEVICE_AC875U	= 1300, /*!< AirCard 875U (GSM) */
	SWI_DEVICE_AC880U,			/*!< AirCard 880U (GSM) */
	SWI_DEVICE_AC881U,			/*!< AirCard 881U (GSM) */
	SWI_DEVICE_C885,			/*!< Compass 885 (GSM) */
	SWI_DEVICE_C886,			/*!< Compass 886 (GSM) */
	SWI_DEVICE_C888,			/*!< Compass 888 (GSM) */
	SWI_DEVICE_C889,			/*!< Compass 889 (GSM) */
	SWI_DEVICE_K888,			/*!< Karbon 888 (GSM) */
	SWI_DEVICE_K889,			/*!< Karbon 889 (GSM) */
	SWI_DEVICE_C22,				/*!< Compass 22 (GSM) */
	SWI_DEVICE_C23,				/*!< Compass 33 (GSM) */
	SWI_DEVICE_K22,				/*!< Karbon 22 (GSM) */
	SWI_DEVICE_K23,				/*!< Karbon 23 (GSM) */
	SWI_DEVICE_USB303,			/*!< USB 303 (GSM) */
	SWI_DEVICE_USB304,			/*!< USB 304 (GSM) */
	SWI_DEVICE_USB305,			/*!< USB 305 (GSM) */
	SWI_DEVICE_USB306,			/*!< USB 306 (GSM) */
	SWI_DEVICE_CHspa	= 1399,	/*!< Compass HSPA (GSM) */
	// Mass Storage
	SWI_DEVICE_MassStorage	= 2000,	/*!< Mass storage device */
};

///////////////////////////////////////////////////////////////////////////////
///
///	An enumeration of wireless mobile technologies
///
///	Wireless technologies including CDMA and GSM
///
///	\sa	SWI_STRUCT_AirServerExtended
///	\sa	See sample code, ConnectApi
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_WirelessTech
{
	SWI_WIRELESSTECH_Unknown,
	SWI_WIRELESSTECH_Cdma,
	SWI_WIRELESSTECH_Gsm,
	SWI_WIRELESSTECH_Wifi,
	SWI_WIRELESSTECH_Wimax,
};

///////////////////////////////////////////////////////////////////////////////
///
///	An enumeration of product classes
///
///	Product classes are broken into the following categories PC Cards 
///	(PCMCIA, express cards, USB), embedded modules (MC, EM, M81), and MP.
///
///	Supports PC cards, embedded devices, and MP line of products. 
///
///	\sa	SWI_STRUCT_AirServerExtended
///	\sa	See sample code, ConnectApi
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_ProductClass
{
	SWI_PRODUCTCLASS_Unknown,
	SWI_PRODUCTCLASS_PcCard,
	SWI_PRODUCTCLASS_Embedded,
	SWI_PRODUCTCLASS_Mp,
};

///////////////////////////////////////////////////////////////////////////////
///
/// This structure contains basic air server information.
///
///	This structure is used by ::SwiGetAvailAirServers to return the list
///	of available air servers (devices) on the system.  Similarly,
///	::SwiSelectAirServer uses this structure to bind to an air server.
///	::SWI_NOTIFY_AirServerChange uses this structure to signal the 
/// availability of an air server.
///
///	Supports both GSM and CDMA PC cards, embedded devices, and MP line
///	of products. 
///
///	\sa SWI_TYPE_Device
///	\sa SWI_NOTIFY_AirServerChange
///	\sa SwiGetAvailAirServers
///	\sa SwiSelectAirServer
///	\sa	See sample code, ConnectApi
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_AirServer
{
	/*! The size, in bytes, of this structure.  This value must always be 
		populated by the calling application. */
	U32	sizeStruct;		

	/*! MAC address of local adapter through which we access the air server.
		This field mainly applies to MP devices.  When calling 
		::SwiSelectAirServer, simply provide the value returned from 
		::SwiGetAvailAirServers or ::SWI_NOTIFY_AirServerChange.*/
	U8	ClientMac[LENGTH_MacAddress];	

	/*!	MAC address of the air server.  When calling ::SwiSelectAirServer,
		simply provide the value returned from ::SwiGetAvailAirServers
		or ::SWI_NOTIFY_AirServerChange.*/
	U8	ServerMac[LENGTH_MacAddress];	

	/*!	Device of interest.	*/
	SWI_TYPE_Device	eDevice;	
};

///////////////////////////////////////////////////////////////////////////////
///
///	This structure contains extended air server information
///
///	This structure is used by ::SwiGetAirServerInfo to retrieve additional
///	information about a particular air server.
///
///	Supports both GSM and CDMA PC cards, embedded devices, and MP line
///	of products.
///
/// See Also
///
///	\sa	SWI_TYPE_ProductClass
///	\sa	SWI_TYPE_WirelessTech
///	\sa	SwiGetAirServerInfo
///	\sa See sample code, ConnectApi
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_AirServerExtended
{
	/*! The size, in bytes, of this structure.  This value must always be
		populated by the calling application. */
	U32	sizeStruct;

	/*! A NULL terminated string which contains the Sierra Wireless product
		name.  Length of value is restricted to LENGTH_ProductName. */
	WCHAR szProductName[LENGTH_ProductName];

	/*!	A Product class enumeration.  See ::SWI_TYPE_ProductClass for list
		of possible values. */
	SWI_TYPE_ProductClass	eProductClass;

	/*! A Mobile wireless technology enumeration.  See ::SWI_TYPE_WirelessTech 
		for list of possible values. */
	SWI_TYPE_WirelessTech eWirelessTech;
		
	/*! A NULL terminated string which contains the friendly dial-up modem 
		name.  This is the same value listed under Device Manager->Modems. */	
	WCHAR szModemName[LENGTH_ModemName];
	
	/*! A NULL terminated string which contains the hardware ID of the
		network adapter interface. */
	WCHAR szHardwareId[LENGTH_HardwareId];

	/*! Bitmask indicating available interfaces/functionality:
		- 0x0000: Unknown. There are conflicting SDK components running which 
				  is preventing the retrieval of this information.  This 
				  should be treated as a success condition.
		- 0x0001: This bit is set if control & status interface is available.  
				  This indicates communication with the air server is possible.
		- 0x0002: This bit is set if the NDIS interface is available.  This 
				  interface is required to create a data connection.
		- 0x0004: This bit is set if the Modem interface is available.  This
				  interface is required to create a dial-up connection. */
	UINT nInterfaceAvail;
};

///////////////////////////////////////////////////////////////////////////////
///
/// Creates a mac address corresponding to "no" mac on-the-fly.
/// Call this macro and then you can use the variable MacNone for 
/// mac comparisons etc...
///////////////////////////////////////////////////////////////////////////////
#define DECLARE_MacNone \
	U8 MacNone[] = {0x00, 0x00, 0x00, 0x00, 0x00, 0x00}

///////////////////////////////////////////////////////////////////////////////
///
/// Creates a mac address corresponding to the broadcast, or wild card,
/// mac on-the-fly.
/// Call this macro and then you can use the variable MacAny for 
/// mac comparisons etc...
/// 
///////////////////////////////////////////////////////////////////////////////
#define DECLARE_MacAny \
	U8 MacAny[] = {0xff, 0xff, 0xff, 0xff, 0xff, 0xff}

///////////////////////////////////////////////////////////////////////////////
///
/// Creates a mac address corresponding to the VSP adapter mac on-the-fly.
/// Call this macro and then you can use the variable MacVspAdapter for 
/// mac comparisons etc..
/// 
///////////////////////////////////////////////////////////////////////////////
#define DECLARE_MacVspAdapter \
	U8 MacVspAdapter[] = {0x00, 0x00, 0x00, 0x00, 0x00, 0x01}

///////////////////////////////////////////////////////////////////////////////
///
/// Creates a mac address corresponding to the VSP air server mac on-the-fly.
/// Call this macro and then you can use the variable MacVspAirServer for 
/// mac comparisons etc..
/// 
///////////////////////////////////////////////////////////////////////////////
#define DECLARE_MacVspAirServer \
	U8 MacVspAirServer[] = {0x00, 0x00, 0x00, 0x00, 0x00, 0x02}


///////////////////////////////////////////////////////////////////////////////
///
/// Useful MACRO to initialize an empty air server structure called 
/// AirServerNone.
/// 
///////////////////////////////////////////////////////////////////////////////
#define DECLARE_AirServerNone \
	DECLARE_MacNone; \
	SWI_STRUCT_AirServer AirServerNone; \
	AirServerNone.eDevice = SWI_DEVICE_None; \
	memcpy(AirServerNone.ClientMac, MacNone, LENGTH_MacAddress); \
	memcpy(AirServerNone.ServerMac, MacNone, LENGTH_MacAddress); \
	AirServerNone.sizeStruct = sizeof(SWI_STRUCT_AirServer)

///////////////////////////////////////////////////////////////////////////////
///
/// Returns true if air servers are identical.
/// 
///////////////////////////////////////////////////////////////////////////////
#define COMPARE_AIR_SERVER(pA,pB) \
	( \
	(pA)->eDevice == (pB)->eDevice && \
	!memcmp((pA)->ClientMac, (pB)->ClientMac, LENGTH_MacAddress) && \
	!memcmp((pA)->ServerMac, (pB)->ServerMac, LENGTH_MacAddress) \
	)

///////////////////////////////////////////////////////////////////////////////
///
///	This structure contains the number of available air servers.  It also
///	lists the available air servers.
///
///	Supports both GSM and CDMA PC cards, embedded devices, and MP line
///	of products. 
///
///	\sa	SWI_TYPE_ProductClass
///	\sa	SWI_TYPE_WirelessTech
///	\sa	SwiGetAirServerInfo
///	\sa	See sample code, ConnectApi
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_AirServerList
{
	/*! The size, in bytes, of this structure.  This value must always be
		populated by the calling application. */
	U32	sizeStruct;

	/*!	The number of available air servers ranging from 0 to 
		MAX_AIR_SERVERS. */
	U32	nNumber; 
	
	/*!	A list of available air servers.  Only valid if nNumber is greater
		than 0.  The array of SWI_STRUCT_AirServer structures is populated
		beginning with index 0 up to index nNumber-1 sequentially. */
	SWI_STRUCT_AirServer	AirServers[MAX_AIR_SERVERS];
};

#define LENGTH_LogFileName		128		/*!< Maximum log file name */

///////////////////////////////////////////////////////////////////////////////
///
/// This structure contains logging information. 
///
///	For processes running in Session 0, log files are created under
///	%PROGRAMDATA% (Vista and newer).  Otherwise, logs are created under
///	%APPDATA% (if defined) or %ALLUSERSPROFILE%.
///
///	To enable advanced logging, apply the SwiApiX_Advanced.reg registry
///	file provided in the SDK.  This will allow the capture of detailed
///	control and status information exchanged between the host application
///	and the modem.
///
///	Supports both GSM and CDMA PC cards, embedded devices, and MP line
///	of products. 
///
/// \sa	SWI_STRUCT_ApiStartup
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_Logging
{
	/*!	The size, in bytes, of this structure.  This value must always be
		populated by the calling application. */
	U32	sizeStruct;

	/*! A NULL terminated string which contains the log file name.  DO
		NOT include the path.  See "Notes" for location of log files. */
	WCHAR szFileName[LENGTH_LogFileName];

	/*! Set to true to enable API logging, false to disable API logging. */
	bool bEnable;
};

///////////////////////////////////////////////////////////////////////////////
///
///	This structure is used as input for ::SwiApiStartup and contains
///	information needed to configure the API.
///	
///	Supports both GSM and CDMA PC cards, embedded devices, and MP line
///	of products.
///
///	\sa	SwiApiStartup
///	\sa	See sample code, ConnectApi
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_ApiStartup
{
	/*!	The size, in bytes, of this structure.  This value should always be
		populated by the calling application. */
	U32	sizeStruct;

	/*!	Parameters used to enable SwiApiInterface logging.  See
		SWI_STRUCT_Logging for additional information. */
	SWI_STRUCT_Logging sLogging;
};

///////////////////////////////////////////////////////////////////////////////
///
///	This structure is used by the ::SWI_NOTIFY_AirServerChange notification
///	to signal the arrival or removal of an air server.
///
/// When an air server becomes unavailable, any pending requests will be
/// canceled with a return code of ::SWI_RCODE_CANCEL.  Any modem commands
/// made after this event will fail with a ::SWI_RCODE_DEVICE_UNAVAIL return
/// code.  When the air server becomes available again, SwiSelectAirServer
/// must be called to re-bind to the air server before any modem commands
/// can be made.
///
///	This object supports both GSM and CDMA technologies for PC cards, embedded
/// devices, and MP line of products.
///
///	\sa	SWI_NOTIFY_AirServerChange
/// \sa SWI_RCODE_CANCEL
/// \sa SWI_RCODE_DEVICE_UNAVAIL
///	\sa	See sample code, DeviceChange
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_AirServerChange
{
	/*!	The size, in bytes, of this structure. */
	U32	sizeStruct;	

	/*! A structure of type SWI_STRUCT_AirServer containing information
		about the air server of interest. */
	SWI_STRUCT_AirServer AirServer;

	/*!	True is returned if the air server has become available or false if 
		the air server has become unavailable.  */
	bool bInsert;		

	/*! Bitmask indicating available interfaces/functionality:
		- 0x0000: Unknown. There are conflicting SDK components running which 
				  is preventing the retrieval of this information.  This 
				  should be treated as a success condition.
		- 0x0001: This bit is set if control & status interface is available.  
				  This indicates communication with the air server is possible.
		- 0x0002: This bit is set if the NDIS interface is available.  This 
				  interface is required to create a data connection.
		- 0x0004: This bit is set if the Modem interface is available.  This
				  interface is required to create a dial-up connection. */
	UINT nInterfaceAvail;           
};

///////////////////////////////////////////////////////////////////////////////
///
///	This enumerates services that could be locked for exclusive use.
///
///	This object supports both GSM and CDMA technologies for PC cards, embedded
/// devices, and MP line of products.
///
///	\sa	SWI_NOTIFY_AirServerChange
///	\sa	See sample code, DeviceChange
///
///////////////////////////////////////////////////////////////////////////////
typedef enum
{
	LOCKSERV_All,		/*!< All features and services */
	LOCKSERV_Sms,		/*!< SMS features (currently not supported) */
	LOCKSERV_Phonebook,	/*!< Phonebook features (currently not supported) */
} SWI_TYPE_LockServ;

///////////////////////////////////////////////////////////////////////////////
///
/// This structure is used by the ::SWI_NOTIFY_LockAirServer notification to
/// present the lock status of an air server.
///
/// When an air server becomes locked, any pending requests will be canceled 
/// with a return code of ::SWI_RCODE_CANCEL.  Any modem commands made after this
/// event will fail with a ::SWI_RCODE_DEVICE_LOCKED return code.  
///
/// Locking of the air server is done by high priority tasks where exclusive 
/// access to the air server is crucial in order to prevent errors.  An example
/// of such a task is a firmware upgrade process.  Client applications will be
/// notified with a ::SWI_NOTIFY_LockAirServer notification when these high 
/// priority tasks complete and the air server is once again available for use.
/// Note that SwiSelectAirServer DOES NOT have to be called to re-bind to the
/// air server.  Client applications should not tamper with (remove power or 
/// reset, etc) the air server while the air server is in a locked state.
///
/// The SDK will automatically unlock an air server if the application, which
/// has previously locked the air server for exclusive use, loses communication
/// with the SDK (perhaps due to the application crashing).
/// 
/// Multiple client access is exclusively handled by the SDK.  The modem 
/// themselves are not designed for simultaneous access by multiple clients.  
/// Therefore, interfacing with the modem outside of the SDK (AT commands) is 
/// not recommended (especially when the air server is locked).
///
///	This object supports both GSM and CDMA technologies for PC cards, embedded
/// devices, and MP line of products.
///
///	\sa	SWI_NOTIFY_LockAirServer
/// \sa SWI_RCODE_CANCEL
/// \sa SWI_RCODE_DEVICE_LOCKED
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_LockAirServer
{
	/*!	The size, in bytes, of this structure. */
	U32 sizeStruct;	

	/*!	A structure of type SWI_STRUCT_AirServer containing information
		about the air server of interest. */
	SWI_STRUCT_AirServer AirServer;
	
	/*!	A SWI_TYPE_LockServ enumeration of the feature/service of interest */
	SWI_TYPE_LockServ eService;

	/*!	True is returned if the service of interest is locked for exclusive use
		by another application.  A value of false indicates the air server is 
		no longer locked and is available for use.  */
	bool bLocked;
};

///////////////////////////////////////////////////////////////////////////////
///
/// An enumeration of firmware download states.  
///
/// Supports all GSM devices.  CDMA MPs are also supported, other CDMA
///	devices are not supported.
///
///	\sa	SWI_STRUCT_FwDownload
///	\sa	SWI_NOTIFY_FwDownload
///
///////////////////////////////////////////////////////////////////////////////
typedef enum
{		
	/*! Initializing and opening the specified image file to download.	*/
	FW_INIT,
		
	/*! Initializing error occurred. */
	FW_INIT_ERR,
	
	/*! Resetting the modem. */
	FW_SOFT_RESET,
	
	/*! Timeout expired.  Failed to detect the modem after a reset. */
	FW_SOFT_RESET_ERR,

	/*!	Sending the Start Firmware Download request. */
	FW_START_REQ,
	
	/*! A Firmware Download Start request error has occurred.  Possible 
		errors include:
			-# A firmware download is already in progress.  
			-# Failed to read from the firmware image file
			-# The modem rejected the Firmware Download Start request.
		Call SwiGetLastError to get additional information of the error. */
	FW_START_REQ_ERR,
	
	/*! Error reading from firmware file. */
	FW_FILE_ERR,
	
	/*! Firmware download packets being sent. */
	FW_DWN,
	
	/*! A error occurred during a Firmware Download Continuation request.
		Possible errors include:
			-# Timeout waiting for response from modem.
			-# Failed to read from the firmware image file. */
	FW_DWN_ERR,
	
	/*! Calculating the check sum. */
	FW_CHKSUM,
	
	/*! Modem rejected the check sum value.  Possible causes:
			-# Firmware image may be corrupt.
			-# Loss of packet during the firmware download process. */
	FW_CHKSUM_ERR,
	
	/*! Sending the Program Flash request (Application image only) */
	FW_FLASH,
	
	/*! An error has occurred while sending the Program Flash request. */
	FW_FLASH_ERR,
	
	/*! Sending the Launch Fragment request (for all firmware image types
		except Application images). */
	FW_LAUNCH_FRAG,
	
	/*!	An error has occurred while sending the Launch Fragment request. */
	FW_LAUNCH_FRAG_ERR,
			
	/*!	Modem performing a reset. */
	FW_RESET,
	
	/*!	Firmware reset error occurred.  The API was unable to detect the
		modem within a predefined timeout period after the modem reset. */
	FW_RESET_ERR,
			
	/*!	Firmware download complete. */
	FW_DONE
} SWI_NOTIF_FW_TYPE;

///////////////////////////////////////////////////////////////////////////////
///
/// Enumerates firmware image types.
///
///	Supports all GSM devices.  CDMA MPs are also supported, other CDMA
///	devices are not supported.
///
/// \sa SWI_STRUCT_FlashImgInfo
///	\sa	SwiFirmwareDownload
///
///////////////////////////////////////////////////////////////////////////////
typedef enum
{
	FW_DWN_APPL,	/*!< Firmware application image */
	FW_DWN_BOOT,	/*!< Firmware bootloader image */
	FW_DWN_QCOM,	/*!< Qualcomm bootloader image */
	FW_DWN_USBD,	/*!< USB device descriptor image */
	FW_DWN_EXEC,	/*!< Firmware executable image */
	FW_DWN_SWOC,	/*!< Software on card image */
} SWI_TYPE_FW_IMAGE;

///////////////////////////////////////////////////////////////////////////////
///
/// This structure is used to notify firmware download states.
///
///	Supports all GSM devices.  CDMA MPs are also supported, other CDMA
///	devices are not supported.
///
///	\sa	SWI_NOTIF_FW_TYPE
///	\sa	SWI_NOTIFY_FwDownload
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_FwDownload
{
	/*!	The size, in bytes, of this structure.  This value should always be
		populated by the calling application. */
	U32	sizeStruct;
		
	/*!	Firmware download state.  See SWI_NOTIF_FW_TYPE for additional
		information. */	
	SWI_NOTIF_FW_TYPE State;						
};

///////////////////////////////////////////////////////////////////////////////
///
/// This data structure is used as a member of the SWI_NOTIFY_Reset
///	notification and currently contains no data.
///
///	Supports both GSM and CDMA PC cards, embedded devices, and MP line
///	of products.
///
///	\sa	SWI_NOTIFY_Reset
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_Reset
{
	U32	sizeStruct; /*!< The size, in bytes, of this structure. */
	// No other data members
};

///////////////////////////////////////////////////////////////////////////////
///
/// This structure is used by the SWI_NOTIFY_HeartBeat notification.
///
///	Supports both GSM and CDMA PC cards, embedded devices, and MP line
///	of products.
///
///	\sa	SWI_NOTIFY_HeartBeat
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_HeartBeat
{
	U32	sizeStruct;		/*!< The size, in bytes, of this structure. */	
	// No other data members
};

///////////////////////////////////////////////////////////////////////////////
///
/// This structure is used by the SWI_NOTIFY_HeadsetIcon notification.
///
///	Supports both GSM and CDMA PC cards, embedded devices, and MP line
///	of products.
///
///	\sa	SWI_NOTIFY_HeadsetIcon
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_HeadsetIcon
{
	/*! The size, in bytes, of this structure. */
	U32 sizeStruct;		
	
	/*! Object version number (ignore) */
	U32 nVersion;   
	
	/*! Boolean where if headset is connected, a value of true is returned.
		False is returned if headset is not connected.   */
	bool bHeadsetIcon;
};

///////////////////////////////////////////////////////////////////////////////
///
/// A bit mask which indicates the reason for modem power off state.  Only 
/// available to power notification (and only make sense in RF power off case)
///
///	This is only used in SWI_STRUCT_Power which is sent as a notification
///	(SWI_NOTIFY_Power).
///
///	Only CDMA devices supported.
///
///	\sa	SWI_STRUCT_Power
///	\sa	SWI_NOTIFY_Power
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_RFPOWEROFF_Mask
{
	/*!	Hardware failure (unknown reason - 0x00000001) */
	SWI_RFPOWEROFF_HW_Reason = 0x00000001,
	
	/*!	UI reason (UI initiated - 0x00000002) */
	SWI_RFPOWEROFF_UI_Reason = 0x00000002,

	/*! Temperature reason (too hot or too cold - 0x00000004) */
    SWI_RFPOWEROFF_Temperature_Reason = 0x00000004,
    
	/*!	Voltage reason (too high or low voltage - 0x00000008) */
	SWI_RFPOWEROFF_Voltage_Reason = 0x00000008
};

///////////////////////////////////////////////////////////////////////////////
///
/// This data structure is used as a member of the SWI_NOTIFY_Power
/// notification to signal a power state change.
///
/// Power state is not supported on the SB555.  
///
///	GSM products primarily used this structure for indicating when a device
///	has become unavailable.  However, SWI_NOTIFY_Power is only 
///	available in the R4 SDK.  SWI_NOTIFY_AirServerChange should now be used
///	for the monitoring of device availability for all products.
///
///	\sa	SWI_TYPE_RFPOWEROFF_Mask
///	\sa	SWI_NOTIFY_Power
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_Power
{
	/*! The size, in bytes, of this structure. */
	U32	sizeStruct;	
		
	/*! Current power state enumeration.  See SWI_TYPE_Power for details. */
	SWI_TYPE_Power State;	
	
	/*!	Power change reason code mask.  See SWI_TYPE_RFPOWEROFF_Mask for
		details. */	
	SWI_TYPE_RFPOWEROFF_Mask PowerOffReason;	
};

///////////////////////////////////////////////////////////////////////////////
///
/// Enumerate of DHCP actions
///
/// Currently not supported in any product.
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_Dhcp
{
	SWI_TYPE_DhcpRenew,		/*!< Renew IP address request */							
	SWI_TYPE_DhcpRelease,	/*!< Release IP address request */								
};

///////////////////////////////////////////////////////////////////////////////
///
/// This data structure is used as a member of the notification 
/// SWI_NOTIFY_Dhcp.
///
///	Currently not supported in any product.
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_Dhcp
{
	/*!	The size, in bytes, of this structure. */
	U32 sizeStruct;		

	/*!	Request type enumeration.  See SWI_TYPE_Dhcp for more details. */
	SWI_TYPE_Dhcp Request;					
};

///////////////////////////////////////////////////////////////////////////////
///
/// Defines the PPP states available from the NDIS driver
///
/// PPP State is not supported on the SB555.
///
/// PPP States are particularly useful as sub-states for the 
///	SWI_NOTIFY_CallConnected state during a data (NDIS) call.
///
///	Only CDMA devices supported.
///
///	\sa	SWI_STRUCT_PPP
///	\sa	SWI_NOTIFY_PPP
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_PPP
{
	/*!	LCP connection to network has been started. */
	SWI_TYPE_PPPEstablish = 0x04,	 
	
	/*!	Connection to network is being authenticated. */
	SWI_TYPE_PPPAuthenticate = 0x05,	
	
	/*! IPCP connection to network has started. */
	SWI_TYPE_PPPNetwork	= 0x07,	 
	
	/*!	Connection to network ready for traffic.  This state does not imply
		that a valid IP Address has been obtained. */
	SWI_TYPE_Running = 0x08,	
	
	/*!	Connection to network ended. */  
	SWI_TYPE_Terminate = 0x09,	  
};

///////////////////////////////////////////////////////////////////////////////
///
/// This data structure is used as a member of the notification SWI_NOTIFY_PPP. 
///
/// PPP state is not supported on the SB555.
///
///	Used primarily for detecting power off state (i.e. card ejection).
///	Other states may not be reported correctly.
///
///	Only CDMA devices supported.
///
///	\sa	SWI_TYPE_PPP
///	\sa	SWI_NOTIFY_PPP
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_PPP
{
	/*!	The size, in bytes, of this structure. */
	U32 sizeStruct;	
	
	/*!	Current PPP state enumeration.  See SWI_TYPE_PPP for details. */
	SWI_TYPE_PPP State;
		
	/*!	NULL terminated description of error.  Only available in error 
		conditions. */					
	WCHAR szReason[LENGTH_MaxPPPString];
};

///////////////////////////////////////////////////////////////////////////////
// Not used, but kept for compatibility with previous technologies (SDK)
///////////////////////////////////////////////////////////////////////////////
enum SWI_SESSION
{
	SWI_SESS_UNK,
	SWI_SESS_DIA,
	SWI_SESS_NEC,
	SWI_SESS_DIS
};

///////////////////////////////////////////////////////////////////////////////
// Not used, but kept for compatibility with previous technologies (SDK)
///////////////////////////////////////////////////////////////////////////////
enum SWI_CHNST
{
	SWI_CHNST_AQR,
	SWI_CHNST_SLP,
	SWI_CHNST_SCN
};

////////////////////////////////internal///////////////////////////////////////
#define LENGTH_MaxDebugString				201

///////////////////////////////////////////////////////////////////////////////
///
/// This data structure contains debug information.
///
/// For internal debugging purposes only.
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_Debug
{
	/*!	The size, in bytes, of this structure. */
	U32 sizeStruct;	

	/*!	NULL terminated debug string of maximum length 
		LENGTH_MaxDebugString. */							
	WCHAR szDebugString[LENGTH_MaxDebugString];
};

///////////////////////////////////////////////////////////////////////////////
///
/// This structure contains TCP optimization parameters.
///
///	TcpWindowSize is modified per-interface while other values are modified
///	on a global level.  Global values do not take effect until after the OS
///	reboots.  Per-interface values are used once the AirCard is re-inserted
///	or if the mini-cards is reset.
///
///		- Suggested values for AC750:
///			- nTcpWindowSize = 19200
///			- bSackOpts = true
///			- nTcpMaxDupAcks = 1	
///				
///		- Suggested values for AC775:
///			- nTcpWindowSize = 42300
///			- bSackOpts = true
///			- nTcpMaxDupAcks = 1
///
///		- Suggested values for AC8xx and MC87xx:
///			- nTcpWindowSize = 65535
///			- bSackOpts = true
///			- nTcpMaxDupAcks = 1			
///
///	Further tests indicate that the GlobalTcpWindowSize must be greater
///	or equal to the per-interface TcpWindowSize, as the lower of the
///	two is used GlobalMaxTcpWindowSize, while it has no effect on NDIS,
///	does appear to be used by the DUN interface.
///
///	Windows Vista, Windows XP, Windows 2000, and Windows 98 and Windows CE
///	are supported for all devices.
///
/// \sa SwiGetTcpOpt
/// \sa SwiOptimizeTcp
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_TcpOpt
{
	/*!	TCP receive window size.  Modification will be done per-interface.
			- Suggested value for AC750 is 19200
			- Suggested value for AC775 is 42300
			- Suggested value for AC8xx is 65535
			- Suggested value for MC87xx is 65535 */
	U32 nTcpWindowSize;
	
	/*! Global TCP window size */
	U32	nTcpWindowSizeGlobal;
	
	/*! Maximum global TCP window size */
	U32	nTcpWindowSizeGlobalMax;
	
	/*!	Set to true to enable Selective Acks, false otherwise.  Modification 
		will be done globally and will affect all interfaces on the OS. */
	bool bSackOpts;	

	/*! Fast re-transmission and recovery.  Modification will be done globally 
		and will affect all interfaces on the OS. */
	U32 nTcpMaxDupAcks;
	
	/*! TCP RFC 1323 Options*/
	U32	nTcp1323Opts;
	
	/*! Maximum TCP connection retransmissions */
	U32	nTcpMaxConnectRetransmissions;
};

///////////////////////////////////////////////////////////////////////////////
///
/// This structure contains USB descriptor information. 
///
/// Only GSM and CDMA USB based PC cards and embedded modules are supported.  
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_UsbdInfo
{
	/*!	The size, in bytes, of this structure.  This value must always be
		populated by the calling application. */
	U32 sizeStruct;

	/*!	A NULL terminated string containing the USB descriptor version.
		Maximum length of string is LENGTH_UsbdVersion. */
	WCHAR szVersion[LENGTH_UsbdVersion];

	/*!	A NULL terminated string containing the USB descriptor build date.
		Maximum length of string is LENGTH_UsbdBuildDate. */
	WCHAR szBuildDate[LENGTH_UsbdBuildDate];
};

///////////////////////////////////////////////////////////////////////////////
///
/// This enumeration contains the headset states
///
///	These enumeration values are used in SWI_STRUCT_HeadsetState.
///	Supports PC cards, embedded devices, and MP line of products. 
///
///	\sa	SWI_STRUCT_HeadsetState 
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_HeadsetState
{
	SWI_HEADSET_Unplugged,	/*!< The headset is unplugged. */
	SWI_HEADSET_Plugged		/*!< The headset is plugged in.	*/
};

///////////////////////////////////////////////////////////////////////////////
///
/// This structure is used by the SWI_NOTIFY_HeadsetState notification to 
///	indicate the state of the headset.	
///
/// Supports PC cards, embedded devices, and MP line of products. 
///
///	\sa	SWI_TYPE_HeadsetState
///	\sa	SWI_NOTIFY_HeadsetState  
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_HeadsetState
{
	/*! The size, in bytes, of this structure. */
	U32 sizeStruct;       
	
	/*! Current headset state enumeration.  See SWI_TYPE_HeadsetState for
		more details. */
	SWI_TYPE_HeadsetState eHeadsetState;    
};

///////////////////////////////////////////////////////////////////////////////
///
/// This structure contains the radio signal strength indicator and bit
///	error rate information. 
///
/// Supports PC cards, embedded devices, and MP line of products. 
///
///	\sa	SWI_NOTIFY_Rssi
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_Rssi
{
	/*! The size, in bytes, of this structure. */
	U32 sizeStruct; 
		
	/*!	Radio signal strength signal in dBm. */
	I32 iRssi;	

	/*!	Bit error rate (currently only used by GSM products). */			
	I32 iBer;			
};

///////////////////////////////////////////////////////////////////////////////
///
/// Enumeration of radio power modes.
///
/// This enumeration is used by SWI_STRUCT_RadioPower. 
///
///	\sa	SWI_STRUCT_RadioPower
///	\sa	SWI_NOTIFY_RadioPower 
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_RadioPowerMode
{
	SWI_RADIOPOWERMODE_Low,		/*!< Radio is in low power mode */
	SWI_RADIOPOWERMODE_Online,	/*!< Radio is online (full power mode) */
};

///////////////////////////////////////////////////////////////////////////////
///
/// Low power modem reason bit mask values.
///
/// Supports PC cards, embedded devices, and MP line of products. 
///
///	\sa	SWI_STRUCT_RadioPower
///	\sa	SWI_NOTIFY_RadioPower  
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_RadioPowerReason
{
	/*!	W_DISABLED is asserted */
	SWI_RADIOPOWERREASON_WDISABLE = 0x0001,

	/*!	User request */
	SWI_RADIOPOWERREASON_UserRequest = 0x0002,

	/*!	Out of operational temperature range */
	SWI_RADIOPOWERREASON_Temperature = 0x0004,

	/*!	Out of operational supply voltage range */	
	SWI_RADIOPOWERREASON_Battery = 0x0008,
};

///////////////////////////////////////////////////////////////////////////////
///
/// Enumeration of power down request reasons.
///
/// This enumeration is used by SWI_STRUCT_RadioPower
///
///	\sa	SWI_STRUCT_RadioPower
///	\sa	SWI_NOTIFY_RadioPower
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_ModuleReqReason
{
	SWI_MODULEREQREASON_NoReason,		/*!< No reason given (e.g. when no 
											 requests are being made) */
	SWI_MODULEREQREASON_Temperature,	/*!< Temperature exceeds limit */
	SWI_MODULEREQREASON_Battery,		/*!< Voltage exceeds limit */
	SWI_MODULEREQREASON_Network,		/*!< Network related reason */
	SWI_MODULEREQREASON_Other,			/*!< All other reasons */
};

///////////////////////////////////////////////////////////////////////////////
///
/// This structure contains the radio power information.
///
/// Certain host platforms may be driving the power rail of the module
///	and thus if the module tries to power itself down, it will just be
///	powered back up.  Therefore, when bModuleReqPowerDown is returned
///	as true, the host must remove power from the power rail to the module.
///
///	This structure is valid for MiniCards only.  Both GSM and CDMA
///	MiniCards are supported.
///
///	\sa	SWI_NOTIFY_RadioPower
///	\sa	SwiGetRadioPower
///	\sa	SwiSetRadioPower  
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_RadioPower
{
	/*!	The size, in bytes, of this structure.  This value must always be
		populated by the calling application when calling SwiGetRadioPower
		or SwiSetRadioPower. */
	U32 sizeStruct;

	/*!	Radio power mode enumeration.  See SWI_TYPE_RadioPowerMode for more
		details. */
	SWI_TYPE_RadioPowerMode eMode;

	/*! Bit mask indicating reason for entering the radio power mode.  
		See SWI_TYPE_RadioPowerReason for mask definitions.  This value is
		ignored when setting the radio power state. */
	U32 nLowPowerReason;

	/*! Set to true if the module has requested to be powered down.  Only 
		valid when returned in a notification.  This field only applies to 
		CDMA MiniCards. */
	bool bModuleReqPowerDown;
	
	/*!	Reason enumeration stating why the modem has requested to be
		powered down.  Only valid when returned in a notification. */
	SWI_TYPE_ModuleReqReason eRequestReason;
};

///////////////////////////////////////////////////////////////////////////////
///
/// Enumeration of radio temperature states
///
///	This enumeration is used by the SWI_STRUCT_RadioTempState structure.
///
///	\sa	SWI_STRUCT_RadioTempState
///	\sa	SWI_NOTIFY_RadioTempState
///	\sa	SwiGetRadioTempState
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_RadioTempState
{
	SWI_RADIOTEMPSTATE_Normal,		/*!< Normal temperature state */
	SWI_RADIOTEMPSTATE_HighWarning,	/*!< High temperature warning state */
	SWI_RADIOTEMPSTATE_HighCrit,	/*!< High temperature critical state */
	SWI_RADIOTEMPSTATE_LowCrit,		/*!< Low temperature critical state */
};

///////////////////////////////////////////////////////////////////////////////
///
/// This structure contains the radio temperature state.
///
/// Supports PC cards, embedded devices, and MP line of products. 
///
///	\sa	SWI_TYPE_RadioTempState
///	\sa	SWI_NOTIFY_RadioTempState
///	\sa	SwiGetRadioTempState
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_RadioTempState
{
	/*! The size, in bytes, of this structure.  This value must always be
		populated by the calling application when calling 
		SwiGetRadioTempState.  */
	U32 sizeStruct;
	
	/*!	Temperature state enumeration.  See SWI_TYPE_RadioTempState for
		more details. */
	SWI_TYPE_RadioTempState	eState;
	
	/*!	A numerical representation of the current temperature in degrees
		Celsius. */
	I16 nCurrent;
};

///////////////////////////////////////////////////////////////////////////////
///
/// Enumeration of radio battery states
/// 
/// This enumeration is used by SWI_STRUCT_RadioBattery.
///
///	\sa	SWI_STRUCT_RadioBattery
///	\sa	SWI_NOTIFY_RadioBattery
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_RadioBatteryState
{
	SWI_RADIOBATTERYSTATE_Normal,		/*!< Normal state */
	SWI_RADIOBATTERYSTATE_LowWarning,	/*!< Low battery warning state */
	SWI_RADIOBATTERYSTATE_LowCrit,		/*!< Low battery critical state */
	SWI_RADIOBATTERYSTATE_HighCrit,		/*!< High battery critical state */
};

///////////////////////////////////////////////////////////////////////////////
///
/// This structure contains the radio battery state.
///
/// Supports PC cards, embedded devices, and MP line of products. 
///
///	\sa	SWI_TYPE_RadioBatteryState
///	\sa	SWI_NOTIFY_RadioBattery
///	\sa	SwiGetRadioBattery
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_RadioBattery
{
	/*! The size, in bytes, of this structure.  This value must always be
		populated by the calling application when calling 
		SwiGetRadioBattery. */
	U32 sizeStruct;

	/*!	Current battery state enumeration. See SWI_TYPE_RadioBatteryState
		for more details. */
	SWI_TYPE_RadioBatteryState eState;
	
	/*!	Current supply voltage in mV */
	U32 nCurrent;
};

/** 
*	\addtogroup GroupNetwork Network Management and Status
*/
/*@{*/

///////////////////////////////////////////////////////////////////////////////
///
/// Enumeration of radio technologies.
///
///	\sa	SWI_STRUCT_RadioBandInfo
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_RadioType
{
	SWI_RADIOTYPE_1xrtt,		/*!< 1xRTT */
	SWI_RADIOTYPE_Evdo,			/*!< EVDO */
	SWI_RADIOTYPE_GsmWcdma,		/*!< GSM/WCDMA */
};

///////////////////////////////////////////////////////////////////////////////
///
/// Enumeration of radio bands.
///
/// This enumeration is used by SWI_STRUCT_RadioBandInfo and
///	SWI_STRUCT_GmsCellMeasure.
///
///	\sa	SWI_STRUCT_RadioBandInfo
///	\sa	SWI_STRUCT_GsmCellMeasure
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_RadioBand
{
	SWI_RADIOBAND_CdmaClass0		= 0x00,	/*!< CDMA Band Class 0 */
	SWI_RADIOBAND_CdmaClass1,				/*!< CDMA Band Class 1 */
	SWI_RADIOBAND_CdmaClass2,				/*!< CDMA Band Class 2 */
	SWI_RADIOBAND_CdmaClass3,				/*!< CDMA Band Class 3 */
	SWI_RADIOBAND_CdmaClass4,				/*!< CDMA Band Class 4 */
	SWI_RADIOBAND_CdmaClass5,				/*!< CDMA Band Class 5 */
	SWI_RADIOBAND_CdmaClass6,				/*!< CDMA Band Class 6 */
	SWI_RADIOBAND_CdmaClass7,				/*!< CDMA Band Class 7 */
	SWI_RADIOBAND_CdmaClass8,				/*!< CDMA Band Class 8 */
	SWI_RADIOBAND_CdmaClass9,				/*!< CDMA Band Class 9 */
	SWI_RADIOBAND_CdmaClass10,				/*!< CDMA Band Class 10 */
	SWI_RADIOBAND_CdmaClass11,				/*!< CDMA Band Class 11 */
	SWI_RADIOBAND_CdmaClass12,				/*!< CDMA Band Class 12 */
	SWI_RADIOBAND_Gsm450			= 0x28,	/*!< GSM 450 Band */
	SWI_RADIOBAND_Gsm480,					/*!< GSM 480 Band */
	SWI_RADIOBAND_Gsm750,					/*!< GSM 750 Band */
	SWI_RADIOBAND_Gsm850,					/*!< GSM 850 Band */
	SWI_RADIOBAND_GsmEGsm900,				/*!< GSM E-GSM 900 Band */
	SWI_RADIOBAND_GsmPGsm900,				/*!< GSM P-GSM 900 Band */
	SWI_RADIOBAND_GsmRGsm900,				/*!< GSM R-GSM 900 Band */
	SWI_RADIOBAND_GsmDcs1800,				/*!< GSM DCS 1800 Band */
	SWI_RADIOBAND_GsmPcs1900,				/*!< GSM DCS 1900 Band */
	SWI_RADIOBAND_WcdmaIImt2000		= 0x50,	/*!< WCDMA I IMT 2000 */
	SWI_RADIOBAND_WcdmaIIPcs1900,			/*!< WCDMA II PCS 1900 */
	SWI_RADIOBAND_WcdmaIIIDcs1800,			/*!< WCDMA III DCS 1800 */
	SWI_RADIOBAND_WcdmaIV1700,				/*!< WCDMA IV 1700 */
	SWI_RADIOBAND_WcdmaV850,				/*!< WCDMA V 850 */
	SWI_RADIOBAND_WcdmaVI800,				/*!< WCDMA VI 800 */
	SWI_RADIOBAND_WcdmaVII2600,				/*!< WCDMA VII 2600 */
	SWI_RADIOBAND_WcdmaVIII900,				/*!< WCDMA VIII 900 */
	SWI_RADIOBAND_WcdmaIX1700,				/*!< WCDMA IX 1700 */
	SWI_RADIOBAND_Invalid			= 0xFF,	/*!< Invalid band */
};

///////////////////////////////////////////////////////////////////////////////
///
/// This structure contains radio band information
///
/// Supports PC cards, embedded devices, and MP line of products. 
///
///	\sa	SWI_TYPE_RadioType
///	\sa	SWI_TYPE_RadioBand
///	\sa	SWI_STRUCT_RadioBandList
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_RadioBandInfo
{
	/*! Radio type enumeration.  See SWI_TYPE_RadioType for more details. */
	SWI_TYPE_RadioType eType;

	/*!	Radio band enumeration.  See SWI_TYPE_RadioBand for more details. */
	SWI_TYPE_RadioBand eBand;
};

///////////////////////////////////////////////////////////////////////////////
///
/// This structure contains list of radio bands.
///
/// This structure replaces SWI_STRUCT_Band and should be used
///	with SwiGetCurrentRadioBand.  Both SwiGetBandInfo and SWI_STRUCT_Band
///	is obsolete and should no longer be used with devices that support
///	3G networks.
///
///	Supports PC cards, embedded devices, and MP line of products. 
///
///	\sa	SWI_TYPE_RadioType
///	\sa	SWI_TYPE_RadioBand
///	\sa	SWI_STRUCT_RadioBandInfo
///	\sa	SwiGetCurrentRadioBand
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_RadioBandList
{
	/*!	The size, in bytes, of this structure.  This value must always be
		populated by the calling application. */
	U32 sizeStruct;

	/*!	Number of radio bands in list.  Ranging from 0 to MAX_BAND_LIST. */
	U32 nNumBands;

	/*!	List of radio bands.  Only valid if nNumBands is greater than 0.
		The array of SWI_STRUCT_RadioBandList structures is populated
		beginning with index 0 up to index nNumBands-1 sequentially. */
	SWI_STRUCT_RadioBandInfo sList[MAX_BAND_LIST];	
};

///////////////////////////////////////////////////////////////////////////////
///
/// Band Class 0 A-system only (Cellular)
/// 
/// This radio band group is to be used with SWI_STRUCT_RadioBandConfig.
///
///	\sa	SWI_STRUCT_RadioBandInfo
///	\sa	SwiGetCurrentRadioBand
///
///////////////////////////////////////////////////////////////////////////////
#define SWI_RADIOBANDGROUP_CdmaClass0A				0x0000000000000001ui64

///////////////////////////////////////////////////////////////////////////////
///
/// Band Class 0 B-system only (Cellular)
/// 
/// This radio band group is to be used with SWI_STRUCT_RadioBandConfig.
///
///	\sa	SWI_STRUCT_RadioBandInfo
///	\sa	SwiGetCurrentRadioBand
///
///////////////////////////////////////////////////////////////////////////////
#define SWI_RADIOBANDGROUP_CdmaClass0B				0x0000000000000002ui64

///////////////////////////////////////////////////////////////////////////////
///
/// Band Class 1 (US PCS)
/// 
/// This radio band group is to be used with SWI_STRUCT_RadioBandConfig.
///
///	\sa	SWI_STRUCT_RadioBandInfo
///	\sa	SwiGetCurrentRadioBand
///
///////////////////////////////////////////////////////////////////////////////
#define SWI_RADIOBANDGROUP_CdmaClass1				0x0000000000000004ui64

///////////////////////////////////////////////////////////////////////////////
///
/// Band Class 2 (TACS)
/// 
/// This radio band group is to be used with SWI_STRUCT_RadioBandConfig.
///
///	\sa	SWI_STRUCT_RadioBandInfo
///	\sa	SwiGetCurrentRadioBand
///
///////////////////////////////////////////////////////////////////////////////
#define SWI_RADIOBANDGROUP_CdmaClass2				0x0000000000000008ui64

///////////////////////////////////////////////////////////////////////////////
///
/// Band Class 3 (JTACS)
/// 
/// This radio band group is to be used with SWI_STRUCT_RadioBandConfig.
///
///	\sa	SWI_STRUCT_RadioBandInfo
///	\sa	SwiGetCurrentRadioBand
///
///////////////////////////////////////////////////////////////////////////////
#define SWI_RADIOBANDGROUP_CdmaClass3				0x0000000000000010ui64

///////////////////////////////////////////////////////////////////////////////
///
/// Band Class 4 (Korean PCS)
/// 
/// This radio band group is to be used with SWI_STRUCT_RadioBandConfig.
///
///	\sa	SWI_STRUCT_RadioBandInfo
///	\sa	SwiGetCurrentRadioBand
///
///////////////////////////////////////////////////////////////////////////////
#define SWI_RADIOBANDGROUP_CdmaClass4				0x0000000000000020ui64

///////////////////////////////////////////////////////////////////////////////
///
/// Band Class 5 (450 MHz)
/// 
/// This radio band group is to be used with SWI_STRUCT_RadioBandConfig.
///
///	\sa	SWI_STRUCT_RadioBandInfo
///	\sa	SwiGetCurrentRadioBand
///
///////////////////////////////////////////////////////////////////////////////
#define SWI_RADIOBANDGROUP_CdmaClass5				0x0000000000000040ui64

///////////////////////////////////////////////////////////////////////////////
///
/// Band Class 6 (2 GHz)
/// 
/// This radio band group is to be used with SWI_STRUCT_RadioBandConfig.
///
///	\sa	SWI_STRUCT_RadioBandInfo
///	\sa	SwiGetCurrentRadioBand
///
///////////////////////////////////////////////////////////////////////////////
#define SWI_RADIOBANDGROUP_CdmaClass6				0x0000000000000080ui64

///////////////////////////////////////////////////////////////////////////////
///
/// Band Class 7 (700 MHz)
/// 
/// This radio band group is to be used with SWI_STRUCT_RadioBandConfig.
///
///	\sa	SWI_STRUCT_RadioBandInfo
///	\sa	SwiGetCurrentRadioBand
///
///////////////////////////////////////////////////////////////////////////////
#define SWI_RADIOBANDGROUP_CdmaClass7				0x0000000000000100ui64

///////////////////////////////////////////////////////////////////////////////
///
/// Band Class 8 (1800 MHz)
/// 
/// This radio band group is to be used with SWI_STRUCT_RadioBandConfig.
///
///	\sa	SWI_STRUCT_RadioBandInfo
///	\sa	SwiGetCurrentRadioBand
///
///////////////////////////////////////////////////////////////////////////////
#define SWI_RADIOBANDGROUP_CdmaClass8				0x0000000000000200ui64

///////////////////////////////////////////////////////////////////////////////
///
/// Band Class 9 (900 MHz)
/// 
/// This radio band group is to be used with SWI_STRUCT_RadioBandConfig.
///
///	\sa	SWI_STRUCT_RadioBandInfo
///	\sa	SwiGetCurrentRadioBand
///
///////////////////////////////////////////////////////////////////////////////
#define SWI_RADIOBANDGROUP_CdmaClass9				0x0000000000000400ui64

///////////////////////////////////////////////////////////////////////////////
///
/// Band Class 10 (Secondary 800 MHz)
/// 
/// This radio band group is to be used with SWI_STRUCT_RadioBandConfig.
///
///	\sa	SWI_STRUCT_RadioBandInfo
///	\sa	SwiGetCurrentRadioBand
///
///////////////////////////////////////////////////////////////////////////////
#define SWI_RADIOBANDGROUP_CdmaClass10				0x0000000000000800ui64

///////////////////////////////////////////////////////////////////////////////
///
/// Band Class 11 (400 MHz European PAMR)
/// 
/// This radio band group is to be used with SWI_STRUCT_RadioBandConfig.
///
///	\sa	SWI_STRUCT_RadioBandInfo
///	\sa	SwiGetCurrentRadioBand
///
///////////////////////////////////////////////////////////////////////////////
#define SWI_RADIOBANDGROUP_CdmaClass11				0x0000000000001000ui64

///////////////////////////////////////////////////////////////////////////////
///
/// Band Class 12 (800 MHz PAMR)
/// 
/// This radio band group is to be used with SWI_STRUCT_RadioBandConfig.
///
///	\sa	SWI_STRUCT_RadioBandInfo
///	\sa	SwiGetCurrentRadioBand
///
///////////////////////////////////////////////////////////////////////////////
#define SWI_RADIOBANDGROUP_CdmaClass12				0x0000000000002000ui64

///////////////////////////////////////////////////////////////////////////////
///
/// GSM 450
/// 
/// This radio band group is to be used with SWI_STRUCT_RadioBandConfig.
///
///	\sa	SWI_STRUCT_RadioBandInfo
///	\sa	SwiGetCurrentRadioBand
///
///////////////////////////////////////////////////////////////////////////////
#define SWI_RADIOBANDGROUP_Gsm450					0x0000000000010000ui64

///////////////////////////////////////////////////////////////////////////////
///
/// GSM 480
/// 
/// This radio band group is to be used with SWI_STRUCT_RadioBandConfig.
///
///	\sa	SWI_STRUCT_RadioBandInfo
///	\sa	SwiGetCurrentRadioBand
///
///////////////////////////////////////////////////////////////////////////////
#define SWI_RADIOBANDGROUP_Gsm480					0x0000000000020000ui64

///////////////////////////////////////////////////////////////////////////////
///
/// GSM 750
/// 
/// This radio band group is to be used with SWI_STRUCT_RadioBandConfig.
///
///	\sa	SWI_STRUCT_RadioBandInfo
///	\sa	SwiGetCurrentRadioBand
///
///////////////////////////////////////////////////////////////////////////////
#define SWI_RADIOBANDGROUP_Gsm750					0x0000000000040000ui64

///////////////////////////////////////////////////////////////////////////////
///
/// GSM 850
/// 
/// This radio band group is to be used with SWI_STRUCT_RadioBandConfig.
///
///	\sa	SWI_STRUCT_RadioBandInfo
///	\sa	SwiGetCurrentRadioBand
///
///////////////////////////////////////////////////////////////////////////////
#define SWI_RADIOBANDGROUP_Gsm850					0x0000000000080000ui64

///////////////////////////////////////////////////////////////////////////////
///
/// GSM RGSM 900
/// 
/// This radio band group is to be used with SWI_STRUCT_RadioBandConfig.
///
///	\sa	SWI_STRUCT_RadioBandInfo
///	\sa	SwiGetCurrentRadioBand
///
///////////////////////////////////////////////////////////////////////////////
#define SWI_RADIOBANDGROUP_GsmRGsm900				0x0000000000100000ui64

///////////////////////////////////////////////////////////////////////////////
///
/// GSM PCS 1900
/// 
/// This radio band group is to be used with SWI_STRUCT_RadioBandConfig.
///
///	\sa	SWI_STRUCT_RadioBandInfo
///	\sa	SwiGetCurrentRadioBand
///
///////////////////////////////////////////////////////////////////////////////
#define SWI_RADIOBANDGROUP_GsmPcs1900				0x0000000000200000ui64

///////////////////////////////////////////////////////////////////////////////
///
/// GSM DCS 1800
/// 
/// This radio band group is to be used with SWI_STRUCT_RadioBandConfig.
///
///	\sa	SWI_STRUCT_RadioBandInfo
///	\sa	SwiGetCurrentRadioBand
///
///////////////////////////////////////////////////////////////////////////////
#define SWI_RADIOBANDGROUP_GsmDcs1800				0x0000000000400000ui64

///////////////////////////////////////////////////////////////////////////////
///
/// GSM EGSM 900
/// 
/// This radio band group is to be used with SWI_STRUCT_RadioBandConfig.
///
///	\sa	SWI_STRUCT_RadioBandInfo
///	\sa	SwiGetCurrentRadioBand
///
///////////////////////////////////////////////////////////////////////////////
#define SWI_RADIOBANDGROUP_GsmEGsm900				0x0000000000800000ui64

///////////////////////////////////////////////////////////////////////////////
///
/// GSM PGSM 900
/// 
/// This radio band group is to be used with SWI_STRUCT_RadioBandConfig.
///
///	\sa	SWI_STRUCT_RadioBandInfo
///	\sa	SwiGetCurrentRadioBand
///
///////////////////////////////////////////////////////////////////////////////
#define SWI_RADIOBANDGROUP_GsmPGsm900				0x0000000001000000ui64

///////////////////////////////////////////////////////////////////////////////
///
/// WCDMA I IMT 2000 (EU)
/// 
/// This radio band group is to be used with SWI_STRUCT_RadioBandConfig.
///
///	\sa	SWI_STRUCT_RadioBandInfo
///	\sa	SwiGetCurrentRadioBand
///
///////////////////////////////////////////////////////////////////////////////
#define SWI_RADIOBANDGROUP_WcdmaIImt2000			0x0000000100000000ui64

///////////////////////////////////////////////////////////////////////////////
///
/// WCDMA II PCS 1900
/// 
/// This radio band group is to be used with SWI_STRUCT_RadioBandConfig.
///
///	\sa	SWI_STRUCT_RadioBandInfo
///	\sa	SwiGetCurrentRadioBand
///
///////////////////////////////////////////////////////////////////////////////
#define SWI_RADIOBANDGROUP_WcdmaIIPcs1900			0x0000000200000000ui64

///////////////////////////////////////////////////////////////////////////////
///
/// WCDMA III 1700
/// 
/// This radio band group is to be used with SWI_STRUCT_RadioBandConfig.
///
///	\sa	SWI_STRUCT_RadioBandInfo
///	\sa	SwiGetCurrentRadioBand
///
///////////////////////////////////////////////////////////////////////////////
#define SWI_RADIOBANDGROUP_WcdmaIII1700				0x0000000400000000ui64

///////////////////////////////////////////////////////////////////////////////
///
/// WCDMA IV 1700
/// 
/// This radio band group is to be used with SWI_STRUCT_RadioBandConfig.
///
///	\sa	SWI_STRUCT_RadioBandInfo
///	\sa	SwiGetCurrentRadioBand
///
///////////////////////////////////////////////////////////////////////////////
#define SWI_RADIOBANDGROUP_WcdmaIV1700				0x0000000800000000ui64

///////////////////////////////////////////////////////////////////////////////
///
/// WCDMA V 850
/// 
/// This radio band group is to be used with SWI_STRUCT_RadioBandConfig.
///
///	\sa	SWI_STRUCT_RadioBandInfo
///	\sa	SwiGetCurrentRadioBand
///
///////////////////////////////////////////////////////////////////////////////
#define SWI_RADIOBANDGROUP_WcdmaV850				0x0000001000000000ui64

///////////////////////////////////////////////////////////////////////////////
///
/// WCDMA VI 800
/// 
/// This radio band group is to be used with SWI_STRUCT_RadioBandConfig.
///
///	\sa	SWI_STRUCT_RadioBandInfo
///	\sa	SwiGetCurrentRadioBand
///
///////////////////////////////////////////////////////////////////////////////
#define SWI_RADIOBANDGROUP_WcdmaVI800				0x0000002000000000ui64

///////////////////////////////////////////////////////////////////////////////
///
/// WCDMA VII 2600
/// 
/// This radio band group is to be used with SWI_STRUCT_RadioBandConfig.
///
///	\sa	SWI_STRUCT_RadioBandInfo
///	\sa	SwiGetCurrentRadioBand
///
///////////////////////////////////////////////////////////////////////////////
#define SWI_RADIOBANDGROUP_WcdmaVII2600				0x0000004000000000ui64

///////////////////////////////////////////////////////////////////////////////
///
/// WCDMA VIII 900
/// 
/// This radio band group is to be used with SWI_STRUCT_RadioBandConfig.
///
///	\sa	SWI_STRUCT_RadioBandInfo
///	\sa	SwiGetCurrentRadioBand
///
///////////////////////////////////////////////////////////////////////////////
#define SWI_RADIOBANDGROUP_WcdmaVIII900				0x0000008000000000ui64

///////////////////////////////////////////////////////////////////////////////
///
/// WCDMA IX 1700
/// 
/// This radio band group is to be used with SWI_STRUCT_RadioBandConfig.
///
///	\sa	SWI_STRUCT_RadioBandInfo
///	\sa	SwiGetCurrentRadioBand
///
///////////////////////////////////////////////////////////////////////////////
#define SWI_RADIOBANDGROUP_WcdmaIX1700				0x0000010000000000ui64

///////////////////////////////////////////////////////////////////////////////
///
/// Auto band
/// 
/// This radio band group is to be used with SWI_STRUCT_RadioBandConfig.
///
///	\sa	SWI_STRUCT_RadioBandInfo
///	\sa	SwiGetCurrentRadioBand
///
///////////////////////////////////////////////////////////////////////////////
#define SWI_RADIOBANDGROUP_AutoBand					0xFFFFFFFFFFFFFFFFui64

///////////////////////////////////////////////////////////////////////////////
///
/// This structure contains radio band configurations.
///
///	Only supported on 3G devices and newer.
///
///	\sa	Radio Band Group Definitions
///	\sa	SwiGetRadioBandCfg
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_RadioBandConfig
{
	/*!	The size, in bytes, of this structure.  This value must always be
		populated by the calling application. */
	U32 sizeStruct;
	
	/*!	A bit mask indicating the last selected band grouping setting.  
		See Radio Band Group Definitions (SWI_RADIOBANDGROUP_XXX) for more 
		details. */
	U64 nLastSelected;

	/*!	Number of band settings in list.  Ranges from 0 to MAX_BAND_GROUPS. */
	U32	nNumInGroup;

	/*!	An array of band settings.  Only valid if nNumInGroup is greater
		than 0.  The array of Radio Band Group Definitions 
		(SWI_RADIOBANDGROUP_XXX) is populated beginning with index 0 up to 
		index nNumInGroup-1 sequentially. */
	U64 arBandSetting[MAX_BAND_GROUPS];
};

/*@}*/	// End of network management and status

///////////////////////////////////////////////////////////////////////////////
///
/// Enumeration of months of a year
///
///	\sa	SWI_STRUCT_DeviceTime
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_Month
{
	SWI_MONTH_Jan	= 0x01,	/*!< January */
	SWI_MONTH_Feb,			/*!< February */
	SWI_MONTH_Mar,			/*!< March */
	SWI_MONTH_Apr,			/*!< April */
	SWI_MONTH_May,			/*!< May */
	SWI_MONTH_Jun,			/*!< June */
	SWI_MONTH_Jul,			/*!< July */
	SWI_MONTH_Aug,			/*!< August */
	SWI_MONTH_Sep,			/*!< September */
	SWI_MONTH_Oct,			/*!< October */
	SWI_MONTH_Nov,			/*!< November */
	SWI_MONTH_Dec			/*!< December */
};

///////////////////////////////////////////////////////////////////////////////
///
/// Enumeration of days of the week.
///
///	\sa	SWI_STRUCT_DeviceTime
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_WeekDay
{
	SWI_WEEKDAY_Mon,	/*< Monday */
	SWI_WEEKDAY_Tue,	/*< Tuesday */
	SWI_WEEKDAY_Wed,	/*< Wednesday */
	SWI_WEEKDAY_Thu,	/*< Thursday */
	SWI_WEEKDAY_Fri,	/*< Friday */
	SWI_WEEKDAY_Sat,	/*< Saturday */
	SWI_WEEKDAY_Sun		/*< Sunday */
};

///////////////////////////////////////////////////////////////////////////////
///
/// Enumeration of daylight savings.
///
/// \sa	SWI_STRUCT_DeviceTime	
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_DaylightSavings
{
	SWI_DAYLIGHTSAVINGS_None,			/*< No daylight savings */
	SWI_DAYLIGHTSAVINGS_PlusOneHour,	/*< Plus one hour */
	SWI_DAYLIGHTSAVINGS_PlusTwoHour		/*< Plus two hours */
};

///////////////////////////////////////////////////////////////////////////////
///
/// This structure contains device time information.
///
///	\sa	SwiGetDeviceTime	
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_DeviceTime
{
	/*! The size, in bytes, of this structure.  This value must always be
		populated by the calling application. */
	U32 sizeStruct;
	
	/*!	Numerical value representing the year. */
	U32 nYear;
	
	/*! Month enumeration.  */
	SWI_TYPE_Month eMonth;
	
	/*! Numerical value representing the day of the month.  Valid values
		range between 1-31. */
	U32 nDay;
	
	/*! Day of the week enumeration. */
	SWI_TYPE_WeekDay eWeekDay;

	/*!	Numerical value representing the hour.  Valid values range between
		0-23 in UTC. */
	U32 nHour;

	/*!	Numerical value representing minutes.  Valid values range between
		0-59 in UTC. */
	U32 nMinute;

	/*!	Numerical value representing seconds.  Valid values range between
		0-59 in UTC. */
	U32 nSecond;

	/*!	Numerical value representing the time zone.  Values range from -48
		to 48 where 1 equals 15 minutes.  For example:
			- -4 is UTC minus 60 minutes
			- -3 is UTC minus 45 minutes
			- -2 is UTC minus 30 minutes
			- -1 is UTC minus 15 minutes
			- 0 is UTC time
			- 1 is UTC plus 15 minutes
			- 2 is UTC plus 30 minutes */
	I32 nTimeZone;

	/*!	Daylight saving enumeration.  See SWI_TYPE_DaylightSavings for more
		details. */
	SWI_TYPE_DaylightSavings eDaylightSavings;
};

///////////////////////////////////////////////////////////////////////////////
///
/// Enumeration of audio profiles configurations
///
///	\sa	SWI_STRUCT_AudioProfile	
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_AudioProfile
{
	SWI_AUDIOPROFILE_Handset,		/*!< Handset mode */
	SWI_AUDIOPROFILE_Headset,		/*!< Headset mode */
	SWI_AUDIOPROFILE_SpeakerPhone,	/*!< Speaker phone mode */
	SWI_AUDIOPROFILE_CarKit,		/*!< Car kit mode */
	SWI_AUDIOPROFILE_TtyFullAudio,	/*!< TTY full audio mode */
	SWI_AUDIOPROFILE_Hac,			/*!< Hearing Aid Compatible */
	SWI_AUDIOPROFILE_ExtPcm128kHz,	/*!< External PCM with 128 kHz clock 
										 (UMTS only) */
	SWI_AUDIOPROFILE_ExtPcm2MHz,	/*!< External PCM with 2 MHz clock (UMTS
										 only */
};

///////////////////////////////////////////////////////////////////////////////
///
/// Enumeration of audio volume levels
///
///	\sa	SWI_STRUCT_AudioProfile
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_AudioVolLevel
{
	SWI_AUDIOVOLLEVEL_0,	/*!< Lowest audio level */
	SWI_AUDIOVOLLEVEL_1,
	SWI_AUDIOVOLLEVEL_2,
	SWI_AUDIOVOLLEVEL_3,
	SWI_AUDIOVOLLEVEL_4,
	SWI_AUDIOVOLLEVEL_5,
	SWI_AUDIOVOLLEVEL_6,
	SWI_AUDIOVOLLEVEL_7,	/*!< Highest audio level */
};

///////////////////////////////////////////////////////////////////////////////
///
/// Enumeration of audio generator values
///
/// \sa	SWI_STRUCT_AudioProfile
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_AudioGen
{
	SWI_AUDIOGEN_Voice,
	SWI_AUDIOGEN_KeyBeep,
	SWI_AUDIOGEN_Midi,
};

///////////////////////////////////////////////////////////////////////////////
///
/// Enumeration of audio action result.
///
///	\sa	SWI_STRUCT_AudioProfile	
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_AudioResult
{
	SWI_AUDIORESULT_Success,		/*!< Action succeeded */
	SWI_AUDIORESULT_InvalidSetting	/*!< Invalid audio profile setting */
};

///////////////////////////////////////////////////////////////////////////////
///
/// This structure contains audio profile information.
///
/// Audio profile settings are not persistent.
/// Supports PC cards, embedded devices, and MP line of products. 
///
///	\sa	SWI_TYPE_AudioProfile
///	\sa	SWI_TYPE_AudioVolLevel
///	\sa	SWI_TYPE_AudioGen
///	\sa	SWI_TYPE_AudioResult
///	\sa	SwiGetAudioProfile
///	\sa	SwiSetAudioProfile
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_AudioProfile
{
	/*!	The size, in bytes, of this structure.  This value must always be
		populated by the calling application when calling SwiGetRadioPower
		or SwiSetRadioPower. */
	U32 sizeStruct;
		
	/*!	Enumeration of the current audio profile setting. */
	SWI_TYPE_AudioProfile eCurrent;

	/*! True is returned if the ear piece is muted, false otherwise. */
	bool bEarPieceMute;
		
	/*! True is returned if the microphone is muted, false otherwise. */
	bool bMicMute;

	/*!	Enumeration of the volume level. */
	SWI_TYPE_AudioVolLevel eVolLevel;

	/*!	Enumeration of the audio generator.  Only valid in SET requests. */
	SWI_TYPE_AudioGen eAudioGen;

	/*!	Enumeration of the result of a SET request.  Ignore when doing a 
		query. */
	SWI_TYPE_AudioResult eActionResult;
};

///////////////////////////////////////////////////////////////////////////////
///
/// This structure contains modem PRI information.
///
/// Supports PC cards, embedded devices, and MP line of products. 
///
///	\sa	SwiGetPriInfo
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_PriInfo
{
	/*!	The size, in bytes, of this structure.  This value must always be
		populated by the calling application when calling SwiGetRadioPower
		or SwiSetRadioPower. */
	U32	sizeStruct;

	/*!	Major PRI version. */
	U32	nMajorVer;

	/*!	Minor version. */
	U32	nMinorVer;

	/*!	Sub-minor version (0xFFFF if unused). */
	U32 nSubMinorVer;

	/*!	Sub-OEM version (0xFFFF if unused). */
	U32 nSubOemVer;

	/*!	SKU ID or part number. */	
	U32 nSkuId;
};

#define LENGTH_ImgInfoVer		85	/*!< Maximum verion info length */
#define LENGTH_ImgInfoRelDate	9	/*!< Maximum release date info length */
#define LENGTH_ImgInfoProdType	5	/*!< Maximum product type info length */
#define LENGTH_ImgInfoImgType	5	/*!< Maximum image type infor length */	

///////////////////////////////////////////////////////////////////////////////
///
/// An enumeration of flash image result codes.
///
/// Supports PC cards, embedded devices, and MP line of products. 
///
///	\sa	SWI_STRUCT_FlashImgInfo
///
///////////////////////////////////////////////////////////////////////////////
typedef enum 
{
	FLASHIMGINFORESULT_Success,				/*!< Action succeeded */
	FLASHIMGINFORESULT_UnsupportedImgType,	/*!< Unsupported image type */
	FLASHIMGINFORESULT_ImgNotFound,			/*!< Image not found */
} TYPE_FlashImgInfo_Result;

///////////////////////////////////////////////////////////////////////////////
///
/// This structure contains flash image information.
///
/// Supports PC cards, embedded devices, and MP line of products. 
///
/// \sa TYPE_FlashImgInfo_Result
///	\sa	SwiGetFlashImgInfo
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_FlashImgInfo
{
	/*!	The size, in bytes, of this structure.  This value must always be
		populated by the calling application. */
	U32	sizeStruct;
	
	/*! This value is case sensitive and must be supplied by the calling
		application.  Possible values include:
		- 'QCOM' - Boot images including NAND image partition table, PBL 
		  (Primary Boot Loader), SBL (Secondary Boot Loader), OEMSBL (OEM
		  Secondary Boot Loader) and the configuration data used by PBL)
		- 'BOOT' - OEMSBL (SWI Boot Loader)
		- 'APPL' - Application code 
		- 'USBD' - USB descriptor table
		- 'SWOC' - Software on card image */
	WCHAR szImageType[LENGTH_ImgInfoImgType];
	
	/*! An enumeration of type TYPE_FlashImgInfo_Result returned from the
		device which specifies the result of the request. */
	TYPE_FlashImgInfo_Result eResult;
	
	/*! A NULL terminated string returned from the device which specifies the 
		version of the flash image of interest.  The format of this string
		varies between technology types and image types:
		- CDMA QCOM, BOOT, APPL: 
			- <product>_<build_type>[_<pid>].<major>.<minor>[.<point>]
				- <product> - ex. EM5625, SWI6800, SWI6800V2
				- <build_type> - Either FP for normal release or PP for point 
					release.
				- <pid> - USB product ID (note: <pid> only appears in 
					dedicated builds like EM5625 or MC5720 and does not appear
					in single builds used for multiple products (ex. SWI6800)).
				- <major>, <minor> and <point> are zero padded two digit
					decimal version numbers.
		- CDMA USBD: 
			- <product>_<customer>.<major>.<minor>
				- <product> - ex. SWI6800 or SWI6800V2
				- <customer> - ex. GENERIC, AC595U
				- <major> and <minor> are zero padded two digit decimal version
					numbers.
		- UMTS QCOM, BOOT, APPL: 
			- AW_X_Y_Zxx
				- A - Device family type (U-6275, H-6280, D-7200R2.x, 
					F-7200R3.x, J-7200A)
				- W - Major release
				- X - Minor release
				- Y - Sub-release identifier (increments with a stack change)
				- Z - Sub-release identifier (increments with a Sierra update)
				- xx - Platform and load type
					- 'ap' - Application
					- 'bt' - Bootloader
		- UMTS USBD: 
			- AW_Xud
				- A - Device family type (U-6275, H-6280, D-7200R2.x, 
					F-7200R3.x, J-7200A)
				- W - Major release
				- X - Minor release	
		- SWOC: 
			- CDPC_<version>_<major>.<minor>.<point>
				- <version> - zero padded 5-digit decimal CDPC (CD Product 
					Code).
				- <major>, <minor>, and <point> are zero padded two digit 
					decimal numbers for CD version. */
	WCHAR szVersion[LENGTH_ImgInfoVer];
	
	/*! A NULL terminated string returned from the device which specifies the 
		release date of the flash image of interest.  The format of the date
		is MM/DD/YY. */
	WCHAR szRelDate[LENGTH_ImgInfoRelDate];
	
	/*! A NULL terminated string returned from the device which specifies the 
		product type of the flash image of interest.  Exact values are image
		specific; examples are '6800' or '5625' for FW_DWN_APPL and 
		FW_DWN_BOOT images.  FW_DWN_SWOC image does not use this field. */
	WCHAR szProdType[LENGTH_ImgInfoProdType];
	
	/*! The size, in bytes, of the image data only and does not include the 
		size of the CWE header. */
	U32	nImgSize;
};

///////////////////////////////////////////////////////////////////////////////
//
// Location Based Services
//
///////////////////////////////////////////////////////////////////////////////

#define MAX_NUM_LBS_SV				12 /*!< Maximum number of sattelites */
#define LENGTH_LbsReqId				33 /*!< Maximum requestor ID length*/
#define LENGTH_LbsClientName		33 /*!< Maximum client name length */

///////////////////////////////////////////////////////////////////////////////
///
/// Enumeration of PD end status values.
///
/// \sa SWI_NOTIFY_LbsPdEnd
/// \sa SWI_STRUCT_LbsPdEnd
/// \sa SWI_STRUCT_LbsPdDloadEnd
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_LbsPdEndStatus
{
	SWI_LBSPDENDSTATUS_Offline,
	SWI_LBSPDENDSTATUS_NoService,
	SWI_LBSPDENDSTATUS_NoConnection,
	SWI_LBSPDENDSTATUS_NoData,
	SWI_LBSPDENDSTATUS_SessionBusy,
	SWI_LBSPDENDSTATUS_CdmaLock,
	SWI_LBSPDENDSTATUS_GpsLock,
	SWI_LBSPDENDSTATUS_ConnectionFailed,
	SWI_LBSPDENDSTATUS_ErrorState,
	SWI_LBSPDENDSTATUS_ClientEnded,
	SWI_LBSPDENDSTATUS_UiEnded,
	SWI_LBSPDENDSTATUS_NetworkEnded,
	SWI_LBSPDENDSTATUS_Timeout,
	SWI_LBSPDENDSTATUS_PrivacyLevel,
	SWI_LBSPDENDSTATUS_NetworkAccessError,
	SWI_LBSPDENDSTATUS_FixError,
	SWI_LBSPDENDSTATUS_PdeRejected,
	SWI_LBSPDENDSTATUS_TrafficChannelExited,
	SWI_LBSPDENDSTATUS_E911,
	SWI_LBSPDENDSTATUS_ServerError,
	SWI_LBSPDENDSTATUS_StaleBsInformation
};

///////////////////////////////////////////////////////////////////////////////
///
/// Enumeration of PD error types
///
/// \sa SWI_STRUCT_LbsPdGetStatus
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_LbsPdErr
{
	SWI_LBSPDERR_NoError,
	SWI_LBSPDERR_InternalModemError,
	SWI_LBSPDERR_BadServiceType,
	SWI_LBSPDERR_BadSessionType,
	SWI_LBSPDERR_InvalidPrivacy,
	SWI_LBSPDERR_InvalidDataDownload,
	SWI_LBSPDERR_InvalidNetworkAccess,
	SWI_LBSPDERR_InvalidOperationMode,
	SWI_LBSPDERR_InvalidNumberOfFixes,
	SWI_LBSPDERR_InvalidServerInfo,
	SWI_LBSPDERR_InvalidTimeout,
	SWI_LBSPDERR_InvalidQosParameter,
	SWI_LBSPDERR_NoSessionActive,
	SWI_LBSPDERR_SessionAlreadyActive,
	SWI_LBSPDERR_SessionBusy,
	SWI_LBSPDERR_PhoneIsOffline,
	SWI_LBSPDERR_CDMALockError,
	SWI_LBSPDERR_GPSLockError,
	SWI_LBSPDERR_InvalidState,
	SWI_LBSPDERR_ConnectionFailure,
	SWI_LBSPDERR_NoBuffersAvailable,
	SWI_LBSPDERR_SearcherError,
	SWI_LBSPDERR_CannotReportNow,
	SWI_LBSPDERR_ModeNotSupported,
	SWI_LBSPDERR_OtherError,
	SWI_LBSPDERR_FixRateForTrackingTooLarge
};

///////////////////////////////////////////////////////////////////////////////
///
/// PD service mask values
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_MASK_LbsPdService
{
	MASK_LbsPdService_Position	= 0x01,
	MASK_LbsPdService_Velocity	= 0x02,
	MASK_LbsPdService_Height	= 0x04
};

///////////////////////////////////////////////////////////////////////////////
///
/// Enumeration of PD download options
///
/// \sa SWI_STRUCT_LbsPdDownload
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_LbsPdDloadOption
{
	SWI_LBSPDDLOADOPTION_Periodic = 0x01,
	SWI_LBSPDDLOADOPTION_Single
};

///////////////////////////////////////////////////////////////////////////////
///
/// Enumeration of session types
///
/// \sa SWI_STRUCT_LbsPdEndSession
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_LbsSession
{
	SWI_LBSSESSION_LocationFix,
	SWI_LBSSESSION_Download
};

///////////////////////////////////////////////////////////////////////////////
///
/// Enumeration of PA error values
///
/// \sa SWI_STRUCT_LbsPaKeepWarmStart
/// \sa SWI_STRUCT_LbsPaKeepWarmStop
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_LbsPaErr
{
	SWI_LBSPAERR_NoError,
	SWI_LBSPAERR_InternalError,
	SWI_LBSPAERR_InvalidClientId,
	SWI_LBSPAERR_ErrorInParamToSet,
	SWI_LBSPAERR_ErrorInLockType,
	SWI_LBSPAERR_PhoneOffline,
	SWI_LBSPAERR_ParamCommandAlreadyActive,
	SWI_LBSPAERR_IncorrectAppSpecificInfo
};

///////////////////////////////////////////////////////////////////////////////
///
/// LBS location notification status bit masks
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_MASK_LbsLocNotifyStatus
{
	MASK_LbsPdLocNotifyStatus_Begin			= 0x0001,
	MASK_LbsPdLocNotifyStatus_Data			= 0x0002,
	MASK_LbsPdLocNotifyStatus_End			= 0x0004,
	MASK_LbsPdLocNotifyStatus_Done			= 0x0008,
	MASK_LbsPdLocNotifyStatus_UpdateFailure	= 0x0010,
};

///////////////////////////////////////////////////////////////////////////////
///
/// LBS download notification status bit masks
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_MASK_LbsDloadNotifyStatus
{
	MASK_LbsPdDloadNotifyStatus_Begin	= 0x0001,
	MASK_LbsPdDloadNotifyStatus_Data	= 0x0002,
	MASK_LbsPdDloadNotifyStatus_End		= 0x0004,
	MASK_LbsPdDloadNotifyStatus_Done	= 0x0008,
};

///////////////////////////////////////////////////////////////////////////////
///
/// LBS parameter notificatoin status bit masks
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_MASK_LbsParamNotifyStatus
{
	MASK_LbsPaParamNotifyStatus_Address		= 0x0001,
	MASK_LbsPaParamNotifyStatus_GpsLock		= 0x0002,
	MASK_LbsPaParamNotifyStatus_PtlmMode	= 0x0004,
	MASK_LbsPaParamNotifyStatus_PortId		= 0x0008,
	MASK_LbsPaParamNotifyStatus_Privacy		= 0x0010,
	MASK_LbsPaParamNotifyStatus_NetAccess	= 0x0020,
};

///////////////////////////////////////////////////////////////////////////////
///
/// An enumeration of LBS notification state
///
/// \sa SWI_STRUCT_LbsLocNotifyStatus
/// \sa SWI_STRUCT_LbsDloadNotifyStatus
/// \sa SWI_STRUCT_LbsParamNotifyStatus
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_LbsNotifyState
{
	SWI_LBSNOTIFYSTATE_Off,
	SWI_LBSNOTIFYSTATE_On,
};

///////////////////////////////////////////////////////////////////////////////
///
/// Used to enable/disable or check the current notification state of the
/// following group of notifications:
///		- SWI_NOTIFY_LbsPdData
///		- SWI_NOTIFY_LbsPdDone
///		- SWI_NOTIFY_LbsPdEnd
///		- SWI_NOTIFY_LbsPdBegin
///		- SWI_NOTIFY_LbsPdUpdateFailure
///		- SWI_NOTIFY_LbsSatInfo
///
/// \sa SWI_TYPE_LbsNotifyState
/// \sa SWI_NOTIFY_LbsPdData
/// \sa SWI_NOTIFY_LbsPdDone
/// \sa SWI_NOTIFY_LbsPdEnd
/// \sa SWI_NOTIFY_LbsPdBegin
/// \sa SWI_NOTIFY_LbsPdUpdateFailure
/// \sa SWI_NOTIFY_LbsSatInfo
/// \sa SwiGetLbsLocNotifyStatus
/// \sa SwiSetLbsLocNotifyStatus
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_LbsLocNotifyStatus
{
	/*! The size, in bytes, of this structure.  This value must always be 
		populated by the calling application. */
	U32	sizeStruct;	

	/*! An enumeration of type SWI_TYPE_LbsNotifyState which reflects the
		state of the notification */  
	SWI_TYPE_LbsNotifyState	eNotifyFlag;
};

///////////////////////////////////////////////////////////////////////////////
///
/// Used to enable/disable or check the current notification state of the 
/// following group of notifications:
///		- SWI_NOTIFY_LbsPdDloadBegin
///		- SWI_NOTIFY_LbsPdDloadData
///		- SWI_NOTIFY_LbsPdDloadDone
///		- SWI_NOTIFY_LbsPdDloadEnd
///
/// \sa SWI_TYPE_LbsNotifyState
/// \sa SWI_NOTIFY_LbsPdDloadBegin
/// \sa SWI_NOTIFY_LbsPdDloadData
/// \sa SWI_NOTIFY_LbsPdDloadDone
/// \sa SWI_NOTIFY_LbsPdDloadEnd
/// \sa SwiGetLbsDloadNotifyStatus
/// \sa SwiSetLbsDloadNotifyStatus
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_LbsDloadNotifyStatus
{
	/*! The size, in bytes, of this structure.  This value must always be 
		populated by the calling application. */
	U32 sizeStruct;   
	
	/*! An enumeration of type SWI_TYPE_LbsNotifyState which reflects the
		state of the notification */
	SWI_TYPE_LbsNotifyState eNotifyFlag;
};

///////////////////////////////////////////////////////////////////////////////
///
/// Used to enable/disable or check the current notification state of the 
/// following group of notifications:
///		- SWI_NOTIFY_LbsPaIpAddr
///		- SWI_NOTIFY_LbsPaGpsLock
///		- SWI_NOTIFY_LbsPaPtlmMode
///		- SWI_NOTIFY_LbsPaPortId
///		- SWI_NOTIFY_LbsPaPrivacy
///		- SWI_NOTIFY_LbsPaNetAccess
///
/// \sa SWI_TYPE_LbsNotifyState
/// \sa SWI_NOTIFY_LbsPaIpAddr
/// \sa SWI_NOTIFY_LbsPaGpsLock
/// \sa SWI_NOTIFY_LbsPaPtlmMode
/// \sa SWI_NOTIFY_LbsPaPortId
/// \sa SWI_NOTIFY_LbsPaPrivacy
/// \sa SWI_NOTIFY_LbsPaNetAccess
/// \sa SwiGetLbsParamNotifyStatus
/// \sa SwiSetLbsParamNotifyStatus
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_LbsParamNotifyStatus
{
	/*! The size, in bytes, of this structure.  This value must always be 
		populated by the calling application. */
	U32 sizeStruct;     
	
	/*! An enumeration of type SWI_TYPE_LbsNotifyState which reflects the
		state of the notification */
	SWI_TYPE_LbsNotifyState eNotifyFlag;
};

///////////////////////////////////////////////////////////////////////////////
///
/// Used to specify the download option and duration.
/// 
/// The host can use the download option to indicate whether the data download
/// should occur just once or periodically, in an effort to keep the data
/// "warm".  If the application that will be requesting this data will be
/// requiring the use of the data over a period of time, the application should
/// indicate that the download should be periodic.
///
/// \sa SWI_TYPE_LbsPdDloadOption
/// \sa SwiSetLbsPdDownload
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_LbsPdDownload
{
	/*! The size, in bytes, of this structure.  This value must always be 
		populated by the calling application. */
	U32	sizeStruct;	
			
	/*! An enumeration of type SWI_TYPE_LbsPdDloadOption which specifies a
		single or periodic download */
	SWI_TYPE_LbsPdDloadOption	eOption;
			
	/*! Session duration in minutes.  Used only with periodic download
		option. */
	U16	nDuration;
};

///////////////////////////////////////////////////////////////////////////////
///
/// Enumeration of location fix types
///
/// \sa SWI_STRUCT_LbsPdGetPos
/// \sa SWI_STRUCT_LbsPdTrack
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_LbsFix
{
	/*! Mobile does everything involved in computing its position.  
		No PDE required. */
	SWI_LBSFIX_Autonomous = 1,
	
	/*! Mobile gets assistance from the PDE but the mobile computes 
		position. */
	SWI_LBSFIX_MsBased,
	
	/*! Mobile provides information to the PDE so that the PDE can compute
		the mobiles position. */
	SWI_LBSFIX_MsAssisted,
	
	/*! MS Based or MS Assisted depending on Performance and Accuracy 
		settings. */
	SWI_LBSFIX_OptimizedSpeed,
	
	/*! MS-Assisted preferred, MS-Based if MS-Assisted fails */
	SWI_LBSFIX_OptimizedAccuracy,
	
	/*! MS-Based preferred, MS-Assisted if MS-Based fails */
	SWI_LBSFIX_OptimizedData,
};

///////////////////////////////////////////////////////////////////////////////
///
/// Structure containing location fix data
///
/// \sa SWI_TYPE_LbsFix
/// \sa SwiSetLbsPdGetPos
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_LbsPdGetPos
{
	/*! The size, in bytes, of this structure.  This value must always be 
		populated by the calling application. */
	U32	sizeStruct;
	
	/*! An enumeration of type SWI_TYPE_LbsFix which indicates the location 
		fix type */
	SWI_TYPE_LbsFix	eFixType; 
	
	/*! Time allowed for satellite acquisition in seconds */
	U16	nPerformance;
	
	/*! Accuracy limit preferred in meters */
	U32	nAccuracy;
};

///////////////////////////////////////////////////////////////////////////////
///
/// Enumeration of LBS PD status
///
/// \sa SWI_STRUCT_LbsPdGetStatus
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_LbsPdStatus
{
	SWI_LBSPDSTATUS_None    = 0, 
	SWI_LBSPDSTATUS_Active	= 1, 
	SWI_LBSPDSTATUS_Success = 2, 
	SWI_LBSPDSTATUS_Error   = 3,
};

///////////////////////////////////////////////////////////////////////////////
///
/// Structure containing LBS status information.
///
/// \sa SWI_TYPE_LbsPdStatus
/// \sa SWI_TYPE_LbsPdErr
/// \sa SwiGetLbsPdStatus
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_LbsPdGetStatus
{
	/*! The size, in bytes, of this structure.  This value must always be 
		populated by the calling application. */
	U32	sizeStruct;
	
	/*! A NULL terminated string containing the last single fix time stamp */
	WCHAR szLastFixTimeStamp[LENGTH_TimeStamp];
	
	/*! An enumeration of type SWI_TYPE_LbsPdStatus containing the last 
		single fix status */
	SWI_TYPE_LbsPdStatus eLastFixStatus;  
	
	/*! An enumeration of type SWI_TYPE_LbsPdErr containing the last single
		fix error */               
	SWI_TYPE_LbsPdErr eLastFixError;
	
	/*! A NULL terminated string containing the last download time stamp */
	WCHAR szLastDownloadTimeStamp[LENGTH_TimeStamp];
	
	/*! An enumeration of type SWI_TYPE_LbsPdStatus containing the last
		download status */
	SWI_TYPE_LbsPdStatus eLastDownloadStatus;
	
	/*! An enumeration of type SWI_TYPE_LbsPdErr containing the last 
		download error */
	SWI_TYPE_LbsPdErr eLastDownloadError;
	
	/*! A NULL terminated string containing the last tracking time stamp */
	WCHAR szLastFixSessionTimeStamp[LENGTH_TimeStamp];  
	
	/*! An enumeration of type SWI_TYPE_LbsPdStatus containing the last
		tracking fix status */
	SWI_TYPE_LbsPdStatus eLastFixSessionStatus; 
	
	/*! An enumeration of type SWI_TYPE_LbsPdErr containing the last fix 
		session error */       
	SWI_TYPE_LbsPdErr eLastFixSessionError;
	
	/*! A NULL terminated string containing the last download session time
		stamp */        
	WCHAR szLastDownloadSessionTimeStamp[LENGTH_TimeStamp];
	
	/*! An enumeration of type SWI_TYPE_LbsPdStatus containing the last
		download session status */
	SWI_TYPE_LbsPdStatus eLastDownloadSessionStatus;
	
	/*! An enumeration of type SWI_TYPE_LbsPdErr containing the last download 
		session error */
	SWI_TYPE_LbsPdErr eLastDownloadSessionError;
};

///////////////////////////////////////////////////////////////////////////////
///
/// Structure containing information related to starting a tracking session.
///
/// \sa SWI_TYPE_LbsFix
/// \sa SwiSetLbsPdTrack
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_LbsPdTrack
{
	/*! The size, in bytes, of this structure.  This value must always be 
		populated by the calling application. */
	U32	sizeStruct;
	
	/*! An enumeration of type SWI_TYPE_LbsFix which contains the location
		fix type */
	SWI_TYPE_LbsFix eFixType;   
	
	/*! Time allowed for satellite acquisition in seconds */
	U16 nPerformance;	 
	
	/*! Accuracy limit preferred in meters */
	U32	nAccuracy;	
	
	/*! Number of fixes to obtain between 1 and 999.  use 1000 for continuous
		mode	*/
	U16	nFixCount;		
	 
	/*! Frequency of fixes in seconds */
	U32	nFixRate;
};

///////////////////////////////////////////////////////////////////////////////
///
/// Structure containing information related to ending a tracking session
///
/// \sa SWI_TYPE_LbsSession
/// \sa SwiSetLbsPdEndSession
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_LbsPdEndSession
{
	/*! The size, in bytes, of this structure.  This value must always be 
		populated by the calling application. */
	U32	sizeStruct;    
	
	/*! An enumeration of type SWI_TYPE_LbsSession which contains the session 
		type to end */
	SWI_TYPE_LbsSession	eSessionType;
};

///////////////////////////////////////////////////////////////////////////////
///
/// Enumeration of GPS lock values
///
/// \sa SWI_STRUCT_LbsPaGetParam
/// \sa SWI_STRUCT_LbsPaGpsLock
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_LbsPaGpsLock
{
	SWI_LBSPAGPSLOCK_NoLockActive,
	SWI_LBSPAGPSLOCK_MiSessionsLocked,
	SWI_LBSPAGPSLOCK_MtSessionsLocked,
	SWI_LBSPAGPSLOCK_AllSessionsLocked
};

///////////////////////////////////////////////////////////////////////////////
///
/// Enumeration of PD transport mechanisms
///
/// \sa SWI_STRUCT_LbsPaGetParam
/// \sa SWI_STRUCT_LbsPaPtlmMode
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_LbsPaTransMech
{
	SWI_LBSPATRANSMECH_TcpIp,
	SWI_LBSPATRANSMECH_DataBurst
};

///////////////////////////////////////////////////////////////////////////////
///
/// Enumeration of privacy values.
///
/// \sa SWI_STRUCT_LbsPaGetParam
/// \sa SWI_STRUCT_LbsPaPrivacy
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_LbsPaPrivacy
{
	SWI_LBSPAPRIVACY_High,
	SWI_LBSPAPRIVACY_Medium,
	SWI_LBSPAPRIVACY_Low
};

///////////////////////////////////////////////////////////////////////////////
///
/// Enumeration of network access values.
///
/// \sa SWI_STRUCT_LbsPaGetParam
/// \sa SWI_STRUCT_LbsPaNetAccess
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_LbsPaNetAccess
{
	SWI_LBSPANETACCESS_NetworkOnly,
	SWI_LBSPANETACCESS_NoNetworkAccess,
	SWI_LBSPANETACCESS_NetworkWithDemodulation,
	SWI_LBSPANETACCESS_NetworkWithoutDemodulation
};

///////////////////////////////////////////////////////////////////////////////
///
/// Structure containing the modem's default parameter settings.
///
/// Entire set of position determination parameters is returned to the host
/// (IP address, port ID, GPS lock, transport mechanism, privacy, network
/// access).
///
/// \sa SWI_TYPE_LbsPaGpsLock
/// \sa SWI_TYPE_LbsPaTransMech
/// \sa SWI_TYPE_LbsPaPrivacy
/// \sa SWI_TYPE_LbsPaNetAccess
/// \sa SwiGetLbsPaParam
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_LbsPaGetParam
{
	/*! The size, in bytes, of this structure.  This value must always be 
		populated by the calling application. */
	U32 sizeStruct; 
	
	/*! TCP/IP address of PDE.  Only used when eTransportMech is set to 
		TCP/IP. */
	U32 nIpAddress;
	
	/*! Port ID of the PDE.  Only used when eTransportMech is set to TCP/IP. */
	U32 nPortId;
	
	/*! GPS lock state */
	SWI_TYPE_LbsPaGpsLock eGpsLock;
	
	/*! Transport mechanism (TCP/IP or DBM) */
	SWI_TYPE_LbsPaTransMech	eTransportMech;	
	
	/*! Privacy state (low, medium, or high) */
	SWI_TYPE_LbsPaPrivacy ePrivacy;	
	
	/*! Network access state */	
	SWI_TYPE_LbsPaNetAccess	eNetworkAccess;
};

///////////////////////////////////////////////////////////////////////////////
///
/// Enumeration of location fix dimensions.
///
/// \sa SWI_STRUCT_LbsPdData
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_LbsFixDim
{
	SWI_LBSFIXDIM_2D,
	SWI_LBSFIXDIM_3D,
};

///////////////////////////////////////////////////////////////////////////////
///
/// Enumeration representing the Standard Deviation for Position Uncertainty
///
/// From IS801-1
///		- Values are 0 - 31 and map to the list below it (uncertainty values are in Meters)
//		-  0,  1,2,  3,4,5,6,7,8, 9,10,11,12,13,14,15, 16, 17, 18, 19, 20, 21,  22,  23,  24,  25,  26,  27,  28,   29,   30,31,32
//		- .5,.75,1,1.5,2,3,4,6,8,12,16,24,32,48,64,96,128,192,256,384,512,768,1024,1536,2048,3072,4096,6144,8192,12288,12288, 0,0
///
// Doxygen formatting of the same information presented above
/// <table border="1">
/// <tr>
///		<td>0</td><td>1</td><td>2</td><td>3</td><td>4</td><td>5</td><td>6</td>
///		<td>7</td><td>8</td><td>9</td><td>10</td><td>11</td><td>12</td>
///		<td>13</td><td>14</td><td>15</td><td>16</td><td>17</td><td>18</td>
///		<td>19</td><td>20</td><td>21</td><td>22</td><td>23</td><td>24</td>
///		<td>25</td><td>26</td><td>27</td><td>28</td><td>29</td><td>30</td>
///		<td>31</td><td>32</td>
/// </tr>
/// <tr>
///		<td>.5</td><td>.75</td><td>1</td><td>1.5</td><td>2</td><td>3</td>
///		<td>4</td><td>6</td><td>8</td><td>12</td><td>16</td><td>24</td>
///		<td>32</td><td>48</td><td>64</td><td>96</td><td>128</td><td>192</td>
///		<td>256</td><td>384</td><td>512</td><td>768</td><td>1024</td>
///		<td>1536</td><td>2048</td><td>3072</td><td>4096</td><td>6144</td>
///		<td>8192</td><td>12288</td><td>12288</td><td>0</td><td>0</td>
/// </tr>
/// </table>
/// \sa SWI_STRUCT_LbsPdData
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_SDPU
{
	SWI_SDPU_0Dot5,
	SWI_SDPU_0Dot75,
	SWI_SDPU_1,
	SWI_SDPU_1Dot5,
	SWI_SDPU_2,
	SWI_SDPU_3,
	SWI_SDPU_4,
	SWI_SDPU_6,
	SWI_SDPU_8,
	SWI_SDPU_12,
	SWI_SDPU_16,
	SWI_SDPU_24,
	SWI_SDPU_32,
	SWI_SDPU_48,
	SWI_SDPU_64,
	SWI_SDPU_96,
	SWI_SDPU_128,
	SWI_SDPU_192,
	SWI_SDPU_256,
	SWI_SDPU_384,
	SWI_SDPU_512,
	SWI_SDPU_768,
	SWI_SDPU_1024,
	SWI_SDPU_1536,
	SWI_SDPU_2048,
	SWI_SDPU_3072,
	SWI_SDPU_4096,
	SWI_SDPU_6144,
	SWI_SDPU_8192,
	SWI_SDPU_12288,
	SWI_SDPU_GreaterThan12288,
	SWI_SDPU_NotComputable,
};

///////////////////////////////////////////////////////////////////////////////
///
/// Structure containing position fix information.
/// 
/// This object is sent to notify the registered host client of the result
/// of the position fix.  If the host performs a get on this object when
/// there is no position fix to report the modem will respond with a
/// generic error message.
///
/// \sa SWI_TYPE_SDPU
/// \sa SWI_TYPE_LbsFixDim
/// \sa SWI_TYPE_SDPU
/// \sa SWI_NOTIFY_LbsPdData
/// \sa SwiGetLbsPdData
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_LbsPdData
{
	/*! The size, in bytes, of this structure.  This value must always be 
		populated by the calling application. */
	U32 sizeStruct;
	
	/*! 2's complement in units of 180/2^25 degrees between +90 and -90 
		degrees */
	I32 nLatitude;    
	
	/*! 2's complement in units of 180/2^25 degrees between +90 and -90 
		degrees */
	I32 nLongitude;   
	
	/*! To convert time: CTime t(nValue+315964800L).  315964800L is the number
		of seconds between January 6, 1980 and January 1, 1970 */
	U32 nTimeStamp;   
	
	/*! In units of 5.625 degrees from 0 to 84.375 with 0 being true North 
		increasing to the east. */
	U16 nLocUncAngle;
		
	/*! Standard deviation of axis along angle specified for position
		uncertainty */
	SWI_TYPE_SDPU eLocUncA;  
	
	/*! Standard deviation of axis perpendicular to angle specified 
		for position uncertainty */
	SWI_TYPE_SDPU eLocUncP;     
	
	/*! 2-D or 3-D fix */
	SWI_TYPE_LbsFixDim eFix;	
	
	/*! 0 = Height info not available, 1 = Height info included */
	U16 nHeightIncl;	
	
	/*! Valid if iHeightIncl = 1.  Value is in meters */
	I16 nHeight;	
	
	/*! Valid if iHeightIncl = 1, Standard Deviation of Vertical error	 */
	SWI_TYPE_SDPU eLocUncVe;		
	
	/*! 0 = Velocity not included, 1 = Velocity included */
	U16 nVelocityIncl;
	
	/*! Valid if iVelocityInc = 1.  Formatted in units of 360/2^10 degrees. */
	U16 nHeading;	
	
	/*! Valid if iVelocityInc = 1. units of .25m/s in range 0 to 127.75m/s.	*/
	U16 nVelHoriz;	
	
	/*! Valid if iVelocityInc = 1 and Fix type is 1, 2's complement value of
		Vertical Velocity in units of .5m/s in range of -64m/s to 63.6m/s */
	I16 nVelVert;
	
	/*! Formatted in integer steps of 0.25 meters */
	U16 nUncertaintyA;	
	
	/*! Formatted in integer steps of 0.25 meters */
	U16 nUncertaintyP;	
	
	/*! If Height Included =1, this field is valid. Formatted in integer steps
		of 0.25 meters */
	U16 nUncertaintyV;	
	
	/*! Formatted in integer steps of 0.1 meters */
	U16 nHEPE;			
	
	/*! Number of Satellites used in Position Fix (Max 12) */
	U8 nSatelliteNum;	
};

///////////////////////////////////////////////////////////////////////////////
///
/// Skeleton structure returned when a position determination fix session
///	has completed.
///
/// \sa SWI_NOTIFY_LbsPdDone
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_LbsPdDone
{
	U32	sizeStruct;    /*!< The size, in bytes, of this structure. */ 
};

///////////////////////////////////////////////////////////////////////////////
///
/// Structure returned when a position determination fix session encountered
/// an error.
///
/// \sa SWI_TYPE_LbsPdEndStatus
/// \sa SWI_NOTIFY_LbsPdEnd
/// \sa SwiSetLbsPdEndSession
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_LbsPdEnd
{
	/*! The size, in bytes, of this structure.  This value must always be 
		populated by the calling application. */
	U32	sizeStruct;
	
	/*! An enumeration of type SWI_TYPE_LbsPdEndStatus which specifies
		the PD end error status. */
	SWI_TYPE_LbsPdEndStatus	eEndStatus;
};

///////////////////////////////////////////////////////////////////////////////
///
/// Skeleton structure returned when a position determination fix session
/// has begun.
///
/// \sa SWI_NOTIFY_LbsPdBegin
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_LbsPdBegin
{
	U32	sizeStruct; /*!< The size, in bytes, of this structure. */
};

///////////////////////////////////////////////////////////////////////////////
///
/// Skeleton structure returned when a position determination fix session
/// has failed
///
/// \sa SWI_NOTIFY_LbsPdUpdateFailure
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_LbsPdUpdateFailure
{
	U32	sizeStruct; /*!< The size, in bytes, of this structure. */
};

///////////////////////////////////////////////////////////////////////////////
///
/// Skeleton structure returned when a data download session has begun.
///
/// \sa SWI_NOTIFY_LbsPdDloadBegin
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_LbsPdDloadBegin
{
	U32	sizeStruct; /*!< The size, in bytes, of this structure. */
};

///////////////////////////////////////////////////////////////////////////////
///
/// Enumeration of download data types
///
/// \sa SWI_STRUCT_LbsPdDloadData
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_LbsDloadData
{
	SWI_LBSDLOADDATA_Location,
	SWI_LBSDLOADDATA_AA,
	SWI_LBSDLOADDATA_SA,
	SWI_LBSDLOADDATA_Epemeris,
	SWI_LBSDLOADDATA_Almanac,
};

///////////////////////////////////////////////////////////////////////////////
///
/// Enumeration of download source types
///
/// \sa SWI_STRUCT_LbsPdDloadData
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_LbsDloadSource
{
	SWI_LBSDLOADSOURCE_Mobile,
	SWI_LBSDLOADSOURCE_Pde,
};

///////////////////////////////////////////////////////////////////////////////
///
/// Structure containing information on downloaded LBS data.
///
/// This object is sent to notify the registered host client that ephemeris 
/// and almanac data has been downloaded.
///
/// \sa SWI_TYPE_LbsDloadData
/// \sa SWI_TYPE_LbsDloadSource
/// \sa SWI_NOTIFY_LbsPdDloadData
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_LbsPdDloadData
{
	U32 sizeStruct;			/*!< The size, in bytes, of this structure. */
	U16 nValidEntryPairNum; /*!< Indicates how many entries below contain
								 valid data */
	SWI_TYPE_LbsDloadData	eDataType1; /*!< Entry 1 data type */
	SWI_TYPE_LbsDloadSource	eSource1; /*!< Entry 1 source */
	SWI_TYPE_LbsDloadData	eDataType2; /*!< Entry 2 data type */
	SWI_TYPE_LbsDloadSource	eSource2; /*!< Entry 2 source */
	SWI_TYPE_LbsDloadData	eDataType3; /*!< Entry 3 data type */
	SWI_TYPE_LbsDloadSource	eSource3; /*!< Entry 3 source */
	SWI_TYPE_LbsDloadData	eDataType4; /*!< Entry 4 data type */
	SWI_TYPE_LbsDloadSource	eSource4; /*!< Entry 4 source */
	SWI_TYPE_LbsDloadData	eDataType5; /*!< Entry 5 data type */
	SWI_TYPE_LbsDloadSource	eSource5; /*!< Entry 5 source */
};

///////////////////////////////////////////////////////////////////////////////
///
/// Skeleton structure returned when a position determination download
///	session has completed.
///
/// \sa SWI_NOTIFY_LbsPdDloadDone
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_LbsPdDloadDone
{
	U32 sizeStruct;   /*!< The size, in bytes, of this structure. */  
};

///////////////////////////////////////////////////////////////////////////////
///
/// Structure containing status of a position determination download session.
///
/// This object is typically sent to notify the registered host clients that a
/// position determination fix session had an error.
///
/// \sa SWI_NOTIFY_LbsPdDloadEnd
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_LbsPdDloadEnd
{
	U32	sizeStruct;			/*!< The size, in bytes, of this structure. */
	SWI_TYPE_LbsPdEndStatus	eEndStatus; /*!< Status code */
};

///////////////////////////////////////////////////////////////////////////////
///
/// Structure containing TCP/IP address used in LBS sessions.
///
/// \sa SWI_NOTIFY_LbsPaIpAddr
/// \sa SwiGetLbsPaIpAddr
/// \sa SwiSetLbspaIpAddr
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_LbsPaIpAddr
{
	/*! The size, in bytes, of this structure.  This value must always be 
		populated by the calling application. */
	U32 sizeStruct;
	
	/*! TCP/IP address to connect to for LBS activity when using TCP/IP 
		transport mechanism. */
	U32 nIpAddress;
};

///////////////////////////////////////////////////////////////////////////////
///
/// Structure containing GPS lock used in LBS sessions.
///
/// \sa SWI_TYPE_LbsPaGpsLock
/// \sa SWI_NOTIFY_LbsPaGpsLock
/// \sa SwiGetLbsPaGpsLock
/// \sa SwiSetLbsPaGpsLock
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_LbsPaGpsLock
{
	/*! The size, in bytes, of this structure.  This value must always be 
		populated by the calling application. */
	U32 sizeStruct;
	
	/*! An enumeration of type SWI_TYPE_LbsPaGpsLock representing the GPS lock
		state. */
	SWI_TYPE_LbsPaGpsLock eGpsLock;
};

///////////////////////////////////////////////////////////////////////////////
///
/// Structure containing mechanism used to transport LBS messages.
///
/// \sa SWI_TYPE_LbsPaTransMech
/// \sa SWI_NOTIFY_LbsPaPtlmMode
/// \sa SwiGetLbsPaPtlmMode
/// \sa SwiSetLbsPaPtlmMode
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_LbsPaPtlmMode
{
	/*! The size, in bytes, of this structure.  This value must always be 
		populated by the calling application. */
	U32 sizeStruct;
	
	/*! An enumeration of type SWI_TYPE_LbsPaTransMech representing the
		transportation mechanism used. */
	SWI_TYPE_LbsPaTransMech	eTransportMech;
};

///////////////////////////////////////////////////////////////////////////////
///
/// Structure containing port ID used in LBS sessions.
///
/// \sa SWI_NOTIFY_LbsPaPortId
/// \sa SwiGetLbsPaPortId
/// \sa SwiSetLbsPaortId
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_LbsPaPortId
{
	/*! The size, in bytes, of this structure.  This value must always be 
		populated by the calling application. */
	U32	sizeStruct; 
	
	/*! Port ID to connect to for LBS activity when using TCP/IP transport
		mechanism */
	U32	nPortId;
};

///////////////////////////////////////////////////////////////////////////////
///
/// Structure containing privacy level used in LBS sessions.
///
/// \sa SWI_TYPE_LbsPaPrivacy
/// \sa SWI_NOTIFY_LbsPaPrivacy
/// \sa SwiGetLbsPaPrivacy
/// \sa SwiSetLbsPaPrivacy
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_LbsPaPrivacy
{
	/*! The size, in bytes, of this structure.  This value must always be 
		populated by the calling application. */
	U32 sizeStruct; 
	
	/*! An enumeration of type SWI_TYPE_LbsPaPrivacy representing the privacy
		level */
	SWI_TYPE_LbsPaPrivacy ePrivacy;
};

///////////////////////////////////////////////////////////////////////////////
///
/// Structure containing network access permission used during LBS sessions.
///
/// \sa SWI_TYPE_LbsPaNetAccess
/// \sa SWI_NOTIFY_LbsPaNetAccess
/// \sa SwiGetLbsPaNetAccess
/// \sa SwiSetLbsPaNetAccess
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_LbsPaNetAccess
{
	/*! The size, in bytes, of this structure.  This value must always be 
		populated by the calling application. */
	U32 sizeStruct; 
	
	/*! An enumeration of type SWI_TYPE_LbsPaNetAccess representing the
		network access permissions */
	SWI_TYPE_LbsPaNetAccess eNetAccess;
};

///////////////////////////////////////////////////////////////////////////////
///
/// Structure containing base station information.
///
/// \sa SWI_NOTIFY_LbsPaBsInfo
/// \sa SwiGetLbsPaBsInfo
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_LbsPaBsInfo
{
	U32		sizeStruct;		/*!< The size, in bytes, of this structure.  This 
								 value must always be populated by the calling
								 application. */
	bool	bInfoStale;		/*!< False if info not stale, true otherwise */
	U32		nId;			/*!< Base station ID */
	U32		nSid;			/*!< System ID */
	U32		nNid;			/*!< Network ID */
	U32		nInfoTimeHigh;	/*!< Time stamp high DWORD */
	U32		nInfoTimeLow;	/*!< Time stamp low DWORD */
	I32		nLatitude;		/*!< Base station latitude */
	I32		nLongitude;		/*!< Base station longitude */
};

///////////////////////////////////////////////////////////////////////////////
///
/// Structure containing Keep Warm start status.
///
/// This object is only supported on UMTS devices.
///
/// \sa SWI_TYPE_LbsPaErr
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_LbsPaKeepWarmStart
{
	/*! The size, in bytes, of this structure.  This value must always be 
		populated by the calling application. */
	U32 sizeStruct;
	
	/*! An enumeration of type SWI_TYPE_LbsPaErr representing the PA error
		state. */
	SWI_TYPE_LbsPaErr eStatus;
};

///////////////////////////////////////////////////////////////////////////////
///
/// Skeleton structure returned when Keep Warm processing has begun.
///
/// This object is only supported on UMTS devices.
///
/// \sa SWI_NOTIFY_LbsPaWarmBegin
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_LbsPaWarmBegin
{
	U32	sizeStruct;		/*!< The size, in bytes, of this structure. */
};

///////////////////////////////////////////////////////////////////////////////
///
/// Enumeration of Keep Warm status
///
/// \sa SWI_STRUCT_LbsPaWarmStatus
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_LbsPaWarmStatus
{
	SWI_LBSPAWARMSTATUS_NotWarm,
	SWI_LBSPAWARMSTATUS_Warm,
};

///////////////////////////////////////////////////////////////////////////////
///
/// Structure containing Keep Warm status information.
///
/// This object is only supported on UMTS devices.
///
/// \sa SWI_TYPE_LbsPaWarmStatus
/// \sa SWI_NOTIFY_LbsPaWarmStatus
/// \sa SwiGetLbsPaWarmStatus
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_LbsPaWarmStatus
{
	/*! The size, in bytes, of this structure.  This value must always be 
		populated by the calling application. */
	U32 sizeStruct;
	
	/*! True is returned if Keep Warm processing is enabled, false otherwise.*/
	bool bEnabled;
	
	/*! An enumeration of type SWI_TYPE_LbsPaWarmStatus representing the
		Keep Warm status. */
	SWI_TYPE_LbsPaWarmStatus eStatus;
};

///////////////////////////////////////////////////////////////////////////////
///
/// Skeleton structure returned when Keep Warm processing has completed.
///
/// \sa SWI_NOTIFY_LbsPaWarmDone
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_LbsPaWarmDone
{
	U32	sizeStruct;	/*!< The size, in bytes, of this structure. */
};

///////////////////////////////////////////////////////////////////////////////
///
/// Structure used to stop the Keep Warm processing.
///
/// This object is only supported on UMTS devices.
///
/// \sa SWI_TYPE_LbsPaErr
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_LbsPaKeepWarmStop
{
	/*! The size, in bytes, of this structure. */
	U32 sizeStruct;		
	
	/*! An enumeration of type SWI_TYPE_LbsPaErr representing the result of
		the Keep Warm stop request */		
	SWI_TYPE_LbsPaErr eStatus;
};

///////////////////////////////////////////////////////////////////////////////
///
/// Structure containing satellite information
///
/// \sa SWI_STRUCT_LbsSatInfo
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_SatView
{
	/*! Satellite bitmask
		- Bit 7: "1" indicates the satellite is used in latest fix
		- Bits 0-6: Satellite Number (0-32) */	
	U8  nSvNumber;			
	U8  nSvElevation;	/*!< Satellite Elevation in degrees (0-90) */	
	U16 nSvAzimuth;		/*!< Satellite Azimuth in degrees (0-360) */
	U8	nSvSnr;			/*!< Satellite Signal/Noise Ratio in dB (0-99) */
} ;

///////////////////////////////////////////////////////////////////////////////
///
/// Structure containing base station information.
///
/// Used by SwiGetLbsSatInfo to retrieve information about the current
/// base station currently being accessed.
///
/// \sa SWI_NOTIFY_LbsSatInfo
/// \sa SwiGetLbsSatInfo
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_LbsSatInfo
{
	/*! The size, in bytes, of this structure.  This value must always be 
		populated by the calling application. */
	U32 sizeStruct; 
	
	/*! Number of satellites in view (max 12) */
	U8	nSvInView;

	/*! Array of satellite information */
	SWI_STRUCT_SatView sSatView[MAX_NUM_LBS_SV];
};

///////////////////////////////////////////////////////////////////////////////
///
/// Structure containing clear assistance parameters
///
/// Used by SwiSetLbsClearAssistance to clear various location assistance
/// parameters to simulate a cold start.
///
/// \sa SwiSetLbsClearAssistance
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_LbsClearAssistance
{
	/*! The size, in bytes, of this structure.  This value must always be 
		populated by the calling application. */
	U32 sizeStruct; 
	
	/*! Set to true to clear satellite ephemeris data. */
	bool bClrEphemerisData; 
	
	/*! Set to true to clear satellite almanac data. */		
	bool bClrAlmanacData;
	
	/*! Set to true to clear position and time data. */
	bool bClrPosData;
	
	/*! Set to true to clear standalone self learning data base. */
	bool bClrSelfLearnDb;
	
	/*! Set to true to clear standalone serving system data base. */
	bool bClrServSysDb;	
	
	/*! Set to true to clear standalone time reference. */	
	bool bClrTimeRef;		
	
	/*! Set to true to reset MSB throttling parameters. */
	bool bResetThrottleParams; 
};

///////////////////////////////////////////////////////////////////////////////
///
/// Structure containing LBS user options
///
/// \sa SWI_STRUCT_LbsFixSettings
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_LbsUserOptions
{		
	/*! Indicates if the LBS option is readable by the user. */
	bool bReadable;
	
	/*! Indicates if the LBS option is writable by the user. */
	bool bWritable;
};

///////////////////////////////////////////////////////////////////////////////
///
/// Enumeration of LBS setting status return codes.
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_LbsSettingStatus
{
	SWI_LBSSETTINGSTATUS_Success,
};

///////////////////////////////////////////////////////////////////////////////
///
/// Structure containing LBS settings.
///
/// This object allows the host to use the device as storage for location
///	fix settings.  This allows the location fix settings to persist.
/// 
/// In the future if it possible that the initial values of these settings 
/// will be customized for specific carriers.  Carriers may also require that
/// some of these settings be read only.  However, until the requirements are
/// better understood this object will allow settings to be written.
///
/// \sa SWI_STRUCT_LbsUserOptions
/// \sa SWI_TYPE_LbsFix
/// \sa SWI_TYPE_LbsSettingStatus
/// \sa SwiGetLbsFixSettings
/// \sa SwiSetLbsFixSettings
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_LbsFixSettings
{
	/*! The size, in bytes, of this structure.  This value must always be 
		populated by the calling application. */
	U32 sizeStruct; 
	
	/*! An enumeration of type SWI_STRUCT_LbsUserOptions representing fix type
		user options */
	SWI_STRUCT_LbsUserOptions sFixTypeUserOp;
	
	/*! An enumeration of type SWI_TYPE_LbsFix representing the fix type 
		setting */
	SWI_TYPE_LbsFix eFixType;
	
	/*! An enumeration of type SWI_STRUCT_LbsUserOptions representing the
		performance user option. */
	SWI_STRUCT_LbsUserOptions sPerformanceUserOp;
	
	/*! Time allowed for satellite acquisition in seconds. */
	U32 nPerformance;
	
	/*! An enumeration of type SWI_STRUCT_LbsUserOptions representing the
		accuracy user option. */
	SWI_STRUCT_LbsUserOptions sAccuracyUserOp;
	
	/*! Accuracy limit preferred in meters. */
	U32 nAccuracy;
	
	/*! An enumeration of type SWI_STRUCT_LbsUserOptions representing the
		fix count user option. */
	SWI_STRUCT_LbsUserOptions sFixCountUserOp;
	
	/*! Number of fixes to obtain between 1 and 999, use 1000 for continuous
		mode. */
	U32 nFixCount;
	
	/*! An enumeration of type SWI_STRUCT_LbsUserOptions representing the
		fix rate user option. */
	SWI_STRUCT_LbsUserOptions sFixRateUserOp;
	
	/*! Frequency of fixes in seconds. */
	U32 nFixRate;
	
	/*! An enumeration of type SWI_TYPE_LbsSettingStatus representing the
		result of configuration request. */	
	SWI_TYPE_LbsSettingStatus eResult;
};

///////////////////////////////////////////////////////////////////////////////
///
/// Enumeration of LBS network initiated request responses.
///
/// \sa SWI_STRUCT_LbsNiReq
/// \sa SWI_NOTIFY_LbsNiReq
/// \sa SwiSetLbsNiReq
///
///////////////////////////////////////////////////////////////////////////////
typedef enum 
{
	/*! This value should be used with SwiSetLbsNiReq to signal the host has 
		rejected the network initiated request. */
	LBSNIREQRESP_Reject,
	
	/*! This value should be used with SwiSetLbsNiReq to signal the host has 
		accepted the network initiated request. */	
	LBSNIREQRESP_Accept,
	
	/*! This value should be used with SwiSetLbsNiReq to signal the host has
		canceled the network initiated request or the specified timeout
		period has expired. */
	LBSNIREQRESP_Cancel,
}TYPE_LbsNiReqResp;

///////////////////////////////////////////////////////////////////////////////
///
/// Enumeration of LBS network initiated error codes.
/// 
/// Used by SWI_STRUCT_LbsNiReq to indicate the status of the SwiLbsSetNiReq
/// request.
///
/// \sa SWI_STRUCT_LbsNiReq
/// \sa SwiSetLbsNiReq
///
///////////////////////////////////////////////////////////////////////////////
typedef enum 
{
	/*! Request was successful. */
	LBSNIREQERRCODE_NoError,
	
	/*! Network request ID provided is invalid. */
	LBSNIREQERRCODE_HandleMismatch,
	
	/*! Response was not received within the specified timeout period. */
	LBSNIREQERRCODE_UserRespTimeout,
	
	/*! No user response was required. */
	LBSNIREQERRCODE_NoUserRespReq,
}TYPE_LbsNiReqErrCode;

///////////////////////////////////////////////////////////////////////////////
///
/// Enumeration of LBS network initiated notification types.
/// 
/// Used by SWI_STRUCT_LbsNiReq to indicate whether the SWI_NOTIFY_LbsNiReq
/// notification requires a user response.
///
/// \sa SWI_STRUCT_LbsNiReq
/// \sa SWI_NOTIFY_LbsNiReq
/// \sa SwiSetLbsNiReq
///
///////////////////////////////////////////////////////////////////////////////
typedef enum 
{
	/*! No user response required. */
	LBSNIREQNOTIF_NotifyOnly,
	
	/*! User must respond with SwiSetLbsNiReq. */
	LBSNIREQNOTIF_UserRespReq,
}TYPE_LbsNiReqNotif;

///////////////////////////////////////////////////////////////////////////////
///
/// Enumeration of LBS network initiated requester ID types.
///
///////////////////////////////////////////////////////////////////////////////
typedef enum
{
	LBSNIREQID_Unknown,
	LBSNIREQID_LogicalName,
	LBSNIREQID_Msisdn,
	LBSNIREQID_Email,
	LBSNIREQID_Url,
	LBSNIREQID_SipUrl,
	LBSNIREQID_ImsPublicId,
	LBSNIREQID_Min,
	LBSNIREQID_Mdn,
} TYPE_LbsNiReqId;

///////////////////////////////////////////////////////////////////////////////
///
/// Enumeration of LBS network initiated client name types.
///
///////////////////////////////////////////////////////////////////////////////
typedef enum
{
	LBSNIREQCLIENTNAME_Unknown,
	LBSNIREQCLIENTNAME_LogicalName,
	LBSNIREQCLIENTNAME_Msisdn,
	LBSNIREQCLIENTNAME_Email,
	LBSNIREQCLIENTNAME_Url,
	LBSNIREQCLIENTNAME_SipUrl,
	LBSNIREQCLIENTNAME_ImsPublicId,
	LBSNIREQCLIENTNAME_Min,
	LBSNIREQCLIENTNAME_Mdn,
} TYPE_LbsNiReqClientName;

///////////////////////////////////////////////////////////////////////////////
///
/// This object contains network initiated location fix request information.
/// 
/// SWI_NOTIFY_LbsNiReq uses this object to notify the host of a network
/// initiated location fix request.  
/// 
/// SwiLbsSetNiReq uses this object to send the user's response to the modem.
/// This object also contains the response to the SwiSetLbsNiReq transaction.
///
/// \sa SWI_NOTIFY_LbsNiReq
/// \sa SwiSetLbsNiReq
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_LbsNiReq
{
	/*! The size, in bytes, of this structure.  This value must always be 
	populated by the calling application. */
	U32 sizeStruct;
	
	/*! Notification ID.  This value is returned in SWI_NOTIFY_LbsNiReq and
		must be supplied when calling SwiSetLbsNiReq. */
	U32	nNiId;
	
	/*! An enumeration of type TYPE_LbsNiReqResp, this value must be supplied
		by the caller when calling SwiSetLbsNiReq.  This value represents the
		response the user has chosen.  See notes above.  This field is not
		valid with SWI_NOTIFY_LbsNiReq. */
	TYPE_LbsNiReqResp	eReqResp; 
	
	/*! An enumeration of type TYPE_LbsNiReqErrCode which indicates the status
		of the SwiSetLbsNiReq request.  This field is not valid with 
		SWI_NOTIFY_LbsNiReq.*/
	TYPE_LbsNiReqErrCode	eErrCode;
	
	/*! Timeout period allocated for the host to respond to the network 
		initiated location fix request.  Valid ranges are between 0x0000 -
		0xFFFF.  If the host does not respond within this specified timeout
		period, the modem will assume the host has canceled the request. */
	U32	nTimeout;
	
	/*! An enumeration of type TYPE_LbsNiReqNotif which indicates whether a
		user response is required.  This field is ignored when used with
		SwiSetLbsNiReq. */
	TYPE_LbsNiReqNotif	eNotifType;
	
	/*! An enumeration of type TYPE_LbsNiReqId which indicates the format of
		szReqId.  This field is ignored when used with SwiSetLbsNiReq. */
	TYPE_LbsNiReqId	eReqIdType;
	
	/*! A NULL terminated string containing the requester ID.  */
	WCHAR szReqId[LENGTH_LbsReqId];
	
	/*! An enumeration of type TYPE_LbsNiReqClientName which indicates the
		format of szClientName.  This field is ignored when used with 
		SwiSetLbsNiReq. */
	TYPE_LbsNiReqClientName	eClientName;
	
	/*! A NULL terminated string containing the client name.  */
	WCHAR	szClientName[LENGTH_LbsClientName];
};

/////////////////////////////////////////////////////////////////////////////////
///
/// This data structure is used as a member of the SWI_HW_NOTIFY_Power
/// notification.  
///
///	\sa SWI_TYPE_Power
///	\sa SWI_HW_NOTIFY_Power
///
/////////////////////////////////////////////////////////////////////////////////
struct SWI_HW_STRUCT_Power
{
	/*!	The size, in bytes, of this structure. */
	U32 sizeStruct;		

	/*! Current power state of the modem. */		
	SWI_TYPE_Power State;	
};

/** 
* \addtogroup GroupModemInfo Modem Information and Management
*/
/*@{*/

///////////////////////////////////////////////////////////////////////////////
///
/// Enumeration of device information types.
/// 
/// Used by SWI_STRUCT_DeviceInformation_Request and 
/// SWI_STRUCT_DeviceInformation_Response to indicate the type of data being
/// requested in ::SwiGetDeviceInformation.
///
/// \sa SWI_STRUCT_DeviceInformation_Request
/// \sa SWI_STRUCT_DeviceInformation_Response
/// \sa SwiGetDeviceInformation
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_DeviceInformationType
{
	SWI_DEVICEINFORMATION_Technology = 1,	/*!< Technology type (CDMA, GPRS) */
	SWI_DEVICEINFORMATION_Product,			/*!< Product string */
	SWI_DEVICEINFORMATION_FrmDwlProtocol,	/*!< Firmware download protocol */
	SWI_DEVICEINFORMATION_DeviceReEnum,		/*!< Device re-enumeration */
	SWI_DEVICEINFORMATION_CnS,				/*!< Proprietary control and status
												 protocol support */
	SWI_DEVICEINFORMATION_CweHdrProdType,	/*!< CWE header product type */
};

///////////////////////////////////////////////////////////////////////////////
///
/// Enumeration indicates return status of request.
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_RequestStatus
{
	SWI_REQUESTSTATUS_SUCCESS,
	SWI_REQUESTSTATUS_UnknownType,
	SWI_REQUESTSTATUS_GenFailure
};

///////////////////////////////////////////////////////////////////////////////
///
/// Enumeration of control and status protocol technology.
/// 
/// Returned by ::SwiGetDeviceInformation in conjunction with 
/// SWI_DEVICEINFORMATION_Technology information request.
///
/// \sa SWI_TYPE_DeviceInformationType
/// \sa SwiGetDeviceInformation
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_Technology
{
	SWI_TECHNOLOGY_Unknown,
	SWI_TECHNOLOGY_CDMA,
	SWI_TECHNOLOGY_GSM
};

//////////////////////////////////////////////////////////////////////////////
///
/// Enumeration of protocols to be used for firmware download.
/// 
/// Returned by SwiGetDeviceInformation in conjunction with 
/// SWI_DEVICEINFORMATION_FrmDwlProtocol information request.
///
/// \sa SWI_TYPE_DeviceInformationType
/// \sa SwiGetDeviceInformation
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_FrmDlwProtocol
{
    /*! 0x00  Host must use firmware download protocol 1 to download images 
        to this modem */
	SWI_FRMDLWPROTOCOL_One,

    /*! 0x01  Host must use firmware download protocol 2 to download images 
        to this modem */
	SWI_FRMDLWPROTOCOL_Two,

	/*! 0x02 - Host must use firmware download protocol 3 to download images
		to htis modem */
	SWI_FRMDLWPROTOCOL_Three,
};

//////////////////////////////////////////////////////////////////////////////
///
/// Enumeration of PnP behaviour.
/// 
/// Returned by SwiGetDeviceInformation in conjunction with 
/// SWI_DEVICEINFORMATION_DeviceReEnum information request.
///
/// \sa SWI_TYPE_DeviceInformationType
/// \sa SwiGetDeviceInformation
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_DeviceReEnum
{
    /*! 0x00  Modem reset causes PnP device removal/arrival or media 
        disconnect/reconnect notifications on the host platform */
    SWI_DEVICEREENUM_Trigger_Remove,   

    /*! 0x01  Modem reset does not trigger PnP device removal/arrival or 
        media disconnect/reconnect notifications on the host platform */
	SWI_DEVICEREENUM_Trigger_NoRemove  
};

///////////////////////////////////////////////////////////////////////////////
///
///	This structure sets the context for a device information request.
///
///	This structure is used by ::SwiGetDeviceInformation to specify the type of
/// information to be retrieved about the physical device.
///
/// See Also
///
///	\sa	SwiGetDeviceInformation
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_DeviceInformation_Request
{
	/*! The size, in bytes, of this structure.  This value must always be 
		populated by the calling application. */
	U32	sizeStruct;	

	/*! Device information request type. */
    SWI_TYPE_DeviceInformationType eDeviceInformationType; 
};

///////////////////////////////////////////////////////////////////////////////
///
///	This structure contains the response for a device information request.
///
///	This structure is used by ::SwiGetDeviceInformation to retrieve
///	fundamental information about the stack's physical device.
///
/// See Also
///
///	\sa	SwiGetDeviceInformation
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_DeviceInformation_Response
{
	/*! The size, in bytes, of this structure. */
	U32 sizeStruct;

    /*! Request status. */
	SWI_TYPE_RequestStatus eRequestStatus;		

    /*! Device information request type. */
	SWI_TYPE_DeviceInformationType eDeviceInformationType;

    /*! Valid if eDeviceInformationType = SWI_DEVICEINFORMATION_Technology. */
	SWI_TYPE_Technology eTechnology;

    /*! Valid if eDeviceInformationType = SWI_DEVICEINFORMATION_Product. */	
	WCHAR szProduct[LENGTH_ProductString];

    /*! Valid if eDeviceInformationType = SWI_DEVICEINFORMATION_FrmDwlProtocol. */
	SWI_TYPE_FrmDlwProtocol eFrmDlwProtocol;

	/*! Valid if eDeviceInformationType = SWI_DEVICEINFORMATION_DeviceReEnum. */
	SWI_TYPE_DeviceReEnum eDeviceReEnum;

	/*! Valid if eDeviceInformationType = SWI_DEVICEINFORMATION_CnS.
		Proprietary control and status protocol supported */
	BOOL bCnsSupported;

	/*!	Valid if eDeviceInformationType = SWI_DEVICEINFORMATION_CweHdrProdType.
		CWE header product type */
	WCHAR szCweHeaderProductType[LENGTH_CweHeaderProductType];
};

/*@}*/	// End of modem information and management group

/**
* \addtogroup GroupNotif Notifications
*/
/*@{*/

///////////////////////////////////////////////////////////////////////////////
///
/// This enumerated data type defines a variety of notification types.
///
/// API notifications are always enabled while modem originated notifications
/// must be enabled before an update is sent form the modem.  Notifications are
/// disabled by default at power up and after a reset.  Therefore, application
/// must re-enable all desired notifications when device powers up or a reset
/// is detected.
///
///	The following common API notifications are always enabled and do not 
/// require enabling.  Modem originated notifications must be enabled
/// before an update is sent from the modem.
///		- SWI_NOTIFY_AirServerChange
///		- SWI_NOTIFY_LockAirServer
///		- SWI_HW_NOTIFY_Power
///		- SWI_NOIIFY_Power
///		- SWI_NOTIFY_MUX_Shutdown
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_Notify
{	
	/*! Invalid notification.  This is simply a place holder. */
	SWI_NOTIFY_NULL,	
	
	/*! Air server insertion/removal notification.  This notification is 
		always enabled and can not be disabled. 
		\sa The corresponding user structure is SWI_STRUCT_AirServerChange */
	SWI_NOTIFY_AirServerChange,
	
	/*! Air server lock notification.  This notification is always enabled
		and can not be disabled. 
		\sa The corresponding user structure is SWI_STRUCT_LockAirServer*/
	SWI_NOTIFY_LockAirServer,	
	
	/*! Hardware power state change. No need to re-enable mask.  This 
		notification is always enabled and can not be disabled.  Only supported
		on CDMA devices.
		\sa The corresponding user structure is SWI_HW_STRUCT_Power */
	SWI_HW_NOTIFY_Power = 4,
	
	/*! Device power notification.  Previously used to indicate device 
		removal.  SWI_NOTIFY_AirServerChange should now be used instead. 
		This notification is always enabled and can not be disabled. 
		\sa The corresponding user structure is SWI_STRUCT_Power */			
	SWI_NOTIFY_Power,
	
	/*! API service has shutdown.  API service must be restarted and 
		SwiApiClose and SwiApiOpenEx must be called before normal operation
		can proceed.  This notification is always enabled and can not be
		disabled.  This notification does not have an associated user 
		structure. */
	SWI_NOTIFY_MUX_Shutdown,

	/*! Provides a mechanism to assure the application that the modem is still
		connected and running normally.  This event is forwarded approximately
		every 10 seconds.  It is recommended that this object no longer be used
		as it prevents the host USB bus controller from entering into low
		power state to conserve battery life.
		\sa The corresponding user structure is SWI_STRUCT_HeartBeat */
	SWI_NOTIFY_HeartBeat = 100,	
	
	/*! Notifies the app of headset attachment state.
		\sa The corresponding user structure is SWI_STRUCT_HeadsetIcon */
	SWI_NOTIFY_HeadsetIcon,
	
	/*! Notifies the application of the headset state.  Headset state is not
		supported on the SB555. 
		\sa The corresponding user structure is SWI_STRUCT_HeadsetState */
	SWI_NOTIFY_HeadsetState,
	
	/*! The Received Signal Strength Indicator (RSSI) is reported only when the
		value changes.  The notification is issued at the slot cycle index as
		set by the service provider.  For larger slot cycle indexes, the 
		notification is issued less often.  A slot cycle index of 1 generates
		this notification at about 2-second intervals. 
		\sa The corresponding user structure is SWI_STRUCT_Rssi */
	SWI_NOTIFY_Rssi,
	
	/*! Indicates to the application that there is a problem with the antenna.
		It should be assumed that the problem will not persist longer than 10
		seconds.  If the antenna problem continues another transmit alert event
		will be generated by the modem. 
		\sa The corresponding user structure is SWI_STRUCT_TransmitAlert */
	SWI_NOTIFY_TransmitAlert,
	
	/*! Reports to the application when the modem resets. This notification is
		received when modem is inserted, after power up, after a firmware
		download and during any process which cause a modem reset.  Modem 
		notifications which were previously enabled, will default back to its
		original state (off).  When received, the application must re-enable 
		all desired notifications again.  This notification is always enabled 
		and can not be disabled. 
		\sa The corresponding user structure is SWI_STRUCT_Reset */
	SWI_NOTIFY_Reset,	
	
	/*! Provides the application with band status updates, typically occurring
		after the frequency band has changed. 
		\sa The corresponding user structure is SWI_STRUCT_Band*/
	SWI_NOTIFY_Band,
	
	/*! Not supported in this version of the SDK.
		\sa The corresponding user structure is SWI_STRUCT_Debug */
	SWI_NOTIFY_Debug,
	
	/*! Provides firmware download progress status.  Errors during the firmware
		download process are also reported. 
		\sa The corresponding user structure is SWI_STRUCT_FwDownload*/
	SWI_NOTIFY_FwDownload,
	
	/*! Not supported in this version of the SDK.
		\sa The corresponding user structure is SWI_STRUCT_Dhcp */
	SWI_NOTIFY_Dhcp,
	
	/*! Not supported in this version of the SDK.
		\sa The corresponding user structure is SWI_STRUCT_PPP */
	SWI_NOTIFY_PPP,
	
	/*! Indicates the modem power state has changed.  This notification is only
		available on 3G or newer CDMA and GSM products.  
		\sa The corresponding user structure is SWI_STRUCT_RadioPower. */
	SWI_NOTIFY_RadioPower,
	
	/*! Indicates the modem temperature state has changed.  This notification 
		is only available on 3G or newer CDMA and GSM products. 
		\sa The corresponding user structure is SWI_STRUCT_RadioTempState. */
	SWI_NOTIFY_RadioTempState,
	
	/*! Indicates the current supply voltage of the modem has changed.  This 
		notification is only available on CDMA and GSM MiniCard products. 
		\sa The corresponding user structure is SWI_STRUCT_RadioBattery. */
	SWI_NOTIFY_RadioBattery,
	
	/*! Indicates there is a change in the band(s) the modem is currently 
		using.  This notification is available on 3G CDMA and GSM products.
		On some CDMA devices, multiple bands can be used at one time.  
		\sa The corresponding user structure is SWI_STRUCT_RadioBandList. */
	SWI_NOTIFY_RadioBand,
	
	/*! Indicates there is a change in the modem's audio profile.  This 
		notification is available on 3G CDMA and GSM products.  
		\sa The corresponding user structure is SWI_STRUCT_AudioProfile. */
	SWI_NOTIFY_AudioProfile,
	
	/*! Indicates a change in the system time of the device  This notification
		is available on 3G CDMA and GSM products.  This notification is only 
		sent on initial network attach for GSM products, when service is
		acquired/reacquired for CDMA based products, and if and when the time
		zone information changes. 
		\sa The corresponding user structure is SWI_STRUCT_DeviceTime. */
	SWI_NOTIFY_DeviceTime,

	/*! MP firmware download notification.  There is no user structure
		associated with this object. */
	SWI_NOTIFY_MpFwDownload = 300,
	
	/*! Provides constant and up-to-date GPS information at regular intervals.
		\sa The corresponding user structure is SWI_STRUCT_Gps */
	SWI_NOTIFY_Gps,		
	
	/*! Provides current logic level of all external digital I/Os.
		\sa The corresponding user structure is SWI_STRUCT_ExtDioNotif */
	SWI_NOTIFY_ExtDio,
	
	/*! Provides current logic level of all external analog inputs.
		\sa The corresponding user structure is SWI_STRUCT_ExtAiNotif */
	SWI_NOTIFY_ExtAi,	
	
	/*! Provides the result/response of a GPS command sent to the GPS module
		in the modem.
		\sa The corresponding user structure is SWI_STRUCT_GpsCommand */
	SWI_NOTIFY_GpsCommand,	
	
	/*! Provides byte counter information.
		\sa The corresponding user structure is SWI_STRUCT_MpByteCounter */		
	SWI_NOTIFY_MpByteCount,	
	
	/*! First informs the host software when the ignition is turned off, then 
		when shutdown time approaches, more notifications are sent to indicate
		that the MP750 will soon be shutdown.
		\sa The corresponding user structure is SWI_STRUCT_IgnSense */
	SWI_NOTIFY_MPIgnSense,
	
	/*! RF download progress.
		\sa The corresponding user structure is SWI_STRUCT_RfDownload */			
	SWI_NOTIFY_RfDownload,	
	
	/*! Provides SIM sled status.
		\sa The corresponding user structure is SWI_STRUCT_SimSled */		
	SWI_NOTIFY_SimSled,		
	
	/*! Provides low battery alert.
		\sa The corresponding user structure is SWI_STRUCT_BatteryStatus */		
	SWI_NOTIFY_BatteryStatus,
	
	/*! Provides the reason behind a MP shutdown 
		\sa The corresponding user structure is SWI_STRUCT_MpShutdown */
	SWI_NOTIFY_MpShutdown,	
	
	/*! Provides MP test connection result (Under a Serial connection). 
		Provides MP connection result (Under a USB connection)
		\sa The corresponding user structure is SWI_STRUCT_MpConnect */
	SWI_NOTIFY_MpConnect,
	
	/*! MP startup diagnostics.
		\sa The corresponding user structure is SWI_STRUCT_MpStartupDiag */
	SWI_NOTIFY_MpStartupDiag,	
	
	/*! MP disconnect notification.  
		\sa The corresponding user structure is SWI_STRUCT_MpDisconnect */	
	SWI_NOTIFY_MpDisconnect,	

	/*! Reports the status of SMS records on the modem whenever a new message
		arrives.  Whenever an SMS message arrives, the modem can generate this
		event notification.  The data reported advises the application of the 
		number of SMS messages stored in the modem.  This SmsStatus 
		notification will trigger on the arrival of any SMS message that can 
		be stored in the modem. If the modem memory fills, and additional
		messages are declined, there will be no further notifications.
		\sa The corresponding user structure is SWI_STRUCT_GSM_SMS_Status for
		GMS devices and SWI_STRUCT_CDMA_SMS_Status for CDMA devices. */
	SWI_NOTIFY_SmsStatus = 500,
	
	/*! Reports the results of sending a mobile originated SMS message.  This 
		notification passes the acknowledgment from the network to the 
		application for SMS messages sent. 
		\sa The corresponding user structure is SWI_STRUCT_GSM_SMS_SendStatus 
		for GSM devices and SWI_STRUCT_CDMA_SMS_SendStatus for CDMA devices. */
	SWI_NOTIFY_SmsSendStatus,

	/*! Notifies the host application of the result of the position fix. 
		\sa The corresponding user structure is SWI_STRUCT_LbsPdData. */
	SWI_NOTIFY_LbsPdData = 603,
	
	/*! Notifies the host application that a position determination download
		session has completed. 
		\sa The corresponding user structure is SWI_STRUCT_LbsPdDone. */ 
	SWI_NOTIFY_LbsPdDone,
	
	/*! Notifies the host application that a position determination fix session
		had an error. 
		\sa The corresponding user structure is SWI_STRUCT_LbsPdEnd. */
	SWI_NOTIFY_LbsPdEnd,
	
	/*! Notifies the host application that a position determination fix session
		has begun. 
		\sa The corresponding user structure is SWI_STRUCT_LbsPdBegin. */
	SWI_NOTIFY_LbsPdBegin,
	
	/*! Notifies the host application that a position determination session
		has failed. 
		\sa The corresponding user structure is SWI_STRUCT_LbsPdUpdateFailure. */
	SWI_NOTIFY_LbsPdUpdateFailure,
	
	/*! Notifies the host application that a data download session has begun.
		\sa The corresponding user structure is SWI_STRUCT_LbsPdDloadBegin. */
	SWI_NOTIFY_LbsPdDloadBegin,
	
	/*! Notifies the host application that ephemeris and almanac data has been
		downloaded.
		\sa The corresponding user structure is SWI_STRUCT_LbsPdDloadData. */
	SWI_NOTIFY_LbsPdDloadData,
	
	/*! Notifies the host application that a position determination download
		session has completed. 
		\sa The corresponding user structure is SWI_STRUCT_LbsPdDloadDone. */
	SWI_NOTIFY_LbsPdDloadDone,
	
	/*! Notifies the host application that a position determination download
		data session had an error. 
	\sa The corresponding user structure is SWI_STRUCT_LbsPdDloadEnd. */
	SWI_NOTIFY_LbsPdDloadEnd,
	
	/*! This notification contains the default value for the TCP/IP address
		used in LBS sessions. 
		\sa The corresponding user structure is SWI_STRUCT_LbsPaIpAddr. */
	SWI_NOTIFY_LbsPaIpAddr,
	
	/*! This notification contains the default value for the GPS lock used in
		LBS sessions. 
		\sa The corresponding user structure is SWI_STRUCT_LbsPaGpsLock. */
	SWI_NOTIFY_LbsPaGpsLock,
	
	/*! This notification contains the mechanism used to transport LBS 
		messages.
		\sa The corresponding user structure is SWI_STRUCT_LbsPaPtlmMode. */
	SWI_NOTIFY_LbsPaPtlmMode,
	
	/*! This notification contains the default value for the port ID used in
		LBS sessions. 
		\sa The corresponding user structure is SWI_STRUCT_LbsPaPortId. */
	SWI_NOTIFY_LbsPaPortId,
	
	/*! This notification contains the default value for the privacy level
		used for LBS sessions. 
		\sa The corresponding user structure is SWI_STRUCT_LbsPaPrivacy. */
	SWI_NOTIFY_LbsPaPrivacy,
	
	/*! This notification contains the default value for the network access
		permissions used during LBS sessions.
		\sa The corresponding user structure is SWI_STRUCT_LbsPaNetAccess. */
	SWI_NOTIFY_LbsPaNetAccess,
	
	/*! This notification contains the base station currently being accessed. 
		\sa The corresponding user structure is SWI_STRUCT_LbsPaBsInfo. */
	SWI_NOTIFY_LbsPaBsInfo,
	
	/*! Notifies the registered host application that keep warming processing
		has begun.  
		\sa The corresponding user structure is SWI_STRUCT_LbsPaWarmBegin. */
	SWI_NOTIFY_LbsPaWarmBegin,
	
	/*! This notification reports the keep warm processing status and is only
		available on GSM devices. 
		\sa The corresponding user structure is SWI_STRUCT_LbsPaWarmStatus. */
	SWI_NOTIFY_LbsPaWarmStatus,
	
	/*! Notifies the host application that keep warm processing is done. 
		\sa The corresponding user structure is SWI_STRUCT_LbsPaWarmDone. */
	SWI_NOTIFY_LbsPaWarmDone,
	
	/*! This notification lists satellites visible during the last position fix
		session.  It also identifies the satellites used in the latest position
		fix. 
		\sa The corresponding user structure is SWI_STRUCT_LbsSatInfo. */
	SWI_NOTIFY_LbsSatInfo,
	
	/*! This notification provides the current status of the LBS. 
		\sa The corresponding user structure is SWI_STRUCT_LbsPdGetStatus. */
	SWI_NOTIFY_LbsPdGetStatus,
	
	/*! Notifies the host of a network initiated location fix request. 
	
		The associated user structure is SWI_STRUCT_LbsNiReq.  The host should 
		display the requester ID and client name if these fields are present.  
	 
		If the notification type requires a user response, the host should 
		present a dialog to the user with the options &quot;Accept&quot; and 
		&quot;Reject&quot; for the user to choose from.  The host will respond 
		using SwiSetLbsNiReq to the modem based on the user&apos;s selection
		(TYPE_LbsNiReqResp).  If the user chooses not to respond (ex. closed 
		dialog box), the host must respond with a set request where the user 
		response is &quot;Cancel request&quot;.  If the user does not respond 
		to the dialog within the specified timeout period, the host should
		close the dialog and send a set request where the user response is 
		&quot;Cancel request&quot;.  Note that the modem will assume the user 
		response is &quot;Cancel request&quot; after the timeout period has 
		elapsed regardless of what the host continues to send.
		
		\sa SWI_STRUCT_LbsNiReq 
		\sa SwiSetLbsNiReq */
	SWI_NOTIFY_LbsNiReq,

	/*! Reports each channel number the radio tunes to.  Using this 
		notification type, the application is advised each time the radio tunes
		to a different channel. This can be very frequent when the radio is 
		scanning for a usable channel.  
		
		Only supported on CDMA devices.
		\sa The corresponding user structure is SWI_STRUCT_ChannelNumber */
	SWI_NOTIFY_ChannelNumber = 1000,
	
	/*! Reports channel acquisition and scanning.  Using this notification 
		type, the application can keep the user aware of changes in the channel
		lock of the radio. Whenever the radio acquires or loses a channel,
		this notification is issued.  
		
		Only supported on CDMA devices.
		\sa The corresponding user structure is SWI_STRUCT_ChannelState */
	SWI_NOTIFY_ChannelState,
	
	/*! Reports entering and leaving coverage.  Using this notification type, 
		the application can keep the user aware of changes in the channel lock
		of the radio. Whenever the radio acquires or loses a channel, this 
		notification is issued.  
		
		Only supported on CDMA devices.
		\sa The corresponding user structure is SWI_STRUCT_ServiceIndication */
	SWI_NOTIFY_ServiceIndication,
	
	/*! Reports the current roaming state of the modem.  Using this 
		notification type, the application can keep the user aware of changes
		in the received signal strength.  
		
		Only supported on CDMA devices.
		\sa The corresponding user structure is SWI_STRUCT_RoamingStatus */
	SWI_NOTIFY_RoamingStatus,
	
	/*! Not supported in this version of the SDK. */
	SWI_NOTIFY_Ecio,
	
	/*! Not supported in this version of the SDK. */
	SWI_NOTIFY_AuthenticationStatus,
	
	/*! Reports data traffic received and transmitted.  Using this notification
		type, the application can keep the user aware of the amount of traffic 
		on the current connection. The notification is issued at 1-second 
		intervals during a data connection.  
		
		Only supported on CDMA devices.
		\sa The corresponding user structure is SWI_STRUCT_CallByteCounter */
	SWI_NOTIFY_CallByteCounter,
	
	/*! Reports when a call connection is initiated.  This notification 
		advises the application that the process of connecting a call has
		initiated. There is no polling equivalent.  This notification is
		enabled and disabled via SWI_NOTIFY_CallNotificationStatus.
		 
		Only supported on CDMA devices.
		\sa The corresponding user structure is SWI_STRUCT_CallConnecting */
	SWI_NOTIFY_CallConnecting,
	
	/*! Reports the successful connection of a call.  This notification 
		advises the application that a call has been successfully connected. 
		This notification is enabled and disabled via 
		SWI_NOTIFY_CallNotificationStatus.  
		
		Only supported on CDMA devices.
		\sa The corresponding user structure is SWI_STRUCT_CallConnected */
	SWI_NOTIFY_CallConnected,
	
	/*! Equivalent to a ring, this advises of the incoming call type as 
		well.  This notification advises the application that there is an 
		incoming call request.  This notification is enabled and disabled via
		SWI_NOTIFY_CallNotificationStatus.  
		
		Only supported on CDMA devices.
		\sa The corresponding user structure is SWI_STRUCT_CallIncoming */
	SWI_NOTIFY_CallIncoming,
	
	/*! Reports the standard caller ID of incoming calls (where supported by 
		the network).  This notification type passes the caller ID string to 
		the application for incoming calls (where supported by the network).
		The format of the string is determined by the network. Both the 
		standard and extended caller IDs are sent if enabled. 
		
		Only supported on CDMA devices.
		\sa The corresponding user structure is SWI_STRUCT_CallCallerID */
	SWI_NOTIFY_CallCallerID,
	
	/*! Reports the extended caller ID of incoming calls (where supported by 
		the network).  This notification type passes an extended caller ID 
		string to the application for incoming calls (where supported by the 
		network).  The format of the string is determined by the network. Both
		the standard and extended caller IDs are sent if enabled.  
		
		Only supported on CDMA devices.
		\sa The corresponding user structure is SWI_STRUCT_CallExtendedCallerID */
	SWI_NOTIFY_CallExtendedCallerID,
	
	/*! Reports when a call is disconnected.  This notification advises the 
		application that a call has been disconnected. This notification is
		enabled and disabled via SWI_NOTIFY_CallNotificationStatus. 
		
		Only supported on CDMA devices.
		\sa The corresponding user structure is SWI_STRUCT_CallDisconnected */
	SWI_NOTIFY_CallDisconnected,
	
	/*! Reports errors in call management operations.  This notification 
		advises the application that an error or fault has been detected in a
		call.  This can happen anytime during a connection.  This notification
		is enabled and disabled via SWI_NOTIFY_CallNotificationStatus.
		
		Only supported on CDMA devices.
		\sa The corresponding user structure is SWI_STRUCT_CallError */
	SWI_NOTIFY_CallError,
	
	/*! Reports changes in the protocol revision available from the serving
		base station.  This notification type advises the application when 
		there is a change in the protocol revision supported by the serving 
		base station.  
		
		Only supported on CDMA devices.
		\sa The corresponding user structure is SWI_STRUCT_Prev */
	SWI_NOTIFY_Prev,
	
	/*! Only supported on CDMA devices. */
	SWI_NOTIFY_ActiveNam,
	
	/*! Only supported on CDMA devices. */
	SWI_NOTIFY_TechSid,
	
	/*! Only supported on CDMA devices. */
	SWI_NOTIFY_TechNid,
	
	/*! Only supported on CDMA devices. */
	SWI_NOTIFY_TechBsInfo,
	
	/*! Reports changes in the radio band being used (cellular or PCS).  This 
		notification type informs the application of changes in the radio
		band being used: cellular or PCS.  
		
		Only supported on CDMA devices.
		\sa The corresponding user structure is SWI_STRUCT_TechBandClass */
	SWI_NOTIFY_TechBandClass,
	
	/*! Only supported on CDMA devices. */
	SWI_NOTIFY_TechRegZone,
	
	/*! Only supported on CDMA devices. */
	SWI_NOTIFY_TechPacketZone,
	
	/*! Only supported on CDMA devices. */
	SWI_NOTIFY_TechPcsBlock,
	
	/*! Only supported on CDMA devices. */
	SWI_NOTIFY_TechCellChannel,
	
	/*! Only supported on CDMA devices.*/
	SWI_NOTIFY_SystemTime,
	
	/*! Only supported on CDMA devices. */
	SWI_NOTIFY_ActivationStatus,
	
	/*! Only supported on CDMA devices. */
	SWI_NOTIFY_V42BisEnabled,
	
	/*! Enables and disables a group of notifications related to call 
		management.  This notification type is used to enable and disable
		the following call management notifications as a single block:
			- SWI_NOTIFY_CallConnecting
			- SWI_NOTIFY_CallConnected
			- SWI_NOTIFY_CallIncoming
			- SWI_NOTIFY_CallDisconnected
			- SWI_NOTIFY_CallError
			- SWI_NOTIFY_CallDormant
			- SWI_NOTIFY_OTASPState
			
		There is no actual notification data associated with 
		CallNotificationStatus itself.  
		
		Only supported on CDMA devices.
		\sa SWI_NOTIFY_CallConnecting
		\sa SWI_NOTIFY_CallConnected
		\saSWI_NOTIFY_CallIncoming
		\saSWI_NOTIFY_CallDisconnected
		\saSWI_NOTIFY_CallError
		\saSWI_NOTIFY_CallDormant
		\saSWI_NOTIFY_OTASPState */
	SWI_NOTIFY_CallNotificationStatus,
	
	/*! Reports when a call enters dormant state.  This notification advises
		the application that a call has been placed in dormant state.  When a
		call leaves dormant state, the SWI_NOTIFY_CallConnected notification 
		is issued.  This notification is enabled and disabled via 
		SWI_NOTIFY_CallNotificationStatus.  
		
		Only supported on CDMA devices.
		\sa The corresponding user structure is SWI_STRUCT_CallDormant */
	SWI_NOTIFY_CallDormant,
	
	/*! Reports changes in voice call privacy.  When the Enhanced Privacy 
		Option is enabled (at manufacturing time), the modem issues a request
		to use the Call Privacy feature whenever a voice call (both incoming 
		and outgoing) is established. The base station can accept or reject 
		the request depending on its settings. If voice privacy is successfully
		established, this notification indicates that call privacy is on. In 
		addition, when a handover to a new base station occurs, the voice 
		privacy feature may or may not be available at the new base station;
		again triggering the notificiation if there is a change.  
		
		Only supported on CDMA devices.
		\sa The corresponding user structure is SWI_STRUCT_CallPrivacy */
	SWI_NOTIFY_CallPrivacy,
	
	/*! Reports entry to, and exit from, E911 mode.  This notification type 
		advised the application when the modem enters or leaves E911 mode.
		 
		Only supported on CDMA devices.
		\sa The corresponding user structure is SWI_STRUCT_E911Mode */
	SWI_NOTIFY_E911Mode,
	
	/*! Not supported in this version of the SDK. */
	SWI_NOTIFY_ModemTooHotIndication,
	
	/*! Reports each stage of the OTASP process.  This notification advises
		the application that a call has been placed in dormant state. This 
		notification is enabled and disabled via 
		SWI_NOTIFY_CallNotificationStatus.  
		
		Only supported on CDMA devices.
		\sa The corresponding user structure is SWI_STRUCT_OTASPState
		\sa SWI_NOTIFY_CallNotificationStatus */
	SWI_NOTIFY_OTASPState,
	
	/*! Reports entry to power-save mode.  This notification type advised the
		application when the modem enters power-save mode.  
		
		Only supported on CDMA devices.
		\sa The corresponding user structure is SWI_STRUCT_PowerSaveEnter */
	SWI_NOTIFY_PowerSaveEnter,
	
	/*! Reports exit from power-save mode.  This notification type advised the
		application when the modem leaves power-save mode.  
		
		Only supported on
		CDMA devices.
		\sa The corresponding user structure is SWI_STRUCT_PowerSaveExit */
	SWI_NOTIFY_PowerSaveExit,
	
	/*! Not supported in this version of the SDK. */
	SWI_NOTIFY_FlashBurn,
	
	/*! Not supported in this version of the SDK. */
	SWI_NOTIFY_ExcessSPCFailure,
	
	/*! Not supported in this version of the SDK. */
	SWI_NOTIFY_HdrNotificationStatus,
	
	/*! Not supported in this version of the SDK.  Use SWI_NOTIFY_Hdr_Srv_State
		instead.
		\sa SWI_NOTIFY_Hdr_Srv_State */
	SWI_NOTIFY_Hdr_Acq,
	
	/*! Not supported in this version of the SDK.  Use 
		SWI_NOTIFY_Rssi_Ecio instead.
		\sa SWI_NOTIFY_Rssi_Ecio */
	SWI_NOTIFY_Hdr_Rssi,
	
	/*! Indicates a threshold change in RSSI or EcIo.  
	
		Only supported on CDMA
		devices.
		\sa The corresponding user structure is SWI_STRUCT_Rssi_Ecio */
	SWI_NOTIFY_Rssi_Ecio,
	
	/*! Indicates a change in HDR Roam status.  
	
		Only supported on CDMA devices.
		\sa The corresponding user structure is SWI_STRUCT_Hdr_Roam_Status */
	SWI_NOTIFY_Hdr_Roam_Status,
	
	/*! Indicates a change in HDR Service State.  
	
		Only supported on CDMA devices.
		\sa The corresponding user structure is SWI_STRUCT_Hdr_Srv_State */
	SWI_NOTIFY_Hdr_Srv_State,
	
	/*! Indicates a change in HDR Hybrid Pref.  
	
		Only supported on CDMA devices.
		\sa The corresponding user structure is SWI_STRUCT_Hdr_Hybr_Pref */
	SWI_NOTIFY_Hdr_Hybr_Pref,
	
	/*! Not supported in this version of the SDK. */
	SWI_NOTIFY_Idle_Digital_Mode,
	
	/*! Indicates a change in DDTM pref.  
	
		Only supported on CDMA devices.
		\sa The corresponding user structure is SWI_STRUCT_DDTM_Pref */
	SWI_NOTIFY_DDTM_Pref,
	
	/*! Indicates when modem has entered HDR Power save mode.  
	
		Only supported on CDMA devices.
		\sa The corresponding user structure is SWI_STRUCT_Hdr_PowerSave_Enter */
	SWI_NOTIFY_Hdr_PowerSave_Enter,
	
	/*! Indicates when modem has exited HDR power save mode.  Only supported 
		on CDMA devices.
		\sa The corresponding user structure is SWI_STRUCT_Hdr_PowerSave_Exit */
	SWI_NOTIFY_Hdr_PowerSave_Exit,
	
	/*! Not supported in this version of the SDK. */
	SWI_NOTIFY_TechHdrNotificationStatus,
	
	/*! Not supported in this version of the SDK. */
	SWI_NOTIFY_Tech_Hdr_Prev,
	
	/*! Not supported in this version of the SDK. */
	SWI_NOTIFY_Tech_Hdr_Sector,
	
	/*! Not supported in this version of the SDK. */
	SWI_NOTIFY_Tech_Hdr_State,
	
	/*! Not supported in this version of the SDK. */
	SWI_NOTIFY_Tech_Hdr_Channel,
	
	/*! Not supported in this version of the SDK. */
	SWI_NOTIFY_Tech_Hdr_Session,
	
	/*! Not supported in this version of the SDK. */
	SWI_NOTIFY_Tech_Hdr_An_Auth,
	
	/*! Not supported in this version of the SDK. */
	SWI_NOTIFY_Tech_Hdr_Drc_Val,
	
	/*! Not supported in this version of the SDK. */
	SWI_NOTIFY_Tech_Hdr_Drc_Cover,
	
	/*! Not supported in this version of the SDK. */
	SWI_NOTIFY_Tech_Hdr_Rri,
	
	/*! Not supported in this version of the SDK. */
	SWI_NOTIFY_Tech_Hdr_Stats,
	
	/*! Not supported in this version of the SDK. */
	SWI_NOTIFY_DebugRevMsg,
	
	/*! Not supported in this version of the SDK. */
	SWI_NOTIFY_SPCS_HIOTA_STATUS,
	
	/*! Not supported in this version of the SDK. */
	SWI_NOTIFY_RuimStatus,
	
	/*! Embedded IOTA  status notification.  Need to enable/disable the mask.
	
		Only supported on CDMA devices.
		\sa The corresponding user structure is SWI_STRUCT_IOTA_State */
	SWI_NOTIFY_IOTA_Status,	
	
	/*! Embedded IOTA  WAP URI notification.  This should be enabled to receive
		the WAP trigger.  
		
		Only supported on CDMA devices.
		\sa The corresponding user structure is SWI_STRUCT_IOTA_WAPPush */		
	SWI_NOTIFY_IOTA_WAPPush,

	/*! Notifies the application of the network status with each change
		in service (status, roaming, cell ID, etc).
		
		Only supports GSM devices.
		\sa The corresponding user structure is SWI_STRUCT_GSM_NetworkStatus */
	SWI_NOTIFY_NetworkStatus = 2000,
	
	/*! Reports the temperature of the radio whenever it changes. If the 
		temperature gets high, the application may elect to disconnect or 
		throttle back on traffic.		
		
		Only supports GSM devices. 
		\sa The corresponding user structure is SWI_STRUCT_Temperature */
	SWI_NOTIFY_Temperature,		
	
	/*! Reports that the SIM Card memory has been filled and any subsequent SMS
		messages will be declined by the modem (and possibly held at the SMS
		Service Center).
		
		Only supports GSM devices.
		\sa The corresponding user structure is SWI_STRUCT_SMS_SimFull */
	SWI_NOTIFY_SmsSimFull,	
	
	/*! Reports the status of the frequency band change request initiated by 
		the SwiSetBandInfo function.  The new frequency band will be reported
		by the SWI_NOTIFY_Band notification.		
		
		Only supports GSM devices.
		\sa The corresponding user structure is SWI_STRUCT_Band */
	SWI_NOTIFY_BandWrite,	
	
	/*! Notifies the application of the number of missed voice calls.  The 
		missed voice call count can be cleared by the application using the 
		SwiAcknowledgeMissedCall function.  The missed voice call count will 
		not persist through a modem reset.	
		
		Only supports GSM devices.
		\sa The corresponding user structure is SWI_STRUCT_MissedCall */
	SWI_NOTIFY_MissedCall,		
	
	/*! Reports the current packet session status.  Used with AirCard 750 or 
		older GSM devices.  When working with newer GSM devices, 
		SWI_NOTIFY_PktSessionCall should be used instead.
		\sa The corresponding user structure is SWI_STRUCT_PktSessionStatus
		\sa SWI_NOTIFY_PktSessionCall */		
	SWI_NOTIFY_PktSessionStatus,	
	
	/*! Not supported in this version of the SDK. */
	SWI_NOTIFY_Registration,
	
	/*! Not supported in this version of the SDK. */		
	SWI_NOTIFY_SmsSendReference, 
	
	/*! Notifies the application of the SIM's status.  This notification 
		provides a mechanism for the modem to prompt the user to enter the 
		PIN, PIN2, PUK, PUK2 or Special Code (MEP unlocking code).  After 
		every SIM related operation (PIN Change, Enabling of PIN Verification
		or PUK Entry) this notification will inform the host software of the 
		SIM Status and the result of the previous operation.  
		
		Only supported on GSM devices.
		\sa The corresponding user structure is SWI_STRUCT_SIM_StatusExp */
	SWI_NOTIFY_SimStatusExp,	
	
	/*! Provides the PLMN and/or SPN to be displayed to the user to indicate 
		what network the mobile is registered on.  This information should 
		only be displayed if the mobile is currently registered.  The 
		application will receive a new notification every time the mobile 
		registers on a new network.	
		
		Only supported on GSM devices.
		\sa The corresponding user structure is SWI_STRUCT_Registration */
	SWI_NOTIFY_RegistrationExp, 
	
	/*! Reports the progress of voice calls.  The host is notified of new 
		incoming voice calls.   
		
		Only supported on GSM devices.
		\sa The corresponding user structure is SWI_STRUCT_CALL_EXP_Progress */
	SWI_NOTIFY_CallProgress,
	
	/*! Reports the connected calls state.  Connected calls can be active, on 
		hold, in a multi-party call or suspended.
		
		Only supported on GSM devices.
		\sa The corresponding user structure is SWI_STRUCT_CALL_Status */
	SWI_NOTIFY_CallStatus,	
	
	/*! Reports the transmit and receive byte counters on the modem.  The
		byte counters can be cleared by the application using the 
		SwiClearDataCounters function. The byte counters will not persist 
		through a modem reset.	
		
		Only supported on GSM devices.
		\sa The corresponding user structure is SWI_STRUCT_ByteCounter */
	SWI_NOTIFY_ByteCounter,
	
	/*! Reports the availability of Phonebook service (includes the ability to 
		read and edit the phonebooks).	
		
		Only supported on GSM devices 
		\sa The corresponding user structure is SWI_STRUCT_PhonebookReady */
	SWI_NOTIFY_PhonebookReady,	
	
	/*! Reports a phonebook entry.  Currently, only ADN phonebook is read from 
		this notification.  Note, when a new phonebook entry is added, a
		notification is not sent.	
		
		Only supported on GSM devices.
		\sa The corresponding user structure is SWI_STRUCT_PHONEBK_Entry */
	SWI_NOTIFY_PhonebookEntry,	
	
	/*! Reports the success of the PLMN mode change request initiated by the 
		SwiSetPLMNMode function.	
		
		Only supported on GSM devices.
		\sa The corresponding user structure is SWI_STRUCT_PlmnMode */
	SWI_NOTIFY_PlmnMode,			
	
	/*! Reports the success of the PLMN scan initiated by the 
		SwiStartPLMNSearch function.  This notification will indicate if any 
		networks were found in the scan.  The SwiGetPLMNSelection function 
		should be used to fetch the members of the list of found networks.
		
		Only supported on GSM devices.
		\sa The corresponding user structure is SWI_STRUCT_PlmnAvailable */
	SWI_NOTIFY_PlmnAvailable,	
	
	/*! Reports the modem's enable/disable status.	
	
		Only supported on GSM devices.
		\sa The corresponding user structure is SWI_STRUCT_ModemDisabled */
	SWI_NOTIFY_ModemDisabled,		
	
	/*! Reports the availability of manual PLMN selection service.
	
		Only supported on GSM devices.
		\sa The corresponding user structure is SWI_STRUCT_PlmnReady */
	SWI_NOTIFY_PlmnReady,	
	
	/*! Notifies the application of a change in voice message waiting flags 
		that reside on the SIM.  These flags identify whether or not voice
		messages and data messages are being stored by the network for 
		retrieval by the mobile.  Since this notification will only be sent to 
		the application if there is a change in the mailbox flags it is 
		necessary for the application to call the SwiGetVoiceMessage function 
		to get the initial state of the mailbox flags at startup.  
		
		Only supported on GSM devices 
		\sa The corresponding user structure is SWI_STRUCT_VoiceMessage */
	SWI_NOTIFY_VoiceMessage,	
	
	/*! Allows the application to hide, gray out or display the GPRS icon 
		according to different carrier requirements.  When the notification 
		is enabled, a notification is immediately sent to the application.	
		
		Only supported on GSM devices 
		\sa The corresponding user structure is SWI_STRUCT_IconGprsState */
	SWI_NOTIFY_IconGprsState,		
	
	/*! Allows the application to hide, gray out or display the ROAMING icon
		according to different carrier requirements.  When the notification is 
		enabled, a notification is immediately sent to the application. 
		
		Only supported on GSM devices 
		\sa The corresponding user structure is SWI_STRUCT_IconRoamState */
	SWI_NOTIFY_IconRoamState,	
	
	/*! Provides an indication to the application to display the "Call 
		Forwarded" string to the user.  Some subscriptions on some networks
		notify the user when a call is forwarded or has been forwarded.	
		
		Only supported on GSM devices.
		\sa The corresponding user structure is SWI_STRUCT_CallForwarded */
	SWI_NOTIFY_CallForwarded,	
	
	/*! Allows the application to gray out or display the Call Forwarding icon
		depending on the users current call forwarding configuration.  When the
		notification is enabled, a notification is immediately sent to the 
		application.
		
		Only supported on GSM devices.
		\sa The corresponding user structure is SWI_STRUCT_CFIcon */
	SWI_NOTIFY_CFIcon,		
	
	/*! Not supported in this version of the SDK. */		
	SWI_NOTIFY_STKCommand,	
	
	/*! Updates the application with GPRS data rate statistics.  This 
		notification is sent periodically once it is enabled.  If the data 
		rate information has not change since the last SWI_NOTIFY_DataRate 
		notification was sent then no notification will be sent. 
		
		Only supported on GSM devices.
		\sa The corresponding user structure is SWI_STRUCT_DataRate */
	SWI_NOTIFY_DataRate,	
	
	/*! Provides the application with the service status information needed to
		inform the user of its current GPRS/EDGE service state.		
		\sa The corresponding user structure is SWI_STRUCT_ServiceIcon. */
	SWI_NOTIFY_ServiceIcon,		
	
	/*! Not supported in this version of the SDK. */	
	SWI_NOTIFY_TTYControl,	
	
	/*! Packet session call status.  Used with AirCard 875 or newer devices.
	
		Only supported on GSM devices.
		\sa The corresponding user structure is SWI_STRUCT_PktSessionCall */
	SWI_NOTIFY_PktSessionCall,	
	
	/*! NV backup notification.  Used before a firmware upgrade is
		initiated to instruct the modem to back up information
		stored in non-volatile memory.  
		
		Only supported on GSM devices.
		\sa The corresponding user structure is SWI_STRUCT_NvStore */	
	SWI_NOTIFY_NvStore,		
	
	/*! HSDPA test channel.  Only supported on GSM devices.
		\sa The corresponding user structure is SWI_STRUCT_HSDPA_TestChan */
	SWI_NOTIFY_HSDPA_TestChan,

	/*! GSM System Status.  Notifies the application of system status with
		each change in service.

		Only supported on GSM devices.
		\sa The corresponding user structure is SWI_STRUCT_GsmSystemStatus */
	SWI_NOTIFY_GsmSystemStatus,

	/*! GSM Received Signal Code Power(RSCP) and Energy per Chip per 
		Power Density (Ec/Io) of the active set's strongest cells.  

		This notifications is to be used for diagnostic purposes.  It 
		will be sent periodically and only if the reported data has changed.

		Information on the strongest active cells will be reported in 
		order of strongest to weakest for a maximum of six cells.
		These measurements are valid only for UMTS, if the current service 
		is GSM, no information shall be reported in this notification.

		The Ec/Io value will represent -dB in half step increments.  For
		example, a reported value of 0x0015 means Ec/Io = -10.5dB.
		
		Only supported on GSM devices.
		\sa The corresponding user structure is SWI_STRUCT_RscpEcIo */
	SWI_NOTIFY_RscpEcIo,
 
	/*! GSM 2G Cell Information.  
	
		This notifications is to be used for diagnostic purposes.  It 
		will be sent periodically and only if the reported data has changed.
		
		Only supported on GSM devices.
		\sa The corresponding user structure is SWI_STRUCT_GsmCellInfo */
	SWI_NOTIFY_GsmCellInfo,
 
	/*! GSM Profile Change.
	
		This notification indicates that a Connection Profile has changed and
		it gives the profile ID and info type that the application may wish
		to refresh.
		
		Only supported on GSM devices.
		\sa The corresponding user structure is SWI_STRUCT_GsmProfileChange */
	SWI_NOTIFY_GsmProfileChange,
   
	/*! GSM Default Profile Change.
	
		This notification indicates that a default Connection Profile has
		changed.
		
		Only supported on GSM devices.
		\sa The corresponding user structure is SWI_STRUCT_GsmDefaultChange */
	SWI_NOTIFY_GsmDefaultChange,

	/*! Reports the availability of SMS service (includes the ability to
		read SMS messages from the SIM).  
		
		Only supported on GSM devices
		\sa The corresponding user structure is SWI_STRUCT_SmsReady */
	SWI_NOTIFY_SmsReady = 2200,
	
	/*! Indicates that the SMS copy initiated by the calling of the
	    SwiStoreSMSMessageExp API is complete and that the application
		is now free to take another mobile-originated action using
        SwiStoreSMSMessageExp or SwiSendSMSMessageExp.  This notification
		will report the success of the last SMS copy request.

		Only supported on GSM devices.
		\sa The corresponding user structure is SWI_STRUCT_SmsStoreExp
		\sa The SwiStoreSMSMessageExp API is associated with this 
		notification */
	SWI_NOTIFY_SmsStoreExp,     
	
	/*! Indicates that the SMS send initiated by the calling of the
	    SwiSendSMSMessageExp API is complete and that the application
		is now free to take another mobile-originated action using
        SwiStoreSMSMessageExp or SwiSendSMSMessageExp.  This notification
		will report the success of the last SMS send request.

		Only supported on GSM devices.
		\sa The corresponding user structure is SWI_STRUCT_SmsSendExp
		\sa The SwiSendSMSMessageExp API is associated with this 
		notification */
	SWI_NOTIFY_SmsSendExp, 
	
	/*! Delivers an incoming SMS message or segment that is not to
	    be stored on the SIM to the application. 

		\sa The corresponding user structure is SWI_STRUCT_SMS_Deliver */
	SWI_NOTIFY_SmsDeliver,
	
	/*! Not supported in this version of the SDK. */		
	SWI_NOTIFY_SmsReceived,
	
	/*! Not supported in this version of the SDK. */		
	SWI_NOTIFY_SmsSubmit,
	
	/*! Delivers an incoming SMS status report to the application. 
	
	    Only supported on GSM devices. 
		\sa The corresponding user structure is SWI_STRUCT_SMS_StatusReport */
	SWI_NOTIFY_SmsStatusReport,
	
	/*! Not supported in this version of the SDK. */		
	SWI_NOTIFY_SmsSimStatus,

      /*! Indicates that the network is request a particular supplementary
          service password.  This notification may be a result of the 
          application initiating the password registration process 
          through the SwiStartSSPassReg API or the network may have
          initiated the process.

          The application is expected to answer this network
          request for password using the SwiSetSSPassword API.  

          Only supported on GSM devices.
          \sa SwiStartSSPassReg
          \sa SwiSetSSPassword
          \sa SWI_STRUCT_SS_PasswordStatus */
	SWI_NOTIFY_SSPasswordStatus = 2250,
	
	/*! Indicates that a supplementary service action
          completed successfully. This notification is 
          a network response to a supplementary service
          request that was completed successful and 
          returned no information.

          The application uses the SwiSetSSRequest
          API to make supplementary service requests.
          The handle returned by this API call is
          used to tie the request to its network
          response.
   
          Only supported on GSM device.
          \sa SwiSetSSRequest
          \sa SWI_STRUCT_SS_RespOK */
	SWI_NOTIFY_SSRespOK,
	
	/*! Indicates that a supplementary service action
          completed successfully. This notification is 
          a network response to a supplementary service
          request and it gives call forwarding service 
          status.

          The application uses the SwiSetSSRequest
          API to make supplementary service requests.
          The handle returned by this API call is
          used to tie the request to its network
          response.
   
          Only supported on GSM device.
          \sa SwiSetSSRequest
          \sa SWI_STRUCT_SS_RespFwdInfo */
	SWI_NOTIFY_SSRespFwdInfo,
	
      /*! Indicates that a supplementary service action
          completed successfully. This notification is 
          a network response to a supplementary service
          request and it gives call barring service 
          status.

          The application uses the SwiSetSSRequest
          API to make supplementary service requests.
          The handle returned by this API call is
          used to tie the request to its network
          response.
   
          Only supported on GSM device.
          \sa SwiSetSSRequest
          \sa SWI_STRUCT_SS_RespCallBar */
	SWI_NOTIFY_SSRespCallBar,
	
	/*! Indicates that a supplementary service action
          completed successfully. This notification is 
          a network response to a supplementary service
          request and it gives service status on the  
          requested supplementary service.

          The application uses the SwiSetSSRequest
          API to make supplementary service requests.
          The handle returned by this API call is
          used to tie the request to its network
          response.

          Only supported on GSM device.
          \sa SwiSetSSRequest
          \sa SWI_STRUCT_SS_RespInfoData */
	SWI_NOTIFY_SSRespInfoData,
	
	/*! Indicates that a supplementary service action
          completed successfully. This notification is 
          a network response to a supplementary service
          request and it gives the service status on 
          the requested supplementary service.

          The application uses the SwiSetSSRequest
          API to make supplementary service requests.
          The handle returned by this API call is
          used to tie the request to its network
          response.
   
          Only supported on GSM device.
          \sa SwiSetSSRequest
          \sa SWI_STRUCT_SS_RespStatus */
	SWI_NOTIFY_SSRespStatus,
	
	/*! Indicates that a supplementary service action
          completed successfully. This notification is 
          a network response to a supplementary service
          request and it returns a single forwarded 
          number. 

          The application uses the SwiSetSSRequest
          API to make supplementary service requests.
          The handle returned by this API call is
          used to tie the request to its network
          response.
   
          Only supported on GSM device.
          \sa SwiSetSSRequest
          \sa SWI_STRUCT_SS_RespFwdNum */
	SWI_NOTIFY_SSRespFwdNum,
	
      /*! Indicates that a supplementary service action
          completed successfully. This notification is 
          a network response to a supplementary service
          request and it returns a list of basic
          service groups in used for the requested
          supplementary service.

          The application uses the SwiSetSSRequest
          API to make supplementary service requests.
          The handle returned by this API call is
          used to tie the request to its network
          response.
   
          Only supported on GSM device.
          \sa SwiSetSSRequest
          \sa SWI_STRUCT_SS_RespBSList */
	SWI_NOTIFY_SSRespBSList,
	
      /*! Indicates that a supplementary service action
          completed successfully. This notification is 
          a network response to a supplementary service
          request and it returns a list of call 
          forwarding information for the requested
          supplementary service.

          The application uses the SwiSetSSRequest
          API to make supplementary service requests.
          The handle returned by this API call is
          used to tie the request to its network
          response.
   
          Only supported on GSM device.
          \sa SwiSetSSRequest
          \sa SWI_STRUCT_SS_RespListFwdInfo */
	SWI_NOTIFY_SSRespFwdList,
	
	/*! Indicates that a supplementary service action
          completed successfully. This notification is 
          a network response to a supplementary service
          request and it returns a raw binary data.

          The application uses the SwiSetSSRequest
          API to make supplementary service requests.
          The handle returned by this API call is
          used to tie the request to its network
          response.
   
          Only supported on GSM device.
          \sa SwiSetSSRequest
          \sa SWI_STRUCT_SS_RespRaw */
	SWI_NOTIFY_SSRespRaw,
	
	/*! Indicates that a supplementary service action
          completed successfully. This notification is 
          a network response to a supplementary service
          request and it returns password information.

          The application uses the SwiSetSSRequest
          API to make supplementary service requests.
          The handle returned by this API call is
          used to tie the request to its network
          response.
   
          Only supported on GSM device.
          \sa SwiSetSSRequest
          \sa SWI_STRUCT_SS_RespPassword */
	SWI_NOTIFY_SSRespPassword,
	
	/*! Indicates that a supplementary service action
          completed successfully. This notification is 
          a network response to a supplementary service
          request and it returns CLIR service
          and setting information.

          The application uses the SwiSetSSRequest
          API to make supplementary service requests.
          The handle returned by this API call is
          used to tie the request to its network
          response.
   
          Only supported on GSM device.
          \sa SwiSetSSRequest
          \sa SWI_STRUCT_SS_RespClir  */
	SWI_NOTIFY_SSRespClir,
	
	/*! Indicates that a supplementary service action
          completed unsuccessfully. This notification is 
          a network response to a supplementary service
          request and it returns error cause information.

          The application uses the SwiSetSSRequest
          API to make supplementary service requests.
          The handle returned by this API call is
          used to tie the request to its network
          response.
   
          Only supported on GSM device.
          \sa SwiSetSSRequest
          \sa SWI_STRUCT_SS_RespError  */
	SWI_NOTIFY_SSRespError,
	
	/*! Indicates that a supplementary service action
          completed unsuccessfully. This notification is 
          a network response to a supplementary service
          request and it returns rejection cause information.

          The application uses the SwiSetSSRequest
          API to make supplementary service requests.
          The handle returned by this API call is
          used to tie the request to its network
          response.
   
          Only supported on GSM device.
          \sa SwiSetSSRequest
          \sa SWI_STRUCT_SS_RespReject  */
	SWI_NOTIFY_SSRespReject,
	
	/*! Indicates that a supplementary service action
          completed cancelled. This notification is 
          a network response to a supplementary service
          request and it returns cancel cause.

          The application uses the SwiSetSSRequest
          API to make supplementary service requests.
          The handle returned by this API call is
          used to tie the request to its network
          response.
   
          Only supported on GSM device.
          \sa SwiSetSSRequest
          \sa SWI_STRUCT_SS_RespCancel  */
	SWI_NOTIFY_SSRespCancel,
	
	/*! Indicates that an outstanding supplementary 
          service action has been released.  This 
          notification is a network response to a
          supplementary service request.
          completed cancelled. This notification is 
          a network response to a supplementary service
          request and it returns cancel cause.

          The application uses the SwiSetSSRequest
          API to make supplementary service requests.
          The handle returned by this API call is
          used to tie the request to its network
          response.
   
          Only supported on GSM device.
          \sa SwiSetSSRequest
          \sa SWI_STRUCT_SS_RespRelease  */
	SWI_NOTIFY_SSRespRelease,
	
	/*! Indicates that a particular supplemenary
          service is active.  This notification
          is a network indication.
   
          Only supported on GSM device.
          \sa SwiSetSSRequest
          \sa SWI_STRUCT_SSNotify  */
	SWI_NOTIFY_SSNotify,
	
	/*! Not supported in this version of the SDK. */
	SWI_NOTIFY_SS_USSD_REQ,
	
	/*! Place holder.  Must be last entry in this list. */
	SWI_NOTIFY_END_NOTIFY,
};

#define MAX_NOTIF_LIST		122	/*!< Maximum size of notification list */

///////////////////////////////////////////////////////////////////////////////
///
/// This structure is used for enabling multiple notifications simultaneously
/// using the SwiEnableNotif() function call.
///
/// This object is only supported on GSM devices.
/// 
/// \sa SwiEnableNotif
/// \sa See SWI_TYPE_Notify for list of notifications.
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_NotifList
{
	/*!	The size, in bytes, of this structure.  This value must always be
	populated by the calling application when calling SwiGetRadioPower
	or SwiSetRadioPower. */
	U32 sizeStruct;
	
	/*! The number of notifications events to enable.  This value must be 
		greater than 0. */
	U32 nNumNotif;		
	
	/*! Array of notification event types to be enabled.  The API will enable
		all events in the array starting with index 0 up to index nNumNotif-1.
		*/			
	SWI_TYPE_Notify	arrNotif[MAX_NOTIF_LIST];	
};

///////////////////////////////////////////////////////////////////////////////
///
/// Notification variant.
///
/// This structure contains information pertaining to a particular event
/// notification.  Depending on the notification type, the appropriate
/// user structure will be provided.  ::See SWI_TYPE_Notify for a complete list
/// of event notifications and its corresponding user structure.
///
/// Event notifications are passed up to the host application
/// through callback function handlers previously registered with the 
/// ::SwiRegisterCallback command.
///
/// \sa SWI_TYPE_Notify
/// \sa SwiRegisterCallback
///
///////////////////////////////////////////////////////////////////////////////
struct SwiNotifyVariant
{
	SWI_TYPE_Notify  eNotify;

	union
	{
		////////////////////////////////////////////////////////////
		/// common 
		////////////////////////////////////////////////////////////
		SWI_STRUCT_AirServerChange  		_AirServerChange;
		SWI_STRUCT_LockAirServer			_LockAirServer;
		SWI_STRUCT_HeartBeat				_HeartBeat;
		SWI_STRUCT_HeadsetIcon				_HeadsetIcon;
		SWI_STRUCT_Rssi						_Rssi;
		SWI_STRUCT_FwDownload				_FwDownload;
		SWI_STRUCT_Reset					_Reset;
		SWI_STRUCT_Power					_Power;
		SWI_HW_STRUCT_Power					_HWPower;
		SWI_STRUCT_Dhcp						_Dhcp;
		SWI_STRUCT_PPP						_PPP;
		SWI_STRUCT_Debug					_Debug;
		SWI_STRUCT_RadioPower				_RadioPower;
		SWI_STRUCT_RadioTempState			_RadioTempState;
		SWI_STRUCT_RadioBattery				_RadioBattery;
		SWI_STRUCT_RadioBandList			_RadioBand;
		SWI_STRUCT_AudioProfile				_AudioProfile;
		SWI_STRUCT_DeviceTime				_DeviceTime;

		/// MP notifications
		SWI_STRUCT_Gps						_Gps;
		SWI_STRUCT_ExtDioNotif				_ExtDio;
		SWI_STRUCT_ExtAiNotif				_ExtAi;
		SWI_STRUCT_GpsCommand				_GpsCommand;
		SWI_STRUCT_IgnSense					_MPIgnSense;
		SWI_STRUCT_RfDownload				_RfDownload;
		SWI_STRUCT_SimSled					_SimSled;
		SWI_STRUCT_BatteryStatus			_BatteryStatus;
		SWI_STRUCT_MpShutdown				_MpShutdown;
		SWI_STRUCT_MpConnect				_MpConnect;
		SWI_STRUCT_MpStartupDiag			_MpStartupDiag;
		SWI_STRUCT_MpStartupConfig			_MpStartupConfig;
		SWI_STRUCT_MpByteCounter			_MpByteCounter;
		SWI_STRUCT_MpDisconnect				_MpDisconnect;
		SWI_STRUCT_MpManagerData			_MpManagerData;

		/// LBS notifications
		SWI_STRUCT_LbsPdData				_LbsPdData;
		SWI_STRUCT_LbsPdDone				_LbsPdDone;
		SWI_STRUCT_LbsPdEnd					_LbsPdEnd;
		SWI_STRUCT_LbsPdBegin				_LbsPdBegin;
		SWI_STRUCT_LbsPdUpdateFailure		_LbsPdUpdateFailure;
		SWI_STRUCT_LbsPdDloadBegin			_LbsPdDloadBegin;
		SWI_STRUCT_LbsPdDloadData			_LbsPdDloadData;
		SWI_STRUCT_LbsPdDloadDone			_LbsPdDloadDone;
		SWI_STRUCT_LbsPdDloadEnd			_LbsPdDloadEnd;
		SWI_STRUCT_LbsPaIpAddr				_LbsPaIpAddr;
		SWI_STRUCT_LbsPaGpsLock				_LbsPaGpsLock;
		SWI_STRUCT_LbsPaPtlmMode			_LbsPaPtlmMode;
		SWI_STRUCT_LbsPaPortId				_LbsPaPortId;
		SWI_STRUCT_LbsPaPrivacy				_LbsPaPrivacy;
		SWI_STRUCT_LbsPaNetAccess			_LbsPaNetAccess;
		SWI_STRUCT_LbsPaBsInfo				_LbsPaBsInfo;
		SWI_STRUCT_LbsPaWarmBegin			_LbsPaWarmBegin;
		SWI_STRUCT_LbsPaWarmStatus			_LbsPaWarmStatus;
		SWI_STRUCT_LbsPaWarmDone			_LbsPaWarmDone;
		SWI_STRUCT_LbsSatInfo				_LbsSatInfo;
		SWI_STRUCT_LbsPdGetStatus			_LbsPdGetStatus;
		SWI_STRUCT_LbsNiReq					_LbsNiReq;

		////////////////////////////////////////////////////////////
		/// CDMA 
		////////////////////////////////////////////////////////////
		SWI_STRUCT_ChannelNumber			_ChannelNumber;
		SWI_STRUCT_ChannelState				_ChannelState;
		SWI_STRUCT_ServiceIndication		_ServiceIndication;
		SWI_STRUCT_RoamingStatus			_RoamingStatus;
		SWI_STRUCT_Ecio						_Ecio;
		SWI_STRUCT_AuthenticationStatus		_AuthenticationStatus;
		SWI_STRUCT_CallByteCounter			_CallByteCounter;
		SWI_STRUCT_CallConnecting			_CallConnecting;
		SWI_STRUCT_CallConnected			_CallConnected;
		SWI_STRUCT_CallIncoming				_CallIncoming;
		SWI_STRUCT_CallCallerID				_CallCallerID;
		SWI_STRUCT_CallExtendedCallerID		_CallExtendedCallerID;
		SWI_STRUCT_CallDisconnected			_CallDisconnected;
		SWI_STRUCT_CallError				_CallError;
		SWI_STRUCT_CDMA_SMS_Status			_CdmaSmsStatus;
		SWI_STRUCT_CDMA_SMS_SendStatus		_CdmaSmsSendStatus;
		SWI_STRUCT_Prev						_Prev;
		SWI_STRUCT_HeadsetState				_HeadsetState;
		SWI_STRUCT_ActiveNam				_ActiveNam;
		SWI_STRUCT_TechSid					_TechSid;
		SWI_STRUCT_TechNid					_TechNid;
		SWI_STRUCT_TechBsInfo				_TechBsInfo;
		SWI_STRUCT_TechBandClass			_TechBandClass;
		SWI_STRUCT_TechRegZone				_TechRegZone;
		SWI_STRUCT_TechPacketZone			_TechPacketZone;
		SWI_STRUCT_TechPcsBlock				_TechPcsBlock;
		SWI_STRUCT_TechCellChannel			_TechCellChannel;
		SWI_STRUCT_SystemTime				_SystemTime;
		SWI_STRUCT_ActivationStatus			_ActivationStatus;
		SWI_STRUCT_V42BisEnabled			_V42BisEnabled;
		SWI_STRUCT_CallNotificationStatus	_CallNotificationStatus;
		SWI_STRUCT_CallDormant				_CallDormant;
		SWI_STRUCT_CallPrivacy				_CallPrivacy;	
		SWI_STRUCT_E911Mode					_E911Mode;
		SWI_STRUCT_ModemTooHotIndication	_ModemTooHotIndication;
		SWI_STRUCT_OTASPState				_OTASPState;
		SWI_STRUCT_FlashBurn				_FlashBurn;
		SWI_STRUCT_ExcessSPCFailures		_ExcessSPCFailures;
		SWI_STRUCT_PowerSaveEnter			_PowerSaveEnter;
		SWI_STRUCT_PowerSaveExit			_PowerSaveExit;
		SWI_STRUCT_HdrNotificationStatus	_HdrNotificationStatus;
		SWI_STRUCT_Hdr_Acq					_Hdr_Acq;
		SWI_STRUCT_Hdr_Rssi					_Hdr_Rssi;
		SWI_STRUCT_Rssi_Ecio				_Rssi_Ecio;
		SWI_STRUCT_Hdr_Roam_Status			_Hdr_Roam_Status;
		SWI_STRUCT_Hdr_Srv_State			_Hdr_Srv_State;
		SWI_STRUCT_Hdr_Hybr_Pref			_Hdr_Hybr_Pref;
		SWI_STRUCT_Idle_Digital_Mode		_Idle_Digital_Mode;
		SWI_STRUCT_DDTM_Pref				_DDTM_Pref;
		SWI_STRUCT_Hdr_PowerSave_Enter		_Hdr_PowerSave_Enter;
		SWI_STRUCT_Hdr_PowerSave_Exit		_Hdr_PowerSave_Exit;
		SWI_STRUCT_TechHdrNotificationStatus _TechHdrNotificationStatus;
		SWI_STRUCT_Tech_Hdr_Prev			_Tech_Hdr_Prev;
		SWI_STRUCT_Tech_Hdr_Sector			_Tech_Hdr_Sector;
		SWI_STRUCT_Tech_Hdr_State			_Tech_Hdr_State;
		SWI_STRUCT_Tech_Hdr_Channel			_Tech_Hdr_Channel;
		SWI_STRUCT_Tech_Hdr_Session			_Tech_Hdr_Session;
		SWI_STRUCT_Tech_Hdr_An_Auth			_Tech_Hdr_An_Auth;
		SWI_STRUCT_Tech_Hdr_Drc_Val			_Tech_Hdr_Drc_Val;
		SWI_STRUCT_Tech_Hdr_Drc_Cover		_Tech_Hdr_Drc_Cover;
		SWI_STRUCT_Tech_Hdr_Rri				_Tech_Hdr_Rri;
		SWI_STRUCT_Tech_Hdr_Stats			_Tech_Hdr_Stats;
		SWI_STRUCT_DebugPacket				_DebugPacket;
		SWI_STRUCT_HIOTAStatus				_HIOTA_Status;
		SWI_STRUCT_RuimStatus				_RuimStatus;
		SWI_STRUCT_SwiApi_State				_SwiApi_State;
		SWI_STRUCT_IOTA_State				_EMIOTAStauts;
		SWI_STRUCT_IOTA_WAPPush				_EMIOTAWAPPush;

		////////////////////////////////////////////////////////////
		/// GSM 
		////////////////////////////////////////////////////////////
		SWI_STRUCT_GSM_NetworkStatus		_NetworkStatus;
		SWI_STRUCT_Temperature				_Temperature;
		SWI_STRUCT_GSM_SMS_Status			_GsmSmsStatus;
		SWI_STRUCT_SMS_SimFull				_SmsSimFull;
		SWI_STRUCT_Band						_Band;
		SWI_STRUCT_Band						_BandWrite;
		SWI_STRUCT_MissedCall				_MissedCall;
		SWI_STRUCT_PktSessionStatus			_PktSessionStatus;
		SWI_STRUCT_Registration				_Registration;
		SWI_STRUCT_TransmitAlert			_TransmitAlert;
		SWI_STRUCT_SMS_SendReference		_SmsSendReference;
		SWI_STRUCT_GSM_SMS_SendStatus		_GsmSmsSendStatus;
		SWI_STRUCT_SIM_StatusExp			_SimStatusExp;
		SWI_STRUCT_CALL_EXP_Progress		_CallProgress;
		SWI_STRUCT_CALL_Status				_CallStatus;
		SWI_STRUCT_ByteCounter				_ByteCounter;
		SWI_STRUCT_SmsReady					_SmsReady;
		SWI_STRUCT_PhonebookReady			_PhonebookReady;
		SWI_STRUCT_PlmnAvailable			_PlmnAvailable;
		SWI_STRUCT_PlmnMode					_PlmnMode;
		SWI_STRUCT_ModemDisabled			_ModemDisabled;
		SWI_STRUCT_SS_PasswordStatus		_SSPasswordStatus;
		SWI_STRUCT_SS_RespOK				_SSRespOK;
		SWI_STRUCT_SS_RespFwdInfo			_SSRespFwdInfo;
		SWI_STRUCT_SS_RespCallBar			_SSRespCallBar;
		SWI_STRUCT_SS_RespInfoData			_SSRespInfoData;
		SWI_STRUCT_SS_RespStatus			_SSRespStatus;
		SWI_STRUCT_SS_RespFwdNum			_SSRespFwdNum;
		SWI_STRUCT_SS_RespBSList			_SSRespBSList;
		SWI_STRUCT_SS_RespListFwdInfo		_SSRespFwdList;
		SWI_STRUCT_SS_RespRaw				_SSRespRaw;
		SWI_STRUCT_SS_RespPassword			_SSRespPassword;
		SWI_STRUCT_SS_RespClir				_SSRespClir;
		SWI_STRUCT_SS_RespError				_SSRespError;
		SWI_STRUCT_SS_RespReject			_SSRespReject;
		SWI_STRUCT_SS_RespCancel			_SSRespCancel;
		SWI_STRUCT_SS_RespRelease			_SSRespRelease;
		SWI_STRUCT_SSNotify					_SSNotify;
		SWI_STRUCT_PlmnReady				_PlmnReady;
		SWI_STRUCT_VoiceMessage				_VoiceMessage;
		SWI_STRUCT_IconGprsState			_IconGprsState;
		SWI_STRUCT_IconRoamState			_IconRoamState;
		SWI_STRUCT_CallForwarded			_CallForwarded;
		SWI_STRUCT_CFIcon					_CFIcon;
		SWI_STRUCT_STK_Notif_Command		_Notif_STKCommand;
		SWI_STRUCT_DataRate					_DataRate;
		SWI_STRUCT_PHONEBK_Entry			_PhonebookEntry;
		SWI_STRUCT_SmsStoreExp				_SmsStoreExp;
		SWI_STRUCT_SmsSendExp				_SmsSendExp;
		SWI_STRUCT_ServiceIcon				_ServiceIcon;
		SWI_STRUCT_TTYControl				_TTYControl;
		SWI_STRUCT_SMS_Received				_SmsReceived;
		SWI_STRUCT_SMS_Deliver				_SmsDeliver;
		SWI_STRUCT_SMS_Submit				_SmsSubmit;
		SWI_STRUCT_SMS_StatusReport			_SmsStatusReport;
		SWI_STRUCT_SMS_SimStatus			_SmsSimStatus;
		SWI_STRUCT_UnstructSupplServiceExp	_USSDExp;  
		SWI_STRUCT_PktSessionCall			_PktSessionCall;
		SWI_STRUCT_NvStore					_NvStore;
		SWI_STRUCT_HSDPA_TestChan			_HSDPA_TestChan;
		SWI_STRUCT_SmsStatusReportCfg		_SmsStsReportCfg;
		SWI_STRUCT_GsmSystemStatus			_GsmSystemStatus;
		SWI_STRUCT_RscpEcIo					_RscpEcIo;
		SWI_STRUCT_GsmCellInfo				_GsmCellInfo;
		SWI_STRUCT_GsmProfileChange			_GsmProfileChange;
		SWI_STRUCT_GsmDefaultChange			_GsmDefaultChange;
	};
};

///////////////////////////////////////////////////////////////////////////////
///
/// Callback
///
///////////////////////////////////////////////////////////////////////////////
typedef void (*SWI_CALLBACK_EX)(SwiNotifyVariant *pNotify);

/*@}*/ // End of Notification group

#define SERIAL_MUX_COMM_PORT_UNASSIGNED 0x0000	/*!< Serial mux physical COMM port unassigned */
#define SERIAL_MUX_COMM_PORT_DISABLED   0xffff	/*!< Serial mux driver is disabled */

#endif ///__SWI_STRUCTS_CM_H__
