//////////////////////////////////////////////////////////////////////////////////
//                                                                              
//	$Revision: 11 $														
//										
//	Name       : SwiMpStructsCm.h		                                
//                                                                              
//	Purpose    : Contains all MP related structures and enumerations	
//                                                                              
//	Note       : The contents of this header file are specific to the       
//               MP products only          
//					                                        
//	Copyright (c) 2003 Sierra Wireless, Inc.  All rights reserved		
//                                                                              
//////////////////////////////////////////////////////////////////////////////////

#ifndef __SWI_MP_STRUCTS_
#define __SWI_MP_STRUCTS_

#include "SwiDatatypes.h"

#define LENGTH_IoName				21
#define LENGTH_IoLowName			21
#define LENGTH_IoHighName			21
#define LENGTH_IoUnitName			21
#define NUM_EXT_DIO					5
#define NUM_EXT_AI					5
#define MAX_NOTIF_LIST				122
#define LENGTH_GpsCommand			129
#define LENGTH_MPProuductSig		9
#define LENGTH_MpVersion			85
#define LENGTH_MpFwBuildDate		9
#define LENGTH_MpHwVersion			5
#define LENGTH_MpHwBuildDate		7
#define LENGTH_MpFsn				16  // backward compatible with pre-R1_0_9AP firmware (currently it's 14)
#define LENGTH_MpName				33
#define LENGTH_MpBatchNumber		4
#define LENGTH_AccessPointName		101
#define LENGTH_UserNameMp			33
#define LENGTH_PasswordMp			33
#define LENGTH_Label				31
#define LENGTH_MaxMp555Name			73
#define LENGTH_MaxMp555Phone		33
#define LENGTH_MaxMp555Pass			17
#define LENGTH_MpManagerData		1412
#define LENGTH_DnsName				128
#define LENGTH_InitString			129
#define MAX_MpGpsInitStrings		5
#define LENGTH_Domain				15
#define LENGTH_MP_IPAddress			16
#define LENGTH_Ssid					33
#define LENGTH_WifiKey				65
#define LENGTH_MpUnlockCode			16


/////////////////////////////////////////////////////////////////////////////////
//
// Name:	SWI_TYPE_GpsStatus - enumerations for Gps status
//
// Purpose:	Enumerations used to classify different Gps statuses
//
// Members:	SWI_GPSSTATUS_Reserved	- Reserved for future use
//
//			SWI_GPSSTATUS_None		- None status
//
//			SWI_GPSSTATUS_NotFixed	- Minimum number of satellite signals not yet
//									  acquired
//
//			SWI_GPSSTATUS_Full		- Minimum number of satellite signals acquired
//
// Notes:	None
//
/////////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_GpsStatus
{
	SWI_GPSSTATUS_Reserved,
	SWI_GPSSTATUS_None,
	SWI_GPSSTATUS_NotFixed,
	SWI_GPSSTATUS_Full,
};

/////////////////////////////////////////////////////////////////////////////////
//
// Name:	SWI_TYPE_Direction - enumerations of Gps directions
//
// Purpose:	Enumerations used to classify different Gps directions
//
// Members:	SWI_DIRECTION_North	 
//
//			SWI_DIRECTION_South	
//
//			SWI_DIRECTION_East	
//
//			SWI_DIRECTION_West 
//
// Notes:	Note that within the Gps notification structure (SWI_STRUCT_Gps),
//			a validity flag is present along with any SWI_TYPE_Direction field.
//			Check the corresponding validity flag first before looking at any 
//			SWI_TYPE_Direction field to make sure that it's valid.
//
/////////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_Direction
{
	SWI_DIRECTION_North,
	SWI_DIRECTION_South,
	SWI_DIRECTION_East,
	SWI_DIRECTION_West
};


/////////////////////////////////////////////////////////////////////////////////
//
// Name:	SWI_TYPE_GpsProtocol - enumerations of Gps protocols
//
// Purpose:	Enumerations used to classify different Gps protocols
//
// Members:	SWI_GPSPROTOCOL_Taip	- TAIP protocol
//
//			SWI_GPSPROTOCOL_Nmea	- NMEA protocol
//
//			SWI_GPSPROTOCOL_Tsip	- TSIP protocol
//
// Notes:	None
//
/////////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_GpsProtocol
{
	SWI_GPSPROTOCOL_Taip,
	SWI_GPSPROTOCOL_Nmea,
	SWI_GPSPROTOCOL_Tsip,
};


/////////////////////////////////////////////////////////////////////////////////
//
// Name:	SWI_STRUCT_Gps - Gps notification structure
//
// Purpose:	This structure contains the GPS data information sent by the GPS unit. 
//			It provides constant and up to date Gps data to the host software. 
//			 
//
// Members:	sizeStruct		- size of this structure
//
//			bStatusValid	- true - eGpsStatus valid, false otherwise
//
//			eProtocol		- SWI_TYPE_GpsProtocol enumerated type
//
//			eGpsStatus		- SWI_TYPE_GpsStatus enumerated type
//
//			bLatitudeValid	- true - latitude info valid, false otherwise
//
//			eLatDirection	- SWI_TYPE_Direction enumerated type
//
//			nLatDegree		- latitude degree
//
//			nLatMinute		- latitude minute
//
//			nLatSecond		- latitude second
//
//			nLatSecondDecimal	- latitude second decimal
//
//			bLongtitudeValid	- true - longtitude info valid, false otherwise
//
//			eLongDirection	- SWI_TYPE_Direction enumerated type
//
//			nLongDegree		- longtitude degree
//
//			nLongMinute		- longtitude minute
//
//			nLongSecond		- longtitude second
//
//			nLongSecondDecimal	- longtitude second decimal
//
//			bAltitudeValid	- true - altitude info valid, false otherwise
//
//			nAltitudeDirection	- 0 - '+' above sea level, 1 - '-' below sea level
//
//			nAltitude		- meters
//
//			nAltitudeDecimal	- meters
//
//			bSpeedValid		- true - horizontal speed info valid, false otherwise
//
//			nHorizSpeed		- km/h
//
//			nHorizSpeedDecimal	- km/h
//
//			bHeadingValid	- true - heading info valid, false otherwise
//
//			nHeading		- degrees
//
//			nHeadingDecimal - heading decimal degrees
//
//			bNumSvUsedValid - true - number of satellites used info valid, false otherwise
//
//			nNumSvUsed		- number of satellites used, 0-12
//
//			bUtcValid		- true - UTC info valid, false otherwise
//
//			nUtcHour		- hour in UTC, 0-23
//
//			nUtcMinute		- minute in UTC, 0-59	
//
//			nUtcSecond		- second in UTC, 0-59
//
//			nUtcDay			- day in UTC, 1-31
//
//			nUtcMonth		- month in UTC,	1-12
//
//			nUtcYear		- year in UTC, 1997-2016
//
// Notes:	None
//
/////////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_Gps
{
	U32						sizeStruct;			
	bool					bStatusValid;		
	SWI_TYPE_GpsProtocol	eProtocol;			
	SWI_TYPE_GpsStatus		eGpsStatus;			
	bool					bLatitudeValid;		
	SWI_TYPE_Direction		eLatDirection;		
	U32						nLatDegree;			
	U32						nLatMinute;			
	U32						nLatSecond;			
	U32						nLatSecondDecimal;	
	bool					bLongtitudeValid;	
	SWI_TYPE_Direction		eLongDirection;		
	U32						nLongDegree;		
	U32						nLongMinute;		
	U32						nLongSecond;		
	U32						nLongSecondDecimal;
	bool					bAltitudeValid;		
	U32						nAltitudeDirection;	
	U32						nAltitude;			
	U32						nAltitudeDecimal;	
	bool					bSpeedValid;		
	U32						nHorizSpeed;		
	U32						nHorizSpeedDecimal;	
	bool					bHeadingValid;	
	U32						nHeading;			
	U32						nHeadingDecimal;	
	bool					bNumSvUsedValid;	
	U32						nNumSvUsed;			
	bool					bUtcValid;		
	U32						nUtcHour;			
	U32						nUtcMinute;			
	U32						nUtcSecond;			
	U32						nUtcDay;			
	U32						nUtcMonth;			
	U32						nUtcYear;			
};


/////////////////////////////////////////////////////////////////////////////////
//
// Name:	SWI_STRUCT_GpsCommand - Gps command structure
//
// Purpose:	This structure is used as input by the SwiSetGPSCommand function, 
//			it stores the Gps command to be sent to the Gps module. 
//
// Members:	sizeStruct	- size of this structure
//
//			szCommand	- null terminated Gps command
//
// Notes:	None
//
/////////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_GpsCommand
{
	U32			sizeStruct;					
	WCHAR		szCommand[LENGTH_GpsCommand];  
};


/////////////////////////////////////////////////////////////////////////////////
//
// Name:	SWI_TYPE_SwitchMode - enumerations for data link modes
//
// Purpose:	These enumerations are used as output by SwiGetSwitchMode and input by 
//			SwiSwitchMode. 
//
// Members:	MODE_None	- AT command mode
//
//			MODE_Comm	- HDLC (Serial) mode
//
//			MODE_Udp	- UDP mode, used during an active data connection
//
//			MODE_Ndis	- USB/NDIS mode
//
// Notes:	None
//
/////////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_SwitchMode
{
	MODE_None,
	MODE_Comm,
	MODE_Udp,
	MODE_Ndis,
};


/////////////////////////////////////////////////////////////////////////////////
//
// Name:	SWI_TYPE_IO - IO type
//
// Purpose:	Enumerations used to classify types of input/output
//			
//
// Members:	IO_Input	- IO input
//
//			IO_Output	- IO output
//
//			IO_Unused	- IO unused
//
// Notes:	None
//
/////////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_IO
{
	IO_Input,
	IO_Output,
	IO_Unused = 0xFF
};

/////////////////////////////////////////////////////////////////////////////////
//
// Name:	SWI_TYPE_IoAlarm - input/output alarm type
//
// Purpose:	Enumerations used to classify input/output alarm types
//			
//
// Members:	IOALARM_None - never trigger an alarm	
//
//			IOALARM_Low	- trigger alarm when signal goes low
//	
//			IOALARM_High - trigger alarm when signal goes high
//
//			IOALARM_LogOnly - log signal only
//
// Notes:	None
//
/////////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_IoAlarm
{
	IOALARM_None,
	IOALARM_Low,
	IOALARM_High,
	IOALARM_LogOnly
};


/////////////////////////////////////////////////////////////////////////////////
//
// Name:	SWI_STRUCT_ExtDioCfg - external digital input/output configuration
//
// Purpose:	Used by functions SwiGetExternalDigitalIOConfig and 
//			SwiSetExternalDigitalIOConfig.  The host software uses this structure
//			to get/set an external digital I/O using SwiGetExternalDigitalIOConfig 
//			and SwiSetExternalDigitalIOConfig respectively.
//			
//
// Members:	sizeStruct	- size of this structure
//
//			nIndex		- external IO index
//
//			eIoType		- SWI_TYPE_IO enumerated type
//
//			strIoName	- label
//
//			strIoLowName	- IO name to use when signal is low
//
//			strIoHighName	- IO name to use when signal is high
//
//			eAlarmType	- SWI_TYPE_IoAlarm enumerated type
//
//			bLogicLevelHigh - false-signal is low, true-signal is high
//
// Notes:	None
//
/////////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_ExtDioCfg
{
	U32					sizeStruct;								
	U32					nIndex;									
	SWI_TYPE_IO			eIoType;								
	WCHAR				strIoName[LENGTH_IoName];				
	WCHAR				strIoLowName[LENGTH_IoLowName];		
	WCHAR				strIoHighName[LENGTH_IoHighName];		
	SWI_TYPE_IoAlarm	eAlarmType;								
	bool				bLogicLevelHigh;					
};

/////////////////////////////////////////////////////////////////////////////////
//
// Name:	SWI_STRUCT_ExtDioNotif - external digital input/output notification
//
// Purpose:	Received through the SWI_NOTIFY_ExtDio notification.  This notification 
//			returns the current logic level of all the I/O's.
//			
// Members:	sizeStruct	- size of this structure
//
//			bLevelHigh	- false-signal is low, true-signal is high
//
// Notes:	Index 0 is reserved
//
/////////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_ExtDioNotif
{
	U32			sizeStruct;						
	bool		bLevelHigh[NUM_EXT_DIO];			
};

/////////////////////////////////////////////////////////////////////////////////
//
// Name:	SWI_STRUCT_ExtAiCfg
//
// Purpose:	Used by functions SwiGetExternalAnalogIOConfig and
//			SwiSetExternalAnalogIOConfig.  The host software uses this structure
//			to get/set the logic level of an external analog output using 
//			SwiGetExternalAnalogIOConfig and SwiSetExternalAnalogIOConfig respectively. 
//			
//
// Members:	sizeStruct	- size of this structure
//
//			nIndex		- external analog I/O index
//
//			strIoName	- IO name
//
//			strUnitName - unit name
//
//			nRawValue	- 0-1023
//
//			nZeroScale	- user specified bottom scale value
//
//			nFullScale	- user specified top scale value
//
//			nCurrentValue - calculated value based on user specified range
//
// Notes:	Index 0 is reserved
//
/////////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_ExtAiCfg
{
	U32			sizeStruct;					
	U32			nIndex;							
	WCHAR		strIoName[LENGTH_IoName];			
	WCHAR		strUnitName[LENGTH_IoUnitName];		
	U32			nRawValue;							
	U32			nZeroScale;						
	U32			nFullScale;							
	U32			nCurrentValue;											
};

/////////////////////////////////////////////////////////////////////////////////
//
// Name:	SWI_STRUCT_ExtAiNotif
//
// Purpose:	Received through the SWI_NOTIFY_ExtAi notification.  This notification 
//			returns the current logic level of all the external analog Input's.
//			
//
// Members:	sizeStruct		- size of this structure
//
//			nRawValue		- raw value 
//
//			nCurrentValue	- calculated value based on user specified range
//
// Notes:	None
//
/////////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_ExtAiNotif
{
	U32			sizeStruct;						
	U32			nRawValue[NUM_EXT_AI];		
	U32			nCurrentValue[NUM_EXT_AI];	
};


/////////////////////////////////////////////////////////////////////////////////
//
// Name:	SWI_STRUCT_MpRevision
//
// Purpose:	Used for detecting compatibility between MP firmware and software
//			
// Members:	sizeStruct	- size of this structure
//
//			szSignature		
//
//			nReverseProductId	
//
//			nForwardProductId
//
// Notes:	None
//
/////////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_MpRevision
{
	U32			sizeStruct;						     
	WCHAR		szSignature [LENGTH_MPProuductSig];  
    U32         nReverseProductId;
    U32         nForwardProductId;
};


/////////////////////////////////////////////////////////////////////////////////
//
// Name:	SWI_STRUCT_MPIgnSense - Mp ignition sense structure
//
// Purpose:	Used by SwiGetMpIgnitionSense and SwiSetMpIgnitionSense.  
//			Structure used to retrieve or set the 'time delay' between loss of
//			ignition sense and modem power-off.
//
// Members:	sizeStruct		- size of this structure
//
//			nTimeRemaining	- 0-240 (minutes)
//
//			bIgnitionSenseOn	
//
// Notes:	None
//
/////////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_IgnSense
{
	U32	 sizeStruct;		
    U32  nTimeRemaining;     
    bool bIgnitionSenseOn;   
};


/////////////////////////////////////////////////////////////////////////////////
//
// Name:	SWI_STRUCT_MpDataCount - Data counter structure
//
// Purpose:	Used by functions SwiGetMpDataCount and SwiResetMpByteCount.  User
//			must set the appropriate values for nYear, nMonth, nDay, nHour, 
//			nMinute, and nSecond before passing the structure to one of the 
//			above API calls.
//			
// Members:	sizeStruct	- size of structure
//
//			nTotalBytesTx	 
//
//			nTotalBytesRx	
//
//			nLifetimeBytesTxUpper 
//
//			nLifetimeBytesTxLower
//
//			nLifetimeBytesRxUpper
//
//			nLifetimeBytesRxLower
//
//			nYear - (1-255, 0 if not initialized)
//
//			nMonth - (1-12, 0 if not initialized)
//
//			nDay - (1-31, 0 if not initialized)
//
//			nHour - (0-23)
//
//			nMinute - (0-59)
//
//			nSecond - (0-59)
//
// Notes:	None
//
/////////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_MpDataCount
{
	U32	sizeStruct;
    U32 nTotalBytesTx;
    U32 nTotalBytesRx;
    U64 nLifetimeBytesTx;
    U64 nLifetimeBytesRx;
	U32 nYear;				
    U32 nMonth;				
    U32 nDay;			
    U32 nHour;				
    U32 nMinute;		
    U32 nSecond;		
};

/////////////////////////////////////////////////////////////////////////////////
//
// Name:	SWI_STRUCT_MpByteCounter - MP byte counter structure
//
// Purpose:	Received through the SWI_NOTIFY_MpByteCount notification.  Generally
//			used by the host software to detect the amount of transmit and receive
//			bytes being passed during an active data connection.  		
//
// Members:	sizeStruct		- size of this structure
//
//			TransmitBytes	- total transmit bytes
//
//			ReceiveBytes	- total received bytes
//
// Notes:	None
//
/////////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_MpByteCounter
{
	U32				sizeStruct;							
	U32				TransmitBytes;						
	U32				ReceiveBytes;						
};

/////////////////////////////////////////////////////////////////////////////////
//
// Name:	SWI_STRUCT_RfDownload - RF download structure
//
// Purpose:	Received through the SWI_NOTIFY_RfDownload notification.  Reports
//			the progress of the download to the RF module in the MP.
//
// Members:	sizeStruct			- size of this structure
//
//			nTotalSize			- total size of download
//
//			nCurrentProgress	- size remaining to download
//
// Notes:	None
//
/////////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_RfDownload
{
	U32	sizeStruct;				
	U32 nTotalSize;			
	U32 nCurrentProgress;	
};

/////////////////////////////////////////////////////////////////////////////////
//
// Name:	SWI_STRUCT_SimSled - SimSled status structure
//
// Purpose:	Received through the SWI_NOTIFY_SimSled notification.  Used to provide
//			the open/close status of the SIM sled (drawer).  Note that the SIM 
//			sled may be closed, but without a SIM.
//			
// Members:	sizeStruct	- size of this structure
//
//			bSledOpen	- true-sled open, false otherwise
//
// Notes:	None
//
/////////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_SimSled
{
	U32		sizeStruct;			
	bool	bSledOpen;			
};

/////////////////////////////////////////////////////////////////////////////////
//
// Name:	SWI_STRUCT_BatteryStatus - Battery status structure
//
// Purpose:	Received through the SWI_NOTIFY_BatteryStatus notification.  Used by
//			the host software to detect battery status.  A notification is sent
//			when the battery voltage has dropped to a sustained low level.  If the 
//			battery voltage rises back to a normal status a notification is sent.
//			
// Members:	sizeStruct	- size of this structure
//
//			bLow		- true if battery status low
//
//			nMillivolts	- voltage in millivolts
//
// Notes:	None
//
/////////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_BatteryStatus
{
	U32		sizeStruct;			
	bool	bLow;				
	U32		nMillivolts;		
};

/////////////////////////////////////////////////////////////////////////////////
//
// Name:	SWI_TYPE_BarredServices 
//
// Purpose:	Enumerations used to classify barred services
//			
// Members:	BARREDSERV_None			- Default, no services are restricted
//
//			BARREDSERV_All			- restrict all services
//
//			BARREDSERV_Fallback		- restrict circuit switched data
//
//			BARREDSERV_Packet		- restrict packet switched data 
//
// Notes:	None
//
/////////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_BarredServices
{
	BARREDSERV_None,
	BARREDSERV_All,
	BARREDSERV_Fallback,
	BARREDSERV_Packet
};

/////////////////////////////////////////////////////////////////////////////////
//
// Name:	SWI_STRUCT_MpNetworkConf 
//
// Purpose: Used by functions SwiGetMpNetworkConf and SwiSetMpNetworkConf to
//			retrieve or set network configuration information stored on the MP modem.		
//
// Members:	sizeStruct			- size of this structure
//
//			nFallbackInterval	- in seconds
//
//			nInactivityInterval - in seconds
//
//			nFallbackRecovery	- 0x00-disconnect, 0x01-Nothing
//
//			nOperatingMode		- 0x00-on demand, 0x01-always on
//
//			eBarredServices		-  default none
//
// Notes:	None
//
/////////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_MpNetworkConf
{
	U32						sizeStruct;				
	U32						nFallbackInterval;		
	U32						nInactivityInterval;	
	U32						nFallbackRecovery;		
	U32						nOperatingMode;			
	SWI_TYPE_BarredServices eBarredServices;		
};

/////////////////////////////////////////////////////////////////////////////////
//
// Name:	SWI_STRUCT_MpFwVersion - MP Firmware version
//
// Purpose:	This structure is used as output by the SwiGetMpFwVersion function. 
//
// Members:	sizeStruct	- size of this structure
//
//			strVersion	- null terminated firmware version
//
// Notes:	None
//
/////////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_MpFwVersion
{
	U32		sizeStruct;		
	WCHAR	strVersion[LENGTH_MpVersion];
};

/////////////////////////////////////////////////////////////////////////////////
//
// Name:	SWI_STRUCT_MpFwBuildDate - MP Firmware build date
//
// Purpose:	This structure is used as output by the SwiGetMpFwBuildDate function. 
//
// Members:	sizeStruct		- size of this structure
//
//			strBuildDate	- null terminated firmware build date
//
// Notes:	None
//
/////////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_MpFwBuildDate
{
	U32		sizeStruct;		
	WCHAR	strBuildDate[LENGTH_MpFwBuildDate];		
};

/////////////////////////////////////////////////////////////////////////////////
//
// Name:	SWI_STRUCT_MpBootLoaderVersion - MP Boot loader version
//
// Purpose:	This structure is used as output by the SwiGetMpBootLoaderVersion function. 
//
// Members:	sizeStruct	- size of this structure
//
//			strVersion	- null terminated boot loader version
//
// Notes:	None
//
/////////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_MpBootLoaderVersion
{
	U32		sizeStruct;		
	WCHAR	strVersion[LENGTH_MpVersion];	
};

/////////////////////////////////////////////////////////////////////////////////
//
// Name:	SWI_STRUCT_MpHwVersion - MP hardware version
//
// Purpose:	This structure is used as output by the SwiGetMpHwVersion function. 
//
// Members:	sizeStruct	- size of this structure
//
//			strVersion	- null terminated hardware version
//
// Notes:	None
//
/////////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_MpHwVersion
{
	U32		sizeStruct;		
	WCHAR	strVersion[LENGTH_MpHwVersion];
};

/////////////////////////////////////////////////////////////////////////////////
//
// Name:	SWI_STRUCT_MpHwBuildDate - MP hardware build date
//
// Purpose:	This structure is used as output by the SwiGetMpHwBuildDate function. 
//
// Members:	sizeStruct		- size of this structure
//
//			strBuildDate	- null terminated hardware build date
//
// Notes:	None
//
/////////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_MpHwBuildDate
{
	U32		sizeStruct;			
	WCHAR	strBuildDate[LENGTH_MpHwBuildDate];
};

/////////////////////////////////////////////////////////////////////////////////
//
// Name:	SWI_STRUCT_MpBatchNumber - MP batch number
//
// Purpose:	This structure is used as output by the SwiGetMpBatchNumber function. 
//
// Members:	sizeStruct		- size of this structure
//
//			strBatchNumber	- null terminated batch number
//
// Notes:	None
//
/////////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_MpBatchNumber
{
	U32		sizeStruct;			
	WCHAR	strBatchNumber[LENGTH_MpBatchNumber];
};

/////////////////////////////////////////////////////////////////////////////////
//
// Name:	SWI_STRUCT_MpFsn - MP factory serial number
//
// Purpose:	This structure is used as output by the SwiGetMpFsn function. 
//
// Members:	sizeStruct	- size of this structure
//
//			strFsn		- null terminated fsn number
//
// Notes:	None
//
/////////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_MpFsn
{
	U32		sizeStruct;			
	WCHAR	strFsn[LENGTH_MpFsn];
};

/////////////////////////////////////////////////////////////////////////////////
//
// Name:	SWI_STRUCT_MpName - MP device name
//
// Purpose:	This structure is used as output by the SwiGetMpDeviceName function. 
//
// Members:	sizeStruct	- size of this structure
//
//			strFsn		- null terminated device name
//
// Notes:	None
//
/////////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_MpName
{
	U32		sizeStruct;
	WCHAR	strName[LENGTH_MpName];
};

/////////////////////////////////////////////////////////////////////////////////
//
// Name:	SWI_TYPE_MpShutdown - enumerations for cause of MP shutdown
//
// Purpose:	Enumerations used to classify MP shutdown reasons
//
// Members:	MPSHUTDOWN_Unknown			- reason unknown
//
//			MPSHUTDOWN_PowerOffTimer	- shutdown due to power off timer
//
//			MPSHUTDOWN_LowBattery		- shutdown due to low battery
//
// Notes:	None
//
/////////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_MpShutdown
{
	MPSHUTDOWN_Unknown,
	MPSHUTDOWN_PowerOffTimer,
	MPSHUTDOWN_LowBattery,
};

/////////////////////////////////////////////////////////////////////////////////
//
// Name:	SWI_STRUCT_MpShutdown - MP shutdown information structure
//
// Purpose:	This structure contains the reason behind a MP shutdown
//
// Members:	sizeStruct	- size of this structure
//
//			eShutdown	- reason for shutdown
//
// Notes:	None
//
/////////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_MpShutdown
{
	U32					sizeStruct;			
	SWI_TYPE_MpShutdown	eShutdown;
};

/////////////////////////////////////////////////////////////////////////////////
//
// Name:	SWI_STRUCT_MpConnectionSetup - profile information structure
//
// Purpose:	Used by functions SwiSetMpCnxSetup and SwiGetMpCnxSetup.  Structure
//			stores profile information to be retrieved/set. The 'sizeStruct' and 
//			'nIndex' fields must be set in the structure before passing it to 
//			SwiGetMpCnxSetup.  The 'sizeStruct', 'nIndex', and 'szLabel' fields must 
//			be set in the structure before passing it to SwiSetMpCnxSetup.  When using 
//			SwiSetMpCnxSetup the rest of the fields should be filled out as 
//			well (ie. szUserName, szPassword, szApnPhone), if these fields aren't 
//			filled out then the API will write NULL to them .
//
// Members:	sizeStruct	- size of this structure
//
//			nIndex		- 0x00 Reserved, 0x01-0x03
//
//			szLabel		- Profile label
//
//			szUserName	- User name
//
//			szPassword	- User password
//
//			szApnPhone	- access point name/phone number
//
//			bValid		- true if this is a valid profile
//
//			bDefault	- true if this is a default profile
//
// Notes:	None
//
/////////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_MpConnectionSetup
{
    U32                     sizeStruct;									
	U32						nIndex;										
    WCHAR	                szLabel[LENGTH_Label];				 
	WCHAR                   szUserName[LENGTH_UserNameMp];					
	WCHAR                   szPassword[LENGTH_PasswordMp];
	WCHAR                   szDomain[LENGTH_Domain];				
	WCHAR	                szApnPhone[LENGTH_AccessPointName];	
	bool					bValid;										
	bool					bDefault;									
};

struct SWI_STRUCT_Mp555ConnectionSetup
{
	U32						sizeStruct;
	U32						nVersion;
	U32						nIndex;
	bool					bValid;
	bool					bDefault;
    WCHAR	                szLabel[LENGTH_Label];				 
	WCHAR                   szUserName[LENGTH_MaxMp555Name];					
	WCHAR                   szPassword[LENGTH_MaxMp555Pass];
	WCHAR                   szDomain[LENGTH_Domain];
	WCHAR					szPhone[LENGTH_MaxMp555Phone];

};

/////////////////////////////////////////////////////////////////////////////////
//
// Name:	SWI_TYPE_MpConnectResult - Result of an Mp test connection
//
// Purpose:	Enumerations used to classify test connection results
//
// Members:	MPCONNECT_Ok	
//
//			MPCONNECT_OkFallback	
//
//			MPCONNECT_Failed
//
//			MPCONNECT_NoService
//
//			MPCONNECT_NoPacketService
//
//			MPCONNECT_NoProfile
//
//			MPCONNECT_ServiceBarred
//
//			MPCONNECT_IncorrectService
//
//			MPCONNECT_Busy
//
// Notes:	None
//
/////////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_MpConnectResult
{
	MPCONNECT_Ok,
	MPCONNECT_OkFallback,
	MPCONNECT_Failed,
	MPCONNECT_NoService,
	MPCONNECT_NoPacketService,
	MPCONNECT_NoProfile,
	MPCONNECT_ServiceBarred,
	MPCONNECT_IncorrectService,
	MPCONNECT_Busy,
	MPCONNECT_IncorrectId,
	MPCONNECT_IpReady = 0xc,	// Same as MPDISCONNECT_IpReady.
};

/////////////////////////////////////////////////////////////////////////////////
//
// Name:	SWI_STRUCT_MpConnect 
//
// Purpose:	Received through the SWI_NOTIFY_MpConnect notification.  Stores
//			the result of a MP test connection
//
// Members:	sizeStruct	- size of this structure
//
//			nIndex		- index of profile
//
//			eResult		- result of connection attempt
//
// Notes:	None
//
/////////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_MpConnect
{
	U32							sizeStruct;	
	U32							nIndex;			
	SWI_TYPE_MpConnectResult	eResult;	
};

/////////////////////////////////////////////////////////////////////////////////
//
// Name:	SWI_STRUCT_MpStartupDiag
//
// Purpose:	Structure used to store results of start up diagnostics
//
// Members:	sizeStruct	- size of this structure
//
// Notes:	None
//
/////////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_MpStartupDiag	  
{
	U32			sizeStruct;		
};

/////////////////////////////////////////////////////////////////////////////////
//
// Name:	SWI_STRUCT_MpStartupConfig
//
// Purpose:	Used to configure what UDP port to use on the MP
//
// Members:	sizeStruct			- size of this structure
//
//			nModemPortNumber	- port number on the modem side
//
//			nHostPortNumber		- port number on the host side
//
//			nLengthIp			- length of IP
//
//			szIp				- internal IP
//
// Notes:	None
//
/////////////////////////////////////////////////////////////////////////////////	
struct SWI_STRUCT_MpStartupConfig
{
	U32			sizeStruct;				
	U32			nModemPortNumber;		
	U32			nHostPortNumber;		
	U32			nLengthIp;				
	U8			byIp[LENGTH_MP_IPAddress];	
};

/////////////////////////////////////////////////////////////////////////////////
//
// Name:	SWI_TYPE_MpDisconnectResult - Result of an Mp test disconnection
//
// Purpose:	Enumerations used to classify test disconnection results
//
// Members:	MPDISCONNECT_Ok	
//
//			MPDISCONNECT_IpReady	
//
// Notes:	None
//
/////////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_MpDisconnectResult
{
	MPDISCONNECT_Ok			= 0x0,
	MPDISCONNECT_IpReady	= 0xc,	// Chosen to be same as MPCONNECT_IpReady .
};

/////////////////////////////////////////////////////////////////////////////////
//
// Name:	SWI_STRUCT_MpDisconnect - Mp disconnection structure
//
// Purpose:	Received through the SWI_NOTIFY_MpDisconnect notification.
//			Note: This is a USB only structure
//
// Members:	sizeStruct	- size of this structure
//
//			eResult		- result of disconnection attempt
//
// Notes:	None
//
/////////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_MpDisconnect
{
	U32							sizeStruct;				
	SWI_TYPE_MpDisconnectResult	eResult;	
};

/////////////////////////////////////////////////////////////////////////////////
//
// Name:	SWI_STRUCT_MpActiveSetup - Mp active setup structure
//
// Purpose:	Used by SwiGetMpActiveSetup to determine the active setup index
//
// Members:	sizeStruct		- size of this structure
//
//			nActiveSetup	- 0x00: reserved, 
//							  0x01-0x03: setup index 1 to 3, 
//							  0x04: fallback profile,
//							  0x0ff: no active setup
//
// Notes:	None
//
/////////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_MpActiveSetup
{
	U32		sizeStruct;
	U32		nActiveSetup;
};

/////////////////////////////////////////////////////////////////////////////////
//
// Name:	SWI_STRUCT_MpManagerCfg - Mp Manager configuration
//
// Purpose:	Contains MP Manager configuration settings 
//
// Members:	sizeStruct		- size of this structure
//
//			
//
// Notes:	None
//
/////////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_MpManagerCfg
{
	U32		sizeStruct;
	bool	bVpnSupport;
	U16		nRnapUdpPort;
	U16		nRawUdpPort;
};

/////////////////////////////////////////////////////////////////////////////////
//
// Name:	SWI_TYPE_MpManagerData 
//
// Purpose:	Enumerations used to classify MP Manager data types
//
// Members:	MPMGRDATA_Rnap		- RNAP data
//
//			MPMGRDATA_Raw		- RAW GPS data
//
// Notes:	None
//
/////////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_MpManagerData
{
	MPMGRDATA_Rnap,
	MPMGRDATA_Raw,
};

/////////////////////////////////////////////////////////////////////////////////
//
// Name:	SWI_STRUCT_MpManagerData - Mp Manager Data packet
//
// Purpose:	Contains MP Manager relay data
//
// Members:	sizeStruct			- size of this structure
//			eType				- type of data
//			nDestinationIp		- destination IP
//			nDestinationPort	- destination port
//			nSourceIp			- source IP
//			nSourcePort			- source port
//			nLengthPayload		- length of payload
//			byPayload			- payload
//
// Notes:	None
//
/////////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_MpManagerData
{
	U32						sizeStruct;
	SWI_TYPE_MpManagerData	eType;
	U32						nDestinationIp;
	U32						nDestinationPort;
	U32						nSourceIp;
	U32						nSourePort;
	U32						nLengthPayload;
	BYTE					byPayload[LENGTH_MpManagerData];
};

/////////////////////////////////////////////////////////////////////////////////
//
// Name:	SWI_TYPE_MpMtConnection - Monitor and Tracking connection type
//
// Purpose:	Connection type
//
// Members: 0x00 - Engine unused
//			0x01 - MTP embedded in UDP packets
//			0x02 - Unused
//			0x03 - Raw GPS data embedded in UDP
//
// Notes:	None
//
/////////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_MpMtConnection
{
	MPMTCON_EngineUnused,
	MPMTCON_Mtp,
	MPMTCON_Unused,
	MPMTCON_Gps
};

/////////////////////////////////////////////////////////////////////////////////
//
// Name:	SWI_STRUCT_MpMtCfg - Monitor and Tracking Configuration
//
// Purpose:	Used to configure an Monitor and Tracking engine
//
// Members:	sizeStruct			- size of this structure
//			nEngineID			- reporting engine ID
//			eConType			- connection type
//			nDestinationIp		- destination IP
//			nDestinationPort	- destination port
//			nLowRateTimer		- low rate timer
//			nGpsPollTimer		- GPS polling timer
//
// Notes:	None
//
/////////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_MpMtCfg
{
	U32						sizeStruct;
	U32						nEngineId;
	SWI_TYPE_MpMtConnection	eConType;
	U32						nLengthIp;
	U8						byDestinationIp[LENGTH_MP_IPAddress];
	U32						nDestinationPort;
	U32						nLowRateTimer;
	U32						nFastRateTimer;
	U32						nGpsPollTimer;
};

/////////////////////////////////////////////////////////////////////////////////
//
// Name:	SWI_TYPE_MpCwMode
//
// Purpose:	Connection Watchdog Mode
//
// Members: 0x00 - DNS
//			0x01 - PING
//
// Notes:	None
//
/////////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_MpCwMode
{
	MPCWMODE_Dns,
	MPCWMODE_Ping,
};

/////////////////////////////////////////////////////////////////////////////////
//
// Name:	SWI_STRUCT_MpCwCfg - Connection Watchdog Configuration
//
// Purpose:	Used to configure the Connection Watchdog
//
// Members:	sizeStruct			- size of this structure
//			nConnectTimer		- connection timer
//			nValidTimer			- validation timer
//			nDnsPort			- DNS port
//			strDnsName			- DNS 
//			bResetFlag			- reset flag, false - do not reset after connection termination
//											  true - reset after connection termination
//			nLengthPingIp		- PING IP length
//			byPingIp			- PING IP address
//			eCwMode				- CW Mode
//			
//
// Notes:	None
//
/////////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_MpCwCfg
{
	U32						sizeStruct;
	U32						nConnectTimer;
	U32						nValidTimer;
	U32						nDnsPort;
	WCHAR					strDnsName[LENGTH_DnsName];
	bool					bResetFlag;
	U32						nLengthPingIp;
	BYTE					byPingIp[LENGTH_MP_IPAddress];
	SWI_TYPE_MpCwMode		eCwMode;
	U32						nConnectionReset;
};

/////////////////////////////////////////////////////////////////////////////////
//
// Name:	SWI_STRUCT_MpGpsInitStr - GPS Initialization String
//
// Purpose:	Used to configure GPS initialization string
//
// Members:	sizeStruct			- size of this structure
//			nStrNum				- initialization string number, 1-5
//			strInitStr			- initialization string, must be NULL terminated
//			
//
// Notes:	None
//
/////////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_MpGpsInitCfg
{
	U32		sizeStruct;
	U32		nStrNum;
	WCHAR	strInitStr[LENGTH_InitString];	
};

/////////////////////////////////////////////////////////////////////////////////
//
// Name:	SWI_STRUCT_MpTestHistory
//
// Purpose:	MP test history information
//
// Members:	sizeStruct		- size of this structure
//			nTestHistory	- 0 <= range <= 255
//			
// Notes:	None
//
/////////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_MpTestHistory
{
	U32		sizeStruct;			
	U32		nTestHistory;	
};

///////////////////////////////////////////////////////////////////////////////
//
// Name:	SWI_Type_MpUnlockLevel
//
// Purpose:	Enumerates MP unlock types
//
// Members:	SWI_MPUNLOCK_Configuration	- Configuration level lock protects
//										  sensitive user configurations
//
//			SWI_MPUNLOCK_Low			- Low level lock protects modem
//										  configuration and diagnostic
//										  operations.
//
//			SWI_MPUNLOCK_High			- High level lock protects modem
//										  calibration and advanced diagnostic
//										  operations.
//			
// Notes:	This enumeration lists the different operation levels that may be
//			locked by the MP.
//
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_MpUnlockLevel
{
	SWI_MPUNLOCK_Configuration = 0x31,
	SWI_MPUNLOCK_Low,
	SWI_MPUNLOCK_High,
};

///////////////////////////////////////////////////////////////////////////////
//
// Name:	SWI_Type_MpUnlockResult
//
// Purpose:	MP unlock / change lock result codes
//
// Members:	SWI_MPUNLOCKRESULT_Success
//
//			SWI_MPUNLOCKRESULT_UnlockFirst - MP must be unlocked first (used for change lock only)
//
//			SWI_MPUNLOCKRESULT_CodeMismatch - Unlock code incorrect (used for unlock only)
//
//			SWI_MPUNLOCKRESULT_InvalidLockLevel - Lock level invalid
//
//			SWI_MPUNLOCKRESULT_InvalidCodeFormat - Code format invalid
//			
// Notes:	
//
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_MpUnlockResult
{
	SWI_MPUNLOCKRESULT_Success,
	SWI_MPUNLOCKRESULT_UnlockFirst,
	SWI_MPUNLOCKRESULT_CodeMismatch,
	SWI_MPUNLOCKRESULT_InvalidLockLevel,
	SWI_MPUNLOCKRESULT_InvalidCodeFormat,
};

///////////////////////////////////////////////////////////////////////////////
//
// Name:	SWI_STRUCT_MpUnlock
//
// Purpose:	Structure used for unlocking MP operations 
//
// Members:	sizeStruct		- size of this structure
//
//			eUnlockType		- type of operation to unlock
//
//			szUnlockCode	- password used to unlock the specified operation
//							  type	
//
//			eUnlockStatus	- Status of request or current unlock status
//			
// Notes:	None
//
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_MpUnlock
{
	U32		sizeStruct;			
	SWI_TYPE_MpUnlockLevel	eUnlockType;
	WCHAR	szUnlockCode[LENGTH_MpUnlockCode];
	SWI_TYPE_MpUnlockResult	eResult;
};

///////////////////////////////////////////////////////////////////////////////
//
// Name:	SWI_Type_MpWifiMode
//
// Purpose:	Enumerates WIFI modes
//
// Members:	SWI_MPWIFIMODE_Disabled - WAP disabled
//
//			SWI_MPWIFIMODE_MixedBg - Mixed mode (Wireless B + G)
//
//			SWI_MPWIFIMODE_GOnly - Wireless G only
//
//			SWI_MPWIFIMODE_BOnly - Wireless B only
//			
// Notes:	
//
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_MpWifiMode
{
	SWI_MPWIFIMODE_Disabled,
	SWI_MPWIFIMODE_MixedBg,
	SWI_MPWIFIMODE_GOnly,
	SWI_MPWIFIMODE_BOnly,
};

///////////////////////////////////////////////////////////////////////////////
//
// Name:	SWI_TYPE_MpWifiSecurity
//
// Purpose:	Enumerates WIFI security modes
//
// Members:	SWI_MPWIFISECURITY_Disabled	- WIFI security disabled
//
//			SWI_MPWIFISECURITY_OpenWep - Open WEP
//
//			SWI_MPWIFISECURITY_SharedWep - Shared WEP
//
//			SWI_MPWIFISECURITY_WpaTkip - WPA TKIP
//
//			SWI_MPWIFISECURITY_Wpa2Aes - WPA2 AES
//
//			SWI_MPWIFISECURITY_Wpa2Tkip - WPA2 TKIP
//
//			SWI_MPWIFISECURITY_Wpa2TkipAes - WPA2 TKIP + AES
//
//			SWI_MPWIFISECURITY_Wpa2Aes - WPA2 AES
//
//			SWI_MPWIFISECURITY_WpaTkipAes - WPA TKIP + AES
//			
// Notes:	None
//
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_MpWifiSecurity
{
	SWI_MPWIFISECURITY_Disabled,
	SWI_MPWIFISECURITY_OpenWep,
	SWI_MPWIFISECURITY_SharedWep,
	SWI_MPWIFISECURITY_WpaTkip,
	SWI_MPWIFISECURITY_Wpa2Aes,
	SWI_MPWIFISECURITY_Wpa2Tkip,
	SWI_MPWIFISECURITY_Wpa2TkipAes,
	SWI_MPWIFISECURITY_WpaAes,
	SWI_MPWIFISECURITY_WpaTkipAes,
};

///////////////////////////////////////////////////////////////////////////////
//
// Name:	SWI_Type_MpWifiCfgResult
//
// Purpose:	MP unlock result codes
//
// Members:	SWI_MPWIFICFGRESULT_Success
//
//			SWI_MPWIFICFGRESULT_MpLocked - MP must be unlocked first
//
//			SWI_MPWIFICFGRESULT_InvalidSecurity - Invalid security type 
//
//			SWI_MPWIFICFGRESULT_InvalidKey - Invalid key format
//
//			SWI_MPWIFICFGRESULT_InvalidSsid - Invalid SSID format
//
//			SWI_MPWIFICFGRESULT_InvalidChannel - Invalid channel
//
//			SWI_MPWIFICFGRESULT_InvalidMode - Invalid mode specified
//
//			
// Notes:	
//
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_MpWifiCfgResult
{
	SWI_MPWIFICFGRESULT_Success,
	SWI_MPWIFICFGRESULT_MpLocked,
	SWI_MPWIFICFGRESULT_InvalidSecurity,
	SWI_MPWIFICFGRESULT_InvalidKey,
	SWI_MPWIFICFGRESULT_InvalidSsid,
	SWI_MPWIFICFGRESULT_InvalidChannel,
	SWI_MPWIFICFGRESULT_InvalidMode,
};

///////////////////////////////////////////////////////////////////////////////
//
// Name:	SWI_STRUCT_MpWifiCfg
//
// Purpose:	Structure used for configuring the WIFI Access Point (WAP) 
//
// Members:	sizeStruct		- size of this structure
//
//			eWifiMode		- WIFI mode
//
//			szSsid			- 1 to 32 characters
//
//			nChannel		- 1 <= range <= 11
//
//			eSecurity		- Security setting
//
//			szWifiKey		- 8 to 64 characters for WPA/WPA2
//							  10 or 26 HEX characters for WEP (ex. 12345ABCDE)
//							  When writing new configuration values to the 
//							  modem, specifying a key value of NULL will result
//							  in modifications to the other fields except
//							  the key value.  When reading the configuration
//							  values from the modem, the key will not be
//							  returned.  Instead, # characters will be returned.
//
//			eResult			- result of operation
//			
// Notes:	None
//
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_MpWifiCfg
{
	U32							sizeStruct;
	SWI_TYPE_MpWifiMode			eWifiMode;
	WCHAR						szSsid[LENGTH_Ssid];
	U32							nChannel;
	SWI_TYPE_MpWifiSecurity		eSecurity;
	WCHAR						szWifiKey[LENGTH_WifiKey];
	SWI_TYPE_MpWifiCfgResult	eResult;
};

///////////////////////////////////////////////////////////////////////////////
//
// Name:	SWI_STRUCT_MpFeatures
//
// Purpose:	Structure used to retrieve list of support features
//
// Members:	sizeStruct		- size of this structure
//
//			bWifiAvailable	- true if WIFI available, false otherwise
//			
// Notes:	None
//
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_MpFeatures
{
	U32		sizeStruct;			
	bool	bWifiAvailable;
};

///////////////////////////////////////////////////////////////////////////////
//
// Name:	SWI_Type_MpFeatCfgResult
//
// Purpose:	MP feature configuration result codes
//
// Members:	SWI_MPFEATCFGRESULT_Success	- success
//
//			SWI_MPFEATCFGRESULT_NotSupported - feature not supported
//			
// Notes:	
//
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_MpFeatCfgResult
{
	SWI_MPFEATCFGRESULT_Success,
	SWI_MPFEATCFGRESULT_NotSupported,
};

///////////////////////////////////////////////////////////////////////////////
//
// Name:	SWI_STRUCT_MpFeatureCfg
//
// Purpose:	Structure used to retrieve and configure programmable MP features
//
// Members:	sizeStruct		- size of this structure
//
//			bNatEnable		- Set to true to enable NAT, false to disable
//
//			eResult			- result of operation
//			
// Notes:	None
//
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_MpFeatureCfg
{
	U32		sizeStruct;			
	bool	bNatEnable;
	SWI_TYPE_MpFeatCfgResult eResult;
};

#endif //__SWI_MP_STRUCTS_
