/**
 *
 *	Name	:	ConnectAPISampleDlg.cpp
 *
 *	Purpose	:	Main dialog implementation file for ConnectAPISample
 *				This sample application demonstrates how to open a
 *				connection to the API.
 *
 *	History	:	created	Oct 23, 2001
 *				- initial version
 *				revised Feb 20 2002
 *				- different implementation with MFC objects
 *				revised	June 17, 2003
 *				- more usage of MFC objects
 *				- replaced obsolete functions
 *
 *	Revision:	2.0
 *
 *	Copyright (c) 2003 Sierra Wireless, Inc. All rights reserved.
 *
 **/

#include "stdafx.h"
#include "ConnectAPISample.h"
#include "ConnectAPISampleDlg.h"

#ifdef _DEBUG
#define new DEBUG_NEW
#undef THIS_FILE
static char THIS_FILE[] = __FILE__;
#endif

/////////////////////////////////////////////////////////////////////////////
// CConnectAPISampleDlg dialog

CConnectAPISampleDlg::CConnectAPISampleDlg(CWnd* pParent /*=NULL*/)
	: CDialog(CConnectAPISampleDlg::IDD, pParent)
{
	//{{AFX_DATA_INIT(CConnectAPISampleDlg)
	m_strStatusIndicator = _T("");
	//}}AFX_DATA_INIT
	// Note that LoadIcon does not require a subsequent DestroyIcon in Win32
	m_hIcon = AfxGetApp()->LoadIcon(IDR_MAINFRAME);
}

void CConnectAPISampleDlg::DoDataExchange(CDataExchange* pDX)
{
	CDialog::DoDataExchange(pDX);
	//{{AFX_DATA_MAP(CConnectAPISampleDlg)
	DDX_Control(pDX, IDC_CONNECT, m_btnConnect);
	DDX_Text(pDX, IDC_CONTEXT, m_strStatusIndicator);
	//}}AFX_DATA_MAP
}

BEGIN_MESSAGE_MAP(CConnectAPISampleDlg, CDialog)
	//{{AFX_MSG_MAP(CConnectAPISampleDlg)
	ON_WM_QUERYDRAGICON()
	ON_BN_CLICKED(IDC_CONNECT, OnConnect)
	ON_BN_CLICKED(IDC_BTN_OK, OnOK)
	//}}AFX_MSG_MAP
END_MESSAGE_MAP()

/////////////////////////////////////////////////////////////////////////////
// CConnectAPISampleDlg message handlers

BOOL CConnectAPISampleDlg::OnInitDialog()
{
	CDialog::OnInitDialog();

	// Set the icon for this dialog.  The framework does this automatically
	//  when the application's main window is not a dialog
	SetIcon(m_hIcon, TRUE);			// Set big icon
	SetIcon(m_hIcon, FALSE);		// Set small icon
	
	// TODO: Add extra initialization here

	//initializing the main variables.
	m_strStatusIndicator = _T("Disconnected from device");
	m_bConnected = FALSE;

	//update values to screen
	UpdateData(FALSE);
	
	return TRUE;  // return TRUE  unless you set the focus to a control
}

// The system calls this to obtain the cursor to display while the user drags
//  the minimized window.
HCURSOR CConnectAPISampleDlg::OnQueryDragIcon()
{
	return (HCURSOR) m_hIcon;
}

/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	ProcessError
//
//	Description	:	Helper function to process error codes
//
//	Arguments	:	[IN]: code - error code from the API
//
//	Returns		:	None
//
//	Comments	:
//
/////////////////////////////////////////////////////////////////////////////
void CConnectAPISampleDlg::ProcessError(SWI_RCODE code)
{
	CString strErrorString;

	strErrorString.Format(_T("Internal error - error code: %d"), code);

	MessageBox(strErrorString, _T("API Message"), MB_OK);
}

SWI_TYPE_Device CConnectAPISampleDlg::GetHighestPriorityDeviceType ()
{
	SWI_TYPE_Device				eTypeDevice = SWI_DEVICE_None;
	SWI_STRUCT_AirServerList	sAvailDevList;
	SWI_RCODE					rCode;

	//--------------------
	// Connect to ANY device
	//--------------------
	sAvailDevList.sizeStruct = sizeof(SWI_STRUCT_AirServerList);
	rCode = SwiGetAvailAirServers(sAvailDevList);
	if (SWI_RCODE_OK != rCode)
	{
		m_strStatusIndicator =  _T("GetAvailDev() Failed");
		return eTypeDevice;
	}

	// how many avail devices?
	if (0 == sAvailDevList.nNumber)
	{
		m_strStatusIndicator = _T("No available devices");
		return eTypeDevice;
	}

	return sAvailDevList.AirServers[0].eDevice;
}

/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	OnConnect
//
//	Description	:	Start a Connection to the Modem
//
//	Arguments	:	None
//
//	Returns		:	None
//
//	Comments	:
//
///////////////////////////////////////////////////////////////////////////
void CConnectAPISampleDlg::OnConnect() 
{	
	SWI_RCODE rCode;
	SWI_TYPE_Device eDevice;
	BOOL bDisconnected; //checks if disconnection was successful

	if (m_bConnected == FALSE)
	{
		//Open a connection with the Modem
		SWI_STRUCT_ApiStartup sOpenParams;
		memset(&sOpenParams, 0, sizeof(SWI_STRUCT_ApiStartup));

		rCode = SwiApiStartup(&sOpenParams);
		if(SWI_RCODE_OK != rCode 
			&& SWI_RCODE_ALREADY_OPEN != rCode) // Bz13170
		{
			ProcessError(rCode);
			return;
		}

		eDevice = GetHighestPriorityDeviceType();
		if (eDevice == SWI_DEVICE_None)
		{
			UpdateData(FALSE);
			return;
		}

		//as we are here there are no errors
		//Initialize member variables and change GUI to reflect a successful connection
		//to the API
		m_bConnected = TRUE;
		m_strStatusIndicator = _T("Connected to device");
		m_btnConnect.SetWindowText(_T("Disconnect"));
		m_btnConnect.EnableWindow(TRUE);

		//Update values to screen
		UpdateData(FALSE);
	} 
	else //Handling a disconnection
	{
		bDisconnected = DisconnectModem();

		//checking if disconnection was successful
		if(bDisconnected)
		{
			m_strStatusIndicator = _T("Disconnected from device");
		}
		else
		{
			m_strStatusIndicator = _T("Error occured while disconnecting");
		}

		//reset member variables and modify GUI to reflect a disconnection from the API
		m_bConnected = FALSE;
		m_btnConnect.SetWindowText(_T("Connect"));
		m_btnConnect.EnableWindow(TRUE);

		//Updating values to screen
		UpdateData(FALSE);
	}
}


/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	OnOK
//
//	Description	:	OK button has been pressed to exit the applications
//
//	Arguments	:	None
//
//	Returns		:	None
//
//	Comments	:
//
///////////////////////////////////////////////////////////////////////////
void CConnectAPISampleDlg::OnOK() 
{

	// if there is an open connection with the modem then it must be closed before
	// closing the window
	if (m_bConnected == TRUE)
	{
		//disconnect from modem then exit application
		DisconnectModem();

		//resetting variables
		m_bConnected = FALSE;
	}	
	CDialog::OnOK();
}


/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	DisconnectModem
//
//	Description	:	Disconnects from the modem
//
//	Arguments	:	IN: None	OUT: TRUE/FALSE
//
//	Returns		:	TRUE/FALSE to indicate success or failure of disconnection
//
//	Comments	:
//
///////////////////////////////////////////////////////////////////////////
BOOL CConnectAPISampleDlg::DisconnectModem()
{
	SWI_RCODE rcode;

	rcode = SwiApiShutdown();	//close connection with modem
	if (SWI_RCODE_OK != rcode)
	{	
		ProcessError(rcode);
		return FALSE;
	}
	
	return TRUE;
}
