/**
 *
 *	Name	:	NotificationSampleDlg.cpp
 *
 *	Purpose	:	Main dialog implementation file for NotificationSample
 * 				This sample application demonstrates how to handle a notification
 *				sent from the modem, in this case, an RSSI notification.
 *
 *	History	:	created	Oct 23, 2001
 *				- initial version
 *				revised Feb 20 2002
 *				- made program more efficient
 *				revised	June 17, 2003
 *				- replaced obsolete functions
 *				- more usage of MFC objects
 *
 *	Revision:	2.0
 *
 *	Copyright (c) 2003 Sierra Wireless, Inc. All rights reserved.
 *
 **/

#include "stdafx.h"
#include "NotificationSample.h"
#include "NotificationSampleDlg.h"
#include "SwiApiGsm.h"

#ifdef _DEBUG
#define new DEBUG_NEW
#undef THIS_FILE
static char THIS_FILE[] = __FILE__;
#endif

CNotificationSampleDlg*	CNotificationSampleDlg::m_instance = NULL; //initializing pointer to this object to NULL

/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	CNotificationSampleDlg
//
//	Description	:	
//
//
/////////////////////////////////////////////////////////////////////////////

CNotificationSampleDlg::CNotificationSampleDlg(CWnd* pParent /*=NULL*/)
	: CDialog(CNotificationSampleDlg::IDD, pParent)
{
	//{{AFX_DATA_INIT(CNotificationSampleDlg)
	m_iRSSI = 0;
	m_instance = this;
	m_strConnectionStatus = _T("Disconnected from device");
	//}}AFX_DATA_INIT
	// Note that LoadIcon does not require a subsequent DestroyIcon in Win32
	m_hIcon = AfxGetApp()->LoadIcon(IDR_MAINFRAME);
}


/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	DoDataExchange
//
//	Description	:	Declaration of MFC objects
//
//
/////////////////////////////////////////////////////////////////////////////

void CNotificationSampleDlg::DoDataExchange(CDataExchange* pDX)
{
	CDialog::DoDataExchange(pDX);
	// {{AFX_DATA_MAP(CNotificationSampleDlg)

	DDX_Control(pDX, IDC_BTN_CONNECT, m_btnConnect);
	DDX_Control(pDX, IDOK, m_btnOK);
	DDX_Text(pDX, IDC_RSSIINT, m_iRSSI);
	DDX_Text(pDX, IDC_STATUSTEXT, m_strConnectionStatus);
	//}}AFX_DATA_MAP
}

BEGIN_MESSAGE_MAP(CNotificationSampleDlg, CDialog)
	// {{AFX_MSG_MAP(CNotificationSampleDlg) */
	ON_WM_QUERYDRAGICON()
	ON_BN_CLICKED(IDC_BTN_CONNECT, OnBtnConnect)

	// }}AFX_MSG_MAP */
	ON_MESSAGE(WM_NOTIFICATION, OnNotification) //function to handle all event notifications
END_MESSAGE_MAP()


/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	OnInitDialog
//
//	Description	:	Initialization of variables and icons
//
//	Arguments	:	None
//
//	Returns		:	Boolean
//
//	Comments	:
//
/////////////////////////////////////////////////////////////////////////////

BOOL CNotificationSampleDlg::OnInitDialog()
{
	CDialog::OnInitDialog();
	// Set the icon for this dialog.  The framework does this automatically
	//  when the application's main window is not a dialog

	SetIcon(m_hIcon, TRUE);			// Set big icon
	SetIcon(m_hIcon, FALSE);		// Set small icon
	
	//initialize connection state variable
	m_bConnected = FALSE;

	m_strConnectionStatus = _T("Disconnected from device");

	//update values to screen
	UpdateData(FALSE);

	return TRUE;  // return TRUE  unless you set the focus to a control
}

SWI_TYPE_Device CNotificationSampleDlg::GetHighestPriorityDeviceType ()
{
	SWI_TYPE_Device				eTypeDevice = SWI_DEVICE_None;
	SWI_STRUCT_AirServerList	sAvailDevList;
	SWI_RCODE					rCode;

	//--------------------
	// Connect to ANY device
	//--------------------
	sAvailDevList.sizeStruct = sizeof(SWI_STRUCT_AirServerList);
	rCode = SwiGetAvailAirServers(sAvailDevList);
	if (SWI_RCODE_OK != rCode)
	{
		m_strConnectionStatus =  _T("GetAvailDev() Failed");
		return eTypeDevice;
	}

	// how many avail devices?
	if (0 == sAvailDevList.nNumber)
	{
		m_strConnectionStatus = _T("No available devices");
		return eTypeDevice;
	}

	return sAvailDevList.AirServers[0].eDevice;
}

/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	OnPaint
//
//	Description	:	MFC function
//
//	Arguments	:	None
//
//	Returns		:	None
//
//	Comments	:
//
/////////////////////////////////////////////////////////////////////////////


// The system calls this to obtain the cursor to display while the user drags
//  the minimized window.
HCURSOR CNotificationSampleDlg::OnQueryDragIcon()
{
	return (HCURSOR) m_hIcon;
}


/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	ProcessError
//
//	Description	:	Helper function to process error codes
//
//	Arguments	:	[IN]: code - error code from the API
//
//	Returns		:	None
//
//	Comments	:
//
/////////////////////////////////////////////////////////////////////////////
void CNotificationSampleDlg::ProcessError(SWI_RCODE code)
{
	CString strErrorString;

	strErrorString.Format(_T("Internal error - error code: %d"), code);

	MessageBox(strErrorString, _T("API Message"), MB_OK);
}


/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	OnOK
//
//	Description	:	OK button has been pressed to exit the application
//
//	Arguments	:	None
//
//	Returns		:	None
//
//	Comments	:
//
///////////////////////////////////////////////////////////////////////////
void CNotificationSampleDlg::OnOK() 
{

	//disabling connection button for duration of disconnection
	m_btnOK.EnableWindow(FALSE);

	//disconnect from modem if there is a live connection
	DisconnectModem();

	CDialog::OnOK();
}


/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	NotificationCallback
//
//	Description	:	Callback that receives all event notifications
//
//	Arguments	:	[IN]: pNotify - pointer to notification variant
//
//	Returns		:	None
//
//	Comments	:	Even if no notifications are being processed,
//					this function still needs to be registered and declared
//					for calls to the API to function properly.
//
/////////////////////////////////////////////////////////////////////////////
void NotificationCallback(SwiNotifyVariant *pNotify)
{
	CNotificationSampleDlg* pThisObject = CNotificationSampleDlg::Instance();
	SWI_TYPE_Notify  eNotify = pNotify->eNotify;

	//used for debugging purposes, displays the notifications received
	TRACE(_T("Got notif %i\n"), eNotify);

    //Catch the info and post a message
    switch (eNotify) //add notifications here
    {
		case SWI_NOTIFY_Rssi:
			{
				I32 rssi = pNotify->_Rssi.iRssi;
	//			AfxGetMainWnd()->PostMessage(WM_NOTIFICATION, eNotify, rssi); 
				pThisObject->PostMessage(WM_NOTIFICATION, eNotify, rssi); 
			return;
			}
		default:
			break;
	}


}


/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	OnNotification
//
//	Description	:	Handler for received notifications
//
//	Arguments	:	[IN]: wParam - Contains the notification type
//					[IN]: lParam - Contains the data to be updated
//
//	Returns		:	None
//
//	Comments	:
//
/////////////////////////////////////////////////////////////////////////////
LRESULT CNotificationSampleDlg::OnNotification(WPARAM wParam, LPARAM lParam)
{
	switch(wParam) // notifications here
	{
		case SWI_NOTIFY_Rssi:
			//assigning the new RSSI received from the notification to the
			//member variable then proceed to update this value to screen
			m_iRSSI = (int)lParam;
			break;
		default:
			break;
	}

	//update the values to the screen
	UpdateData(FALSE);	
	return NULL;
}


/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	DisconnectModem
//
//	Description	:	Disconnects from the modem
//
//	Arguments	:	None
//
//	Returns		:	TRUE/FALSE to indicate success or failure of disconnection
//
//	Comments	:
//
///////////////////////////////////////////////////////////////////////////
BOOL CNotificationSampleDlg::DisconnectModem()
{
	SWI_RCODE rcode;

	//disconnect if a connection to the modem exists
	if(m_bConnected == TRUE)
	{
		// Disable notifications
		rcode = SwiStopNotify(SWI_NOTIFY_Rssi, TIMEOUT);
		if (SWI_RCODE_OK != rcode)
		{
			ProcessError(rcode);
			return FALSE;
		}

		//detaching modem from network; this has been commented out because
		//it can sometimes take up to 20 seconds to detach from the network,
		//since it is not absolutely necessary to detach from the network,
		//it has been commented out for the SDK sample apps.
	/*	rcode = SwiSetHostStartup(FALSE, TIMEOUT*20);
		if(SWI_RCODE_OK != rcode)
		{
			ProcessError(rcode);
			return FALSE;
		}
	*/

		//close connection with modem
		rcode = SwiApiShutdown();	
		if (SWI_RCODE_OK != rcode)
		{

			ProcessError(rcode);
			return FALSE;

		}
	}

	return TRUE;

}

/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	OnBtnConnect
//
//	Description	:	Connects/Disconnects to/from modem
//
//	Arguments	:	None
//
//	Returns		:	None
//
//	Comments	:
//
///////////////////////////////////////////////////////////////////////////
void CNotificationSampleDlg::OnBtnConnect() 
{
	ConnectModem();
}


/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	ConnectModem
//
//	Description	:	Connects/Disconnects from modem
//
//	Arguments	:	None
//
//	Returns		:	TRUE/FALSE to indicate success or failure of disconnection
//
//	Comments	:
//
///////////////////////////////////////////////////////////////////////////
BOOL CNotificationSampleDlg::ConnectModem()
{	
	SWI_RCODE rCode;
	SWI_TYPE_Device eDevice;
	BOOL bDisconnected; //checks if disconnection was successful

	//connect if there is no connection to the modem
	if(m_bConnected == FALSE)
	{
		//Open a connection with the Modem
		SWI_STRUCT_ApiStartup sOpenParams;
		memset(&sOpenParams, 0, sizeof(SWI_STRUCT_ApiStartup));

		rCode = SwiApiStartup(&sOpenParams);
		if(SWI_RCODE_OK != rCode 
			&& SWI_RCODE_ALREADY_OPEN != rCode) // Bz13170
		{
			ProcessError(rCode);
			return FALSE;
		}

		eDevice = GetHighestPriorityDeviceType ();
		if (eDevice == SWI_DEVICE_None)
		{
			UpdateData(FALSE);
			return FALSE;
		}

		DECLARE_MacAny;
		SWI_STRUCT_AirServer sAirServer;
		sAirServer.sizeStruct = sizeof(SWI_STRUCT_AirServer);
		memcpy(sAirServer.ClientMac, MacAny, LENGTH_MacAddress);
		memcpy(sAirServer.ServerMac, MacAny, LENGTH_MacAddress);
		sAirServer.eDevice = eDevice;

		rCode = SwiSelectAirServer(sAirServer);
		if(SWI_RCODE_OK != rCode)
		{
			ProcessError(rCode);
			return FALSE;
		}

		//Register the Callback function
		rCode = SwiRegisterCallback(NotificationCallback, 0xFFFFFFFFFFFFFFFF);
		if(SWI_RCODE_OK != rCode)
		{
			ProcessError(rCode);
			return FALSE;
		}

		//Informing modem of host startup state
		//This function attaches the modem to the network
		rCode = SwiSetHostStartup(TRUE, TIMEOUT*20);
		if(SWI_RCODE_OK != rCode)
		{
			ProcessError(rCode);
			return FALSE;
		}

		// Enable notifications
		rCode = SwiNotify(SWI_NOTIFY_Rssi, TIMEOUT);
		if(SWI_RCODE_OK != rCode)
		{
			ProcessError(rCode);
			return FALSE;
		}

		//as we are here there are no errors
		//Initialize member variables and change GUI to reflect a successful connection
		//to the API
		m_bConnected = TRUE;
		m_strConnectionStatus = _T("Connected to device");
		m_btnConnect.SetWindowText(_T("Disconnect"));
		m_btnConnect.EnableWindow(TRUE);

		//Update values to screen
		UpdateData(FALSE);
		return TRUE;
	} 
	else //Handling a disconnection
	{
		//Disconnect from modem
		bDisconnected = DisconnectModem();

		//checking if disconnection was successful
		if(bDisconnected)
		{
			m_strConnectionStatus = _T("Disconnected from device");
		}
		else
		{
			m_strConnectionStatus = _T("Error occured while disconnecting");
		}

		//reset member variables and modify GUI to reflect a disconnection from the API
		m_bConnected = FALSE;
		m_btnConnect.SetWindowText(_T("Connect"));
		m_btnConnect.EnableWindow(TRUE);
		m_iRSSI = 0;

		//Updating values to screen
		UpdateData(FALSE);
		return TRUE;
	}
}

/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	Instance
//
//	Description	:	A static function used to return a pointer to this object
//
//	Arguments	:	None
//
//	Returns		:	m_Instance - a pointer to this object
//
//	Comments	:
//
///////////////////////////////////////////////////////////////////////////
CNotificationSampleDlg* CNotificationSampleDlg::Instance()
{
	return m_instance;
}

