/**
 *
 *	Name	:	NotificationSampleDlg.h
 *
 *	Purpose	:	Main header file for NotificationSample
 *				This sample application demonstrates how to handle a notification
 *				sent from the modem, in this case, an RSSI notification.
 *
 *	History	:	created	Oct 23, 2001
 *				- initial version
 *				revised Feb 20 2002
 *				revised June 17 2003
 *
 *	Revision:	2.0
 *
 *	Copyright (c) 2003 Sierra Wireless, Inc. All rights reserved.
 *
 **/

#if !defined(AFX_NotificationSampleDLG_H__9F685AA6_6C65_11D4_89CB_E0C855C1FFFD__INCLUDED_)
#define AFX_NotificationSampleDLG_H__9F685AA6_6C65_11D4_89CB_E0C855C1FFFD__INCLUDED_

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000

#include "SwiApiCm.h"
#include "SwiStructsGsm.h"

#define BUFFER_SIZE 80
#define TIMEOUT 5000

// user defined windows message identifier for Rssi notification
#define WM_NOTIFICATION WM_USER + 400	//specific notification

////////////////////////////////////////////////////////////////////////////
//
//	Function	:	NotificationCallback
//
//	Description	:	Callback that receives all event notifications
//
//	Arguments	:	pNotify	- pointer to notification variant
//
//	Returns		:	None
//
//	Comments	:
//
/////////////////////////////////////////////////////////////////////////////
void NotificationCallback(SwiNotifyVariant *pNotify);

/////////////////////////////////////////////////////////////////////////////
// CNotificationSampleDlg dialog

class CNotificationSampleDlg : public CDialog
{
// Construction
public:
	CNotificationSampleDlg(CWnd* pParent = NULL);	// standard constructor

// Dialog Data
	//{{AFX_DATA(CNotificationSampleDlg)
	enum { IDD = IDD_NotificationSample_DIALOG };
	CButton	m_btnConnect;
	CButton	m_btnOK;
	int		m_iRSSI;
	CString	m_strConnectionStatus;
	static CNotificationSampleDlg* Instance(); //returns a pointer to this object
	//}}AFX_DATA

	// ClassWizard generated virtual function overrides
	//{{AFX_VIRTUAL(CNotificationSampleDlg)
protected:
	virtual void DoDataExchange(CDataExchange* pDX);	// DDX/DDV support
	//}}AFX_VIRTUAL

// Implementation

	BOOL ConnectModem(); //connects to modem
	BOOL DisconnectModem(); //disconnects from modem
	LRESULT OnNotification(WPARAM wParam, LPARAM lParam); //handles notifications
	void ProcessError(SWI_RCODE code); //handle error codes from the API
	SWI_TYPE_Device GetHighestPriorityDeviceType ();

protected:
	HICON m_hIcon;
	BOOL m_bConnected; //connection state indicator
	SWI_STRUCT_Rssi	m_Rssi;	// cache memory for Rssi notification

	enum TYPE_Device
	{
		DEVICE_AC710_750_775_850,
		DEVICE_MC87xx,
	};

	// Generated message map functions
	//{{AFX_MSG(CNotificationSampleDlg)
	virtual BOOL OnInitDialog();
	afx_msg HCURSOR OnQueryDragIcon();
	afx_msg void OnOK();
	afx_msg void OnBtnConnect();
	//}}AFX_MSG
	DECLARE_MESSAGE_MAP()

private:
	static CNotificationSampleDlg* m_instance; //a pointer to this object
};

//{{AFX_INSERT_LOCATION}}
// Microsoft Visual C++ will insert additional declarations immediately before the previous line.

#endif // !defined(AFX_NotificationSampleDLG_H__9F685AA6_6C65_11D4_89CB_E0C855C1FFFD__INCLUDED_)
