/**
 *
 *	Name	:	BandSelectSampleDlg.cpp
 *
 *	Purpose	:	main implementation file for the BandSelectSample application
 *
 *	History	:	Created Dec 27th, 2007
 *				This sample app demonstrates how to retrieve the bands and set it
 *
 *	Revision:	1.0
 *
 *	Copyright (c) 2003 Sierra Wireless, Inc. All rights reserved.
 *
 **/

#include "stdafx.h"
#include "BandSelectSample.h"
#include "BandSelectSampleDlg.h"
#include "SwiApiGsm.h"

#ifdef _DEBUG
#define new DEBUG_NEW
#undef THIS_FILE
static char THIS_FILE[] = __FILE__;
#endif

/////////////////////////////////////////////////////////////////////////////
// CBandSelectSampleDlg dialog

CBandSelectSampleDlg::CBandSelectSampleDlg(CWnd* pParent /*=NULL*/)
	: CDialog(CBandSelectSampleDlg::IDD, pParent)
{
	//{{AFX_DATA_INIT(CBandSelectSampleDlg)
	m_strStatusIndicator = _T("");
	m_strCurrentBand = _T("");
	//}}AFX_DATA_INIT
	// Note that LoadIcon does not require a subsequent DestroyIcon in Win32
	m_hIcon = AfxGetApp()->LoadIcon(IDR_MAINFRAME);
}

void CBandSelectSampleDlg::DoDataExchange(CDataExchange* pDX)
{
	CDialog::DoDataExchange(pDX);
	//{{AFX_DATA_MAP(CBandSelectSampleDlg)
	DDX_Control(pDX, IDC_BTN_CONNECT, m_btnConnect);
	DDX_Control(pDX, IDC_BTN_SEARCH, m_btnSearchBand);
	DDX_Control(pDX, IDOK, m_btnOK);
	DDX_Control(pDX, IDC_BANDLIST, m_lstBand);
	DDX_Control(pDX, IDC_BTN_SET, m_btnSetBand);
	DDX_Text(pDX, IDC_STATUS, m_strStatusIndicator);
	DDX_Text(pDX, IDC_CURRENTBAND, m_strCurrentBand);
	//}}AFX_DATA_MAP
}

BEGIN_MESSAGE_MAP(CBandSelectSampleDlg, CDialog)
	//{{AFX_MSG_MAP(CBandSelectSampleDlg)
	ON_WM_QUERYDRAGICON()
	ON_BN_CLICKED(IDC_BTN_SET, OnSetBand)
	ON_BN_CLICKED(IDC_BTN_SEARCH, OnGetBandInfo)
	ON_BN_CLICKED(IDC_BTN_CONNECT, OnBtnConnect)
	//}}AFX_MSG_MAP
END_MESSAGE_MAP()

/////////////////////////////////////////////////////////////////////////////
// CBandSelectSampleDlg message handlers

BOOL CBandSelectSampleDlg::OnInitDialog()
{
	CDialog::OnInitDialog();

	// Set the icon for this dialog.  The framework does this automatically
	//  when the application's main window is not a dialog
	SetIcon(m_hIcon, TRUE);			// Set big icon
	SetIcon(m_hIcon, FALSE);		// Set small icon
	

	//initialize connection state variable
	m_bConnected = FALSE;

	//Creating a column in the List Control
	CString strLabel;
	strLabel = _T("Available Bands");
	m_lstBand.InsertColumn(0, strLabel, LVCFMT_LEFT, 224);

	m_strStatusIndicator = _T("Disconnected from device");
	m_btnSearchBand.EnableWindow(FALSE);
	m_btnSetBand.EnableWindow(FALSE);

	//update values to screen
	UpdateData(FALSE);

	return TRUE;  // return TRUE  unless you set the focus to a control
}

SWI_TYPE_Device CBandSelectSampleDlg::GetHighestPriorityDeviceType ()
{
	SWI_TYPE_Device				eTypeDevice = SWI_DEVICE_None;
	SWI_STRUCT_AirServerList	sAvailDevList;
	SWI_RCODE					rCode;

	//--------------------
	// Connect to ANY device
	//--------------------
	sAvailDevList.sizeStruct = sizeof(SWI_STRUCT_AirServerList);
	rCode = SwiGetAvailAirServers(sAvailDevList);
	if (SWI_RCODE_OK != rCode)
	{
		m_strStatusIndicator =  _T("GetAvailDev() Failed");
		return eTypeDevice;
	}

	// how many avail devices?
	if (0 == sAvailDevList.nNumber)
	{
		m_strStatusIndicator = _T("No available devices");
		return eTypeDevice;
	}

	return sAvailDevList.AirServers[0].eDevice;
}

// The system calls this to obtain the cursor to display while the user drags
//  the minimized window.
HCURSOR CBandSelectSampleDlg::OnQueryDragIcon()
{
	return (HCURSOR) m_hIcon;
}

/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	ProcessError
//
//	Description	:	Helper function to process error codes
//
//	Arguments	:	[IN]: code - error code from the API
//
//	Returns		:	None
//
//	Comments	:
//
/////////////////////////////////////////////////////////////////////////////
void CBandSelectSampleDlg::ProcessError(SWI_RCODE code)
{
	CString strErrorString;

	strErrorString.Format(_T("Internal error - error code: %d"), code);

	MessageBox(strErrorString, _T("API Message"), MB_OK);
}


/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	ConnectModem
//
//	Description	:	Start a Connection to the Modem
//
//	Arguments	:	None
//
//	Returns		:	TRUE/FALSE to indicate success of connection
//
//	Comments	:
//
///////////////////////////////////////////////////////////////////////////
BOOL CBandSelectSampleDlg::ConnectModem() 
{	
	SWI_RCODE rCode;
	SWI_TYPE_Device eDevice;
	BOOL bDisconnected; //checks if disconnection was successful

	//connect if there is no connection to the modem
	if(m_bConnected == FALSE)
	{
		//Open a connection with the Modem
		SWI_STRUCT_ApiStartup sOpenParams;
		memset(&sOpenParams, 0, sizeof(SWI_STRUCT_ApiStartup));

		rCode = SwiApiStartup(&sOpenParams);
		if(SWI_RCODE_OK != rCode 
			&& SWI_RCODE_ALREADY_OPEN != rCode) // Bz13170
		{
			ProcessError(rCode);
			return FALSE;
		}

		eDevice = GetHighestPriorityDeviceType ();
		if (eDevice == SWI_DEVICE_None)
		{
			UpdateData(FALSE);
			return FALSE;
		}

		DECLARE_MacAny;
		SWI_STRUCT_AirServer sAirServer;
		sAirServer.sizeStruct = sizeof(SWI_STRUCT_AirServer);
		memcpy(sAirServer.ClientMac, MacAny, LENGTH_MacAddress);
		memcpy(sAirServer.ServerMac, MacAny, LENGTH_MacAddress);
		sAirServer.eDevice = eDevice;

		rCode = SwiSelectAirServer(sAirServer);
		if(SWI_RCODE_OK != rCode)
		{
			ProcessError(rCode);
			return FALSE;
		}

		//as we are here there are no errors
		//Initialize member variables and change GUI to reflect a successful connection
		//to the API
		m_bConnected = TRUE;
		m_strStatusIndicator = _T("Connected to device");
		m_btnSearchBand.EnableWindow(TRUE);
		m_btnConnect.SetWindowText(_T("Disconnect"));
		m_btnConnect.EnableWindow(TRUE);

		//Update values to screen
		UpdateData(FALSE);
		return TRUE;

	}
	else
	{
		//Disconnect from modem
		bDisconnected = DisconnectModem();

		//checking if disconnection was successful
		if(bDisconnected)
		{
			m_strStatusIndicator = _T("Disconnected from device");
		}
		else
		{
			m_strStatusIndicator = _T("Error occured while disconnecting");
		}

		//reset member variables and modify GUI to reflect a disconnection from the API
		m_bConnected = FALSE;
		m_btnSearchBand.EnableWindow(FALSE);
		m_btnSetBand.EnableWindow(FALSE);
		m_lstBand.DeleteAllItems();
		m_btnConnect.SetWindowText(_T("Connect"));
		m_btnConnect.EnableWindow(TRUE);

		//Updating values to screen
		UpdateData(FALSE);
		return TRUE;
	}

	return FALSE;

}


/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	DisconnectModem
//
//	Description	:	Disconnects from the modem
//
//	Arguments	:	None
//
//	Returns		:	TRUE/FALSE to indicate success or failure of disconnection
//
//	Comments	:
//
///////////////////////////////////////////////////////////////////////////
BOOL CBandSelectSampleDlg::DisconnectModem()
{

	SWI_RCODE eRcode;

	//disconnect if a connection to the modem exists
	if(m_bConnected == TRUE)
	{
		//close connection with modem
		eRcode = SwiApiShutdown();	
		if (SWI_RCODE_OK != eRcode)
		{
			ProcessError(eRcode);
			return FALSE;
		}
	}

	return TRUE;
}

/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	OnOK
//
//	Description	:	OK button has been pressed to exit the application
//
//	Arguments	:	None
//
//	Returns		:	None
//
//	Comments	:
//
///////////////////////////////////////////////////////////////////////////
void CBandSelectSampleDlg::OnOK() 
{

	//disabling connection button for duration of disconnection
	m_btnOK.EnableWindow(FALSE);

	//disconnect from modem if there is a live connection
	DisconnectModem();

	CDialog::OnOK();
}

/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	OnBtnConnect
//
//	Description	:	Connect/Disconnect to/from modem
//
//	Arguments	:	None
//
//	Returns		:	None
//
//	Comments	:
//
///////////////////////////////////////////////////////////////////////////
void CBandSelectSampleDlg::OnBtnConnect() 
{
	ConnectModem();	
}

CString CBandSelectSampleDlg::GetFreqBandString(SWI_TYPE_Band eBand)
{
	CString szBand;

	switch (eBand)
	{
	case SWI_BAND_PGSM:
		szBand = _T("2G 900*");
		break;
	case SWI_BAND_EGSM:
		szBand = _T("2G 900");
		break;
	case SWI_BAND_DCS:
		szBand = _T("2G 1800");
		break;
	case SWI_BAND_PGSM_DCS:
		szBand = _T("2G 900*/1800");
		break;
	case SWI_BAND_EGSM_DCS:
		szBand = _T("2G 900/1800");
		break;
	case SWI_BAND_PCS:
		szBand = _T("2G 1900");
		break;
	case SWI_BAND_PGSM_PCS:
		szBand = _T("2G 900*/1900");
		break;
	case SWI_BAND_EGSM_PCS:
		szBand = _T("2G 900/1900");
		break;
	case SWI_BAND_GSM850:
		szBand = _T("2G 850");
		break;
	case SWI_BAND_GSM850_PCS:
		szBand = _T("2G 850/1900");
		break;
	case SWI_BAND_GSM_ALL:
		szBand = _T("2G All");
		break;
	case SWI_BAND_WCDMA_NA:
		szBand = _T("3G 850/1900");
		break;
	case SWI_BAND_WCDMA_EU:
		szBand = _T("3G 2100");
		break;
	case SWI_BAND_WCDMA_GSM_NA:
		szBand = _T("3G 850/1900 - 2G 850/1900");
		break;
	case SWI_BAND_WCDMA_GSM_EU:
		szBand = _T("3G 2100 - 2G 900/1800");
		break;
	case SWI_BAND_WCDMA_ALL:
		szBand = _T("3G All");
		break;
	case SWI_BAND_WCDMA_AU:
		szBand = _T("3G 2100/850");
		break;
	case SWI_BAND_WCDMA_JAP:
		szBand = _T("3G 2100/800");
		break;
	case SWI_BAND_WCDMA_GSM_AU:
		szBand = _T("3G 2100/850 - 2G 900/1800");
		break;
	case SWI_BAND_WCDMA_GSM_AU_2:
		szBand = _T("3G 850 - 2G 900/1800");
		break;
	case SWI_BAND_WCDMA_GSM_AU_3:
		szBand = _T("3G 850");
		break;
	case SWI_BAND_AUTO:
		szBand = _T("Automatic");
		break;
	default:
		szBand = _T("error");
		break;
	}

	return szBand;
}


/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	OnGetBandInfo
//
//	Description	:	Start a search for available bands
//
//	Arguments	:	None
//
//	Returns		:	None
//
//	Comments	:
//
///////////////////////////////////////////////////////////////////////////
void CBandSelectSampleDlg::OnGetBandInfo() 
{
	SWI_RCODE			rCode;
	SWI_STRUCT_Band		sBandInfo;
	CString				szBand;
	int					iCurrBand	= -1;
	int					iIndex		= 0;

	// retrieve setting from API
	//
	memset(&sBandInfo, 0, sizeof(SWI_STRUCT_Band));
	sBandInfo.sizeStruct = sizeof(SWI_STRUCT_Band);

	rCode = SwiGetBandInfo (&sBandInfo, 3000);
	if (rCode != SWI_RCODE_OK)
	{
		m_strStatusIndicator = _T("Failed to get band info");
		ProcessError(rCode);
		UpdateData(FALSE);
		return;
	}

	m_lstBand.DeleteAllItems();

	//modify GUI to reflect a search in progress
	for (UINT i = 0; i < sBandInfo.cntValidBands; i++)
	{
		szBand = GetFreqBandString (sBandInfo.arrBand[i]);

		// load to list control
		m_lstBand.InsertItem(i, szBand);
		BOOL nResult = m_lstBand.SetItemData(i, (DWORD)sBandInfo.arrBand[i]);

		//pOption->AddListValue (szBand, sBandInfo.arrBand[i]);

		// check if THIS is the current band
		if (sBandInfo.arrBand[i] == sBandInfo.eBandType)			
			m_strCurrentBand = szBand;
	}

	m_btnSetBand.EnableWindow(TRUE);

	//update values to screen
	UpdateData(FALSE);
	
}

/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	OnSetBand
//
//	Description	:	Sets the band selected from the list control 'm_lstBand'
//
//	Arguments	:	None
//
//	Returns		:	None
//
//	Comments	:
//
///////////////////////////////////////////////////////////////////////////
void CBandSelectSampleDlg::OnSetBand() 
{
	int iSelection = m_lstBand.GetSelectionMark();
	if(iSelection == -1)
	{
		MessageBox(_T("Please select a band."), NULL, MB_OK);
		return;
	}

	//Extract the selected band from the List Control 
	DWORD dwData = m_lstBand.GetItemData(iSelection);
	m_btnSetBand.EnableWindow(FALSE);
	m_btnSearchBand.EnableWindow(FALSE);

	SWI_RCODE			rCode;
	SWI_STRUCT_SetBand	sBandInfo;

	memset (&sBandInfo, 0, sizeof(SWI_STRUCT_SetBand));
	sBandInfo.sizeStruct	= sizeof(SWI_STRUCT_SetBand);
	sBandInfo.eBandType		=  static_cast<SWI_TYPE_Band>(dwData);

	//SWI_TYPE_Device eSwiDeviceType = CPriModule::Instance()->PriSettings._Card.sDeviceObj.eSwiDeviceType;
	//switch(eSwiDeviceType)
	//{
	//	// A reset only occurs on AC775 and earlier devices when changing frequency bands.  Therefore,
	//	// only prompt the user with a warning message for these devices that share the old stack.
	//case SWI_DEVICE_AC710:
	//case SWI_DEVICE_AC750:
	//case SWI_DEVICE_AC775:
	//	//case SWI_DEVICE_MP700:
	//case SWI_DEVICE_MP750:
	//case SWI_DEVICE_MP775:
	//	// must prompt user to make sure they want to change the band
	//	if (IDYES != MessageBox(IDS_WARNING_ChangeBand, m_pDlgXmlCfg, false, MB_YESNO|MB_ICONQUESTION))
	//	{
	//		// NO, user chose not to continue - refresh dialog with band info:
	//		return;
	//	}
	//	break;
	//default:
	//	// no prompt for any device that does not use the old stack
	//	break;
	//}

	rCode = SwiSetBandInfo(&sBandInfo, 3000);
	if (rCode != SWI_RCODE_OK)
	{
		m_strStatusIndicator = _T("Failed to change band.");
		ProcessError(rCode);
		UpdateData(FALSE);
		return;
	}

	m_strCurrentBand = GetFreqBandString (sBandInfo.eBandType);
	m_btnSetBand.EnableWindow(TRUE);
	m_btnSearchBand.EnableWindow(TRUE);

	//Update values to screen
	UpdateData(FALSE);
	return;

}

