/**
 *
 *	Name	:	GPRSConnectSampleDlg.cpp
 *
 *	Purpose	:	main implementation file for the GPRSConnectSample application
 *
 *	History	:	Created August 26th, 2003
 *				This sample app demonstrates how to make and handle a GPRS connection.
 *				It also shows how to monitor an active connection with various
 *				various notifications.
 *
 *	Revision:	1.0
 *
 *	Copyright (c) 2003 Sierra Wireless, Inc. All rights reserved.
 *
 **/

#include "stdafx.h"
#include "GPRSConnectSample.h"
#include "GPRSConnectSampleDlg.h"
#include "SwiApiGsm.h"

//Following is used for anything but PPC2000, as it does not offer iphlpapi
#if !(WIN32_PLATFORM_PSPC == 1) //If it's not PPC2000...

//Adaptor names used for DHCP renew (PPC2002, PPC2003 and CE.NET)
#if ((WIN32_PLATFORM_PSPC == 310) || (WIN32_PLATFORM_PSPC == 400) || (UNDER_CE <= 420))
const TCHAR ADAPTORNAMEGPRS[] = TEXT("ACGPRS1"); 
const TCHAR ADAPTORNAMEEDGE[] = TEXT("ACEDGE1");
#else //Win32
const TCHAR ADAPTORNAMEGPRS[] = TEXT("Sierra Wireless GPRS Adapter");
const TCHAR ADAPTORNAMEEDGE[] = TEXT("Sierra Wireless EDGE Adapter");
#endif

//prototype functions for dhcp services
typedef DWORD (WINAPI *GETADAPTERSINFOPROC)(PIP_ADAPTER_INFO, PULONG);
typedef DWORD (WINAPI *GETINTERFACEINFOPROC)(PIP_INTERFACE_INFO, PULONG);
typedef DWORD (WINAPI *IPRENEWADDRESSPROC)(PIP_ADAPTER_INDEX_MAP);
GETADAPTERSINFOPROC  g_pGetAdaptersInfo  = NULL;
GETINTERFACEINFOPROC g_pGetInterfaceInfo = NULL;
IPRENEWADDRESSPROC   g_pIpRenewAddress   = NULL;

#endif //!(WIN32_PLATFORM_PSPC == 1)

#ifdef _DEBUG
#define new DEBUG_NEW
#undef THIS_FILE
static char THIS_FILE[] = __FILE__;
#endif

CGPRSConnectSampleDlg*	CGPRSConnectSampleDlg::m_instance = NULL; //initializing pointer to this object to NULL

/////////////////////////////////////////////////////////////////////////////
// CGPRSConnectSampleDlg dialog

CGPRSConnectSampleDlg::CGPRSConnectSampleDlg(CWnd* pParent /*=NULL*/)
	: CDialog(CGPRSConnectSampleDlg::IDD, pParent)
{
	//{{AFX_DATA_INIT(CGPRSConnectSampleDlg)
	m_strStatusIndicator = _T("");
	m_strProfileLabel = _T("None Selected");
	m_strRoaming = _T("");
	m_strRx = _T("");
	m_strTx = _T("");
	m_strRSSI = _T("");
	m_strCellID = _T("");
	m_strServiceStatus = _T("");
	m_strNetwork = _T("");
	m_strServiceAvailFlag = _T("");
	m_instance = this;
	m_intTCPWindowsize = 0;
	//}}AFX_DATA_INIT
	// Note that LoadIcon does not require a subsequent DestroyIcon in Win32
	m_hIcon = AfxGetApp()->LoadIcon(IDR_MAINFRAME);
}

void CGPRSConnectSampleDlg::DoDataExchange(CDataExchange* pDX)
{
	CDialog::DoDataExchange(pDX);
	//{{AFX_DATA_MAP(CGPRSConnectSampleDlg)
	DDX_Control(pDX, IDC_BTN_CONNECT, m_btnConnect);
	DDX_Control(pDX, IDC_BTN_TCPSET, m_btnTCPWindowSet);
	DDX_Control(pDX, IDOK, m_btnOK);
	DDX_Control(pDX, IDC_BTN_DATADISCONNECT, m_btnDataDisconnect);
	DDX_Control(pDX, IDC_BTN_DATACONNECT, m_btnDataConnect);
	DDX_Control(pDX, IDC_COMBOPROFILE, m_comboSelectProfile);
	DDX_Text(pDX, IDC_STATUS, m_strStatusIndicator);
	DDX_Text(pDX, IDC_PROFILELABEL, m_strProfileLabel);
	DDX_Text(pDX, IDC_ROAMING, m_strRoaming);
	DDX_Text(pDX, IDC_RX, m_strRx);
	DDX_Text(pDX, IDC_TX, m_strTx);
	DDX_Text(pDX, IDC_RSSI, m_strRSSI);
	DDX_Text(pDX, IDC_CELLID, m_strCellID);
	DDX_Text(pDX, IDC_SERVICESTATS, m_strServiceStatus);
	DDX_Text(pDX, IDC_NETWORK, m_strNetwork);
	DDX_Text(pDX, IDC_SERVICEAVAILFLAG, m_strServiceAvailFlag);
	DDX_Text(pDX, IDC_EDIT_TCPWINDOWSIZE, m_intTCPWindowsize);
	//}}AFX_DATA_MAP
}

BEGIN_MESSAGE_MAP(CGPRSConnectSampleDlg, CDialog)
	//{{AFX_MSG_MAP(CGPRSConnectSampleDlg)
	ON_WM_QUERYDRAGICON()
	ON_CBN_SELCHANGE(IDC_COMBOPROFILE, OnGetProfileLabel)
	ON_BN_CLICKED(IDC_BTN_DATACONNECT, OnGPRSConnect)
	ON_BN_CLICKED(IDC_BTN_DATADISCONNECT, OnGPRSDisconnect)
	ON_BN_CLICKED(IDC_BTN_TCPSET, OnBtnTcpset)
	ON_BN_CLICKED(IDC_BTN_CONNECT, OnBtnConnect)
	//}}AFX_MSG_MAP
	ON_MESSAGE(WM_NOTIFICATION, OnNotification) //function to handle all event notifications
END_MESSAGE_MAP()

/////////////////////////////////////////////////////////////////////////////
// CGPRSConnectSampleDlg message handlers

BOOL CGPRSConnectSampleDlg::OnInitDialog()
{
	CDialog::OnInitDialog();

	// Set the icon for this dialog.  The framework does this automatically
	//  when the application's main window is not a dialog
	SetIcon(m_hIcon, TRUE);			// Set big icon
	SetIcon(m_hIcon, FALSE);		// Set small icon
	
	// TODO: Add extra initialization here
	
	//initializing variables.
	m_bConnected = FALSE;
	m_iCurrentProfileIndex = NONE_SELECTED; //DEFAULTINDEX = 0
	m_intTCPWindowsize = 0;

	//update values to screen
	UpdateData(FALSE);

	return TRUE;  // return TRUE  unless you set the focus to a control
}

// The system calls this to obtain the cursor to display while the user drags
//  the minimized window.
HCURSOR CGPRSConnectSampleDlg::OnQueryDragIcon()
{
	return (HCURSOR) m_hIcon;
}

SWI_TYPE_Device CGPRSConnectSampleDlg::GetHighestPriorityDeviceType ()
{
	SWI_TYPE_Device				eTypeDevice = SWI_DEVICE_None;
	SWI_STRUCT_AirServerList	sAvailDevList;
	SWI_RCODE					rCode;

	//--------------------
	// Connect to ANY device
	//--------------------
	sAvailDevList.sizeStruct = sizeof(SWI_STRUCT_AirServerList);
	rCode = SwiGetAvailAirServers(sAvailDevList);
	if (SWI_RCODE_OK != rCode)
	{
		m_strStatusIndicator =  _T("GetAvailDev() Failed");
		return eTypeDevice;
	}

	// how many avail devices?
	if (0 == sAvailDevList.nNumber)
	{
		m_strStatusIndicator = _T("No available devices");
		return eTypeDevice;
	}

	return sAvailDevList.AirServers[0].eDevice;
}

/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	ConnectModem
//
//	Description	:	Start a Connection to the Modem
//
//	Arguments	:	None
//
//	Returns		:	TRUE/FALSE to indicate success of connection
//
//	Comments	:
//
///////////////////////////////////////////////////////////////////////////
BOOL CGPRSConnectSampleDlg::ConnectModem() 
{	
	SWI_RCODE rCode;
	SWI_TYPE_Device eDevice;
	BOOL bDisconnected; //checks if disconnection was successful

	//connect if there is no connection to the modem
	if(m_bConnected == FALSE)
	{
		//Open a connection with the Modem
		SWI_STRUCT_ApiStartup sOpenParams;
		memset(&sOpenParams, 0, sizeof(SWI_STRUCT_ApiStartup));

		rCode = SwiApiStartup(&sOpenParams);
		if(SWI_RCODE_OK != rCode 
			&& SWI_RCODE_ALREADY_OPEN != rCode) // Bz13170
		{
			ProcessError(rCode);
			return FALSE;
		}

		eDevice = GetHighestPriorityDeviceType ();
		if (eDevice == SWI_DEVICE_None)
		{
			UpdateData(FALSE);
			return FALSE;
		}

		DECLARE_MacAny;
		SWI_STRUCT_AirServer sAirServer;
		sAirServer.sizeStruct = sizeof(SWI_STRUCT_AirServer);
		memcpy(sAirServer.ClientMac, MacAny, LENGTH_MacAddress);
		memcpy(sAirServer.ServerMac, MacAny, LENGTH_MacAddress);
		sAirServer.eDevice = eDevice;

		rCode = SwiSelectAirServer(sAirServer);
		if(SWI_RCODE_OK != rCode)
		{
			ProcessError(rCode);
			return FALSE;
		}

		//Register the Callback function
		rCode = SwiRegisterCallback(NotificationCallback, 0xFFFFFFFFFFFFFFFF);
		if(SWI_RCODE_OK != rCode)
		{
			ProcessError(rCode);
			return FALSE;
		}

//Following is used for anything but PPC2000, as it does not offer iphlpapi
#ifndef UNDER_CE 

		m_hIpHlpApiDll = LoadLibrary(_T("iphlpapi"));
		if (NULL != m_hIpHlpApiDll)
		{
			//Get functions' addresses
			g_pGetAdaptersInfo	= (GETADAPTERSINFOPROC)GetProcAddress(m_hIpHlpApiDll,  ("GetAdaptersInfo"));
		 	g_pGetInterfaceInfo = (GETINTERFACEINFOPROC)GetProcAddress(m_hIpHlpApiDll, ("GetInterfaceInfo"));
	      	g_pIpRenewAddress   = (IPRENEWADDRESSPROC)GetProcAddress(m_hIpHlpApiDll,   ("IpRenewAddress"));
	 
			if ((NULL == g_pGetInterfaceInfo) && (NULL == g_pIpRenewAddress))
			{
				//Failed to resolve one or both functions
			    MessageBox(_T("Unable to resolve iphlpapi functions"), _T("Error Message"), MB_OK);
			}

		}
		else
		{
			//Library failed to load
		    MessageBox(_T("Unable to load iphlpapi"), _T("Error Message"), MB_OK);
		    return FALSE;
		}

#endif //!(WIN32_PLATFORM_PSPC == 1)

		//Check if modem is ready for instruction, then proceed
		if(IsModemReady())
		{	
			rCode = SwiGetAirCardType(&m_sAirCardType, TIMEOUT);
			if(SWI_RCODE_OK != rCode)
			{
				ProcessError(rCode);
				return FALSE;
			}

			// Enable notifications
			switch(m_sAirCardType.eAirCard)
			{
				case SWI_AIRCARD_AC710:
				case SWI_AIRCARD_AC750:
				case SWI_AIRCARD_AC775:
					break;
				default:
					{
						rCode = SwiNotify(SWI_NOTIFY_ServiceIcon, TIMEOUT);
						if(SWI_RCODE_OK != rCode)
						{
							ProcessError(rCode);
							return FALSE;
						}
					}
					break;
			}

			switch(m_sAirCardType.eAirCard)
			{
				case SWI_AIRCARD_AC710:
				case SWI_AIRCARD_AC750:
				case SWI_AIRCARD_AC775:
					{
						rCode = SwiNotify(SWI_NOTIFY_PktSessionStatus, TIMEOUT);
						if(SWI_RCODE_OK != rCode)
						{
							ProcessError(rCode);
							return FALSE;
						}
					}
					break;
				default:
					{
						rCode = SwiNotify(SWI_NOTIFY_PktSessionCall, TIMEOUT);
						if(SWI_RCODE_OK != rCode)
						{
							ProcessError(rCode);
							return FALSE;
						}
					}
					break;
			}

			rCode = SwiNotify(SWI_NOTIFY_NetworkStatus, TIMEOUT);
			if(SWI_RCODE_OK != rCode)
			{
				ProcessError(rCode);
				return FALSE;
			}

			rCode = SwiNotify(SWI_NOTIFY_ByteCounter, TIMEOUT);
			if(SWI_RCODE_OK != rCode)
			{
				ProcessError(rCode);
				return FALSE;
			}

			rCode = SwiNotify(SWI_NOTIFY_Rssi, TIMEOUT);
			if(SWI_RCODE_OK != rCode)
			{
				ProcessError(rCode);
				return FALSE;
			}

			rCode = SwiNotify(SWI_NOTIFY_IconRoamState, TIMEOUT);
			if(SWI_RCODE_OK != rCode)
			{
				ProcessError(rCode);
				return FALSE;
			}

			//informing modem of host startup state
			//this function will attach the modem onto the network
			rCode = SwiSetHostStartup(TRUE, TIMEOUT*20);
			if(SWI_RCODE_OK != rCode)
			{
				ProcessError(rCode);
				return FALSE;
			}

		}
		else
		{
			m_strStatusIndicator = _T("Modem initialization failed.");
			UpdateData(FALSE);

			//Returning true so user can see the error message
			return TRUE;
		}

		//as we are here there are no errors
		//Initialize member variables and change GUI to reflect a successful connection
		//to the API
		m_bConnected = TRUE;
		m_strStatusIndicator = _T("Connected to device");
		m_comboSelectProfile.EnableWindow(TRUE);
		m_btnConnect.SetWindowText(_T("Disconnect"));
		//m_btnConnect.EnableWindow(TRUE);

		//Update values to screen
		UpdateData(FALSE);
		return TRUE;
	}
	else
	{
		//Disconnect from modem
		bDisconnected = DisconnectModem();

		//checking if disconnection was successful
		if(bDisconnected)
		{
			m_strStatusIndicator = _T("Disconnected from device");
		}
		else
		{
			m_strStatusIndicator = _T("Error occured while disconnecting");
		}

		//reset member variables and modify GUI to reflect a disconnection from the API
		m_bConnected = FALSE;
		m_comboSelectProfile.SetCurSel(0);
		m_comboSelectProfile.EnableWindow(FALSE);
		m_btnDataConnect.EnableWindow(FALSE);
		m_btnDataDisconnect.EnableWindow(FALSE);
		m_btnConnect.SetWindowText(_T("Connect"));
		//m_btnConnect.EnableWindow(TRUE);

		//Updating values to screen
		UpdateData(FALSE);
		return TRUE;
	}

	return FALSE;
}


/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	DisconnectModem
//
//	Description	:	Disconnects from the modem
//
//	Arguments	:	None
//
//	Returns		:	TRUE/FALSE to indicate success or failure of disconnection
//
//	Comments	:
//
///////////////////////////////////////////////////////////////////////////
BOOL CGPRSConnectSampleDlg::DisconnectModem()
{

	SWI_RCODE eRcode;
	SWI_TYPE_ProfileState eCurrentProfileState;

	//disconnect if a connection to the modem exists
	if(m_bConnected == TRUE)
	{

		// Disable notifications
		switch(m_sAirCardType.eAirCard)
		{
			case SWI_AIRCARD_AC710:
			case SWI_AIRCARD_AC750:
			case SWI_AIRCARD_AC775:
				{
					eRcode = SwiStopNotify(SWI_NOTIFY_PktSessionStatus, TIMEOUT);
					if (SWI_RCODE_OK != eRcode)
					{
						ProcessError(eRcode);
						return FALSE;
					}
				}
				break;
			default:
				{
					eRcode = SwiStopNotify(SWI_NOTIFY_PktSessionCall, TIMEOUT);
					if (SWI_RCODE_OK != eRcode)
					{
						ProcessError(eRcode);
						return FALSE;
					}
				}
				break;
		}

		eRcode = SwiStopNotify(SWI_NOTIFY_NetworkStatus, TIMEOUT);
		if (SWI_RCODE_OK != eRcode)
		{
			ProcessError(eRcode);
			return FALSE;
		}

		eRcode = SwiStopNotify(SWI_NOTIFY_ByteCounter, TIMEOUT);
		if (SWI_RCODE_OK != eRcode)
		{
			ProcessError(eRcode);
			return FALSE;
		}

		eRcode = SwiStopNotify(SWI_NOTIFY_Rssi, TIMEOUT);
		if (SWI_RCODE_OK != eRcode)
		{
			ProcessError(eRcode);
			return FALSE;
		}

		eRcode = SwiStopNotify(SWI_NOTIFY_ServiceIcon, TIMEOUT);
		if(SWI_RCODE_OK != eRcode)
		{
			ProcessError(eRcode);
			return FALSE;
		}


//		if(m_iCurrentProfileIndex != 0)
		if(m_iCurrentProfileIndex >= 0)			// m_iCurrentProfileIndex might be -1
		{

			//Retrieving the current profile state (active, inactive, deleted)
			if(!GetProfileState(m_iCurrentProfileIndex, &eCurrentProfileState))
			{
				m_strStatusIndicator = _T("Failed to retrieve Profile state");
				UpdateData(FALSE);
				return FALSE;
			}

			//If a Profile has been activated, deactivate it first before exiting
			if(eCurrentProfileState == SWI_PROFILE_STATE_Activated)
			{

				eRcode = SwiActivateProfile(m_iCurrentProfileIndex, FALSE, TIMEOUT*10);
				if(SWI_RCODE_OK != eRcode)
				{
					ProcessError(eRcode);
					return FALSE;
				}

			}

		}
		

		//detaching modem from network
		eRcode = SwiSetHostStartup(FALSE, TIMEOUT*20);
		if(SWI_RCODE_OK != eRcode)
		{
			ProcessError(eRcode);
			return FALSE;
		}

		//freeing the iphlpapi library
		if (NULL != m_hIpHlpApiDll)
		{
		    ::FreeLibrary(m_hIpHlpApiDll);
			m_hIpHlpApiDll = NULL;
		}

		//close connection with modem
		eRcode = SwiApiShutdown();	
		if (SWI_RCODE_OK != eRcode)
		{

			ProcessError(eRcode);
			return FALSE;

		}

	}

	return TRUE;

}


/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	NotificationCallback
//
//	Description	:	Callback that receives all event notifications
//
//	Arguments	:	[IN]: pNotify - pointer to notification variant
//
//	Returns		:	None
//
//	Comments	:	Even if no notifications are being processed,
//					this function still needs to be registered and declared
//					for calls to the API to function properly.
//
/////////////////////////////////////////////////////////////////////////////
void NotificationCallback(SwiNotifyVariant *pNotify)
{
	//Create a pointer to this object then send pNotify to 'HandleCallback'
	//to cache the data and then process the notification.  Note that notifications
	//should never be processed in the call back function because it will hold
	//up the thread while other notifications are trying to get in
	CGPRSConnectSampleDlg* pThisObject = CGPRSConnectSampleDlg::Instance();
	pThisObject->HandleCallback(pNotify);

}


/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	HandleCallback
//
//	Description	:	Caches data from NotificationCallback (therefore freeing the thread)
//					and posts a message for notification handling
//					
//	Arguments	:	[IN]: pNotify - pointer to notification variant
//
//	Returns		:	None
//
//	Comments	:
//
///////////////////////////////////////////////////////////////////////////
void CGPRSConnectSampleDlg::HandleCallback(SwiNotifyVariant *pNotify)
{
	//used for debugging purposes, displays the notifications received
	TRACE(_T("Got notif %i\n"), pNotify->eNotify);

	// For simplicity, we are allocating a copy of the notification from 
	// the heap. An industrial-strength app would allocate the copy from 
	// a fixed pool of objects to avoid memory fragmentation. 
	SwiNotifyVariant* pCopy = (SwiNotifyVariant*) new SwiNotifyVariant;
	
	if (pCopy)
	{
		*pCopy = *pNotify;
		m_instance->PostMessage(WM_NOTIFICATION, WPARAM(pCopy), NULL ); 
	}
}


/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	OnNotification
//
//	Description	:	Handler for received notifications
//
//	Arguments	:	[IN]: wParam - Contains the notification type
//					[IN]: lParam - Contains the data to be updated
//
//	Returns		:	None
//
//	Comments	:
//
/////////////////////////////////////////////////////////////////////////////
LRESULT CGPRSConnectSampleDlg::OnNotification(WPARAM wParam, LPARAM lParam)
{

	SWI_RCODE eRcode;
	CString strServiceStatus;
	SwiNotifyVariant* pNotify = (SwiNotifyVariant*)wParam;
	SWI_STRUCT_PktSessionCall sPktSessionCall; //Used with HSDPA AC850
  	SWI_STRUCT_PktSessionStatus sPktSessionStatus; //structure used to store a SWI_STRUCT_PktSessionStatus
	memset(&sPktSessionCall, 0, sizeof(SWI_STRUCT_PktSessionCall));
	memset(&sPktSessionStatus, 0, sizeof(SWI_STRUCT_PktSessionStatus));

	switch(pNotify->eNotify) //add notifications here
	{

	//For the 4.0 stream, a new notification has been added that almost serves as a
	//summary of several other notifications allowing a SDK developer to easily
	//develop an app that makes/breaks a GPRS or EDGE connection.  This object
	//is called SWI_NOTIFY_ServiceIcon.  For more details about this notification
	//and what it contains, refer to the swistructs.h header file.
	//This app will demonstrate how to use this notification affectively.

		case SWI_NOTIFY_PktSessionCall: //Used with HSDPA AC850
			sPktSessionCall =  pNotify->_PktSessionCall;

		case SWI_NOTIFY_PktSessionStatus:
			sPktSessionStatus = pNotify->_PktSessionStatus;

			if(sPktSessionStatus.bPacketSessionActive ||
				sPktSessionCall.bPacketSessionActive /*Used with HSDPA AC850*/)
			{
				//active packet session detected
				m_strStatusIndicator = _T("Connection established.");

//Following is used for anything but PPC2000, as it does not offer iphlpapi
#if !(WIN32_PLATFORM_PSPC == 1) //If it's not PPC2000...

#if ((WIN32_PLATFORM_PSPC == 310) || (UNDER_CE<=420))
				//Force a DHCP renewal
				if(!RenewAddressCe())
				{
					MessageBox(_T("DHCP renew failed"), _T("App Message"), MB_OK);
				}

#else //Win32

				OSVERSIONINFO osv;
				osv.dwOSVersionInfoSize = sizeof(OSVERSIONINFO);
	
				//Getting OS version
				if(GetVersionEx(&osv))
				{
					switch(osv.dwPlatformId)
					{
					case VER_PLATFORM_WIN32_WINDOWS: //WIN32 on 95, 98, ME
						if(!RenewAddress())
						{
							MessageBox(_T("DHCP renew failed"), _T("App Message"), MB_OK);
						}
						break;
					case VER_PLATFORM_WIN32_NT: //Win32 on Windows NT.
						//No need to do it for Win2K or WinXP
						break;
					default:
						break;
					}
				}
				
#endif //(WIN32_PLATFORM_PSPC == 310)

#endif //!(WIN32_PLATFORM_PSPC == 1)

				m_strTx = _T("0 Bytes");
				m_strRx = _T("0 Bytes");

				//modify GUI to reflect successful Profile activation
				m_btnDataDisconnect.EnableWindow(TRUE);
				m_btnDataConnect.EnableWindow(FALSE);

			}
			//If there is no active packet session, check if the inactivity reason
			//is normal, if so, then the Profile is just currently de-activated
			else if(sPktSessionStatus.eInactivityReason == SWI_INACTIVITYREASON_Normal ||
				sPktSessionCall.eInactivityReason == SWI_INACTIVITYREASON_Normal /*Used with HSDPA AC850*/)
			{
				m_strStatusIndicator = _T("Data connection disconnected.");

				//Reset Byte counters
				switch(m_sAirCardType.eAirCard)
				{
					case SWI_AIRCARD_AC710:
					case SWI_AIRCARD_AC750:
					case SWI_AIRCARD_AC775:
						{
							eRcode = SwiResetTrafficStatistics(TIMEOUT);
							if (SWI_RCODE_OK != eRcode)
							{
								ProcessError(eRcode);
							}
						}
						break;
					default:
						break;
				}
					
				m_strTx = _T("0 Bytes");
				m_strRx = _T("0 Bytes");

				//modify GUI to reflect successful Profile de-activation
				m_comboSelectProfile.EnableWindow(TRUE);
				m_btnDataDisconnect.EnableWindow(FALSE);
				m_btnDataConnect.EnableWindow(TRUE);

			}
			else
			{
				//If there is no active packet session and the
				//inactivity reason is not normal, something is wrong.
				//Chances are, an invalid Profile has been detected.  More
				//error types are available, read swistructs.h for more information
				m_strStatusIndicator = _T("Operation failed");
	
				//modify GUI to reflect an invalid Profile detection
				m_comboSelectProfile.EnableWindow(TRUE);

			}
			break;
		case SWI_NOTIFY_ServiceIcon:
			//Check what type of service is available then display
			//it on GUI
			SWI_STRUCT_ServiceIcon sServiceIcon; //structure used to store a SWI_STRUCT_ServiceIcon
			sServiceIcon = pNotify->_ServiceIcon;
			if(SWI_SERVICE_None == sServiceIcon.eService)
			{
				m_strServiceAvailFlag = _T("None");
			}
			else if(SWI_SERVICE_Gprs == sServiceIcon.eService)
			{
				m_strServiceAvailFlag = _T("GPRS");
			}
			else if(SWI_SERVICE_Edge == sServiceIcon.eService)
			{
				m_strServiceAvailFlag = _T("EDGE");
			}

			if(TRUE == sServiceIcon.bPktSessionActive)
			{

				//active packet session in progress
				m_strStatusIndicator = _T("Data connection active.");
			
			}
			break;
		case SWI_NOTIFY_NetworkStatus:
			//This is done for backwards compatability with earlier versions of AC750 firmware
			SWI_STRUCT_GSM_NetworkStatus sNetworkStatus; //structure used to store a SWI_STRUCT_GSM_NetworkStatus
			sNetworkStatus = pNotify->_NetworkStatus;
			if(m_sAirCardType.eAirCard == SWI_AIRCARD_AC750)
			{
				//Checking if GPRS service is available
				if(SWI_SERVICE_STATUS_Normal == sNetworkStatus.eServiceStatus && SWI_SERVICE_TYPE_Combined == sNetworkStatus.eServiceType)
				{
					m_strServiceAvailFlag = _T("Available");
				}
				else
				{
					m_strServiceAvailFlag = _T("Unavailable");
				}
			}
			//Checking roaming state
			if(SWI_ROAMING_Home == sNetworkStatus.eRoaming)
			{
				m_strRoaming = _T("No");
			}
			else
			{
				m_strRoaming = _T("Yes");
			}
			//Updating the Service Status
			if(GetServiceStatus(sNetworkStatus.eServiceStatus, &strServiceStatus))
			{
				m_strServiceStatus = strServiceStatus;
			}
			//Update Network Name
			m_strNetwork = sNetworkStatus.szNetwork;
			//Updating Cell ID
			m_strCellID.Format(_T("%d"), sNetworkStatus.nCellID);
			break;
		case SWI_NOTIFY_ByteCounter:
			//Update Tx and Rx
			m_strTx.Format(_T("%d Bytes"), pNotify->_ByteCounter.TransmitBytes);
			m_strRx.Format(_T("%d Bytes"), pNotify->_ByteCounter.ReceiveBytes);
			break;
		case SWI_NOTIFY_Rssi:
			//Update RSSI
			m_strRSSI.Format(_T("%d dBm"), pNotify->_Rssi.iRssi);
			break;
		default:
			break;
	}

	delete (SwiNotifyVariant*)wParam;
	//update values to screen
	UpdateData(FALSE);

	return NULL;
}


/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	Instance
//
//	Description	:	A static function used to return a pointer to this object
//
//	Arguments	:	None
//
//	Returns		:	m_Instance - a pointer to this object
//
//	Comments	:
//
///////////////////////////////////////////////////////////////////////////
CGPRSConnectSampleDlg* CGPRSConnectSampleDlg::Instance()
{
	return m_instance;
}


/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	OnOK
//
//	Description	:	OK button has been pressed to exit the application
//
//	Arguments	:	None
//
//	Returns		:	None
//
//	Comments	:
//
/////////////////////////////////////////////////////////////////////////////
void CGPRSConnectSampleDlg::OnOK() 
{

	//disabling connection button for duration of disconnection
	m_btnOK.EnableWindow(FALSE);

	//disconnect from modem if there is a live connection
	DisconnectModem();

	CDialog::OnOK();
	
}


/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	ProcessError
//
//	Description	:	Helper function to process error codes
//
//	Arguments	:	[IN]: code - error code from the API
//
//	Returns		:	None
//
//	Comments	:
//
/////////////////////////////////////////////////////////////////////////////
void CGPRSConnectSampleDlg::ProcessError(SWI_RCODE code)
{
	CString strErrorString;

	strErrorString.Format(_T("Internal error - error code: %d"), code);

	MessageBox(strErrorString, _T("API Message"), MB_OK);
}


/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	OnGetProfileLabel
//
//	Description	:	Retrieve and display the label of the currently selected Profile
//
//	Arguments	:	None
//
//	Returns		:	None
//
//	Comments	:	
//
///////////////////////////////////////////////////////////////////////////
void CGPRSConnectSampleDlg::OnGetProfileLabel() 
{
	U32 nIndex;
	SWI_RCODE eRcode;

	//retrieve the index of the selected profile
	switch(m_sAirCardType.eAirCard)
	{
		case SWI_AIRCARD_AC710:
		case SWI_AIRCARD_AC750:
		case SWI_AIRCARD_AC775:
			{
				nIndex = m_comboSelectProfile.GetCurSel() - 1;

				//if index is NONE_SELECTED, this means nothing has been selected
				if (NONE_SELECTED == nIndex)
				{
					m_strStatusIndicator = _T("Please select a Profile");
					m_btnDataConnect.EnableWindow(TRUE);
					UpdateData(FALSE);
					return;
				}

				//update current profile index to keep track of what Profile is currently selected
				m_iCurrentProfileIndex = nIndex;

				//retrieve profile info
				SWI_STRUCT_Profile sProfileStruct;
				memset (&sProfileStruct, 0, sizeof(SWI_STRUCT_Profile));
				sProfileStruct.sizeStruct = sizeof(SWI_STRUCT_Profile);

				eRcode = SwiGetProfile(&sProfileStruct, nIndex, TIMEOUT);
				if (SWI_RCODE_OK == eRcode)
				{
					// fill in the Profile Label box with the appropriate value
					m_strProfileLabel = (LPTSTR)sProfileStruct.szLabel;
					if(m_strProfileLabel == "")
					{
						m_strProfileLabel = _T("");
						m_strStatusIndicator = _T("Error: This Profile is deleted.");
						m_btnDataConnect.EnableWindow(FALSE);
						UpdateData(FALSE);
						return;
					}
				}
				else
				{
					ProcessError(eRcode);
					m_strStatusIndicator = _T("Failed to retrieve Profile Label");
					UpdateData(FALSE);
					return;
				}
			}
			break;
		default:
			{
				nIndex = m_comboSelectProfile.GetCurSel();

				//if index is NONE_SELECTEDGSM, this means nothing has been selected
				if (NONE_SELECTEDGSM == nIndex)
				{
					m_strStatusIndicator = _T("Please select a Profile");
					m_btnDataConnect.EnableWindow(TRUE);
					UpdateData(FALSE);
					return;
				}

				//update current profile index to keep track of what Profile is currently selected
				m_iCurrentProfileIndex = nIndex;

				//retrieve profile info
				SWI_STRUCT_GsmProfileBasic sProfileBasic;
	
				memset (&sProfileBasic, 0, sizeof(SWI_STRUCT_GsmProfileBasic));
				sProfileBasic.sizeStruct = sizeof(SWI_STRUCT_GsmProfileBasic);
				sProfileBasic.nProfileId = (U8)nIndex;

				eRcode = SwiGetGsmProfileBasic(&sProfileBasic, TIMEOUT);
				if (SWI_RCODE_OK == eRcode)
				{
					// fill in the Profile Label box with the appropriate value
					m_strProfileLabel = sProfileBasic.szLabel;
					
					if(m_strProfileLabel == "")
					{
						m_strProfileLabel = _T("");
						m_strStatusIndicator = _T("Error: This Profile is deleted.");
						m_btnDataConnect.EnableWindow(FALSE);
						UpdateData(FALSE);
						return;
					}
				}
				else
				{
					ProcessError(eRcode);
					m_strStatusIndicator = _T("Failed to retrieve Profile Label");
					UpdateData(FALSE);
					return;
				}
			}
			break;
	}

	//modifying GUI to reflect a successful operation
	m_strStatusIndicator = _T("Profile retrieved.");
	m_btnDataConnect.EnableWindow(TRUE);
	m_btnDataDisconnect.EnableWindow(FALSE);

	//update the values to the screen
	UpdateData(FALSE);
	
}


/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	OnGPRSConnect
//
//	Description	:	Makes a GPRS data connection
//
//	Arguments	:	None
//
//	Returns		:	None
//
//	Comments	:	
//
///////////////////////////////////////////////////////////////////////////
void CGPRSConnectSampleDlg::OnGPRSConnect() 
{
	U32 nIndex;
	SWI_RCODE eRcode;
	SWI_TYPE_ProfileState eCurrentProfileState;

	m_btnDataConnect.EnableWindow(FALSE);

	//retrieve the index of the selected profile
	switch(m_sAirCardType.eAirCard)
	{
		case SWI_AIRCARD_AC710:
		case SWI_AIRCARD_AC750:
		case SWI_AIRCARD_AC775:
			{
				nIndex = m_comboSelectProfile.GetCurSel() - 1;

				//if index is NONE_SELECTED, this means nothing has been selected
				if (NONE_SELECTED == nIndex)
				{
					m_strStatusIndicator = _T("Please select a Profile");
					m_btnDataConnect.EnableWindow(TRUE);
					UpdateData(FALSE);
					return;
				}
			}
			break;
		default:
			{
				nIndex = m_comboSelectProfile.GetCurSel();

				//if index is NONE_SELECTEDGSM, this means nothing has been selected
				if (NONE_SELECTEDGSM == nIndex)
				{
					m_strStatusIndicator = _T("Please select a Profile");
					m_btnDataConnect.EnableWindow(TRUE);
					UpdateData(FALSE);
					return;
				}
			}
			break;
	}

	//Setting the current profile variable to keep track of
	//which Profile is currently selected
	m_iCurrentProfileIndex = nIndex;

	//Retrieving the current profile state (active, inactive, deleted)
	if(!GetProfileState(m_iCurrentProfileIndex, &eCurrentProfileState))
	{
		m_strStatusIndicator = _T("Failed to retrieve connection state");
		m_btnDataConnect.EnableWindow(TRUE);
		UpdateData(FALSE);
		return;
	}

	//If the Current Profile is inactive, activate it
	if(eCurrentProfileState == SWI_PROFILE_STATE_Inactive)
	{

		m_strStatusIndicator = _T("Authenticating Profile...");

		//disabling Profile selection combo box while Profile is activated,
		//re-enable combo box when user de-activates the Profile
		m_comboSelectProfile.EnableWindow(FALSE);

		//result of request will be received later in the form of a notification
		eRcode = SwiActivateProfile(nIndex, TRUE, TIMEOUT*10);
		if(SWI_RCODE_OK != eRcode)
		{
			m_comboSelectProfile.EnableWindow(TRUE);
			m_btnDataConnect.EnableWindow(TRUE);
			ProcessError(eRcode);
			return;
		}

	} 
	else if(eCurrentProfileState == SWI_PROFILE_STATE_Deleted)
	{
		//error occurred if it gets here
		m_strStatusIndicator = _T("Invalid Profile");
	}
	
	//update values to screen
	UpdateData(FALSE);
}


/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	OnGPRSDisconnect
//
//	Description	:	Disconnects a GPRS data connection
//
//	Arguments	:	None
//
//	Returns		:	None
//
//	Comments	:	
//
///////////////////////////////////////////////////////////////////////////
void CGPRSConnectSampleDlg::OnGPRSDisconnect() 
{

	SWI_RCODE eRcode;
	SWI_TYPE_ProfileState eCurrentProfileState;

	m_btnDataDisconnect.EnableWindow(FALSE);

	//Retrieving the current profile state (active, inactive, deleted)
	if(!GetProfileState(m_iCurrentProfileIndex, &eCurrentProfileState))
	{
		m_strStatusIndicator = _T("Failed to retrieve connection state");
		m_btnDataDisconnect.EnableWindow(TRUE);

		UpdateData(FALSE);
		return;
	}

	if(eCurrentProfileState == SWI_PROFILE_STATE_Activated)
	{
		m_strStatusIndicator = _T("Disconnecting...");
		UpdateData(FALSE);

		//result of request will be received later in the form of a notification
		eRcode = SwiActivateProfile(m_iCurrentProfileIndex, FALSE, TIMEOUT*10);
		if(SWI_RCODE_OK != eRcode)
		{	
			m_btnDataDisconnect.EnableWindow(TRUE);
			ProcessError(eRcode);
			return;
		}
	}
	else
	{
		m_strStatusIndicator = _T("Unknown error occurred.");
		m_btnDataDisconnect.EnableWindow(TRUE);
		UpdateData(FALSE);
		return;
	}

}


/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	GetProfileState
//
//	Description	:	Retrieve Profile State (Activated, Inactive, Deleted)
//
//	Arguments	:	[IN]: nIndex - Index of Profile (ie. 1,2,3)
//					[OUT]: eProfileState - State of the Profile specified by nIndex
//
//	Returns		:	ProfileState - SWI_TYPE_ProfileState, indicates the Profile State
//								   of the currently selected Profile (Activated, Inactive, Deleted)						   	
//
//	Comments	:
//
///////////////////////////////////////////////////////////////////////////
BOOL CGPRSConnectSampleDlg::GetProfileState(U32 nIndex, SWI_TYPE_ProfileState* eProfileState)
{
	SWI_RCODE eRcode;
	U32 nProfileID;
	SWI_STRUCT_ProfileSummary sProfileSummary;
	SWI_STRUCT_GsmProfileSummary sGsmProfileSummary;

	//retrieve the profile summary
	switch(m_sAirCardType.eAirCard)
	{
		case SWI_AIRCARD_AC710:
		case SWI_AIRCARD_AC750:
		case SWI_AIRCARD_AC775:
			{
				memset(&sProfileSummary, 0, sizeof(SWI_STRUCT_ProfileSummary));
				sProfileSummary.sizeStruct = sizeof(SWI_STRUCT_ProfileSummary);
				eRcode = SwiGetProfileSummary (&sProfileSummary, TIMEOUT);
				if (eRcode != SWI_RCODE_OK)
				{
					ProcessError(eRcode);
					return FALSE; //returns deleted state if error occurs
				}

				//search through array until index matches Profile ID, then return the Profile State
				for(int PID = 0; PID < MAX_NO_CONTEXT; PID++)
				{

					nProfileID = sProfileSummary.arrProfileList[PID].nProfileID;

					if(nIndex == nProfileID)
					{
						*eProfileState = sProfileSummary.arrProfileList[PID].eProfileState;
					}
				}
			}
			break;
		default:
			{
				memset(&sGsmProfileSummary, 0, sizeof(SWI_STRUCT_GsmProfileSummary));
				sGsmProfileSummary.sizeStruct = sizeof(SWI_STRUCT_GsmProfileSummary);
				eRcode = SwiGetGsmProfileSummary (&sGsmProfileSummary, TIMEOUT);
				if (eRcode != SWI_RCODE_OK)
				{
					ProcessError(eRcode);
					return FALSE; //returns deleted state if error occurs
				}

				//Index 0 of the 'arrState' array refers to Profile 1
				if(nIndex > 0)
				{
					*eProfileState = sGsmProfileSummary.arrState[nIndex-1];
				}
				else
				{
					//An error has occurred
					return FALSE;
				}
			}
			break;
	}

	return TRUE; //returning Profile State (Activated, Inactive, Deleted)

}


/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	GetServiceStatus
//
//	Description	:	Function used to retrieve the Service Status in user readible form
//
//	Arguments	:	[OUT]: ServiceStatus - point to a CString to store service status
//					[IN]: eServiceStatus - SWI_TYPE_ServiceStatus
//
//	Returns		:	TRUE/FALSE - indicate success or failure of operation
//
//	Comments	:	
//
///////////////////////////////////////////////////////////////////////////
BOOL CGPRSConnectSampleDlg::GetServiceStatus(SWI_TYPE_ServiceStatus eServiceStatus, CString* ServiceStatus)
{

	switch(eServiceStatus)
	{
		case SWI_SERVICE_STATUS_Normal:
			*ServiceStatus = (_T("Normal"));
			break;
		case SWI_SERVICE_STATUS_Emergency:
			*ServiceStatus = (_T("Emergency"));
			break;
		case SWI_SERVICE_STATUS_NoService:
			*ServiceStatus = (_T("Not in Service"));
			break;
		case SWI_SERVICE_STATUS_AccessDifficulty:
			*ServiceStatus = (_T("Access Difficulties"));
			break;
		case SWI_SERVICE_STATUS_ForbiddenPLMN:
			*ServiceStatus = (_T("Forbidden PLMN"));
			break;
		case SWI_SERVICE_STATUS_ForbiddenArea:
			*ServiceStatus = (_T("Forbidden Area"));
			break;
		case SWI_SERVICE_STATUS_ForbiddenRoaming:
			*ServiceStatus = (_T("Forbidden Roaming"));
			break;
		case SWI_SERVICE_STATUS_IllegalMobStation:
			*ServiceStatus = (_T("Illegal Mobile Station"));
			break;
		case SWI_SERVICE_STATUS_IllegalMobEquip:
			*ServiceStatus = (_T("Illegal Mobile Equipment"));
			break;
		case SWI_SERVICE_STATUS_UnknownIMSI:
			*ServiceStatus = (_T("Unknown IMSI"));
			break;
		case SWI_SERVICE_STATUS_AuthenticationFailure:
			*ServiceStatus = (_T("Authentication Failure"));
			break;
		case SWI_SERVICE_STATUS_GPRSFailed:
			*ServiceStatus = (_T("GPRS failure"));
			break;
		default:
			// shouldn't get here ever
			break;
	}

	return TRUE; //returning true to indicate a successful operation
}


/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	RenewAddressCe
//
//	Description	:	Initiates a DHCP renew for CE (not for PPC2000)
//
//	Arguments	:	None
//
//	Returns		:	TRUE/FALSE - indiates success or failure of operation
//
//	Comments	:	Used specifically in this app for PPC2002.  It is generally good
//					practice to do a DHCP renew for Win32 as well after you make a connection
//                  as it may take awhile before an IP address is assigned to you.
//                  However, since this is only a sample app, we won't do that here.
//
///////////////////////////////////////////////////////////////////////////
BOOL CGPRSConnectSampleDlg::RenewAddressCe() 
{
//Following is used for anything but PPC2000, as it does not offer iphlpapi
#if (WIN32_PLATFORM_PSPC == 310) //If it's not PPC2000...
	
	ULONG sizeofbuffer = 0;
    PIP_INTERFACE_INFO pBuffer=NULL;
    DWORD dwVal;
	BOOL  ret = FALSE;	// Function's ultimate return value.
	WCHAR ADAPTORNAME[BUFFERSIZE];


	do
	{
		// Identify all adapters.
		dwVal = (g_pGetInterfaceInfo)(pBuffer, &sizeofbuffer);
		if (dwVal == ERROR_INSUFFICIENT_BUFFER) 
		{
		   pBuffer = (PIP_INTERFACE_INFO) malloc(sizeofbuffer);
		   dwVal = (g_pGetInterfaceInfo)(pBuffer, &sizeofbuffer);
		}

		if (dwVal != NO_ERROR) 
		{
			ret = FALSE;
			break;
		}

			//Get Aircard type
			SWI_STRUCT_AirCardType sAirCardType;
			sAirCardType.sizeStruct = sizeof (SWI_STRUCT_AirCardType);
			SWI_RCODE rCode = SwiGetAirCardType (&sAirCardType, TIMEOUT);
			//m_eProduct = sAirCardType.eAirCard;
			switch(sAirCardType.eAirCard)
			{
			case SWI_AIRCARD_AC710:
				wcscpy(ADAPTORNAME, ADAPTORNAMEGPRS);
				break;
			case SWI_AIRCARD_AC750:
				wcscpy(ADAPTORNAME, ADAPTORNAMEGPRS);
				break;
			case SWI_AIRCARD_AC775:
				wcscpy(ADAPTORNAME, ADAPTORNAMEEDGE);
				break;
			}

		//Search through the adaptors and find the right one, then
		//renew the ip address
		for (int index = 0; index < pBuffer->NumAdapters; index++) 
		{
			if (!wcscmp(pBuffer->Adapter[index].Name, ADAPTORNAME)) 
			{
				dwVal = (g_pIpRenewAddress)(&(pBuffer->Adapter[index]));
				ret = (NO_ERROR == dwVal);
				break;
			} 
		}
	} while (FALSE);

	// Cleanup.
	free(pBuffer);
	return ret;

#else // Not PPC2002

	// Not supported.
	return TRUE;

#endif //!(WIN32_PLATFORM_PSPC == 1)
}


/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	RenewAddress
//
//	Description	:	Initiates a DHCP renew for Win32
//
//	Arguments	:	None
//
//	Returns		:	TRUE/FALSE - indiates success or failure of operation
//
//	Comments	:	Used specifically in this app for Win32
//
///////////////////////////////////////////////////////////////////////////
BOOL CGPRSConnectSampleDlg::RenewAddress()
{
#ifndef WIN32_PLATFORM_PSPC //If it's not a PPC device

	ULONG sizeofbuffer = 0;
	PIP_INTERFACE_INFO	pInterfaceBuf = NULL;
    PIP_ADAPTER_INFO pAdapterBuf = NULL;
	PIP_ADAPTER_INFO pAdapterPointer = NULL;
    DWORD dwVal;
	BOOL  bRet = FALSE;	// Function's ultimate return value.
	CString strName, strCompare;

	//Get Aircard type
	SWI_STRUCT_AirCardType sAirCardType;
	sAirCardType.sizeStruct = sizeof (SWI_STRUCT_AirCardType);
	SWI_RCODE rCode = SwiGetAirCardType (&sAirCardType, TIMEOUT);
	//m_eProduct = sAirCardType.eAirCard;
	switch(sAirCardType.eAirCard)
	{
	case SWI_AIRCARD_AC710:
		strCompare = ADAPTORNAMEGPRS;
		break;
	case SWI_AIRCARD_AC750:
		strCompare = ADAPTORNAMEGPRS;
		break;
	case SWI_AIRCARD_AC775:
		strCompare = ADAPTORNAMEEDGE;
		break;
	default:
		break;
	}

	// Use loop with one iteration for easy breakout. Steve's trick.
	do
	{
		// Identify all adapters.
		dwVal = (g_pGetAdaptersInfo)(pAdapterBuf, &sizeofbuffer);
		if (dwVal == ERROR_BUFFER_OVERFLOW) 
		{
		   pAdapterBuf = (PIP_ADAPTER_INFO) malloc(sizeofbuffer);
		   dwVal = (g_pGetAdaptersInfo)(pAdapterBuf, &sizeofbuffer);
		}

		// Identify all interfaces
		sizeofbuffer = 0;
		dwVal = (g_pGetInterfaceInfo)(pInterfaceBuf, &sizeofbuffer);
		if (dwVal == ERROR_INSUFFICIENT_BUFFER) 
		{
		   pInterfaceBuf = (PIP_INTERFACE_INFO) malloc(sizeofbuffer);
		   dwVal = (g_pGetInterfaceInfo)(pInterfaceBuf, &sizeofbuffer);
		}

		if (dwVal != NO_ERROR) 
		{
			bRet = FALSE;
			break;
		}

		pAdapterPointer = pAdapterBuf;
		do 
		{
			// find the correct adapter
			strName = pAdapterPointer->Description;

			if (!_tcscmp(strName, strCompare)) 
			{
				int iIndex=0;
				for (int i=0; i<pInterfaceBuf->NumAdapters; i++)
				{
					// search the interfaces to find matching adapter interface
					if (pInterfaceBuf->Adapter[i].Index == pAdapterPointer->Index)
					{
						// renew address with correct interface
						dwVal = (g_pIpRenewAddress)(&(pInterfaceBuf->Adapter[i]));
						bRet = (NO_ERROR == dwVal);
						break;
					}
				}
			} 
			pAdapterPointer = pAdapterPointer->Next;
		} while (NULL != pAdapterPointer);
	} while (FALSE);

	// Cleanup.
	free(pAdapterBuf);
	free(pInterfaceBuf);
	return bRet;

#else
	
	return TRUE;

#endif
}


/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	IsModemReady
//
//	Description	:	Checks if modem is ready for instruction
//
//	Arguments	:	None
//
//	Returns		:	TRUE/FALSE - indiates success or failure of operation
//
//	Comments	:	
//
///////////////////////////////////////////////////////////////////////////
BOOL CGPRSConnectSampleDlg::IsModemReady()
{
	SWI_RCODE rCode;
	for (int i = 0; i < MODEM_READY_RETRIES; i++)
	{
		// Don't care about BuildDate value, just return code.
		TCHAR tchArray[BUFFERSIZE];
        rCode = SwiGetFirmwareBuildDate(tchArray, 10, INFINITE);

		if (SWI_RCODE_OK == rCode)
        {
            return true;
        }
	}

	return false;
}


/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	OnBtnTcpset
//
//	Description	:	Modifies TCP window size in registry
//
//	Arguments	:	None
//
//	Returns		:	None
//
//	Comments	:	Keep in mind that for GPRS AC750 we recommend a TCP 
//					window size of 19200, where as for EDGE AC775 we recommend 
//					a TCP window size of 43000.  Any values higher or lower than 
//					these may cause a degradation in throughput rate.
//
///////////////////////////////////////////////////////////////////////////
void CGPRSConnectSampleDlg::OnBtnTcpset() 
{

	SWI_RCODE eRcode;
	UpdateData(TRUE);

	//TCP window size must be greater than 0, or else it wouldn't make sense.
	if(!(0 < m_intTCPWindowsize))
	{
		m_strStatusIndicator = _T("Invalid entry, please enter a positive integer.");
		UpdateData(FALSE);
		return;
	}

	SWI_STRUCT_TcpOpt sTcpWindowSize;
	sTcpWindowSize.nTcpWindowSize = m_intTCPWindowsize;

	//For more information on the two parameters below, please refer to SwiStructsCm.h
	sTcpWindowSize.bSackOpts = TRUE;
	sTcpWindowSize.nTcpMaxDupAcks = 1;

	//Setting TCP window size
	eRcode = SwiOptimizeTcp(sTcpWindowSize);
	if(eRcode != SWI_RCODE_OK)
	{
		MessageBox(_T("Failed to set TCP Window Size"), _T("Application Error"), MB_OK);
		return;
	}

	//Keep in mind that for GPRS AC750 we recommend a TCP window size of 19200, 
	//where as for EDGE AC775 we recommend a TCP window size of 43000.  Any 
	//values higher or lower than these may cause a degradation in throughput rate.

	//Confirmation message with recommended values for TCP window size.
	MessageBox(_T("TCP window size successfully set!  For these changes to take affect, close this sample app, eject and reinsert the Aircard."), MB_OK);

	return;

}


void CGPRSConnectSampleDlg::OnBtnConnect()
{
	// TODO: Add your control notification handler code here
	ConnectModem();
}
