/**
 *
 *	Name	:	GPRSConnectSampleDlg.h
 *
 *	Purpose	:	main header file for the GPRSConnectSample application
 *
 *	History	:	Created August 26th, 2003
 *				This sample app demonstrates how to make and handle a GPRS connection.
 *				It also shows how to monitor an active connection with various
 *				various notifications.
 *
 *	Revision:	1.0
 *
 *	Copyright (c) 2003 Sierra Wireless, Inc. All rights reserved.
 *
 **/

#if !defined(AFX_GPRSCONNECTSAMPLEDLG_H__003D1DA3_BF1E_4A4B_AC59_6D8425F7A002__INCLUDED_)
#define AFX_GPRSCONNECTSAMPLEDLG_H__003D1DA3_BF1E_4A4B_AC59_6D8425F7A002__INCLUDED_

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000

#include "SwiApiCm.h"
#include "SwiStructsGsm.h"

//Following is used for anything but PPC2000, as it does not offer iphlpapi
#if !(WIN32_PLATFORM_PSPC == 1) //If it's not PPC2000...
//#include <IPHLPAPI.H>
#include <iphlpapi.h>
#endif //!(WIN32_PLATFORM_PSPC == 1)

#define TIMEOUT 5000
#define BUFFERSIZE 256
#define MODEM_READY_RETRIES 10

#define NONE_SELECTED -1
#define NONE_SELECTEDGSM 0

// user defined windows message identifier notifications
#define WM_NOTIFICATION WM_USER + 400	//specific notification

/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	NotificationCallback
//
//	Description	:	Callback that receives all event notifications
//
//	Arguments	:	[IN]: pNotify - pointer to notification variant
//
//	Returns		:	None
//
//	Comments	:	Even if no notifications are being processed,
//					this function still needs to be registered and declared
//					for calls to the API to function properly.
//
/////////////////////////////////////////////////////////////////////////////
void NotificationCallback(SwiNotifyVariant *pNotify);

/////////////////////////////////////////////////////////////////////////////
// CGPRSConnectSampleDlg dialog

class CGPRSConnectSampleDlg : public CDialog
{
// Construction
public:
	CGPRSConnectSampleDlg(CWnd* pParent = NULL);	// standard constructor

// Dialog Data
	//{{AFX_DATA(CGPRSConnectSampleDlg)
	enum { IDD = IDD_GPRSCONNECTSAMPLE_DIALOG };
	CButton	m_btnConnect;
	CButton	m_btnTCPWindowSet;
	CButton	m_btnOK;
	CButton	m_btnDataDisconnect;
	CButton	m_btnDataConnect;
	CComboBox	m_comboSelectProfile;
	CString	m_strStatusIndicator;
	CString	m_strProfileLabel;
	CString	m_strRoaming;
	CString	m_strRx;
	CString	m_strTx;
	CString	m_strRSSI;
	CString	m_strCellID;
	CString	m_strServiceStatus;
	CString	m_strNetwork;
	CString	m_strServiceAvailFlag;
	UINT	m_intTCPWindowsize;
	//}}AFX_DATA

	// ClassWizard generated virtual function overrides
	//{{AFX_VIRTUAL(CGPRSConnectSampleDlg)
	protected:
	virtual void DoDataExchange(CDataExchange* pDX);	// DDX/DDV support
	//}}AFX_VIRTUAL

// Implementation
public:

	BOOL ConnectModem(); //connects to modem
	BOOL DisconnectModem(); //disconnects from modem
	void HandleCallback(SwiNotifyVariant* pNotify); //caches data from notificaiton callback
	LRESULT OnNotification(WPARAM wParam, LPARAM lParam); //handles notifications
	static CGPRSConnectSampleDlg* Instance(); //returns a pointer to this object
	void ProcessError(SWI_RCODE code); //process API error codes
	BOOL GetProfileState(U32 Index, SWI_TYPE_ProfileState* ProfileState); //retrieves Profile state
	BOOL GetServiceStatus(SWI_TYPE_ServiceStatus eServiceStatus, CString* ServiceStatus); //retrieves service status
	BOOL RenewAddressCe(); //Forces a DHCP renewal on CE
	BOOL RenewAddress(); //Forces a DHCP renewal on Win32
	BOOL IsModemReady(); //Checks if modem is ready
	SWI_TYPE_Device GetHighestPriorityDeviceType ();

private:
	static CGPRSConnectSampleDlg* m_instance; //a pointer to this object

// Implementation
protected:
	HICON m_hIcon;
	BOOL m_bConnected;		// connection status indicator
	int m_iCurrentProfileIndex; //current profile selected
	SWI_TYPE_Device m_eProduct; //Aircard type
	
	SWI_STRUCT_AirCardType m_sAirCardType; //structure used to store the AirCard type

	HINSTANCE m_hIpHlpApiDll; //Used to load iphlpapi

	enum TYPE_Device
	{
		DEVICE_AC710_750_775_850,
		DEVICE_MC87xx,
	};

	// Generated message map functions
	//{{AFX_MSG(CGPRSConnectSampleDlg)
	virtual BOOL OnInitDialog();
	afx_msg HCURSOR OnQueryDragIcon();
	virtual void OnOK();
	afx_msg void OnGetProfileLabel();
	afx_msg void OnGPRSConnect();
	afx_msg void OnGPRSDisconnect();
	afx_msg void OnBtnTcpset();
	afx_msg void OnBtnConnect();
	//}}AFX_MSG
	DECLARE_MESSAGE_MAP()
};

//{{AFX_INSERT_LOCATION}}
// Microsoft Visual C++ will insert additional declarations immediately before the previous line.

#endif // !defined(AFX_GPRSCONNECTSAMPLEDLG_H__003D1DA3_BF1E_4A4B_AC59_6D8425F7A002__INCLUDED_)
