/**
 *
 *	Name	:	DTMFSettings.cpp
 *
 *	Purpose	:	Sub dialog implementation for Swi32DialNumber Dialog, here the user will use the
 *				UI to change values for the DTMF tones to be sent from the main dialog
 *
 *	History	:	created	July 8, 2003
 *				- initial version
 *
 *	Revision:	1.0
 *
 *	Copyright (c) 2003 Sierra Wireless, Inc. All rights reserved.
 *
 **/

#include "stdafx.h"
#include "DialNumberSample.h"
#include "DTMFSettings.h"

#ifdef _DEBUG
#define new DEBUG_NEW
#undef THIS_FILE
static char THIS_FILE[] = __FILE__;
#endif

/////////////////////////////////////////////////////////////////////////////
// DTMFSettings dialog


DTMFSettings::DTMFSettings(CWnd* pParent /*=NULL*/)
	: CDialog(DTMFSettings::IDD, pParent)
{
	//{{AFX_DATA_INIT(DTMFSettings)
	m_nCustomOff = 0;
	m_nCustomOn = 0;
	//}}AFX_DATA_INIT
}


void DTMFSettings::DoDataExchange(CDataExchange* pDX)
{
	CDialog::DoDataExchange(pDX);
	//{{AFX_DATA_MAP(DTMFSettings)
	DDX_Control(pDX, IDC_VOLUME, m_ctrVolume);
	DDX_Control(pDX, IDC_LENGTHSELECT, m_ctrDTMFLength);
	DDX_Control(pDX, IDC_FEEDBACK, m_ctrEarFeedback);
	DDX_Control(pDX, ID_OK, m_btnOk);
	DDX_Control(pDX, ID_CANCEL, m_btnCancel);
	DDX_Text(pDX, IDC_CUSTOMOFF, m_nCustomOff);
	DDX_Text(pDX, IDC_CUSTOMON, m_nCustomOn);
	//}}AFX_DATA_MAP
}


BEGIN_MESSAGE_MAP(DTMFSettings, CDialog)
	//{{AFX_MSG_MAP(DTMFSettings)
	ON_BN_CLICKED(ID_OK, OnOk)
	ON_CBN_SELCHANGE(IDC_LENGTHSELECT, OnSelchangeLengthselect)
	ON_BN_CLICKED(ID_CANCEL, OnCancel)
	ON_BN_CLICKED(IDC_FEEDBACK, OnFeedback)
	//}}AFX_MSG_MAP
END_MESSAGE_MAP()

/////////////////////////////////////////////////////////////////////////////
// DTMFSettings message handlers
BOOL DTMFSettings::OnInitDialog()
{
	// initalize RCODE, to trap error conditions
	SWI_RCODE rCode;
	// initialize pop up DTMF setting dialog box
	CDialog::OnInitDialog();

	// init volume slider to 10 increments
	m_ctrVolume.SetRange(0, 10, FALSE);
	
	// declare Speaker volume struct to retrive speaker volume from AC
	SWI_STRUCT_GSM_SpeakerVolume sVolume;
	sVolume.sizeStruct = sizeof (SWI_STRUCT_GSM_SpeakerVolume);
	sVolume.nVolume = 0;

	// get speaker volume
	rCode = SwiGetGsmSpeakerVolume (&sVolume, DIALOG_TIMEOUT);
	// check error code, output if operation failed
	if (rCode != SWI_RCODE_OK)
	{
		ProcessError (rCode);
	}

	// set position of speaker volume slider to match setting in AC
	m_ctrVolume.SetPos((int)sVolume.nVolume / 10);

	// get settings the settings dialog
	SWI_STRUCT_NVToneStore	sTones;

	// init structure members
	sTones.sizeStruct = sizeof (SWI_STRUCT_NVToneStore);
	sTones.bEarpieceFeedback = FALSE;
	sTones.eToneLength = SWI_TYPE_ToneLength (3);
	sTones.nUserDefinedToneOnDuration = 0;  
	sTones.nUserDefinedToneOffDuration = 0; 
	sTones.nComfortToneOnDuration = 0;	// between 80 - 500
	sTones.nComfortToneOffDuration = 0;	// between 80 - 500

	// read settings to card
	rCode = SwiGetNVToneStore (&sTones, DIALOG_TIMEOUT);
	// check error code, output if operation failed
	if (rCode != SWI_RCODE_OK)
	{
		ProcessError (rCode);
	}

	// initialize some member variables
	m_bEarpieceFeedback = sTones.bEarpieceFeedback;
	m_nDurationOn = sTones.nUserDefinedToneOnDuration;
	m_nDurationOff = sTones.nUserDefinedToneOffDuration;
	m_nCustomOn = m_nDurationOn;
	m_nCustomOff = m_nDurationOff;
	
	// set DTMF Length combo box
	if ((m_nDurationOn == 100) && (m_nDurationOff == 80))
	{
		m_ctrDTMFLength.SetCurSel(0);
	}
	else if ((m_nDurationOn == 200) && (m_nDurationOff == 100))
	{
		m_ctrDTMFLength.SetCurSel(1);
	}
	else if ((m_nDurationOn == 350) && (m_nDurationOff == 200))
	{
		m_ctrDTMFLength.SetCurSel(2);
	}
	else
		m_ctrDTMFLength.SetCurSel(3);

	// set mute check box
	if (m_bEarpieceFeedback)
		m_ctrEarFeedback.SetCheck(BST_UNCHECKED);
	else
		m_ctrEarFeedback.SetCheck(BST_CHECKED);
	
	// update to screen
	UpdateData (FALSE);
	
	return TRUE;  // return TRUE  unless you set the focus to a control
}

/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	ProcessError
//
//	Description	:	Helper function to process error codes, displays a 
//					message box indicating the error code that was returned
//
//	Arguments	:	code - an error code of type SWI_RCODE
//
//	Returns		:	None
//
//	Comments	:	
//
/////////////////////////////////////////////////////////////////////////////
void DTMFSettings::ProcessError(SWI_RCODE code)
{
	CString strErrorString;

	// set error string with internal error code
	strErrorString.Format(_T("Internal error - error code: %d"), code);
	
	// output to message box
	MessageBox(strErrorString, _T("API Message"), MB_OK);
}

/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	OnOk
//
//	Description	:	Event when OK button is pressed, stores user preferences 
//					onto the AirCard
//
//	Arguments	:	None
//
//	Returns		:	None
//
//	Comments	:	
//
/////////////////////////////////////////////////////////////////////////////
void DTMFSettings::OnOk() 
{
	// RCODE to trap error conditions
	SWI_RCODE rCode;
	// structure to store DTMF settings to AirCard
	SWI_STRUCT_NVToneStore	sTones;

	// update from screen
	UpdateData (TRUE);

	// if user has selected custom inputs, take values in the 2 text boxes
	if (m_bCustom)
	{
		// error check custom entry values. between 80 and 3000 millisecs?
		if ((m_nCustomOn < 80) || (m_nCustomOn > 3000) || (m_nCustomOff < 80) || (m_nCustomOff > 3000))
		{
			MessageBox(_T("Custom Values must be between 80 and 3000"), _T("Input Error"), MB_OK);
			return;
		}	

		// custom inputs within range, updated values
		m_nDurationOn = m_nCustomOn;
		m_nDurationOff = m_nCustomOff;
	}

	// initialize structure
	sTones.sizeStruct = sizeof (SWI_STRUCT_NVToneStore);
	sTones.bEarpieceFeedback = m_bEarpieceFeedback;
	sTones.eToneLength = SWI_TYPE_ToneLength (3); // custom tone setting (allows store to AC, else store will be rejected)
	sTones.nUserDefinedToneOnDuration = m_nDurationOn;  
    sTones.nUserDefinedToneOffDuration = m_nDurationOff; 
	sTones.nComfortToneOnDuration = 200;	// between 80 - 500
	sTones.nComfortToneOffDuration = 200;	// between 80 - 500

	// store settings to AirCard
	rCode = SwiSetNVToneStore (&sTones, DIALOG_TIMEOUT);
	// check error code, output if operation failed
	if (rCode != SWI_RCODE_OK)
	{
		ProcessError (rCode);
	}	

	// declare volume struct to set slider setting to AC
	SWI_STRUCT_GSM_SpeakerVolume sVolume;

	sVolume.sizeStruct = sizeof (SWI_STRUCT_GSM_SpeakerVolume);
	sVolume.nVolume = m_ctrVolume.GetPos() * 10;

	// set volume slider preference to AC
	rCode = SwiSetGsmSpeakerVolume (&sVolume, DIALOG_TIMEOUT);
	// check error code, output if operation failed
	if (rCode != SWI_RCODE_OK)
	{
		ProcessError (rCode);
	}	

	CDialog::OnOK();	
}

/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	OnCancel
//
//	Description	:	Event when cancel button is pressed, exits dialog
//
//	Arguments	:	None
//
//	Returns		:	None
//
//	Comments	:	
//
/////////////////////////////////////////////////////////////////////////////
void DTMFSettings::OnCancel() 
{
	// close dialog
	CDialog::OnCancel();		
}

/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	OnSelchangeLengthselect
//
//	Description	:	Event when combo box's selection is changed, has 3 presets
//					SHORT, MEDIUM, LONG settings, also a CUSTOM Setting that 
//					will flag OK to use the user entered values for DTMF tone 
//					lengths
//
//	Arguments	:	None
//
//	Returns		:	None
//
//	Comments	:	
//
/////////////////////////////////////////////////////////////////////////////
void DTMFSettings::OnSelchangeLengthselect() 
{
	int	nSelection = m_ctrDTMFLength.GetCurSel();

	switch (nSelection)
	{
	case SELECT_NONE:
		// no choices picked, use some default
		m_bCustom = FALSE;

		break;
	case SELECT_SHORT:
		// short selected
		m_bCustom = FALSE;
		m_nDurationOn = 100;
		m_nDurationOff = 80;

		break;
	case SELECT_MEDIUM:
		// normal selcted
		m_bCustom = FALSE;
		m_nDurationOn = 200;
		m_nDurationOff = 100;

		break;
	case SELECT_LONG:
		// long selected
		m_bCustom = FALSE;
		m_nDurationOn = 350;
		m_nDurationOff = 200;

		break;
	case SELECT_CUSTOM:
		// custom selected
		m_bCustom = TRUE;

		break;
	default:
		break;
	}
}


/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	OnFeedback
//
//	Description	:	Event when the mute check box is checked/unchecked
//					When mute IS checked, Earpiece Feedback is set to FALSE
//					and TRUE when unchecked.
//
//	Arguments	:	None
//
//	Returns		:	None
//
//	Comments	:	
//
/////////////////////////////////////////////////////////////////////////////
void DTMFSettings::OnFeedback() 
{
 	// set the feedback bool, if checked
 	if (m_ctrEarFeedback.GetCheck() == 1)
 			m_bEarpieceFeedback = FALSE;
 	else
 			m_bEarpieceFeedback = TRUE;
}
