/**
*
*	Name	:	DialNumberSampleDlg.cpp
*
*	Purpose	:	Main dialog implementation for DialNumberSample Dialog, Dialog will dial/connect
*				an entered phone number, as well as display the usage of DTMF tones.
*
*	History	:	created	July 2, 2003
*				- initial version
*
*	Revision:	1.0
*
*	Copyright (c) 2003 Sierra Wireless, Inc. All rights reserved.
*
**/

#include "stdafx.h"
#include "DialNumberSample.h"
#include "DialNumberSampleDlg.h"

#ifdef _DEBUG
#define new DEBUG_NEW
#endif

CDialNumberSampleDlg*	CDialNumberSampleDlg::m_instance = NULL; //initializing pointer to this object to NULL
// CDialNumberSampleDlg dialog

CDialNumberSampleDlg::CDialNumberSampleDlg(CWnd* pParent /*=NULL*/)
	: CDialog(CDialNumberSampleDlg::IDD, pParent)
{
	m_szDialpadNum = _T("");	// initialize member string for buffering phone number
	m_instance = this;	// initialize object
	m_strCallStatus = _T("");
	m_hIcon = AfxGetApp()->LoadIcon(IDR_MAINFRAME);
	m_bUmts = TRUE;
}

void CDialNumberSampleDlg::DoDataExchange(CDataExchange* pDX)
{
	CDialog::DoDataExchange(pDX);
	//{{AFX_DATA_MAP(CDialNumberSampleDlg)
	DDX_Control(pDX, IDC_HEADSETSTATUS, m_ctrHeadset);
	DDX_Control(pDX, IDC_BUTTONDTMFSETTINGS, m_btnDTMFSettings);
	DDX_Control(pDX, IDC_SEND, m_btnSend);
	DDX_Control(pDX, IDC_END, m_btnEnd);
	DDX_Control(pDX, IDC_CLEAR, m_btnClear);
	DDX_Control(pDX, IDC_BUTTONSTAR, m_btnStar);
	DDX_Control(pDX, IDC_BUTTONPOUND, m_btnPound);
	DDX_Control(pDX, IDC_BUTTON9, m_btn9);
	DDX_Control(pDX, IDC_BUTTON8, m_btn8);
	DDX_Control(pDX, IDC_BUTTON7, m_btn7);
	DDX_Control(pDX, IDC_BUTTON6, m_btn6);
	DDX_Control(pDX, IDC_BUTTON5, m_btn5);
	DDX_Control(pDX, IDC_BUTTON4, m_btn4);
	DDX_Control(pDX, IDC_BUTTON3, m_btn3);
	DDX_Control(pDX, IDC_BUTTON2, m_btn2);
	DDX_Control(pDX, IDC_BUTTON1, m_btn1);
	DDX_Control(pDX, IDC_BUTTON0, m_btn0);
	DDX_Control(pDX, ID_OK, m_btnOK);
	DDX_Text(pDX, IDC_DIALPAD_DISPLAY, m_szDialpadNum);
	DDX_Text(pDX, IDC_CALLSTATUS, m_strCallStatus);
	//}}AFX_DATA_MAP
}

BEGIN_MESSAGE_MAP(CDialNumberSampleDlg, CDialog)
	ON_BN_CLICKED(IDC_SEND, OnSend)	// links event associated /w Send button clicked
	ON_BN_CLICKED(IDC_END, OnEnd)	// links event associated /w End button clicked
	ON_BN_CLICKED(IDC_CLEAR, OnClear)	// links event associated /w Clear button clicked
	ON_BN_CLICKED(IDC_BUTTON1, OnButton1)	// links event associated /w '1' button clicked
	ON_BN_CLICKED(IDC_BUTTON2, OnButton2)	// links event associated /w '2' button clicked
	ON_BN_CLICKED(IDC_BUTTON3, OnButton3)	// links event associated /w '3' button clicked
	ON_BN_CLICKED(IDC_BUTTON4, OnButton4)	// links event associated /w '4' button clicked
	ON_BN_CLICKED(IDC_BUTTON5, OnButton5)	// links event associated /w '5' button clicked
	ON_BN_CLICKED(IDC_BUTTON6, OnButton6)	// links event associated /w '6' button clicked
	ON_BN_CLICKED(IDC_BUTTON7, OnButton7)	// links event associated /w '7' button clicked
	ON_BN_CLICKED(IDC_BUTTON8, OnButton8)	// links event associated /w '8' button clicked
	ON_BN_CLICKED(IDC_BUTTON9, OnButton9)	// links event associated /w '9' button clicked
	ON_BN_CLICKED(IDC_BUTTONSTAR, OnButtonStar)	// links event associated /w '*' button clicked
	ON_BN_CLICKED(IDC_BUTTON0, OnButton0)	// links event associated /w '0' button clicked
	ON_BN_CLICKED(IDC_BUTTONPOUND, OnButtonPound)	// links event associated /w '#' button clicked
	ON_BN_CLICKED(IDC_BUTTONDTMFSETTINGS, OnDTMFSetting)
	ON_BN_CLICKED(ID_OK, OnOK)	// links event associated /w OK button clicked
#if defined(_DEVICE_RESOLUTION_AWARE) && !defined(WIN32_PLATFORM_WFSP)
	ON_WM_SIZE()
#endif
	//}}AFX_MSG_MAP
	ON_MESSAGE(WM_NOTIFICATION, OnNotification)
END_MESSAGE_MAP()


// CDialNumberSampleDlg message handlers

BOOL CDialNumberSampleDlg::OnInitDialog()
{
	CDialog::OnInitDialog();

	// Set the icon for this dialog.  The framework does this automatically
	//  when the application's main window is not a dialog
#ifdef WIN32_PLATFORM_WFSP
	if (!m_dlgCommandBar.Create(this) ||
	    !m_dlgCommandBar.InsertMenuBar(IDR_MAINFRAME))
	{
		TRACE0("Failed to create CommandBar\n");
		return FALSE;      // fail to create
	}
#endif // WIN32_PLATFORM_WFSP
	// TODO: Add extra initialization here
	SetIcon(m_hIcon, TRUE);			// Set big icon
	SetIcon(m_hIcon, FALSE);		// Set small icon
	m_bConnected = FALSE;	// init to False, since no connection
	m_bCallInProgress = FALSE;	// init to False, since no call
	m_bIncomingCall = FALSE;	// init to False, since no incoming call
	m_nIncomingCallID = 0;	// init to 0, no incoming call to handle	
	m_nOutgoingCallID = 0;	// init to 0, no outgoing call to handle
	m_bEarpieceFeedback = TRUE;
	m_nDTMFOnDuration = 200;
	m_nDTMFOffDuration = 100;

	// connect to modem
	if (ConnectModem())
	{
		// flag boolean to indicated Connected
		m_bConnected = TRUE;
		// update status box to inform user of connections
		m_strCallStatus = _T("Modem is Connected");
	}
	else
	{
		// close dialog if unable to open API
		OnOK();
	}		

	// update to screen
	UpdateData (FALSE);
	
	return TRUE;  // return TRUE  unless you set the focus to a control
}

/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	ProcessError
//
//	Description	:	Helper function to process error codes, displays a 
//					message box indicating the error code that was returned
//
//	Arguments	:	code - an error code of type SWI_RCODE
//
//	Returns		:	None
//
//	Comments	:	
//
/////////////////////////////////////////////////////////////////////////////
void CDialNumberSampleDlg::ProcessError(SWI_RCODE code)
{
	CString strErrorString;

	// set error string with internal error code
	strErrorString.Format(_T("Internal error - error code: %d"), code);

	// output to message box
	MessageBox(strErrorString, _T("API Message"), MB_OK);
}

////////////////////////////////////////////////////////////////////////////
//
//	Function	:	NotificationCallback
//
//	Description	:	Callback that receives all event notifications
//
//	Arguments	:	[IN] - pNotify	- pointer to notification variant
//
//	Returns		:	None
//
//	Comments	:	Even if no notifications are being processed, this 
//					function still needs to be registered and declared for 
//					calls to the API to function properly
//
/////////////////////////////////////////////////////////////////////////////
void NotificationCallback(SwiNotifyVariant *pNotify)
{
	CDialNumberSampleDlg* pThisObject = CDialNumberSampleDlg::Instance();
	pThisObject->HandleCallback(pNotify);
}

/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	OnNotification
//
//	Description	:	Handler for received notifications
//
//	Arguments	:	[IN] - wParam - Contains the notification type
//					[IN] - lParam - Contains the data to be updated
//
//	Returns		:	None
//
//	Comments	:
//
/////////////////////////////////////////////////////////////////////////////
LRESULT CDialNumberSampleDlg::OnNotification(WPARAM wParam, LPARAM lParam)
{

	SWI_STRUCT_CALL_EXP_Progress sCallProgress;
	SWI_STRUCT_HeadsetState sHeadsetState;
	SwiNotifyVariant* pNotify = (SwiNotifyVariant*)wParam;

	switch(pNotify->eNotify)
	{
	case SWI_NOTIFY_HeadsetState:
		sHeadsetState = pNotify->_HeadsetState;
		switch (sHeadsetState.eHeadsetState)
		{
		case SWI_HEADSET_Unplugged:
			m_ctrHeadset.EnableWindow (FALSE);
			break;
		case SWI_HEADSET_Plugged:
			m_ctrHeadset.EnableWindow (TRUE);

			break;
		default:
			break;
		}
		break;

	case SWI_NOTIFY_CallProgress:
		 	
		sCallProgress = pNotify->_CallProgress;
		// switch depending on the eCallProgress enum
		switch (sCallProgress.eCallProgress)
		{
			// case where call progress indicates a failed call
		case SWI_CALL_PROGRESS_Failed:
			m_strCallStatus = _T("Failed");
			m_szDialpadNum= _T("");
			m_bCallInProgress = false;
			m_nIncomingCallID = 0;
			m_nOutgoingCallID = 0;
			m_btnSend.EnableWindow (TRUE);
			m_btnEnd.EnableWindow (TRUE);
			break;
			// case where outgoing call is connecting
		case SWI_CALL_PROGRESS_Connecting:
			m_strCallStatus = _T("Connecting...");
			m_CurCallProgress = sCallProgress;
			m_nOutgoingCallID = sCallProgress.CallID;
			break;
			// case exists, but not used in this application
		case SWI_CALL_PROGRESS_Queued:
			break;
			// case exists, but not used in this application
		case SWI_CALL_PROGRESS_Waiting:
			break;
			// case where a call is incoming
		case SWI_CALL_PROGRESS_Incoming:
			m_CurCallProgress = sCallProgress;
			m_strCallStatus = _T("Incoming...");
			m_nIncomingCallID = sCallProgress.CallID;	// set incoming call ID
			m_bIncomingCall = TRUE;	// set incoming bool to true so SEND can answer incoming call
			break;
			// case where call progress indicates AC is ringing
		case SWI_CALL_PROGRESS_Ringing:
			m_strCallStatus = _T("Ringing...");
			break;
			// case where call progress indicates a connected state
		case SWI_CALL_PROGRESS_Connected:
			m_CurCallProgress = sCallProgress;
			m_strCallStatus = _T("Connected");
			m_btnSend.EnableWindow (TRUE);
			break;
			// case where call progress indicates a disconnection
		case SWI_CALL_PROGRESS_Disconnecting:
			if (m_CurCallProgress.CallID == sCallProgress.CallID)
			{
				m_strCallStatus = _T("Disconnecting...");
				//update to screen, before call
				UpdateData (FALSE);
				ProcessDisconnecting (sCallProgress.eCallError);	// process the disconnection
			}
			break;
			// case where call progress indicates disconnected state
		case SWI_CALL_PROGRESS_Disconnected:
			if (m_CurCallProgress.CallID == sCallProgress.CallID)
			{
				m_strCallStatus = _T("Disconnected");
				m_nOutgoingCallID = 0;	// reset outgoing call ID
				m_nIncomingCallID = 0;	// reset incoming call ID
				m_btnEnd.EnableWindow (TRUE);
				m_btnSend.EnableWindow (TRUE);
			}
			break;
		default:
			break;
		}
		break;
	default:
		break;
	}
	delete (SwiNotifyVariant*)wParam;	
	//update to screen
	UpdateData (FALSE);
	return TRUE;
}

SWI_TYPE_Device CDialNumberSampleDlg::GetHighestPriorityDeviceType ()
{
	SWI_TYPE_Device				eTypeDevice = SWI_DEVICE_None;
	SWI_STRUCT_AirServerList	sAvailDevList;
	SWI_RCODE					rCode;

	//--------------------
	// Connect to ANY device
	//--------------------
	sAvailDevList.sizeStruct = sizeof(SWI_STRUCT_AirServerList);
	rCode = SwiGetAvailAirServers(sAvailDevList);
	if (SWI_RCODE_OK != rCode)
		return eTypeDevice;

	// how many avail devices?
	if (0 == sAvailDevList.nNumber)
		return eTypeDevice;

	return sAvailDevList.AirServers[0].eDevice;
}

////////////////////////////////////////////////////////////////////////////
//
//	Function	:	ConnectModem
//
//	Description	:	Starts a Connection to the Modem
//
//	Arguments	:	None
//
//	Returns		:	BOOL (True/False), to indicate success of connection
//
//	Comments	:
//
/////////////////////////////////////////////////////////////////////////////
BOOL CDialNumberSampleDlg::ConnectModem()
{
	// define rCode for error handling
	if (!m_bConnected) // if API is NOT connected, select and open AC710 API
	{
		// if not connected, open the API
		SWI_STRUCT_ApiStartup sOpenParams;
		memset(&sOpenParams, 0, sizeof(SWI_STRUCT_ApiStartup));

		SWI_RCODE rCode = SwiApiStartup(&sOpenParams);
		if(SWI_RCODE_OK != rCode)
		{
			ProcessError(rCode);
			return FALSE;
		}

		// get available device type
		SWI_TYPE_Device eDevice = GetHighestPriorityDeviceType();
		if (eDevice == SWI_DEVICE_None)
			return FALSE;

		DECLARE_MacAny;
		SWI_STRUCT_AirServer sAirServer;
		sAirServer.sizeStruct = sizeof(SWI_STRUCT_AirServer);
		memcpy(sAirServer.ClientMac, MacAny, LENGTH_MacAddress);
		memcpy(sAirServer.ServerMac, MacAny, LENGTH_MacAddress);
		sAirServer.eDevice = eDevice;

		rCode = SwiSelectAirServer(sAirServer);
		if(SWI_RCODE_OK != rCode)
		{
			ProcessError(rCode);
			return FALSE;
		}

		switch (eDevice)
		{
		case SWI_DEVICE_None:
		case SWI_DEVICE_AC710:
		case SWI_DEVICE_AC750:
		case SWI_DEVICE_AC775:
		case SWI_DEVICE_MP750:
		case SWI_DEVICE_MP775:
			m_bUmts = FALSE;
			break;
		default:
			m_bUmts = TRUE;
			break;
		}

		// register the Callback function
		rCode= SwiRegisterCallback(NotificationCallback, 0xFFFFFFFFFFFFFFFF);	
		// check error code, output if operation failed
		if (SWI_RCODE_OK != rCode)
		{
			ProcessError(rCode);
			// return false, since failed
			return FALSE;
		}

		//enable CallProgress notification
		rCode = SwiNotify(SWI_NOTIFY_CallProgress, TIMEOUT);
		// check error code, output if operation failed
		if (SWI_RCODE_OK != rCode)
		{
			ProcessError(rCode);
			// return false, since failed
			return FALSE;
		}

		//enable Headset notification
		rCode = SwiNotify(SWI_NOTIFY_HeadsetState, TIMEOUT);
		// check error code, output if operation failed
		if (SWI_RCODE_OK != rCode)
		{
			ProcessError(rCode);
			// return false, since failed
			return FALSE;
		}

		// informing modem of host startup state
		// this function will attach the modem onto the Network (in the event it's not)
		// modem needs to be on mobile network to send SMS
		rCode = SwiSetHostStartup (TRUE, (TIMEOUT * 20));
		// check error code, output if operation failed
		if (SWI_RCODE_OK != rCode)
		{
			ProcessError(rCode);
			// return false, since failed
			return FALSE;
		}

		// when all the above statments are executed without error, API is opened
		// so return true
		return TRUE;

	}

	// modem is already connected, API already opened, return false
	// since this is called only once on startup, there should be no connection to modem
	return FALSE;

}


////////////////////////////////////////////////////////////////////////////
//
//	Function	:	DisconnectModem
//
//	Description	:	Ends a Connection to the Modem
//
//	Arguments	:	None
//
//	Returns		:	BOOL (True/False), to indicate success of disconnection
//
//	Comments	:
//
/////////////////////////////////////////////////////////////////////////////
BOOL CDialNumberSampleDlg::DisconnectModem()
{
	// define rCode for error handling
	SWI_RCODE rCode;

	//disconnect if a connection to the modem exists
	if(m_bConnected)
	{
		// Disable Call Progress notifications
		rCode = SwiStopNotify(SWI_NOTIFY_CallProgress, TIMEOUT);
		// check error code, output if operation failed
		if (SWI_RCODE_OK != rCode)
		{
			ProcessError(rCode);
			// return false, since failed
			return FALSE;
		}

		// Disconnect any active calls before exiting
		OnEnd();

		// detaching modem from network; this has been commented out because
		// it can sometimes take up to 20 seconds to detach from the network,
		// since it is not absolutely necessary to detach from the network,
		// it has been commented out for the SDK sample apps.
		//
		// rcode = SwiSetHostStartup(FALSE, TIMEOUT*20);
		// if(SWI_RCODE_OK != rcode)
		// {
		//		ProcessError(rcode);
		//		return FALSE;
		// }

		//close connection with modem
		rCode = SwiApiShutdown();	
		// check error code, output if operation failed
		if (SWI_RCODE_OK != rCode)
		{
			ProcessError(rCode);
			// return false, since failed
			return FALSE;
		}

		// when all the above statments are executed without error, API is closed
		// so return true
		m_bConnected = FALSE;
		return TRUE;
	}

	// modem is already disconnected, API already closed, return true for is disconnected
	// since this is called only once on startup, there should be no connection to modem
	return TRUE;

}

/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	ConvertPhoneNumberToBinary
//
//	Description	:	Helper function to convert phone string to BCD
//
//	Arguments	:	SWI_RCODE
//
//	Returns		:	None
//
//	Comments	:
//
/////////////////////////////////////////////////////////////////////////////
void CDialNumberSampleDlg::ConvertPhoneNumberToBinary (CString &strNumber,  BYTE *pBuffer, unsigned long &nPhoneNumberLength, bool &bInternaional)
{
	//binary (',' = 0x0C '*' = 0x0A '#' = 0x0B '?' = 0x0D '0'-'9')
	TCHAR   tch;
	int     idx = 0; 
	int     iLength = strNumber.GetLength ();

	nPhoneNumberLength = 0;
	if (iLength > 0 && strNumber.GetAt (0) == _T('+'))
	{
		bInternaional = true;
		++idx;
	}
	else
		bInternaional = false;

	for (idx; idx < iLength && idx <= 40; ++idx)
	{
		tch = strNumber.GetAt (idx);
		++nPhoneNumberLength;

		// if tch is a number between '0' - '9'
		if (tch >= _T('0') && tch <= _T('9'))
		{
			*pBuffer = tch - _T('0');
			++pBuffer;
		}
		// else entered tch is either a '*', or '#'
		else
		{
			switch (tch)
			{
			case _T('*'):
				*pBuffer = 0x0A;
				++pBuffer;
				break;
			case _T('#'):
				*pBuffer = 0x0B;
				++pBuffer;
				break;
			default:
				--nPhoneNumberLength;
				break;
			}
		}
	}
}

/////////////////////////////////////////////////////////////////////////////
//
//	Event		:	OnSend
//
//	Description	:	Event triggered when the Send button is pressed, 
//					either dial a call, answer a call, or
//					when during a call, to end the call
//
//	Arguments	:	None
//
//	Returns		:	None
//
//	Comments	:	
//
/////////////////////////////////////////////////////////////////////////////
void CDialNumberSampleDlg::OnSend() 
{
	// disable the Send button for subsequent use
	m_btnSend.EnableWindow(FALSE);

	// if there is no call and in progress and not and incoming call, dial out
	if (!m_bCallInProgress && !m_bIncomingCall)
	{
		ProcessOutgoingCall();
	}
	// if there is no call in progress and a call is incoming, answer call
	else if (!m_bCallInProgress && m_bIncomingCall)
	{
		ProcessIncomingCall();
	}
	// any other time button is pressed, call OnEnd
	else
	{
		OnEnd();
	}
}

/////////////////////////////////////////////////////////////////////////////
//
//	Event		:	OnEnd
//
//	Description	:	Event triggered when the End button is pressed, if there
//					is a call in progress, disconnect it (assumues only 1 active call) 
//					and flags the m_bCallInProgress boolean to false
//
//	Arguments	:	None
//
//	Returns		:	None
//
//	Comments	:	
//
/////////////////////////////////////////////////////////////////////////////
void CDialNumberSampleDlg::OnEnd() 
{
	// define rCode for error handling
	SWI_RCODE rCode;

	// if there is a call in progress
	if (m_bCallInProgress)
	{
		// disable End button for duration of the function operation
		m_btnEnd.EnableWindow(FALSE);

		if (m_bUmts)
			rCode = SetCallControlUmts(0, SWI_CALL_CONTROL_UMTS_DisconnectAll);    
		else
			rCode = SetCallControl(0, SWI_CALL_CONTROL_DisconnectAll);

		// check error code, output if operation failed
		if (SWI_RCODE_OK != rCode)
		{
			ProcessError(rCode);
		}
		// if ok, disconnect succeeded, flag bool
		else if (SWI_RCODE_OK == rCode)
		{
			m_bCallInProgress = FALSE;
		}

		// enable the End button for subsequent use
		m_btnEnd.EnableWindow(TRUE);
	}
	else
		m_szDialpadNum = _T("");

	UpdateData (FALSE);
}

/////////////////////////////////////////////////////////////////////////////
//
//	Event		:	OnClear
//
//	Description	:	Event triggered when the Clear button is pressed, clears  
//					the last character fromthe m_szDialpadNum string and 
//					and updates the UI
//
//	Arguments	:	None
//
//	Returns		:	None
//
//	Comments	:	
//
/////////////////////////////////////////////////////////////////////////////
void CDialNumberSampleDlg::OnClear() 
{
	//read the value from the screen
	UpdateData(TRUE);

	//clear the last number off the screen
	m_szDialpadNum.Delete(m_szDialpadNum.GetLength()-1, 1);

	//update the value to the screen
	UpdateData(FALSE);

}

/////////////////////////////////////////////////////////////////////////////
//
//	Event		:	OnOK
//
//	Description	:	Event triggered when the OK button is pressed, disables OK 
//					button calls DisconnectModem and renables OK button
//
//	Arguments	:	None
//
//	Returns		:	None
//
//	Comments	:	
//
/////////////////////////////////////////////////////////////////////////////
void CDialNumberSampleDlg::OnOK() 
{
	// Disable the OK button
	m_btnOK.EnableWindow(FALSE);

	// run Disconnect Modem function
	DisconnectModem();

	CDialog::OnOK();
}

/////////////////////////////////////////////////////////////////////////////
//
//	Event		:	OnButtonX
//
//	Description	:	Event triggered when the X button is pressed, calls the KeyPress 
//					function /w the ASCII and string value of
//					the key pressed
//
//	Arguments	:	None
//
//	Returns		:	None
//
//	Comments	:	
//
/////////////////////////////////////////////////////////////////////////////
void CDialNumberSampleDlg::OnButton1() 
{
	KeyPress(ASCII_1, _T("1"));
}
void CDialNumberSampleDlg::OnButton2() 
{
	KeyPress(ASCII_2, _T("2"));
}
void CDialNumberSampleDlg::OnButton3() 
{
	KeyPress(ASCII_3, _T("3"));
}
void CDialNumberSampleDlg::OnButton4() 
{
	KeyPress(ASCII_4, _T("4"));
}
void CDialNumberSampleDlg::OnButton5() 
{
	KeyPress(ASCII_5, _T("5"));
}
void CDialNumberSampleDlg::OnButton6() 
{
	KeyPress(ASCII_6, _T("6"));
}
void CDialNumberSampleDlg::OnButton7() 
{
	KeyPress(ASCII_7, _T("7"));
}
void CDialNumberSampleDlg::OnButton8() 
{
	KeyPress(ASCII_8, _T("8"));
}
void CDialNumberSampleDlg::OnButton9() 
{
	KeyPress(ASCII_9, _T("9"));
}
void CDialNumberSampleDlg::OnButton0() 
{
	KeyPress(ASCII_0, _T("0"));
}
void CDialNumberSampleDlg::OnButtonStar() 
{
	KeyPress(ASCII_STAR, _T("*"));
}
void CDialNumberSampleDlg::OnButtonPound() 
{
	KeyPress(ASCII_POUND, _T("#"));
}


/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	Instance
//
//	Description	:	A static function used to return a pointer to this object
//
//	Arguments	:	None
//
//	Returns		:	m_Instance - a pointer to this object
//
//	Comments	:
//
///////////////////////////////////////////////////////////////////////////
CDialNumberSampleDlg* CDialNumberSampleDlg::Instance()
{
	return m_instance;
}

/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	HandleCallback
//
//	Description	:	Caches data from NotificationCallback (therefore freeing the thread)
//					and posts a message for notification handling
//					
//	Arguments	:	[IN]: pNotify - pointer to notification variant
//
//	Returns		:	None
//
//	Comments	:
//
///////////////////////////////////////////////////////////////////////////
void CDialNumberSampleDlg::HandleCallback(SwiNotifyVariant *pNotify)
{

	//used for debugging purposes, displays the notifications received
	TRACE(_T("Got notif %i\n"), pNotify->eNotify);

	// For simplicity, we are allocating a copy of the notification from 
	// the heap. An industrial-strength app would allocate the copy from 
	// a fixed pool of objects to avoid memory fragmentation. 
	SwiNotifyVariant* pCopy = (SwiNotifyVariant*) new SwiNotifyVariant;
	
	if (pCopy)
	{
		*pCopy = *pNotify;
		m_instance->PostMessage(WM_NOTIFICATION, WPARAM(pCopy), NULL ); 
	}

}

/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	ProcessOutgoingCall
//
//	Description	:	Dials the number entered by the user, if no calls in progress
//
//	Arguments	:	not used
//
//	Returns		:	None
//
//	Comments	:	
//
/////////////////////////////////////////////////////////////////////////////
void CDialNumberSampleDlg::ProcessOutgoingCall ()
{
	// define rCode for error handling
	SWI_RCODE rCode;

	//read the data from the screen
	UpdateData(TRUE);

	// User wants to initiate a voice connection, with no existing connection
	if (!m_bIncomingCall && (!m_szDialpadNum.IsEmpty()) && (m_szDialpadNum.GetLength() <= LENGTH_MaxPhone))
	{
		SWI_STRUCT_CALL_Create sCallCreate;

		sCallCreate.sizeStruct    = sizeof(SWI_STRUCT_CALL_Create);
		sCallCreate.eCallRestrict = SWI_CALL_RESTRICT_Default;

		ConvertPhoneNumberToBinary (m_szDialpadNum, sCallCreate.bcdPhone, sCallCreate.nNumberLength, sCallCreate.bInternational);

		// initiate the actual call /w the CallCreate struct
		rCode = SwiSetCallOriginate (&sCallCreate, VALUE_WAIT);
		// check error code, output if operation failed
		if (rCode != SWI_RCODE_OK)
		{
			ProcessError (rCode);
			return;
		}
		else
		{
			// flag m_bCallInProgress boolean to true, indicate call in progress
			m_bCallInProgress = TRUE;
			return;
		} 

		// enable the Send button for subsequent use
		m_btnSend.EnableWindow (TRUE);
	}
	else if (m_szDialpadNum.IsEmpty())
	{
		MessageBox (_T("Dial string is empty"), _T("Input Error"), MB_OK);
		// enable the Send button for subsequent use
		m_btnSend.EnableWindow (TRUE);
	}
	else if (m_szDialpadNum.GetLength() > LENGTH_MaxPhone)
	{
		MessageBox (_T("Dial string is too long"), _T("Input Error"), MB_OK);
		// enable the Send button for subsequent use
		m_btnSend.EnableWindow (TRUE);
	}

	//update the Variables to the Screen
	UpdateData(FALSE);

}

/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	ProcessIncomingCall
//
//	Description	:	Answers incoming call, when the status box indicates 
//					there is an incoming call to the AC
//
//	Arguments	:	not used
//
//	Returns		:	None
//
//	Comments	:	
//
/////////////////////////////////////////////////////////////////////////////
void CDialNumberSampleDlg::ProcessIncomingCall ()
{ 
	// define rCode for error handling
	SWI_RCODE rCode;	

	// create structure used to answer an incoming call
	if (m_bUmts)
		rCode = SetCallControlUmts(m_nIncomingCallID, SWI_CALL_CONTROL_UMTS_RelAllActAccHeldWait);
	else
		rCode = SetCallControl(m_nIncomingCallID, SWI_CALL_CONTROL_Connect);

	// if succeeded, flag booleans, call in progress TRUE, no more incoming call so FALSE
	if (rCode == SWI_RCODE_OK)
	{
		m_bIncomingCall = FALSE;
		m_bCallInProgress = TRUE;
	}
	// check error code, output if operation failed
	else if (rCode != SWI_RCODE_OK)
	{
		ProcessError (rCode);
	}

	// enable the Send button for subsequent use
	m_btnSend.EnableWindow (TRUE);
}

/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	ProcessDisconnecting
//
//	Description	:	The various different cases SWI_TYPE_GSM_CallError can take
//
//	Arguments	:	not used
//
//	Returns		:	None
//
//	Comments	:	
//
/////////////////////////////////////////////////////////////////////////////
void CDialNumberSampleDlg::ProcessDisconnecting (SWI_TYPE_GSM_CallError eCallError)
{
	switch (eCallError)
	{
	case SWI_CALL_ERROR_OK:
		m_bIncomingCall = FALSE;
		m_bCallInProgress = FALSE;
		return;
	case SWI_CALL_ERROR_SubsciberBusy:
		//subscriber busy
		break;
	case SWI_CALL_ERROR_Congestions:
		// congestions
		break;
	case SWI_CALL_ERROR_RadioPathUnavail:   // radio path unavailable
	case SWI_CALL_ERROR_BckgndCallCtrlFail: // background call control failure        
	case SWI_CALL_ERROR_ModifyFail:         // modify failed
	case SWI_CALL_ERROR_NotInControl:       // not in control
	case SWI_CALL_ERROR_Error:
		// general error
		break;
	case SWI_CALL_ERROR_NumberUnobtain:
		// number unobtainable
		break;
	case SWI_CALL_ERROR_AuthFailure:
		// authentication failure
		break;
	case SWI_CALL_ERROR_NoNumber:
		// no number present
		break;
	case SWI_CALL_ERROR_ChannelBusy:
		// channel busy
		break;
	case SWI_CALL_ERROR_FDNMismatch:
		// FDN mismatch
		break;
	case SWI_CALL_ERROR_BCFail:
		// BC fail
		break;
	case SWI_CALL_ERROR_EmergencyOnly:
		// emergency calls only
		break;
	case SWI_CALL_ERROR_ACMExceeded:
		// ACM limit exceeded
		break;
	case SWI_CALL_ERROR_HoldError:
		// hold error
		break;
	case SWI_CALL_ERROR_BusyProcReq:
		// busy processing request
		break;
	case SWI_CALL_ERROR_ChannelUnavail:
		// active channel unavailable
		break;
	case SWI_CALL_ERROR_OutgoingBarred:
		// outgoing calls barred
		break;
	case SWI_CALL_ERROR_NumberBlacklisted:
		// number blacklisted
		break;
	case SWI_CALL_ERROR_BlackListFull:
		// black list full
		break;
	case SWI_CALL_ERROR_RedialNotTimedOut:
		// redial not timed out
		break;
	case SWI_CALL_ERROR_NoCauseCode:
		// no cause code
		break;
	default:
		break;
	}
}

/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	OnDTMFSetting
//
//	Description	:	Calls a dialog to modify user settings for headset volume,
//					ON/OFF DTMF tone durations and earpiece feeback disabling
//					
//	Arguments	:	None
//
//	Returns		:	None
//
//	Comments	:
//
///////////////////////////////////////////////////////////////////////////
void CDialNumberSampleDlg::OnDTMFSetting() 
{
	// traps error code conditions
	SWI_RCODE rCode;
	// create instance of DTMF Settings Dialog box
	DTMFSettings dlgDTMFSettings;

	// if cancel from dlgDTMGSettings was NOT pressed, update member var /w new values
	if (dlgDTMFSettings.DoModal() != ID_CANCEL)
	{
		// get settings the settings dialog
		SWI_STRUCT_NVToneStore	sTones;

		// init structure members
		sTones.sizeStruct = sizeof (SWI_STRUCT_NVToneStore);
		sTones.bEarpieceFeedback = FALSE;
		sTones.eToneLength = SWI_TYPE_ToneLength (3);
		sTones.nUserDefinedToneOnDuration = 0;  
		sTones.nUserDefinedToneOffDuration = 0; 
		sTones.nComfortToneOnDuration = 0;	// between 80 - 500
		sTones.nComfortToneOffDuration = 0;	// between 80 - 500

		// read settings to card
		rCode = SwiGetNVToneStore (&sTones, TIMEOUT);
		// check error code, output if operation failed
		if (rCode != SWI_RCODE_OK)
		{
			ProcessError (rCode);
		}	

		//update member variables /w values read from AirCard
		m_bEarpieceFeedback = sTones.bEarpieceFeedback;
		m_nDTMFOnDuration = sTones.nUserDefinedToneOnDuration;
		m_nDTMFOffDuration = sTones.nUserDefinedToneOffDuration;
	}
}

/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	KeyPress
//
//	Description	:	Processes a key press from the dial pad
//					uses the ASCII value to send a DTMF tone and
//					display key press string to screen
//					
//	Arguments	:	[IN]- DTMFKey - U8 value for DTMF tone
//					[IN]- strKeyPressed - string value of key pressed
//
//	Returns		:	None
//
//	Comments	:
//
///////////////////////////////////////////////////////////////////////////
void CDialNumberSampleDlg::KeyPress(U8 DTMFKey, CString strKeyPressed)
{
	SWI_STRUCT_DTMFSend sDTMFSend;	// structure to store each key's DTMF settings
	SWI_RCODE rCode;	// captures error conditions

	// update from screen
	UpdateData (TRUE);

	// if there is call call in progress, can send DTMF
	if (m_bCallInProgress)
	{
		sDTMFSend.sizeStruct = sizeof (SWI_STRUCT_DTMFSend);
		sDTMFSend.nNumberOfDigits = 1;	// number of DTMF tones to send = 1
		sDTMFSend.byDigits[0] = (BYTE)strKeyPressed.GetAt(0);	// the value to echo on DTMF
		sDTMFSend.nToneOnDuration = m_nDTMFOnDuration;	// the duration of the DTMF tone on
		sDTMFSend.nToneOffDuration = m_nDTMFOffDuration;	// the duration of the DTMF tone off
		sDTMFSend.bEarpieceFeedback =  m_bEarpieceFeedback;	// whether earpiece feeback is enabled

		rCode = SwiSetDTMFSend (&sDTMFSend, TIMEOUT);	//send DTMF tone
		// check error code, output if operation failed
		if (SWI_RCODE_OK != rCode)
		{
			ProcessError(rCode);
			// problem /w DTMF tone send, return control to UI
			return;
		}
	}

	// update number input string /w value of key that was pressed
	m_szDialpadNum += strKeyPressed;

	// update data to screen
	UpdateData (FALSE);
}

SWI_RCODE CDialNumberSampleDlg::SetCallControlUmts(UINT nCallID, const SWI_TYPE_UMTS_CallControl& eCallControl)
{
	SWI_STRUCT_CALL_UMTS_Control sCallControl;
	memset (&sCallControl, 0, sizeof(SWI_STRUCT_CALL_UMTS_Control));
	sCallControl.sizeStruct  = sizeof(SWI_STRUCT_CALL_UMTS_Control);
	sCallControl.nVersion	 = 1;
	sCallControl.nCallID     = nCallID;
	sCallControl.eCallAction = eCallControl;

	return SwiSetCallControlUMTS(&sCallControl, TIMEOUT);

};

SWI_RCODE CDialNumberSampleDlg::SetCallControl(UINT nCallID, const SWI_TYPE_CallControl& eCallControl)
{
	SWI_STRUCT_CALL_Control sCallControl;
	memset (&sCallControl, 0, sizeof(SWI_STRUCT_CALL_Control));
	sCallControl.sizeStruct  = sizeof(SWI_STRUCT_CALL_Control);
	sCallControl.nCallID     = nCallID;
	sCallControl.eCallAction = eCallControl;

	// Terminate the call
	return SwiSetCallControlExp(&sCallControl, TIMEOUT);
};

#if defined(_DEVICE_RESOLUTION_AWARE) && !defined(WIN32_PLATFORM_WFSP)
void CDialNumberSampleDlg::OnSize(UINT /*nType*/, int /*cx*/, int /*cy*/)
{
	DRA::RelayoutDialog(
		AfxGetInstanceHandle(), 
		this->m_hWnd, 
		DRA::GetDisplayMode() != DRA::Portrait ? 
		MAKEINTRESOURCE(IDD_DIALNUMBERSAMPLE_DIALOG_WIDE) : 
	MAKEINTRESOURCE(IDD_DIALNUMBERSAMPLE_DIALOG));
}
#endif