/**
 *
 *	Name	:	DialNumberSample.h
 *
 *	Purpose	:	Header file for DialNumberSample Dialog, Dialog will dial/connect
 *				an entered phone number, as well as display the usage of DTMF tones.
 *
 *	History	:	created	July 2, 2003
 *				- initial version
 *
 *	Revision:	1.0
 *
 *	Copyright (c) 2003 Sierra Wireless, Inc. All rights reserved.
 *
 **/

#if !defined(AFX_DialNumberSampleDLG_H__6DDF5F73_EF3F_4F99_BD16_DA82F24772B0__INCLUDED_)
#define AFX_DialNumberSampleDLG_H__6DDF5F73_EF3F_4F99_BD16_DA82F24772B0__INCLUDED_

#include "DTMFSettings.h"

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000


const U32 TIMEOUT = 3000;
const UINT VALUE_WAIT   = 1000;
const U8 ASCII_0 = 0x30;
const U8 ASCII_1 = 0x31;
const U8 ASCII_2 = 0x32;
const U8 ASCII_3 = 0x33;
const U8 ASCII_4 = 0x34;
const U8 ASCII_5 = 0x35;
const U8 ASCII_6 = 0x36;
const U8 ASCII_7 = 0x37;
const U8 ASCII_8 = 0x38;
const U8 ASCII_9 = 0x39;
const U8 ASCII_STAR = 0x2A;
const U8 ASCII_POUND = 0x23;

// user message identifiers for SMS status and SIM full notifications
#define WM_NOTIFICATION WM_USER + 400	//specific notification

/////////////////////////////////////////////////////////////////////////////
// CDialNumberSampleDlg dialog

class CDialNumberSampleDlg : public CDialog
{
// Construction
public:
	CDialNumberSampleDlg(CWnd* pParent = NULL);	// standard constructor

// Dialog Data
	//{{AFX_DATA(CDialNumberSampleDlg)
	enum { IDD = IDD_DIALNUMBERSAMPLE_DIALOG };
	CStatic	m_ctrHeadset;
	CButton	m_btnDTMFSettings;
	CButton	m_btnSend;
	CButton	m_btnEnd;
	CButton	m_btnClear;
	CButton	m_btnStar;
	CButton	m_btnPound;
	CButton	m_btn9;
	CButton	m_btn8;
	CButton	m_btn7;
	CButton	m_btn6;
	CButton	m_btn5;
	CButton	m_btn4;
	CButton	m_btn3;
	CButton	m_btn2;
	CButton	m_btn1;
	CButton	m_btn0;
	CButton	m_btnOK;
	CString	m_szDialpadNum;	// holds dial string
	CString	m_strCallStatus;
	//}}AFX_DATA

	// ClassWizard generated virtual function overrides
	//{{AFX_VIRTUAL(CDialNumberSampleDlg)
	protected:
	virtual void DoDataExchange(CDataExchange* pDX);	// DDX/DDV support
	//}}AFX_VIRTUAL

// Implementation
public:
	static CDialNumberSampleDlg* Instance();	// returns a pointer to this object
	void ProcessError(SWI_RCODE code);	// processes API error codes
	LRESULT OnNotification(WPARAM wParam, LPARAM lParam);	// handles notifications recieved
	void HandleCallback (SwiNotifyVariant* pNotify);	// caches data data from callbacks, avoid congestion

private:
	static CDialNumberSampleDlg* m_instance;	//a pointer back to this object
	BOOL m_bUmts;

protected:
	void KeyPress (U8 DTMFKey, CString strKeyPressed);
	UINT m_nDTMFOnDuration;
	UINT m_nDTMFOffDuration;
	bool m_bEarpieceFeedback;
	HICON m_hIcon;

	bool m_bConnected;	// bool to indicate modem connection
	bool m_bCallInProgress;	// boolean to indicate whether a call is in progress
	bool m_bIncomingCall;	// bool to indicate incoming call
	UINT m_nOutgoingCallID;	// stores outgoing call ID
    UINT m_nIncomingCallID;	// stores incoming call ID

	SWI_STRUCT_CALL_EXP_Progress m_CurCallProgress;

	BOOL ConnectModem();// Connects to the modem/API
	BOOL DisconnectModem();	//Disconnects from the modem/API
	void ConvertPhoneNumberToBinary (CString &strNumber,  BYTE *pBuffer, unsigned long &nPhoneNumberLength, bool &bInternaional);	// convert number
	void ProcessIncomingCall ();	// dials out
	void ProcessOutgoingCall ();	// receive incoming call
	void ProcessDisconnecting (SWI_TYPE_GSM_CallError eCallError);	// process disconnection messages
	SWI_TYPE_Device GetHighestPriorityDeviceType();
	SWI_RCODE SetCallControlUmts(UINT nCallID, const SWI_TYPE_UMTS_CallControl& eCallControl);
	SWI_RCODE SetCallControl(UINT nCallID, const SWI_TYPE_CallControl& eCallControl);


	// Generated message map functions
	//{{AFX_MSG(CDialNumberSampleDlg)
	virtual BOOL OnInitDialog();
	afx_msg HCURSOR OnQueryDragIcon();
	afx_msg void OnOK();
	afx_msg void OnSend();
	afx_msg void OnEnd();
	afx_msg void OnClear();
	afx_msg void OnButton1();
	afx_msg void OnButton2();
	afx_msg void OnButton3();
	afx_msg void OnButton4();
	afx_msg void OnButton5();
	afx_msg void OnButton6();
	afx_msg void OnButton7();
	afx_msg void OnButton8();
	afx_msg void OnButton9();
	afx_msg void OnButtonStar();
	afx_msg void OnButton0();
	afx_msg void OnButtonPound();
	afx_msg void OnDTMFSetting();
#if defined(_DEVICE_RESOLUTION_AWARE) && !defined(WIN32_PLATFORM_WFSP)
	afx_msg void OnSize(UINT /*nType*/, int /*cx*/, int /*cy*/);
#endif
	//}}AFX_MSG
	DECLARE_MESSAGE_MAP()
};

//{{AFX_INSERT_LOCATION}}
// Microsoft Visual C++ will insert additional declarations immediately before the previous line.

#endif // !defined(AFX_DialNumberSampleDLG_H__6DDF5F73_EF3F_4F99_BD16_DA82F24772B0__INCLUDED_)
