/**
 *
 *	Name	:	MultipartyCallSampleDlg.cpp
 *
 *	Purpose	:	main implementation file for the MultipartyCallSample application
 *				This application demonstrates how to do the following:
 *				1) Reject an incomming call (send caller to voicemail/busy signal immediately).
 *				2) Put a call on hold/activate a call on hold.
 *				3) Handle a call waiting. 
 *				4) Initiate a multiparty call/break away from a multiparty call
 *
 *				Note: To keep this application simple, this application only handles 
 *					  two callers (ie. in a multiparty call, the maximum number of
 *					  parties participating will be three)
 *
 *	History	:	Created July 6th, 2003
 *
 *	Revision:	1.0
 *
 *	Copyright (c) 2003 Sierra Wireless, Inc. All rights reserved.
 *
 **/


#include "stdafx.h"
#include "MultipartyCallSample.h"
#include "MultipartyCallSampleDlg.h"

#ifdef _DEBUG
#define new DEBUG_NEW
#undef THIS_FILE
static char THIS_FILE[] = __FILE__;
#endif

enum SWI_TYPE_CallInfo
{
	SWI_CALL_STATE_Held             = 1, 
	SWI_CALL_STATE_MultiParty       = 2, 
	SWI_CALL_STATE_RemoteOnHold     = 4,
	SWI_CALL_STATE_RemoteMultiParty = 8,  
	SWI_CALL_STATE_Suspended        = 16, 
	SWI_CALL_STATE_HostOriginated   = 32 
};

CMultipartyCallSampleDlg*	CMultipartyCallSampleDlg::m_instance = NULL; //initializing pointer to this object to NULL

/////////////////////////////////////////////////////////////////////////////
// CMultipartyCallSampleDlg dialog

CMultipartyCallSampleDlg::CMultipartyCallSampleDlg(CWnd* pParent /*=NULL*/)
	: CDialog(CMultipartyCallSampleDlg::IDD, pParent)
{
	m_strPhoneNumber = _T("");
	m_strStatusIndicator = _T("");
	m_instance = this;
	m_nCallID1 = 0;
	m_nCallID2 = 0;
	m_bUmts = TRUE;
	m_hIcon = AfxGetApp()->LoadIcon(IDR_MAINFRAME);
}

void CMultipartyCallSampleDlg::DoDataExchange(CDataExchange* pDX)
{
	CDialog::DoDataExchange(pDX);
	//{{AFX_DATA_MAP(CMultipartyCallSampleDlg)
	DDX_Control(pDX, IDC_STATIC_CALL2FLAG, m_btnCall2Flag);
	DDX_Control(pDX, IDC_STATIC_CALL1FLAG, m_btnCall1Flag);
	DDX_Control(pDX, IDOK, m_btnOK);
	DDX_Text(pDX, IDC_EDT_PHONENUM, m_strPhoneNumber);
	DDX_Text(pDX, IDC_STATUS, m_strStatusIndicator);
	//}}AFX_DATA_MAP
}

BEGIN_MESSAGE_MAP(CMultipartyCallSampleDlg, CDialog)
	ON_BN_CLICKED(IDC_BTN_SEND, OnSendCall)
	ON_BN_CLICKED(IDC_BTN_END1, OnEndCall1)
	ON_BN_CLICKED(IDC_BTN_END2, OnEndCall2)
	ON_BN_CLICKED(IDC_BTN_HOLD1, OnHoldCall1)
	ON_BN_CLICKED(IDC_BTN_HOLD2, OnHoldCall2)
	ON_BN_CLICKED(IDC_BTN_LINK1, OnLinkCall1)
	ON_BN_CLICKED(IDC_BTN_LINK2, OnLinkCall2)
	ON_BN_CLICKED(IDC_BTN_REJECT, OnRejectCall)
	ON_BN_CLICKED(IDC_BTN_ENDALL, OnEndAllCalls)
#if defined(_DEVICE_RESOLUTION_AWARE) && !defined(WIN32_PLATFORM_WFSP)
	ON_WM_SIZE()
#endif
	ON_MESSAGE(WM_NOTIFICATION, OnNotification)
END_MESSAGE_MAP()

/////////////////////////////////////////////////////////////////////////////
// CMultipartyCallSampleDlg message handlers

BOOL CMultipartyCallSampleDlg::OnInitDialog()
{
	CDialog::OnInitDialog();

	// Set the icon for this dialog.  The framework does this automatically
	//  when the application's main window is not a dialog
	SetIcon(m_hIcon, TRUE);			// Set big icon
	SetIcon(m_hIcon, FALSE);		// Set small icon
	
	// TODO: Add extra initialization here
	
	//initialize variables
	m_bConnected = FALSE;
	m_bCallWaiting = FALSE;
	m_bIncommingCall = FALSE;

	//connect to modem
	if(ConnectModem())
	{
		//No errors, set variables and start modifying GUI
		m_strStatusIndicator = _T("Connected to Modem");
		m_bConnected = TRUE;
		m_iNumActiveCalls = 0;
		GetDlgItem(IDC_BTN_END1)->EnableWindow(FALSE);
		GetDlgItem(IDC_BTN_END2)->EnableWindow(FALSE);
		GetDlgItem(IDC_BTN_HOLD1)->EnableWindow(FALSE);
		GetDlgItem(IDC_BTN_HOLD2)->EnableWindow(FALSE);
		GetDlgItem(IDC_BTN_LINK1)->EnableWindow(FALSE);
		GetDlgItem(IDC_BTN_LINK2)->EnableWindow(FALSE);
		m_btnCall1Flag.EnableWindow(FALSE);
		m_btnCall2Flag.EnableWindow(FALSE);

	}
	else
	{
		//close app if connection is unsuccessful
		OnOK();
	}

	//update values to screen
	UpdateData(FALSE);

	return TRUE;  // return TRUE  unless you set the focus to a control
}

/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	OnOK
//
//	Description	:	OK button has been pressed to exit the application
//
//	Arguments	:	None
//
//	Returns		:	None
//
//	Comments	:
//
///////////////////////////////////////////////////////////////////////////
void CMultipartyCallSampleDlg::OnOK() 
{
	//disabling connection button for duration of disconnection
	m_btnOK.EnableWindow(FALSE);

	//if connected to modem, end all calls before exiting
	if(m_bConnected)
	{
		EndCall(ALLCALLS);
	}

	//disconnect from modem if there is a live connection
	DisconnectModem();
	
	CDialog::OnOK();
}

/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	OnSendCall
//
//	Description	:	Dials the phone number that has been entered or connects to
//					an incomming call
//
//	Arguments	:	None
//
//	Returns		:	None
//
//	Comments	:
//
///////////////////////////////////////////////////////////////////////////
void CMultipartyCallSampleDlg::OnSendCall() 
{
	SWI_RCODE rCode;

	//Disable the Send button, re-enable it when the call has been connected,
	//this will be done in the HandleNotifCallProgress function
	GetDlgItem(IDC_BTN_SEND)->EnableWindow(FALSE);

	//If the number of active calls is equal to the maximum number of calls
	//handled by this application then return an error message
	if(m_iNumActiveCalls == MAXCALLS)
	{
		m_strStatusIndicator = _T("This app only handles 2 active calls.");
		GetDlgItem(IDC_BTN_SEND)->EnableWindow(TRUE);
		UpdateData(FALSE);
		return;
	}

	//Read the data from the screen
	UpdateData(TRUE);

	//Check if there is an incoming call
	if(m_bIncommingCall)
	{
		//Check if there is a call in waiting

		//Connecting to the incoming call
		if (m_bUmts)
			rCode = SetCallControlUmts(0, SWI_CALL_CONTROL_UMTS_HoldAllActAccHeldWait);
		else
		{
			if (m_bCallWaiting)
			{
				//If a call in waiting exists, put all calls on hold before
				//answering this incoming call
				HoldCall(ALLCALLS);
			}
			rCode = SetCallControl(0, SWI_CALL_CONTROL_Connect);
		}

		if (SWI_RCODE_OK != rCode)
		{
			GetDlgItem(IDC_BTN_SEND)->EnableWindow(TRUE);
			ProcessError(rCode);
		}

		//Resetting variables
		m_bIncommingCall = FALSE;
		m_bCallWaiting = FALSE;
	}
	else if (!m_strPhoneNumber.IsEmpty()  && m_strPhoneNumber.GetLength() <= LENGTH_MaxPhone) //Checking if the phone number is empty
	{
		//Create a call create structure to be fed into SwiSetCallOriginate
		SWI_STRUCT_CALL_Create sCallCreate;
	    sCallCreate.sizeStruct    = sizeof(SWI_STRUCT_CALL_Create);
		sCallCreate.eCallRestrict = SWI_CALL_RESTRICT_Default;
    
		//Converting phone number into binary and placing it in call create structure
		ConvertPhoneNumberToBinary(m_strPhoneNumber, sCallCreate.bcdPhone, sCallCreate.nNumberLength, sCallCreate.bInternational);

		rCode = SwiSetCallOriginate (&sCallCreate, TIMEOUT3);
		if (rCode != SWI_RCODE_OK)
		{
			m_strStatusIndicator = _T("Create Call failed.");
			GetDlgItem(IDC_BTN_SEND)->EnableWindow(TRUE);
			ProcessError(rCode);
		}
	}
	else
	{	
		m_strStatusIndicator = _T("Invalid phone number detected");
		GetDlgItem(IDC_BTN_SEND)->EnableWindow(TRUE);
	}

	//update the Variables to the Screen
	UpdateData(FALSE);
}

/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	ConvertPhoneNumberToBinary
//
//	Description	:	Converts a Phone Number from a CString to binary
//
//	Arguments	:	strNumber, pBuffer, nPhoneNumberLength, bInternational
//
//	Returns		:	None
//
//	Comments	:	The converted Phone Number is stored in *pBuffer
//
/////////////////////////////////////////////////////////////////////////////
void CMultipartyCallSampleDlg::ConvertPhoneNumberToBinary (CString &strNumber,  BYTE *pBuffer, unsigned long &nPhoneNumberLength, bool &bInternaional)
{
    //binary (',' = 0x0C '*' = 0x0A '#' = 0x0B '?' = 0x0D '0'-'9')

    TCHAR   tch;
    int     idx = 0; 
    int     iLength = strNumber.GetLength ();

    nPhoneNumberLength = 0;

	//Check if it's an international number
    if (iLength > 0 && strNumber.GetAt (0) == _T('+'))
    {
        bInternaional = true;
        ++idx; //Increment the index
    }
    else
        bInternaional = false;

	//Loop through the phone number until we hit iLength or we hit the maximum length allowed
    for (idx; idx < iLength && idx <= 40; ++idx)
    {
        tch = strNumber.GetAt (idx);
        ++nPhoneNumberLength;

        if (tch >= _T('0') && tch <= _T('9'))
        {
            *pBuffer = tch - _T('0');
			++pBuffer;
        }
		//If the character is not a valid number, it must be one of the following characters,
		//if not, subtract from the length of the phone number and move on
        else
        {
            switch (tch)
            {
            case _T('*'):
                *pBuffer = 0x0A;
				++pBuffer;
                break;
            case _T('#'):
                *pBuffer = 0x0B;
				++pBuffer;
                break;
            case _T(','):
                *pBuffer = 0x0C;
				++pBuffer;
                break;
            case _T('?'):
                *pBuffer = 0x0D;
				++pBuffer;
                break;
            default:
                --nPhoneNumberLength;
                break;
            }
        }
    }
}

SWI_TYPE_Device CMultipartyCallSampleDlg::GetHighestPriorityDeviceType()
{
	SWI_TYPE_Device				eTypeDevice = SWI_DEVICE_None;
	SWI_STRUCT_AirServerList	sAvailDevList;
	SWI_RCODE					rCode;

	//--------------------
	// Connect to ANY device
	//--------------------
	sAvailDevList.sizeStruct = sizeof(SWI_STRUCT_AirServerList);
	rCode = SwiGetAvailAirServers(sAvailDevList);
	if (SWI_RCODE_OK != rCode)
		return eTypeDevice;

	// how many avail devices?
	if (0 == sAvailDevList.nNumber)
		return eTypeDevice;

	return sAvailDevList.AirServers[0].eDevice;
}

/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	ConnectModem
//
//	Description	:	Start a Connection to the Modem
//
//	Arguments	:	None
//
//	Returns		:	TRUE/FALSE to indicate success of connection
//
//	Comments	:
//
///////////////////////////////////////////////////////////////////////////
BOOL CMultipartyCallSampleDlg::ConnectModem() 
{	
	//connect if there is no connection to the modem
	if(m_bConnected == FALSE)
	{
		// if not connected, open the API
		SWI_STRUCT_ApiStartup sOpenParams;
		memset(&sOpenParams, 0, sizeof(SWI_STRUCT_ApiStartup));

		SWI_RCODE rCode = SwiApiStartup(&sOpenParams);
		if(SWI_RCODE_OK != rCode)
		{
			ProcessError(rCode);
			return FALSE;
		}

		// get available device type
		SWI_TYPE_Device eDevice = GetHighestPriorityDeviceType();
		if (eDevice == SWI_DEVICE_None)
			return FALSE;

		DECLARE_MacAny;
		SWI_STRUCT_AirServer sAirServer;
		sAirServer.sizeStruct = sizeof(SWI_STRUCT_AirServer);
		memcpy(sAirServer.ClientMac, MacAny, LENGTH_MacAddress);
		memcpy(sAirServer.ServerMac, MacAny, LENGTH_MacAddress);
		sAirServer.eDevice = eDevice;

		rCode = SwiSelectAirServer(sAirServer);
		if(SWI_RCODE_OK != rCode)
		{
			ProcessError(rCode);
			return FALSE;
		}

		switch (eDevice)
		{
		case SWI_DEVICE_None:
		case SWI_DEVICE_AC710:
		case SWI_DEVICE_AC750:
		case SWI_DEVICE_AC775:
		case SWI_DEVICE_MP750:
		case SWI_DEVICE_MP775:
			m_bUmts = FALSE;
			break;
		default:
			m_bUmts = TRUE;
			break;
		}

		//Register the Callback function
		rCode = SwiRegisterCallback(NotificationCallback, 0xFFFFFFFFFFFFFFFF);
		if(SWI_RCODE_OK != rCode)
		{
			ProcessError(rCode);
			return FALSE;
		}

		//Enable notifications
		rCode = SwiNotify(SWI_NOTIFY_CallProgress, TIMEOUT3);
		if(SWI_RCODE_OK != rCode)
		{
			ProcessError(rCode);
			return FALSE;
		}

		rCode = SwiNotify(SWI_NOTIFY_CallStatus, TIMEOUT3);
		if(SWI_RCODE_OK != rCode)
		{
			ProcessError(rCode);
			return FALSE;
		}

		//Informing modem of host startup state
		//This function attaches the modem to the network
		rCode = SwiSetHostStartup(TRUE, TIMEOUT3*20);
		if(SWI_RCODE_OK != rCode)
		{
			ProcessError(rCode);
			return FALSE;
		}

		return TRUE;
	}

	return FALSE;
}

/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	DisconnectModem
//
//	Description	:	Disconnects from the modem
//
//	Arguments	:	None
//
//	Returns		:	TRUE/FALSE to indicate success or failure of disconnection
//
//	Comments	:
//
///////////////////////////////////////////////////////////////////////////
BOOL CMultipartyCallSampleDlg::DisconnectModem()
{
	SWI_RCODE rCode;

	//disconnect if a connection to the modem exists
	if(m_bConnected == TRUE)
	{
		// Disable notifications
		rCode = SwiStopNotify(SWI_NOTIFY_CallProgress, TIMEOUT3);
		if (SWI_RCODE_OK != rCode)
		{
			ProcessError(rCode);
			return FALSE;
		}

		rCode = SwiStopNotify(SWI_NOTIFY_CallStatus, TIMEOUT3);
		if (SWI_RCODE_OK != rCode)
		{
			ProcessError(rCode);
			return FALSE;
		}

		//detaching modem from network; this has been commented out because
		//it can sometimes take up to 20 seconds to detach from the network,
		//since it is not necessary to detach from the network,
		//it has been commented out for the SDK sample apps.
/*		rCode = SwiSetHostStartup(FALSE, TIMEOUT3*20);
		if(SWI_RCODE_OK != rCode)
		{
			ProcessError(rCode);
			return FALSE;
		}
*/

		//close connection with modem
		rCode = SwiApiShutdown();	
		if (SWI_RCODE_OK != rCode)
		{

			ProcessError(rCode);
			return FALSE;

		}
	}

	return TRUE;
}


/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	HandleCallback
//
//	Description	:	Caches data from NotificationCallback (therefore freeing the thread)
//					and posts a message for notification handling
//					
//	Arguments	:	[IN]: pNotify - pointer to notification variant
//
//	Returns		:	None
//
//	Comments	:
//
///////////////////////////////////////////////////////////////////////////
void CMultipartyCallSampleDlg::HandleCallback(SwiNotifyVariant *pNotify)
{
	//used for debugging purposes, displays the notifications received
	TRACE(_T("Got notif %i\n"), pNotify->eNotify);

	// For simplicity, we are allocating a copy of the notification from 
	// the heap. An industrial-strength app would allocate the copy from 
	// a fixed pool of objects to avoid memory fragmentation. 
	SwiNotifyVariant* pCopy = (SwiNotifyVariant*) new SwiNotifyVariant;
	
	if (pCopy)
	{
		*pCopy = *pNotify;
		m_instance->PostMessage(WM_NOTIFICATION, WPARAM(pCopy), NULL ); 
	}

}


/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	Instance
//
//	Description	:	A static function used to return a pointer to this object
//
//	Arguments	:	None
//
//	Returns		:	m_Instance - a pointer to this object
//
//	Comments	:
//
///////////////////////////////////////////////////////////////////////////
CMultipartyCallSampleDlg* CMultipartyCallSampleDlg::Instance()
{
	return m_instance;
}


/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	OnNotification
//
//	Description	:	Handler for received notifications
//
//	Arguments	:	[IN]: wParam - Contains the notification type
//					[IN]: lParam - Contains the data to be updated
//
//	Returns		:	None
//
//	Comments	:
//
/////////////////////////////////////////////////////////////////////////////
LRESULT CMultipartyCallSampleDlg::OnNotification(WPARAM wParam, LPARAM lParam)
{
	SwiNotifyVariant* pNotify = (SwiNotifyVariant*)wParam;

	switch(pNotify->eNotify) //add notifications here
	{
		case SWI_NOTIFY_CallProgress:
			m_sCallProgress = pNotify->_CallProgress;	
			HandleNotifCallProgress(m_sCallProgress.eCallProgress);
			break;
		case SWI_NOTIFY_CallStatus:
			m_sCallStatus = pNotify->_CallStatus;
			HandleNotifCallStatus(m_sCallStatus);
			break;
		default:
			break;
	}
	delete (SwiNotifyVariant*)wParam;
	return TRUE;
}


/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	NotificationCallback
//
//	Description	:	Callback that receives all event notifications
//
//	Arguments	:	[IN]: pNotify - pointer to notification variant
//
//	Returns		:	None
//
//	Comments	:	Even if no notifications are being processed,
//					this function still needs to be registered and declared
//					for calls to the API to function properly.
//
/////////////////////////////////////////////////////////////////////////////
void NotificationCallback(SwiNotifyVariant *pNotify)
{

	//Create a pointer to this object then send pNotify to 'HandleCallback'
	//to cache the data and then process the notification.  Note that notifications
	//should never be processed in the call back function because it will hold
	//up the thread while other notifications are trying to get in
	CMultipartyCallSampleDlg* pThisObject = CMultipartyCallSampleDlg::Instance();
	pThisObject->HandleCallback(pNotify);
}


/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	ProcessError
//
//	Description	:	Helper function to process error codes
//
//	Arguments	:	[IN]: code - error code from the API
//
//	Returns		:	None
//
//	Comments	:
//
/////////////////////////////////////////////////////////////////////////////
void CMultipartyCallSampleDlg::ProcessError(SWI_RCODE code)
{
	CString strErrorString;

	strErrorString.Format(_T("Internal error - error code: %d"), code);

	MessageBox(strErrorString, _T("API Message"), MB_OK);
}


/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	HandleNotifCallProgress
//
//	Description	:	Handles the SWI_NOTIFY_CallProgress notification
//
//	Arguments	:	[IN]: eCallProgress - SWI_TYPE_CallProgress, indicates the status of a call
//
//	Returns		:	None
//
//	Comments	:
//
/////////////////////////////////////////////////////////////////////////////
void CMultipartyCallSampleDlg::HandleNotifCallProgress(SWI_TYPE_CallProgress eCallProgress)
{
	switch(eCallProgress)
	{
	case SWI_CALL_PROGRESS_Failed: //Call failed
		m_strStatusIndicator.Format(_T("Call Failed."));
        m_strPhoneNumber = _T("");
		GetDlgItem(IDC_BTN_SEND)->EnableWindow(TRUE); //Enable the Send button if a call failed
        break;
    case SWI_CALL_PROGRESS_Connecting: //Call is connecting
		if (m_nCallID1 == 0)
		{
			m_nCallID1 = m_sCallProgress.CallID;
			m_strStatusIndicator = _T("Call 1 Connecting...");
			GetDlgItem(IDC_BTN_END1)->EnableWindow(TRUE);
		}
		else 
		{
			m_nCallID2 = m_sCallProgress.CallID;
			m_strStatusIndicator = _T("Call 2 Connecting...");
			GetDlgItem(IDC_BTN_END2)->EnableWindow(TRUE);
		}
		m_strStatusIndicator = _T("Connecting...");
        break;
    case SWI_CALL_PROGRESS_Queued: //Call is queued
		break;
    case SWI_CALL_PROGRESS_Waiting: //Call is in waiting
		m_strStatusIndicator = _T("waiting...");
		m_bCallWaiting = TRUE;
		m_bIncommingCall = TRUE;
		break;
    case SWI_CALL_PROGRESS_Incoming: //Incomming call
		if (m_nCallID1 == 0)
		{
			m_nCallID1 = m_sCallProgress.CallID;
			m_strStatusIndicator = _T("Call 1 Connecting...");
			GetDlgItem(IDC_BTN_END1)->EnableWindow(TRUE);
		}
		else 
		{
			m_nCallID2 = m_sCallProgress.CallID;
			m_strStatusIndicator = _T("Call 2 Connecting...");
			GetDlgItem(IDC_BTN_END2)->EnableWindow(TRUE);
		}
		m_strStatusIndicator = _T("Incoming call...");
		m_bIncommingCall = TRUE;
        break;
    case SWI_CALL_PROGRESS_Ringing: //Call is ringing
		m_strStatusIndicator = _T("Ringing...");
        break;
    case SWI_CALL_PROGRESS_Connected: //Call is connected
		GetDlgItem(IDC_BTN_SEND)->EnableWindow(TRUE); //Enable the Send button once a call has been connected
		m_strPhoneNumber = _T(""); //Clear the string
		m_iNumActiveCalls++; //Add one to the number of active calls
		if (m_nCallID1 == 0 || m_nCallID1 == m_sCallProgress.CallID)
		{
			m_nCallID1 = m_sCallProgress.CallID;
			m_strStatusIndicator = _T("Call 1 Connected.");
			EnableCallControls(TRUE, CALL1);
		}
		else 
		{
			m_nCallID2 = m_sCallProgress.CallID;
			m_strStatusIndicator = _T("Call 2 Connected.");
			EnableCallControls(TRUE, CALL2);	//Enable the appropriate buttons on the GUI
		}

		//If the number of active calls equal the maximum number of calls this
		//application can handle, disable the send button until a call is disconnected
		if(m_iNumActiveCalls == MAXCALLS) 
		{
			GetDlgItem(IDC_BTN_SEND)->EnableWindow(FALSE);
		}
        break;
    case SWI_CALL_PROGRESS_Disconnecting:		//Call is disconnecting
		m_strStatusIndicator = _T("Call Disconnecting...");
        break;
    case SWI_CALL_PROGRESS_Disconnected:		//Call is disconnected
		if (m_nCallID1 == m_sCallProgress.CallID)
		{
			m_nCallID1 = 0;
			m_strStatusIndicator = _T("Call 1 Disconnected.");
			EnableCallControls(FALSE, CALL1);	//Enable the appropriate buttons on the GUI
		}
		else
		{
			m_nCallID2 = 0;
			m_strStatusIndicator = _T("Call 2 Disconnected.");
			EnableCallControls(FALSE, CALL2); 
		}

		//If the number of active calls is greater than zero, subtract one
		//upon a disconnection
		if(m_iNumActiveCalls > 0)
		{
			m_iNumActiveCalls--;
		}
		GetDlgItem(IDC_BTN_SEND)->EnableWindow(TRUE); //Enable send button
		EnableCallControls(FALSE, m_sCallProgress.CallID); //Enable the appropriate buttons on the GUI
        break;
    default:
        break;
	}

	//update values to screen
	UpdateData(FALSE);
}

/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	OnEndAllCalls
//
//	Description	:	Ends all calls when user presses the 'End All' button
//
//	Arguments	:	None
//
//	Returns		:	None
//
//	Comments	:
//
/////////////////////////////////////////////////////////////////////////////
void CMultipartyCallSampleDlg::OnEndAllCalls() 
{

	//Disable the 'End All' button
	GetDlgItem(IDC_BTN_ENDALL)->EnableWindow(FALSE);

	//Any errors will be caught and handled in 'EndCall'
	EndCall(ALLCALLS);
			
	//Setting the number of active calls to zero
	m_iNumActiveCalls = 0;

	GetDlgItem(IDC_BTN_ENDALL)->EnableWindow(TRUE);

}

/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	EnableCallControls
//
//	Description	:	Enable/disable appropriate buttons on the GUI
//
//	Arguments	:	[IN]: bEnable - Boolean to indicate whether to enable or disable buttons
//					[IN]: iFreeCallID - Integer to 
//
//	Returns		:	None
//
//	Comments	:
//
/////////////////////////////////////////////////////////////////////////////
void CMultipartyCallSampleDlg::EnableCallControls(BOOL bEnable, int iFreeCallID)
{
	switch(iFreeCallID)
	{
	case ALLCALLS:
		break;
	case CALL1:
		GetDlgItem(IDC_BTN_END1)->EnableWindow(bEnable);
		GetDlgItem(IDC_BTN_HOLD1)->EnableWindow(bEnable);
		m_btnCall1Flag.EnableWindow(bEnable);
		if(!bEnable)
		{
			//If bEnable = FALSE, always disable the link button and set the
			//hold button text to "Hold"
			GetDlgItem(IDC_BTN_LINK1)->EnableWindow(FALSE);
			GetDlgItem(IDC_BTN_HOLD1)->SetWindowText(_T("Hold"));
		}
		break;
	case CALL2:
		GetDlgItem(IDC_BTN_END2)->EnableWindow(bEnable);
		GetDlgItem(IDC_BTN_HOLD2)->EnableWindow(bEnable);
		m_btnCall2Flag.EnableWindow(bEnable);
		if(!bEnable)
		{
			//If bEnable = FALSE, always disable the link button and set the
			//hold button text to "Hold"
			GetDlgItem(IDC_BTN_LINK2)->EnableWindow(FALSE);
			GetDlgItem(IDC_BTN_HOLD2)->SetWindowText(_T("Hold"));
		}
		break;
	default:
		break;
	}

}


/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	OnEndCall1
//
//	Description	:	End call one when user presses on the 'End' button
//
//	Arguments	:	None
//
//	Returns		:	None
//
//	Comments	:
//
/////////////////////////////////////////////////////////////////////////////
void CMultipartyCallSampleDlg::OnEndCall1() 
{
	//Any errors will be caught and handled in 'EndCall'
	EndCall(m_nCallID1);

	//Modifying GUI to reflect a disconnected call
	GetDlgItem(IDC_BTN_HOLD1)->SetWindowText(_T("Hold"));
	
}


/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	OnEndCall2
//
//	Description	:	End call two when user presses on the 'End' button
//
//	Arguments	:	None
//
//	Returns		:	None
//
//	Comments	:
//
/////////////////////////////////////////////////////////////////////////////
void CMultipartyCallSampleDlg::OnEndCall2() 
{
	//Any errors will be caught and handled in 'EndCall'
	EndCall(m_nCallID2);

	//Modifying GUI to reflect a disconnected call
	GetDlgItem(IDC_BTN_HOLD2)->SetWindowText(_T("Hold"));

}


/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	EndCall
//
//	Description	:	Ends one or all calls depending on what is passed into the function
//
//	Arguments	:	[IN]: nCallIDtoEnd - U32, indicates which call to end
//
//	Returns		:	None
//
//	Comments	:
//
/////////////////////////////////////////////////////////////////////////////
void CMultipartyCallSampleDlg::EndCall(U32 nCallIDtoEnd)
{
	SWI_RCODE rCode;

	//If ALLCALLS is passed in, disconnect all calls, otherwise,
	//disconnect one call
	if(ALLCALLS == nCallIDtoEnd)
	{
		if (m_bUmts)
			rCode = SetCallControlUmts(0, SWI_CALL_CONTROL_UMTS_DisconnectAll);    
		else
			rCode = SetCallControl(0, SWI_CALL_CONTROL_DisconnectAll);
	}
	else
	{
		if (m_bUmts)
			rCode = SetCallControlUmts(nCallIDtoEnd, SWI_CALL_CONTROL_UMTS_ReleaseCallX);    
		else
			rCode = SetCallControl(nCallIDtoEnd, SWI_CALL_CONTROL_Disconnect);
	}

	if(SWI_RCODE_OK != rCode)
	{
		m_strStatusIndicator = _T("Error occurred while disconnecting");
		ProcessError(rCode);
		UpdateData(FALSE);
	}
}

/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	HoldCall
//
//	Description	:	Places one or all calls on hold
//
//	Arguments	:	[IN]: nCallIDtoHold - indicates which call to place on hold
//
//	Returns		:	None
//
//	Comments	:
//
/////////////////////////////////////////////////////////////////////////////
void CMultipartyCallSampleDlg::HoldCall(U32 nCallIDtoHold)
{
	SWI_RCODE rCode;

	if (m_bUmts == TRUE)
		rCode = SetCallControlUmts(0, SWI_CALL_CONTROL_UMTS_HoldAllActAccHeldWait);
	else
		rCode = SetCallControl(0, SWI_CALL_CONTROL_SwapCall);

	if(SWI_RCODE_OK != rCode)
	{
		m_strStatusIndicator = _T("Error occurred holding call");
		ProcessError(rCode);
		UpdateData(FALSE);
	}
}


/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	OnHoldCall1
//
//	Description	:	Places caller 1 on hold
//
//	Arguments	:	None
//
//	Returns		:	None
//
//	Comments	:
//
/////////////////////////////////////////////////////////////////////////////
void CMultipartyCallSampleDlg::OnHoldCall1() 
{
	//Any errors will be caught and handled in 'HoldCall'
	HoldCall(m_nCallID1);
}

/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	OnHoldCall2
//
//	Description	:	Places caller 2 on hold
//
//	Arguments	:	None
//
//	Returns		:	None
//
//	Comments	:
//
/////////////////////////////////////////////////////////////////////////////
void CMultipartyCallSampleDlg::OnHoldCall2() 
{
	//Any errors will be caught and handled in 'HoldCall'
	HoldCall(m_nCallID2);
}

/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	HandleNotifCallStatus
//
//	Description	:	Handles the SWI_NOTIFY_CallStatus notification
//
//	Arguments	:	[IN]: m_sCallStatus - SWI_STRUCT_CALL_Status
//
//	Returns		:	None
//
//	Comments	:
//
/////////////////////////////////////////////////////////////////////////////
void CMultipartyCallSampleDlg::HandleNotifCallStatus(SWI_STRUCT_CALL_Status m_sCallStatus)
{
	//With every Call Status notification that comes in, search through
	//the array in the structure and act on the call status of each call appropriately
	for(int idx = 0; idx < MAXCALLS; idx++)
	{
		//Check if the call is currently held
		if((m_sCallStatus.CallList[idx].CallInfo & SWI_CALL_STATE_Held) == 1)
		{
			if (m_sCallStatus.CallList[idx].CallID == m_nCallID1)
			{
				//Since the call is held, set the hold button text to 'Activate'
				GetDlgItem(IDC_BTN_HOLD1)->SetWindowText(_T("Activate"));

				//If the number of calls is greater than 1, enable the Link button
				if(m_sCallStatus.nCallSum > 1)
				{
					GetDlgItem(IDC_BTN_LINK1)->EnableWindow(TRUE);

					//If the call is in multiparty, set the Link button text to 'Unlink'
					if(m_sCallStatus.CallList[idx].CallInfo & SWI_CALL_STATE_MultiParty)
					{
						GetDlgItem(IDC_BTN_LINK1)->SetWindowText(_T("Unlink"));
					}
					else
					{
						GetDlgItem(IDC_BTN_LINK1)->SetWindowText(_T("Link"));
					}
					
				}
				else //If the number of calls is equal to or less than 1, disable the Link button
				{
					GetDlgItem(IDC_BTN_LINK1)->EnableWindow(FALSE);
				}
			}
			else
			{
				//Since the call is held, set the hold button text to 'Activate'
				GetDlgItem(IDC_BTN_HOLD2)->SetWindowText(_T("Activate"));

				//If the number of calls is greater than 1, enable the Link button
				if(m_sCallStatus.nCallSum > 1)
				{
					GetDlgItem(IDC_BTN_LINK2)->EnableWindow(TRUE);
	
					//If the call is in multiparty, set the Link button text to 'Unlink'
					if(m_sCallStatus.CallList[idx].CallInfo & SWI_CALL_STATE_MultiParty)
					{
						GetDlgItem(IDC_BTN_LINK2)->SetWindowText(_T("Unlink"));
					}
					else
					{
						GetDlgItem(IDC_BTN_LINK2)->SetWindowText(_T("Link"));
					}
				}
				else //If the number of calls is less than 1, disable the Link button
				{
					GetDlgItem(IDC_BTN_LINK2)->EnableWindow(FALSE);
				}
			}
		} 
		//Check if the call is not being held
		else/* if((m_sCallStatus.CallList[idx].CallInfo & SWI_CALL_STATE_Held) == 0)*/
		{
			if (m_sCallStatus.CallList[idx].CallID == m_nCallID1)
			{
				//Since call is not being held, set Hold button text to 'Hold'
				GetDlgItem(IDC_BTN_HOLD1)->SetWindowText(_T("Hold"));

				//If call is in multiparty, enable link button and set button text
				//to 'Unlink'
				if(m_sCallStatus.CallList[idx].CallInfo & SWI_CALL_STATE_MultiParty)
				{	
					GetDlgItem(IDC_BTN_LINK1)->EnableWindow(TRUE);
					GetDlgItem(IDC_BTN_LINK1)->SetWindowText(_T("Unlink"));
				}
				else
				{
					GetDlgItem(IDC_BTN_LINK1)->EnableWindow(FALSE);
					GetDlgItem(IDC_BTN_LINK1)->SetWindowText(_T("Link"));
				}
			}
			else
			{
				//Since call is not being held, set Hold button text to 'Hold'
				GetDlgItem(IDC_BTN_HOLD2)->SetWindowText(_T("Hold"));

				//If call is in multiparty, enable link button and set button text
				//to 'Unlink'
				if(m_sCallStatus.CallList[idx].CallInfo & SWI_CALL_STATE_MultiParty)
				{	
					GetDlgItem(IDC_BTN_LINK2)->EnableWindow(TRUE);
					GetDlgItem(IDC_BTN_LINK2)->SetWindowText(_T("Unlink"));
				}
				else
				{
					GetDlgItem(IDC_BTN_LINK2)->EnableWindow(FALSE);
					GetDlgItem(IDC_BTN_LINK2)->SetWindowText(_T("Link"));
				}
			}
		}
	}
}


/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	OnLinkCall1
//
//	Description	:	Link/Unlink call 1 into/from a multiparty call
//
//	Arguments	:	None
//
//	Returns		:	None
//
//	Comments	:
//
/////////////////////////////////////////////////////////////////////////////
void CMultipartyCallSampleDlg::OnLinkCall1() 
{
	CString strLinkButtonText;

	GetDlgItem(IDC_BTN_LINK1)->GetWindowText(strLinkButtonText);
	
	if(strLinkButtonText == _T("Link"))
	{
		LinkCall(TRUE, m_nCallID1);
	}
	else
	{
		LinkCall(FALSE, m_nCallID1);
	}	
}


/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	OnLinkCall2
//
//	Description	:	Link/Unlink call 2 into/from a multiparty call
//
//	Arguments	:	None
//
//	Returns		:	None
//
//	Comments	:
//
/////////////////////////////////////////////////////////////////////////////
void CMultipartyCallSampleDlg::OnLinkCall2() 
{
	CString strLinkButtonText;

	GetDlgItem(IDC_BTN_LINK2)->GetWindowText(strLinkButtonText);
	
	if(strLinkButtonText == _T("Link"))
	{
		LinkCall(TRUE, m_nCallID2);
	}
	else
	{
		LinkCall(FALSE, m_nCallID2);
	}	
}

/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	LinkCall
//
//	Description	:	Link/Unlink a call into/from a multiparty call
//
//	Arguments	:	[IN]: nCallIDtoLink - U32, indicates which call to Link/Unlink
//
//	Returns		:	None
//
//	Comments	:
//
/////////////////////////////////////////////////////////////////////////////
void CMultipartyCallSampleDlg::LinkCall(BOOL bLink, U32 nCallIDtoLink)
{
	SWI_RCODE rCode;
	if (m_bUmts == TRUE)
	{
		if (m_sCallStatus.nCallSum == m_sCallStatus.nCallMultiparty)
 			rCode = SetCallControlUmts(nCallIDtoLink, SWI_CALL_CONTROL_UMTS_HoldAllActExceptCallX);
		else
			rCode = SetCallControlUmts(nCallIDtoLink, SWI_CALL_CONTROL_UMTS_AddHeldCall);
	}
	else
	{
		if (m_sCallStatus.nCallSum == m_sCallStatus.nCallMultiparty)
			rCode = SetCallControl(0, SWI_CALL_CONTROL_ActiveOne);
		else
			rCode = SetCallControl(nCallIDtoLink, SWI_CALL_CONTROL_ActiveAll);
	}

	if(rCode != SWI_RCODE_OK)
	{
		m_strStatusIndicator = _T("Error occurred linking call");
		ProcessError(rCode);
		UpdateData(FALSE);
	}
}

/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	OnRejectCall
//
//	Description	:	Sends an incomming call immediately to voicemail/busy signal
//
//	Arguments	:	None
//
//	Returns		:	None
//
//	Comments	:
//
/////////////////////////////////////////////////////////////////////////////
void CMultipartyCallSampleDlg::OnRejectCall() 
{
	if (m_bIncommingCall && m_sCallStatus.nCallSum != 0)
	{
		SWI_RCODE rCode = SwiSetUserdefinedUserBusy(TIMEOUT3);
		if(SWI_RCODE_OK != rCode)
		{
			m_strStatusIndicator = _T("Error occurred rejecting call");
			ProcessError(rCode);
			UpdateData(FALSE);
		}	
	}
}

SWI_RCODE CMultipartyCallSampleDlg::SetCallControlUmts(UINT nCallID, const SWI_TYPE_UMTS_CallControl& eCallControl)
{
	SWI_STRUCT_CALL_UMTS_Control sCallControl;
	memset (&sCallControl, 0, sizeof(SWI_STRUCT_CALL_UMTS_Control));
	sCallControl.sizeStruct  = sizeof(SWI_STRUCT_CALL_UMTS_Control);
	sCallControl.nVersion	 = 1;
	sCallControl.nCallID     = nCallID;
	sCallControl.eCallAction = eCallControl;

	return SwiSetCallControlUMTS(&sCallControl, TIMEOUT3);

};

SWI_RCODE CMultipartyCallSampleDlg::SetCallControl(UINT nCallID, const SWI_TYPE_CallControl& eCallControl)
{
	SWI_STRUCT_CALL_Control sCallControl;
	memset (&sCallControl, 0, sizeof(SWI_STRUCT_CALL_Control));
	sCallControl.sizeStruct  = sizeof(SWI_STRUCT_CALL_Control);
	sCallControl.nCallID     = nCallID;
	sCallControl.eCallAction = eCallControl;

	// Terminate the call
	return SwiSetCallControlExp(&sCallControl, TIMEOUT3);
};

#if defined(_DEVICE_RESOLUTION_AWARE) && !defined(WIN32_PLATFORM_WFSP)
void CMultipartyCallSampleDlg::OnSize(UINT /*nType*/, int /*cx*/, int /*cy*/)
{
	DRA::RelayoutDialog(
		AfxGetInstanceHandle(), 
		this->m_hWnd, 
		DRA::GetDisplayMode() != DRA::Portrait ? 
		MAKEINTRESOURCE(IDD_MULTIPARTYCALLSAMPLE_DIALOG_WIDE) : 
	MAKEINTRESOURCE(IDD_MULTIPARTYCALLSAMPLE_DIALOG));
}
#endif
