/**
 *
 *	Name	:	MultipartyCallSampleDlg.h
 *
 *	Purpose	:	main implementation file for the MultipartyCallSample application
 *				This application demonstrates how to do the following:
 *				1) Reject an incomming call (send caller to voicemail/busy signal immediately).
 *				2) Put a call on hold/activate a call on hold.
 *				3) Handle a call waiting. 
 *				4) Initiate a multiparty call/break away from a multiparty call
 *
 *				Note: To keep this application simple, this application only handles 
 *					  two callers (ie. in a multiparty call, the maximum number of
 *					  parties participating will be three)
 *
 *	History	:	Created July 6th, 2003
 *
 *	Revision:	1.0
 *
 *	Copyright (c) 2003 Sierra Wireless, Inc. All rights reserved.
 *
 **/


#if !defined(AFX_MULTIPARTYCALLSAMPLEDLG_H__F529F7A1_A925_4D82_8F4A_4919DF102C31__INCLUDED_)
#define AFX_MULTIPARTYCALLSAMPLEDLG_H__F529F7A1_A925_4D82_8F4A_4919DF102C31__INCLUDED_

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000

#include "SwiDataTypes.h"
#include "SwiApiCm.h"
#include "SwiApiGsm.h"

#define TIMEOUT3 3000
#define TIMEOUT1 1000

#define MAXCALLS 2 //The maximum number of calls handled by this app
#define MAXPHONENUMLENGTH 20 //maximum number of characters in a phone number

// user defined windows message identifier for notifications
#define WM_NOTIFICATION WM_USER + 400

/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	NotificationCallback
//
//	Description	:	Callback that receives all event notifications
//
//	Arguments	:	[IN]: pNotify - pointer to notification variant
//
//	Returns		:	None
//
//	Comments	:	Even if no notifications are being processed,
//					this function still needs to be registered and declared
//					for calls to the API to function properly.
//
/////////////////////////////////////////////////////////////////////////////
void NotificationCallback(SwiNotifyVariant *pNotify);

/////////////////////////////////////////////////////////////////////////////
// CMultipartyCallSampleDlg dialog

class CMultipartyCallSampleDlg : public CDialog
{
// Construction
public:
	CMultipartyCallSampleDlg(CWnd* pParent = NULL);	// standard constructor
	void HandleCallback(SwiNotifyVariant *pNotify); //caches data from notification callback
	static CMultipartyCallSampleDlg* Instance(); //returns a pointer to this object

// Dialog Data
	//{{AFX_DATA(CMultipartyCallSampleDlg)
	enum { IDD = IDD_MULTIPARTYCALLSAMPLE_DIALOG };
	CButton	m_btnCall2Flag;
	CButton	m_btnCall1Flag;
	CButton	m_btnOK;
	CString	m_strPhoneNumber;
	CString	m_strStatusIndicator;
	//}}AFX_DATA

	// ClassWizard generated virtual function overrides
	//{{AFX_VIRTUAL(CMultipartyCallSampleDlg)
	protected:
	virtual void DoDataExchange(CDataExchange* pDX);	// DDX/DDV support
	//}}AFX_VIRTUAL

// Implementation
protected:
	//function used to convert a phone number into binary
	void ConvertPhoneNumberToBinary (CString &strNumber,  BYTE *pBuffer, unsigned long &nPhoneNumberLength, bool &bInternaional);

	LRESULT OnNotification(WPARAM wParam, LPARAM lParam); //Deals with notifications from the modem
	void ProcessError(SWI_RCODE code); //handle error codes from the API
	void HandleNotifCallProgress(SWI_TYPE_CallProgress eCallProgress); //handles the SWI_NOTIFY_CallProgress notification
	void HandleNotifCallStatus(SWI_STRUCT_CALL_Status m_sCallStatus); //handles the SWI_NOTIFY_CallStatus notification
	void EnableCallControls(BOOL bEnable, int iFreeCallID); //used to enable the appropriate buttons & flags on the GUI
	void EndCall(U32 nCallIDtoEnd); //ends one or all calls
	void HoldCall(U32 nCallIDtoHold); //puts one or all calls on hold
	void LinkCall(BOOL bLink, U32 nCallIDtoLink); //link calls into a multiparty call
	BOOL ConnectModem(); //connects to modem
	BOOL DisconnectModem(); //disconnects from modem
	SWI_TYPE_Device GetHighestPriorityDeviceType();
	SWI_RCODE SetCallControlUmts(UINT nCallID, const SWI_TYPE_UMTS_CallControl& eCallControl);
	SWI_RCODE SetCallControl(UINT nCallID, const SWI_TYPE_CallControl& eCallControl);

private:
	static CMultipartyCallSampleDlg* m_instance; //a pointer to this object
	BOOL m_bUmts;

protected:
	HICON m_hIcon;
	BOOL m_bConnected;	// boolean indicator to check if application is connected to API
	int m_iNumActiveCalls; //indicates the number of active calls
	BOOL m_bIncommingCall; //indicates if there is an incomming call
	BOOL m_bCallWaiting; //indicates if there is a call in waiting
	UINT m_nCallID1;
	UINT m_nCallID2;

	SWI_STRUCT_CALL_EXP_Progress m_sCallProgress; //stores a SWI_STRUCT_CALL_EXP_Progress structure
	SWI_STRUCT_CALL_Status m_sCallStatus; //stores a SWI_STRUCT_CALL_Status structure

	enum{ //enumerations used to track different Calls
		ALLCALLS,
		CALL1,
		CALL2
	};

	// Generated message map functions
	//{{AFX_MSG(CMultipartyCallSampleDlg)
	virtual BOOL OnInitDialog();
	afx_msg HCURSOR OnQueryDragIcon();
	virtual void OnOK();
	afx_msg void OnSendCall();
	afx_msg void OnEndCall1();
	afx_msg void OnEndCall2();
	afx_msg void OnHoldCall1();
	afx_msg void OnHoldCall2();
	afx_msg void OnLinkCall1();
	afx_msg void OnLinkCall2();
	afx_msg void OnRejectCall();
	afx_msg void OnEndAllCalls();
#if defined(_DEVICE_RESOLUTION_AWARE) && !defined(WIN32_PLATFORM_WFSP)
	afx_msg void OnSize(UINT /*nType*/, int /*cx*/, int /*cy*/);
#endif
	//}}AFX_MSG
	DECLARE_MESSAGE_MAP()
};

//{{AFX_INSERT_LOCATION}}
// Microsoft Visual C++ will insert additional declarations immediately before the previous line.

#endif // !defined(AFX_MULTIPARTYCALLSAMPLEDLG_H__F529F7A1_A925_4D82_8F4A_4919DF102C31__INCLUDED_)
