/**
 *
 *	Name	:	PLMNSelectSampleDlg.cpp
 *
 *	Purpose	:	main implementation file for the PLMNSelectSample application
 *
 *	History	:	Created June 11th, 2003
 *				This sample app demonstrates how to search for and switch to
 *				different PLMNs supported by the Aircard
 *
 *	Revision:	1.0
 *
 *	Copyright (c) 2003 Sierra Wireless, Inc. All rights reserved.
 *
 **/

#include "stdafx.h"
#include "PLMNSelectSample.h"
#include "PLMNSelectSampleDlg.h"
#include "SwiApiGsm.h"

#ifdef _DEBUG
#define new DEBUG_NEW
#undef THIS_FILE
static char THIS_FILE[] = __FILE__;
#endif

CPLMNSelectSampleDlg* CPLMNSelectSampleDlg::m_instance = NULL; //initializing pointer to this object to NULL

/////////////////////////////////////////////////////////////////////////////
// CPLMNSelectSampleDlg dialog

CPLMNSelectSampleDlg::CPLMNSelectSampleDlg(CWnd* pParent /*=NULL*/)
	: CDialog(CPLMNSelectSampleDlg::IDD, pParent)
{
	//{{AFX_DATA_INIT(CPLMNSelectSampleDlg)
	m_strStatusIndicator = _T("");
	m_strCurrentMode = _T("");
	m_instance = this;
	//}}AFX_DATA_INIT
	// Note that LoadIcon does not require a subsequent DestroyIcon in Win32
	m_hIcon = AfxGetApp()->LoadIcon(IDR_MAINFRAME);
}

void CPLMNSelectSampleDlg::DoDataExchange(CDataExchange* pDX)
{
	CDialog::DoDataExchange(pDX);
	//{{AFX_DATA_MAP(CPLMNSelectSampleDlg)
	DDX_Control(pDX, IDC_BTN_CONNECT, m_btnConnect);
	DDX_Control(pDX, IDC_BTN_SEARCH, m_btnSearchPlmn);
	DDX_Control(pDX, IDOK, m_btnOK);
	DDX_Control(pDX, IDC_PLMNLIST, m_lstPlmn);
	DDX_Control(pDX, IDC_BTN_SET, m_btnSetPlmn);
	DDX_Text(pDX, IDC_STATUS, m_strStatusIndicator);
	DDX_Text(pDX, IDC_CURRENTMODE, m_strCurrentMode);
	//}}AFX_DATA_MAP
}

BEGIN_MESSAGE_MAP(CPLMNSelectSampleDlg, CDialog)
	//{{AFX_MSG_MAP(CPLMNSelectSampleDlg)
	ON_WM_QUERYDRAGICON()
	ON_BN_CLICKED(IDC_BTN_SET, OnSetPlmn)
	ON_BN_CLICKED(IDC_BTN_SEARCH, OnSearchPlmns)
	ON_BN_CLICKED(IDC_BTN_CONNECT, OnBtnConnect)
	//}}AFX_MSG_MAP
	ON_MESSAGE(WM_NOTIFICATION, OnNotification)
END_MESSAGE_MAP()

/////////////////////////////////////////////////////////////////////////////
// CPLMNSelectSampleDlg message handlers

BOOL CPLMNSelectSampleDlg::OnInitDialog()
{
	CDialog::OnInitDialog();

	// Set the icon for this dialog.  The framework does this automatically
	//  when the application's main window is not a dialog
	SetIcon(m_hIcon, TRUE);			// Set big icon
	SetIcon(m_hIcon, FALSE);		// Set small icon
	

	//initialize connection state variable
	m_bConnected = FALSE;

	//Creating a column in the List Control
	CString strLabel;
	strLabel = _T("Available PLMNs");
	m_lstPlmn.InsertColumn(0, strLabel, LVCFMT_LEFT, 224);

	m_strStatusIndicator = _T("Disconnected from device");
	m_btnSearchPlmn.EnableWindow(FALSE);
	m_btnSetPlmn.EnableWindow(FALSE);

	//update values to screen
	UpdateData(FALSE);

	return TRUE;  // return TRUE  unless you set the focus to a control
}

SWI_TYPE_Device CPLMNSelectSampleDlg::GetHighestPriorityDeviceType ()
{
	SWI_TYPE_Device				eTypeDevice = SWI_DEVICE_None;
	SWI_STRUCT_AirServerList	sAvailDevList;
	SWI_RCODE					rCode;

	//--------------------
	// Connect to ANY device
	//--------------------
	sAvailDevList.sizeStruct = sizeof(SWI_STRUCT_AirServerList);
	rCode = SwiGetAvailAirServers(sAvailDevList);
	if (SWI_RCODE_OK != rCode)
	{
		m_strStatusIndicator =  _T("GetAvailDev() Failed");
		return eTypeDevice;
	}

	// how many avail devices?
	if (0 == sAvailDevList.nNumber)
	{
		m_strStatusIndicator = _T("No available devices");
		return eTypeDevice;
	}

	return sAvailDevList.AirServers[0].eDevice;
}

// The system calls this to obtain the cursor to display while the user drags
//  the minimized window.
HCURSOR CPLMNSelectSampleDlg::OnQueryDragIcon()
{
	return (HCURSOR) m_hIcon;
}


/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	NotificationCallback
//
//	Description	:	Callback that receives all event notifications
//
//	Arguments	:	[IN]: pNotify - pointer to notification variant
//
//	Returns		:	None
//
//	Comments	:	Even if no notifications are being processed,
//					this function still needs to be registered and declared
//					for calls to the API to function properly.
//
/////////////////////////////////////////////////////////////////////////////
void NotificationCallback(SwiNotifyVariant *pNotify)
{
	//Create a pointer to this object then send pNotify to 'HandleCallback'
	//to cache the data and then process the notification.  Note that notifications
	//should never be processed in the call back function because it will hold
	//up the thread while other notifications are trying to get in
	CPLMNSelectSampleDlg* pThisObject = CPLMNSelectSampleDlg::Instance();
	pThisObject->HandleCallback(pNotify);

}


/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	OnNotification
//
//	Description	:	Handler for received notifications
//
//	Arguments	:	[IN]: wParam - Contains the notification type
//					[IN]: lParam - Contains the data to be updated
//
//	Returns		:	None
//
//	Comments	:
//
/////////////////////////////////////////////////////////////////////////////
LRESULT CPLMNSelectSampleDlg::OnNotification(WPARAM wParam, LPARAM lParam)
{
	SwiNotifyVariant* pNotify = (SwiNotifyVariant*)wParam;
	SWI_STRUCT_PlmnMode sPlmnMode;  
	SWI_STRUCT_PlmnReady sPlmnReady;  
	SWI_STRUCT_PlmnAvailable sPlmnAvailable; //stores SWI_STRUCT_PlmnAvailable structure

	switch(pNotify->eNotify)
	{
		case SWI_NOTIFY_PlmnMode: //reports success of a Plmn mode change
			
			sPlmnMode = pNotify->_PlmnMode; 
			if( sPlmnMode.eResult == SWI_PLMNRESULT_Success)
			{
				//Mode change successful
				m_strStatusIndicator = _T("Registered with network.");
				DisplayPlmnMode();
				m_btnSetPlmn.EnableWindow(TRUE);
				m_btnSearchPlmn.EnableWindow(TRUE);

			}
			else if( sPlmnMode.eResult == SWI_PLMNRESULT_InProgress)
			{
				//Change in progress
				m_strStatusIndicator = _T("Network change in progress, please wait.");
				DisplayPlmnMode();
				m_btnSetPlmn.EnableWindow(TRUE);
				m_btnSearchPlmn.EnableWindow(TRUE);

			}
			else if( sPlmnMode.eResult == SWI_PLMNRESULT_InvalidSelection)
			{
				//Invalid selection
				m_strStatusIndicator = _T("Failed to register with network.");
				DisplayPlmnMode();
				m_btnSetPlmn.EnableWindow(TRUE);
				m_btnSearchPlmn.EnableWindow(TRUE);

			}
			else if( sPlmnMode.eResult == SWI_PLMNRESULT_AttemptFailed ||  sPlmnMode.eResult == SWI_PLMNRESULT_GeneralFail ||  sPlmnMode.eResult == SWI_PLMNRESULT_InternalErr)
			{
				//Failed to change Plmn
				m_strStatusIndicator = _T("Failed to set Plmn.");
				DisplayPlmnMode();
				m_btnSetPlmn.EnableWindow(TRUE);
				m_btnSearchPlmn.EnableWindow(TRUE);

			}
			break;
		case SWI_NOTIFY_PlmnAvailable: //reports whether or not a Plmn list is available for extraction
			sPlmnAvailable = pNotify->_PlmnAvailable;
			if(sPlmnAvailable.bAvailable)
			{	
				//Plmns available, proceed to extract the list of networks available
				if(RetrievePlmnList())
				{
					m_strStatusIndicator = _T("Plmn search completed successfully.");
					m_btnSearchPlmn.EnableWindow(TRUE);
					m_btnSetPlmn.EnableWindow(TRUE);
				}
				else
				{
					m_strStatusIndicator = _T("Plmn Search Failed");
					m_btnSearchPlmn.EnableWindow(TRUE);
				}

			}
			else
			{
				//No Plmn list found
				m_strStatusIndicator = _T("Plmn list unavailable.");
				m_btnSearchPlmn.EnableWindow(TRUE);
			}
			break;
		case SWI_NOTIFY_PlmnReady: //reports availability of manual Plmn selection service
			sPlmnReady = pNotify->_PlmnReady;
			if( sPlmnReady.bReady)
			{
				m_strStatusIndicator = _T("PlmnReady received, ready to search for Plmns!");
				DisplayPlmnMode();
			}
			else
			{
				m_strStatusIndicator = _T("Waiting for PlmnReady....");
			}
			break;
		default:
			break;
	}
	delete (SwiNotifyVariant*)wParam;
	//Update values to screen
	UpdateData(FALSE);
	return NULL;

}

/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	ProcessError
//
//	Description	:	Helper function to process error codes
//
//	Arguments	:	[IN]: code - error code from the API
//
//	Returns		:	None
//
//	Comments	:
//
/////////////////////////////////////////////////////////////////////////////
void CPLMNSelectSampleDlg::ProcessError(SWI_RCODE code)
{
	CString strErrorString;

	strErrorString.Format(_T("Internal error - error code: %d"), code);

	MessageBox(strErrorString, _T("API Message"), MB_OK);
}


/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	GetPlmnMode
//
//	Description	:	Get the current Plmn Mode (Automatic or Manual)
//
//	Arguments	:	None
//
//	Returns		:	eCurrentPlmnMode - SWI_TYPE_PLMN_Mode
//
//	Comments	:
//
/////////////////////////////////////////////////////////////////////////////
SWI_TYPE_PLMN_Mode CPLMNSelectSampleDlg::GetPlmnMode()
{
	SWI_RCODE eRcode;
	SWI_TYPE_PLMN_Mode	eCurrentPlmnMode;

	eRcode = SwiGetPLMNMode(&eCurrentPlmnMode, TIMEOUT1);
	ASSERT(SWI_RCODE_OK == eRcode);

	return eCurrentPlmnMode;
}

/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	DisplayPlmnMode
//
//	Description	:	Displays on screen the current Plmn Mode
//
//	Arguments	:	None
//
//	Returns		:	None
//
//	Comments	:
//
/////////////////////////////////////////////////////////////////////////////
void CPLMNSelectSampleDlg::DisplayPlmnMode()
{

	switch(GetPlmnMode())
	{
		case SWI_PLMNMODE_Automatic:
			m_strCurrentMode = _T("Automatic");
			break;
		case SWI_PLMNMODE_Manual:
			m_strCurrentMode = _T("Manual");
			break;
		default:
			m_strCurrentMode = _T("Error occurred");
			break;
	}

	//update value to screen
	UpdateData(FALSE);
}


/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	RetrievePlmnList
//
//	Description	:	Stores Plmns in 'listPlmnStorage' and loads Plmns to screen
//
//	Arguments	:	None
//
//	Returns		:	TRUE/FALSE - indicate success or failure of operation
//
//	Comments	:
//
/////////////////////////////////////////////////////////////////////////////
BOOL CPLMNSelectSampleDlg::RetrievePlmnList()
{

	SWI_RCODE eRcode;
	SWI_STRUCT_PlmnSelection sPlmn;
	CString strPlmn;
	int nIndex = 0;

	// clear current list
	m_lstPlmn.DeleteAllItems();

do{

		sPlmn.sizeStruct = sizeof(SWI_STRUCT_PlmnSelection);
		eRcode = SwiGetPLMNSelection(&sPlmn, TIMEOUT1);
		if (SWI_RCODE_OK == eRcode)
		{
			// add to list
			if (sPlmn.bHome)
			{	
				strPlmn.Format(_T("*%s"), sPlmn.szName);
			}
			else
			{
				strPlmn = sPlmn.szName;
			}
			
			// 3G or 2G ?
			switch (sPlmn.eNetwork)
			{
			case SWI_NETWORK_GSM:
				strPlmn += _T(" (2G)");
				break;

			case SWI_NETWORK_UMTS:
				strPlmn += _T(" (3G)");
				break;
			}

			// load to list control
			m_lstPlmn.InsertItem(nIndex, strPlmn);
			m_lstPlmn.SetItemData(nIndex, nIndex);
			if(nIndex == 0)
			{
				//add to storage list
				m_lstPlmnStorage.AddHead(sPlmn);
			}
			else
			{
				//add to storage list
				m_lstPlmnStorage.AddTail(sPlmn);
			}

			nIndex++;
		}
		else
		{
			return FALSE;
		}

	} 
	while (sPlmn.bMorePlmn); //loop until there are no more Plmns to get

	//Adding the option to switch to Automatic Network Selection at the end of the list
	strPlmn = _T("Automatic Network Selection");
	m_lstPlmn.InsertItem(nIndex, strPlmn);
	m_lstPlmn.SetItemData(nIndex, -1);



	//Update values to screen
	UpdateData(FALSE);

	return TRUE;

}


/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	ConnectModem
//
//	Description	:	Start a Connection to the Modem
//
//	Arguments	:	None
//
//	Returns		:	TRUE/FALSE to indicate success of connection
//
//	Comments	:
//
///////////////////////////////////////////////////////////////////////////
BOOL CPLMNSelectSampleDlg::ConnectModem() 
{	
	SWI_RCODE rCode;
	SWI_TYPE_Device eDevice;
	BOOL bDisconnected; //checks if disconnection was successful

	//connect if there is no connection to the modem
	if(m_bConnected == FALSE)
	{
		//Open a connection with the Modem
		SWI_STRUCT_ApiStartup sOpenParams;
		memset(&sOpenParams, 0, sizeof(SWI_STRUCT_ApiStartup));

		rCode = SwiApiStartup(&sOpenParams);
		if(SWI_RCODE_OK != rCode 
			&& SWI_RCODE_ALREADY_OPEN != rCode) // Bz13170
		{
			ProcessError(rCode);
			return FALSE;
		}

		eDevice = GetHighestPriorityDeviceType ();
		if (eDevice == SWI_DEVICE_None)
		{
			UpdateData(FALSE);
			return FALSE;
		}

		DECLARE_MacAny;
		SWI_STRUCT_AirServer sAirServer;
		sAirServer.sizeStruct = sizeof(SWI_STRUCT_AirServer);
		memcpy(sAirServer.ClientMac, MacAny, LENGTH_MacAddress);
		memcpy(sAirServer.ServerMac, MacAny, LENGTH_MacAddress);
		sAirServer.eDevice = eDevice;

		rCode = SwiSelectAirServer(sAirServer);
		if(SWI_RCODE_OK != rCode)
		{
			ProcessError(rCode);
			return FALSE;
		}

		//Register the Callback function
		rCode = SwiRegisterCallback(NotificationCallback, 0xFFFFFFFFFFFFFFFF);
		if(SWI_RCODE_OK != rCode)
		{
			ProcessError(rCode);
			return FALSE;
		}

		//Informing modem of host startup state
		//This function attaches the modem to the network
		rCode = SwiSetHostStartup(TRUE, TIMEOUT3*20);
		if(SWI_RCODE_OK != rCode)
		{
			ProcessError(rCode);
			return FALSE;
		}

		//Enable notifications
		rCode = SwiNotify(SWI_NOTIFY_PlmnMode, TIMEOUT3);
		if(SWI_RCODE_OK != rCode)
		{

			ProcessError(rCode);
			return FALSE;
		}

		rCode = SwiNotify(SWI_NOTIFY_ModemDisabled, TIMEOUT3);
		if(SWI_RCODE_OK != rCode)
		{
			ProcessError(rCode);
			return FALSE;
		}

		rCode = SwiNotify(SWI_NOTIFY_PlmnAvailable, TIMEOUT3);
		if(SWI_RCODE_OK != rCode)
		{
			ProcessError(rCode);
			return FALSE;
		}

		rCode = SwiNotify(SWI_NOTIFY_PlmnReady, TIMEOUT1);
		if(SWI_RCODE_OK != rCode)
		{
			ProcessError(rCode);
			return FALSE;
		}

		//as we are here there are no errors
		//Initialize member variables and change GUI to reflect a successful connection
		//to the API
		m_bConnected = TRUE;
		m_strStatusIndicator = _T("Connected to device");
		m_btnSearchPlmn.EnableWindow(TRUE);
		m_btnConnect.SetWindowText(_T("Disconnect"));
		m_btnConnect.EnableWindow(TRUE);

		//Update values to screen
		UpdateData(FALSE);
		return TRUE;

	}
	else
	{
		//Disconnect from modem
		bDisconnected = DisconnectModem();

		//checking if disconnection was successful
		if(bDisconnected)
		{
			m_strStatusIndicator = _T("Disconnected from device");
		}
		else
		{
			m_strStatusIndicator = _T("Error occured while disconnecting");
		}

		//reset member variables and modify GUI to reflect a disconnection from the API
		m_bConnected = FALSE;
		m_btnSearchPlmn.EnableWindow(FALSE);
		m_btnSetPlmn.EnableWindow(FALSE);
		m_lstPlmn.DeleteAllItems();
		m_btnConnect.SetWindowText(_T("Connect"));
		m_btnConnect.EnableWindow(TRUE);

		//Updating values to screen
		UpdateData(FALSE);
		return TRUE;
	}

	return FALSE;

}


/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	DisconnectModem
//
//	Description	:	Disconnects from the modem
//
//	Arguments	:	None
//
//	Returns		:	TRUE/FALSE to indicate success or failure of disconnection
//
//	Comments	:
//
///////////////////////////////////////////////////////////////////////////
BOOL CPLMNSelectSampleDlg::DisconnectModem()
{

	SWI_RCODE eRcode;

	//disconnect if a connection to the modem exists
	if(m_bConnected == TRUE)
	{

		// Disable notifications
		eRcode = SwiStopNotify(SWI_NOTIFY_PlmnMode, TIMEOUT3);
		if (SWI_RCODE_OK != eRcode)
		{
			ProcessError(eRcode);
			return FALSE;
		}

		eRcode = SwiStopNotify(SWI_NOTIFY_PlmnAvailable, TIMEOUT3);
		if (SWI_RCODE_OK != eRcode)
		{
			ProcessError(eRcode);
			return FALSE;
		}

		eRcode = SwiStopNotify(SWI_NOTIFY_ModemDisabled, TIMEOUT3);
		if (SWI_RCODE_OK != eRcode)
		{
			ProcessError(eRcode);
			return FALSE;
		}

		eRcode = SwiStopNotify(SWI_NOTIFY_PlmnReady, TIMEOUT1);
		if (SWI_RCODE_OK != eRcode)
		{
			ProcessError(eRcode);
			return FALSE;
		}

		//detaching modem from network; this has been commented out because
		//it can sometimes take up to 20 seconds to detach from the network,
		//since it is not necessary to detach from the network,
		//it has been commented out for the SDK sample apps.
/*		eRcode = SwiSetHostStartup(FALSE, TIMEOUT3*20);
		if(SWI_RCODE_OK != eRcode)
		{
			ProcessError(eRcode);
			return FALSE;
		}
*/

		//close connection with modem
		eRcode = SwiApiShutdown();	
		if (SWI_RCODE_OK != eRcode)
		{
			ProcessError(eRcode);
			return FALSE;

		}

	}

	return TRUE;

}


/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	OnSetPlmn
//
//	Description	:	Sets the Plmn selected from the list control 'm_lstPlmn'
//
//	Arguments	:	None
//
//	Returns		:	None
//
//	Comments	:
//
///////////////////////////////////////////////////////////////////////////
void CPLMNSelectSampleDlg::OnSetPlmn() 
{
	SWI_RCODE eRcode;
	SWI_STRUCT_PlmnSelection sPlmn;
	int nIndex;

	sPlmn.sizeStruct = sizeof(SWI_STRUCT_PlmnSelection);

    int iSelection = m_lstPlmn.GetSelectionMark();
	if(iSelection == -1)
	{
		MessageBox(_T("Please select a PLMN."), NULL, MB_OK);
		return;
	}

	//Extract the selected Plmn from the List Control 
	nIndex = m_lstPlmn.GetItemData(iSelection);
	m_btnSetPlmn.EnableWindow(FALSE);
	m_btnSearchPlmn.EnableWindow(FALSE);

	if(nIndex == -1) 
	{
		//Automatic Network Selection is selected
		sPlmn.eMode = SWI_PLMNMODE_Automatic;
		eRcode = SwiSetPLMNMode(sPlmn, TIMEOUT1);
		if (SWI_RCODE_OK != eRcode)
		{
			m_strStatusIndicator = _T("Failed to change PLMN.");
			ProcessError(eRcode);
			UpdateData(FALSE);
			return;
		}

		m_strStatusIndicator = _T("Setting PLMN, please wait......");
		UpdateData(FALSE);
		return;
	}

	//Manually setting a Plmn
	sPlmn.eMode = SWI_PLMNMODE_Manual;
	sPlmn.nMCC = m_lstPlmnStorage.GetAt(m_lstPlmnStorage.FindIndex(nIndex)).nMCC;
	sPlmn.nMNC = m_lstPlmnStorage.GetAt(m_lstPlmnStorage.FindIndex(nIndex)).nMNC;

	//The SWI_NOTIFY_PlmnMode notification will indicate the result of this request.
	eRcode = SwiSetPLMNMode(sPlmn, TIMEOUT1);
	if (SWI_RCODE_OK != eRcode)
	{
		m_strStatusIndicator = _T("Failed to change PLMN.");
		ProcessError(eRcode);
		UpdateData(FALSE);
		return;
	}

	//Now waiting on SWI_NOTIFY_PlmnMode notification to indicate success or failure of setting Plmn
	m_strStatusIndicator = _T("Setting PLMN, please wait......");

	//Update values to screen
	UpdateData(FALSE);
	return;
	
}


/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	OnSearchPlmns
//
//	Description	:	Start a search for available Plmns
//
//	Arguments	:	None
//
//	Returns		:	None
//
//	Comments	:
//
///////////////////////////////////////////////////////////////////////////
void CPLMNSelectSampleDlg::OnSearchPlmns() 
{

	SWI_RCODE eRcode;

	//The result of the request will be indicated in the SWI_NOTIFY_PlmnAvailable notification.
	eRcode = SwiStartPLMNSearch(TIMEOUT1);
	if (SWI_RCODE_OK != eRcode)
	{
		m_strStatusIndicator = _T("Failed to start Plmn search");
		ProcessError(eRcode);
		UpdateData(FALSE);
		return;
	}

	//modify GUI to reflect a search in progress
	m_strStatusIndicator = _T("Starting Plmn search....");
	m_btnSearchPlmn.EnableWindow(FALSE);
	m_btnSetPlmn.EnableWindow(FALSE);

	//update values to screen
	UpdateData(FALSE);
	
}


/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	OnOK
//
//	Description	:	OK button has been pressed to exit the application
//
//	Arguments	:	None
//
//	Returns		:	None
//
//	Comments	:
//
///////////////////////////////////////////////////////////////////////////
void CPLMNSelectSampleDlg::OnOK() 
{

	//disabling connection button for duration of disconnection
	m_btnOK.EnableWindow(FALSE);

	//disconnect from modem if there is a live connection
	DisconnectModem();
	
	CDialog::OnOK();
}


/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	HandleCallback
//
//	Description	:	Caches data from NotificationCallback (therefore freeing the thread)
//					and posts a message for notification handling
//					
//	Arguments	:	[IN]: pNotify - pointer to notification variant
//
//	Returns		:	None
//
//	Comments	:
//
///////////////////////////////////////////////////////////////////////////
void CPLMNSelectSampleDlg::HandleCallback(SwiNotifyVariant *pNotify)
{

	//used for debugging purposes, displays the notifications received
	TRACE(_T("Got notif %i\n"), pNotify->eNotify);

	// For simplicity, we are allocating a copy of the notification from 
	// the heap. An industrial-strength app would allocate the copy from 
	// a fixed pool of objects to avoid memory fragmentation. 
	SwiNotifyVariant* pCopy = (SwiNotifyVariant*) new SwiNotifyVariant;
	
	if (pCopy)
	{
		*pCopy = *pNotify;
		m_instance->PostMessage(WM_NOTIFICATION, WPARAM(pCopy), NULL ); 
	}


}


/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	Instance
//
//	Description	:	A static function used to return a pointer to this object
//
//	Arguments	:	None
//
//	Returns		:	m_Instance - a pointer to this object
//
//	Comments	:
//
///////////////////////////////////////////////////////////////////////////
CPLMNSelectSampleDlg* CPLMNSelectSampleDlg::Instance()
{
	return m_instance;
}

/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	OnBtnConnect
//
//	Description	:	Connect/Disconnect to/from modem
//
//	Arguments	:	None
//
//	Returns		:	None
//
//	Comments	:
//
///////////////////////////////////////////////////////////////////////////
void CPLMNSelectSampleDlg::OnBtnConnect() 
{
	ConnectModem();	
}
