/**
 *
 *	Name	:	PLMNSelectSampleDlg.h
 *
 *	Purpose	:	main header file for the PLMNSelectSample application
 *
 *	History	:	Created June 11th, 2003
 *				This sample app demonstrates how to search for and switch to
 *				different PLMNs supported by the Aircard
 *
 *	Revision:	1.0
 *
 *	Copyright (c) 2003 Sierra Wireless, Inc. All rights reserved.
 *
 **/


#if !defined(AFX_PLMNSelectSampleDLG_H__F5C8484B_F27F_4280_BB33_D75C5722DE55__INCLUDED_)
#define AFX_PLMNSelectSampleDLG_H__F5C8484B_F27F_4280_BB33_D75C5722DE55__INCLUDED_

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000

#include "SwiStructsGsm.h"
#include "SwiApiCm.h"
#include "Afxtempl.h"

#define TIMEOUT3 3000
#define TIMEOUT1 1000

// user defined windows message identifier for notifications
#define WM_NOTIFICATION WM_USER + 400

/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	NotificationCallback
//
//	Description	:	Callback that receives all event notifications
//
//	Arguments	:	[IN]: pNotify - pointer to notification variant
//
//	Returns		:	None
//
//	Comments	:	Even if no notifications are being processed,
//					this function still needs to be registered and declared
//					for calls to the API to function properly.
//
/////////////////////////////////////////////////////////////////////////////
void NotificationCallback(SwiNotifyVariant *pNotify);

/////////////////////////////////////////////////////////////////////////////
// CPLMNSelectSampleDlg dialog

class CPLMNSelectSampleDlg : public CDialog
{
// Construction
public:
	CPLMNSelectSampleDlg(CWnd* pParent = NULL);	// standard constructor

// Dialog Data
	//{{AFX_DATA(CPLMNSelectSampleDlg)
	enum { IDD = IDD_PLMNSelectSample_DIALOG };
	CButton	m_btnConnect;
	CButton	m_btnSearchPlmn;
	CButton	m_btnOK;
	CListCtrl	m_lstPlmn;
	CButton	m_btnSetPlmn;
	CString	m_strStatusIndicator;
	CString	m_strCurrentMode;
	//}}AFX_DATA

	// ClassWizard generated virtual function overrides
	//{{AFX_VIRTUAL(CPLMNSelectSampleDlg)
	protected:
	virtual void DoDataExchange(CDataExchange* pDX);	// DDX/DDV support
	//}}AFX_VIRTUAL

// Implementation
public:
	LRESULT OnNotification(WPARAM wParam, LPARAM lParam); //handles notifications
	SWI_TYPE_PLMN_Mode GetPlmnMode(); //retrieves the Plmn mode (manual or automatic)
	void DisplayPlmnMode(); //display Plmn mode to screen
	BOOL RetrievePlmnList(); //retrieve & store Plmn list then display it on screen
	BOOL ConnectModem(); //connects to modem
	BOOL DisconnectModem(); //disconnects from modem
	void ProcessError(SWI_RCODE code); //handle error codes from the API
	void HandleCallback(SwiNotifyVariant *pNotify); //caches data from notificaiton callback
	static CPLMNSelectSampleDlg* Instance(); //returns a pointer to this object
	SWI_TYPE_Device GetHighestPriorityDeviceType ();

private:
	static CPLMNSelectSampleDlg* m_instance; //a pointer to this object

protected:
	HICON m_hIcon;

	bool m_bConnected;	// boolean indicator to check if application is connected to API
	CList<SWI_STRUCT_PlmnSelection, SWI_STRUCT_PlmnSelection> m_lstPlmnStorage; //stores available Plmns
	


	enum TYPE_Device
	{
		DEVICE_AC710_750_775_850,
		DEVICE_MC87xx,
	};

	// Generated message map functions
	//{{AFX_MSG(CPLMNSelectSampleDlg)
	virtual BOOL OnInitDialog();
	afx_msg HCURSOR OnQueryDragIcon();
	afx_msg void OnSetPlmn();
	afx_msg void OnSearchPlmns();
	virtual void OnOK();
	afx_msg void OnBtnConnect();
	//}}AFX_MSG
	DECLARE_MESSAGE_MAP()
};

//{{AFX_INSERT_LOCATION}}
// Microsoft Visual C++ will insert additional declarations immediately before the previous line.

#endif // !defined(AFX_PLMNSelectSampleDLG_H__F5C8484B_F27F_4280_BB33_D75C5722DE55__INCLUDED_)
