/**
 *
 *	Name	:	ProfileManipulateSampleDlg.cpp
 *
 *	Purpose	:	main header file for the ProfileManipulateSample application
 *				This sample application demonstrates how to set, delete, 
 *				and activate a Profile.  It also demonstrates how to extract
 *				various types of information from a Profile.  Keep in mind
 *				that this application supports 3 profiles even though there
 *				might be more on the device. All functions dealing with 
 *				profiles are just used to manipulate these 3 Profiles in 
 *				various ways.
 *
 *	History	:	Created June 27, 2003
 *
 *	Revision:	1.0
 *
 *	Copyright (c) 2003 Sierra Wireless, Inc. All rights reserved.
 *
 **/

#include "stdafx.h"
#include "ProfileManipulateSample.h"
#include "ProfileManipulateSampleDlg.h"
#include "SwiApiGsm.h"

#ifdef _DEBUG
#define new DEBUG_NEW
#undef THIS_FILE
static char THIS_FILE[] = __FILE__;
#endif

CProfileManipulateSampleDlg*	CProfileManipulateSampleDlg::m_instance = NULL; //initializing pointer to this object to NULL

/////////////////////////////////////////////////////////////////////////////
// CProfileManipulateSampleDlg dialog

CProfileManipulateSampleDlg::CProfileManipulateSampleDlg(CWnd* pParent /*=NULL*/)
	: CDialog(CProfileManipulateSampleDlg::IDD, pParent)
{
	//{{AFX_DATA_INIT(CProfileManipulateSampleDlg)
	m_strProfileAPN = _T("");
	m_strProfilePassword = _T("");
	m_strProfileUserName = _T("");
	m_strProfileLabel = _T("");
	m_strStatusIndicator = _T("");
	m_instance = this;
	//}}AFX_DATA_INIT
	// Note that LoadIcon does not require a subsequent DestroyIcon in Win32
	m_hIcon = AfxGetApp()->LoadIcon(IDR_MAINFRAME);
}

void CProfileManipulateSampleDlg::DoDataExchange(CDataExchange* pDX)
{
	CDialog::DoDataExchange(pDX);
	//{{AFX_DATA_MAP(CProfileManipulateSampleDlg)
	DDX_Control(pDX, IDC_BTN_CONNECT, m_btnConnect);
	DDX_Control(pDX, IDC_STATIC_ROAMINGYES, m_ctrRoamingYes);
	DDX_Control(pDX, IDC_STATIC_ROAMINGNO, m_ctrRoamingNo);
	DDX_Control(pDX, IDC_STATIC_GPRSAVAIL, m_ctrGPRSAvailFlag);
	DDX_Control(pDX, IDC_FLAG_DEFAULT, m_ctrProfileDefaultFlag);
	DDX_Control(pDX, IDC_FLAG_INACTIVE, m_ctrProfileInactiveFlag);
	DDX_Control(pDX, IDC_FLAG_DELETED, m_ctrProfileDeletedFlag);
	DDX_Control(pDX, IDC_FLAG_ACTIVATED, m_ctrProfileActivatedFlag);
	DDX_Control(pDX, IDC_COMBOPROFILE, m_comboSelectProfile);
	DDX_Control(pDX, IDOK, m_btnOK);
	DDX_Control(pDX, IDC_BTN_DELPROFILE, m_btnDeleteProfile);
	DDX_Control(pDX, IDC_BTN_SETPROFILE, m_btnSetProfile);
	DDX_Control(pDX, IDC_BTN_ACTIVATE, m_btnActivateProfile);
	DDX_Text(pDX, IDC_APN, m_strProfileAPN);
	DDX_Text(pDX, IDC_PASSWORD, m_strProfilePassword);
	DDX_Text(pDX, IDC_USERNAME, m_strProfileUserName);
	DDX_Text(pDX, IDC_PROFILENAME, m_strProfileLabel);
	DDX_Text(pDX, IDC_STATUS, m_strStatusIndicator);
	//}}AFX_DATA_MAP
}

BEGIN_MESSAGE_MAP(CProfileManipulateSampleDlg, CDialog)
	//{{AFX_MSG_MAP(CProfileManipulateSampleDlg)
	ON_WM_QUERYDRAGICON()
	ON_BN_CLICKED(IDC_BTN_ACTIVATE, OnActivateProfile)
	ON_BN_CLICKED(IDC_BTN_DELPROFILE, OnDeleteProfile)
	ON_BN_CLICKED(IDC_BTN_SETPROFILE, OnSetProfileInfo)
	ON_CBN_SELCHANGE(IDC_COMBOPROFILE, OnGetProfileInfo)
	ON_BN_CLICKED(IDC_BTN_CONNECT, OnBtnConnect)
	//}}AFX_MSG_MAP
	ON_MESSAGE(WM_NOTIFICATION, OnNotification) //function to handle all event notifications
END_MESSAGE_MAP()

/////////////////////////////////////////////////////////////////////////////
// CProfileManipulateSampleDlg message handlers

BOOL CProfileManipulateSampleDlg::OnInitDialog()
{
	CDialog::OnInitDialog();

	// Set the icon for this dialog.  The framework does this automatically
	//  when the application's main window is not a dialog
	SetIcon(m_hIcon, TRUE);			// Set big icon
	SetIcon(m_hIcon, FALSE);		// Set small icon
	
	// TODO: Add extra initialization here

	//initializing variables.
	m_bConnected = FALSE;
	m_bFlagAppInitialized = TRUE;
	m_iCurrentProfileIndex = DEFAULTINDEX; //DEFAULTINDEX = -1

	m_strStatusIndicator = _T("Disconnected from device");
	m_comboSelectProfile.SetCurSel(0);
	m_comboSelectProfile.EnableWindow(FALSE);
	m_btnActivateProfile.EnableWindow(FALSE);
	m_btnSetProfile.EnableWindow(FALSE);
	m_btnDeleteProfile.EnableWindow(FALSE);

	//update values to screen
	UpdateData(FALSE);

	return TRUE;  // return TRUE  unless you set the focus to a control
}

SWI_TYPE_Device CProfileManipulateSampleDlg::GetHighestPriorityDeviceType ()
{
	SWI_TYPE_Device				eTypeDevice = SWI_DEVICE_None;
	SWI_STRUCT_AirServerList	sAvailDevList;
	SWI_RCODE					rCode;

	//--------------------
	// Connect to ANY device
	//--------------------
	sAvailDevList.sizeStruct = sizeof(SWI_STRUCT_AirServerList);
	rCode = SwiGetAvailAirServers(sAvailDevList);
	if (SWI_RCODE_OK != rCode)
	{
		m_strStatusIndicator =  _T("GetAvailDev() Failed");
		return eTypeDevice;
	}

	// how many avail devices?
	if (0 == sAvailDevList.nNumber)
	{
		m_strStatusIndicator = _T("No available devices");
		return eTypeDevice;
	}

	return sAvailDevList.AirServers[0].eDevice;
}

// The system calls this to obtain the cursor to display while the user drags
//  the minimized window.
HCURSOR CProfileManipulateSampleDlg::OnQueryDragIcon()
{
	return (HCURSOR) m_hIcon;
}


/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	OnOK
//
//	Description	:	OK button has been pressed to exit the application
//
//	Arguments	:	None
//
//	Returns		:	None
//
//	Comments	:
//
/////////////////////////////////////////////////////////////////////////////
void CProfileManipulateSampleDlg::OnOK() 
{

	//disabling connection button for duration of disconnection
	m_btnOK.EnableWindow(FALSE);

	//disconnect from modem if there is a live connection
	DisconnectModem();

	CDialog::OnOK();
	
}


/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	OnActivateProfile
//
//	Description	:	Activates the currently selected Profile
//
//	Arguments	:	None
//
//	Returns		:	None
//
//	Comments	:
//
/////////////////////////////////////////////////////////////////////////////
void CProfileManipulateSampleDlg::OnActivateProfile() 
{
	U32 nIndex;
	SWI_RCODE eRcode;
	SWI_TYPE_ProfileState eCurrentProfileState;

	//disabling Activate Profile button for duration of operation
	m_btnActivateProfile.EnableWindow(FALSE);

	//retrieve the index of the selected profile
	switch(m_sAirCardType.eAirCard)
	{
		case SWI_AIRCARD_AC710:
		case SWI_AIRCARD_AC750:
		case SWI_AIRCARD_AC775:
			{
				nIndex = m_comboSelectProfile.GetCurSel() - 1;
			}
			break;
		default:
			{
				nIndex = m_comboSelectProfile.GetCurSel();
			}
			break;
	}

	//if index is the default value, this means nothing has been selected
	if (DEFAULTINDEX == nIndex)
	{
		m_strStatusIndicator = _T("Please select a Profile");
		m_btnActivateProfile.EnableWindow(TRUE);
		UpdateData(FALSE);
		return;
	}

	//Setting the current profile variable to keep track of
	//which Profile is currently selected
	m_iCurrentProfileIndex = nIndex;

	//Retrieving the current profile state (active, inactive, deleted)
	if(!GetProfileState(m_iCurrentProfileIndex, &eCurrentProfileState))
	{
		m_strStatusIndicator = _T("Failed to retrieve Profile state");
		m_btnActivateProfile.EnableWindow(TRUE);
		UpdateData(FALSE);
		return;
	}
	
	//If the Current Profile is inactive, activate it
	if(eCurrentProfileState == SWI_PROFILE_STATE_Inactive)
	{

		m_strStatusIndicator = _T("Activating Profile...");

		//disabling Profile selection combo box while Profile is activated,
		//re-enable combo box when user de-activates the Profile
		m_comboSelectProfile.EnableWindow(FALSE);

		//result of request will be received later in the form of a notification
		eRcode = SwiActivateProfile(nIndex, TRUE, TIMEOUT3*10);
		if(SWI_RCODE_OK != eRcode)
		{
			m_btnActivateProfile.EnableWindow(TRUE);
			m_comboSelectProfile.EnableWindow(TRUE);
			ProcessError(eRcode);
			return;
		}

	} //if the current Profile is already activated, de-activate it
	else if(eCurrentProfileState == SWI_PROFILE_STATE_Activated)
	{

		m_strStatusIndicator = _T("Deactivating Profile...");

		//result of request will be received later in the form of a notification
		eRcode = SwiActivateProfile(nIndex, FALSE, TIMEOUT3*10);
		if(SWI_RCODE_OK != eRcode)
		{
			m_btnActivateProfile.EnableWindow(TRUE);
			ProcessError(eRcode);
			return;
		}


	} //if the current Profile is in 'deleted' state, display an error message
	else if(eCurrentProfileState == SWI_PROFILE_STATE_Deleted)
	{
		//error occurred if it gets here
		m_btnActivateProfile.EnableWindow(TRUE);
		m_strStatusIndicator = _T("This Profile is deleted, unable to activate");

	}
	
	//update values to screen
	UpdateData(FALSE);
}


/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	OnDeleteProfile
//
//	Description	:	Sets a Profile to the 'Deleted' state
//
//	Arguments	:	None
//
//	Returns		:	None
//
//	Comments	:	When you 'delete' a profile, it doesn't actually erase it
//					clean from memory.  All it does is set the Profile that you
//					deleted back to default values and set the state of the
//					Profile to the 'deleted' state.  The Aircard supports 3
//					Profiles in total
//
/////////////////////////////////////////////////////////////////////////////
void CProfileManipulateSampleDlg::OnDeleteProfile() 
{

	SWI_RCODE eRcode;
	U32 nIndex;

	//disabling delete button for duration of function call
	m_btnDeleteProfile.EnableWindow(FALSE);

	//retrieve the index of the selected profile
	switch(m_sAirCardType.eAirCard)
	{
		case SWI_AIRCARD_AC710:
		case SWI_AIRCARD_AC750:
		case SWI_AIRCARD_AC775:
			{
				nIndex = m_comboSelectProfile.GetCurSel() - 1;
			}
			break;
		default:
			{
				nIndex = m_comboSelectProfile.GetCurSel();
			}
			break;
	}

	//if index is the default value, this means nothing has been selected
	if (DEFAULTINDEX == nIndex)
	{
		m_strStatusIndicator = _T("Please select a Profile");
		m_btnDeleteProfile.EnableWindow(TRUE);
		UpdateData(FALSE);
		return;
	}

	//update the current profile index to keep track of which Profile is currently selected
	m_iCurrentProfileIndex = nIndex;

	eRcode = SwiEraseProfile(nIndex, TIMEOUT3);
	if (SWI_RCODE_OK != eRcode)
	{
		ProcessError(eRcode);
		m_strStatusIndicator = _T("Failed to delete Profile");
		m_btnDeleteProfile.EnableWindow(TRUE);
		UpdateData(FALSE);
		return;
	}

	//modify GUI to reflect a successful delete operation
	m_strProfileLabel = _T("");
	m_strProfilePassword = _T("");
	m_strProfileUserName = _T("");
	m_strProfileAPN = _T("");
	m_strStatusIndicator = _T("Profile Successfully Deleted");
	m_btnDeleteProfile.EnableWindow(TRUE);

	//update profile state to screen
	if(!UpdateProfileStateToScreen(nIndex))
	{
		m_strStatusIndicator = _T("Failed to update Profile State");
	}

	//Update values to screen
	UpdateData(FALSE);
}

/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	OnSetProfileInfo
//
//	Description	:	Sets information to the currently selected Profile
//
//	Arguments	:	None
//
//	Returns		:	None
//
//	Comments	:	Read the header files to find out what else can be manually set
//					in a Profile.  In this sample application, we decided to use
//					default values generated by the API for most of the fields in a
//					Profile structure.
//
/////////////////////////////////////////////////////////////////////////////
void CProfileManipulateSampleDlg::OnSetProfileInfo() 
{

	SWI_RCODE eRcode;
	SWI_STRUCT_Profile sProfileStruct;
	SWI_STRUCT_GsmProfileBasic sProfileBasic;
	U32 nIndex;

	//disabling the 'Set Profile' button for the duration of this function call
	m_btnSetProfile.EnableWindow(FALSE);
	
	//extract values from screen
	UpdateData(TRUE);

	//getting the index of the selected Profile from the combo box
	switch(m_sAirCardType.eAirCard)
	{
		case SWI_AIRCARD_AC710:
		case SWI_AIRCARD_AC750:
		case SWI_AIRCARD_AC775:
			{
				nIndex = m_comboSelectProfile.GetCurSel() - 1;
			}
			break;
		default:
			{
				nIndex = m_comboSelectProfile.GetCurSel();
			}
			break;
	}

	//if index equals the default value, it means nothing was selected
	if (DEFAULTINDEX == nIndex)
	{
		m_strStatusIndicator = _T("Please select a Profile");
		m_btnSetProfile.EnableWindow(TRUE);
		UpdateData(FALSE);
		return;
	}

	//setting the current profile index to indicate which profile is currently selected
	m_iCurrentProfileIndex = nIndex;

	//every Profile requires a label for it to be a valid profile
	if(m_strProfileLabel.GetLength() == 0)
	{
		MessageBox(_T("Please enter a label"), NULL, MB_OK);
		m_btnSetProfile.EnableWindow(TRUE);
		return;
	}

	//null terminate the entries before saving to the modem
	//m_strProfileLabel = m_strProfileLabel + "\0";
	//m_strProfilePassword = m_strProfilePassword + "\0";
	//m_strProfileUserName = m_strProfileUserName + "\0";
	//m_strProfileAPN = m_strProfileAPN + "\0";
	
	switch(m_sAirCardType.eAirCard)
	{
		case SWI_AIRCARD_AC710:
		case SWI_AIRCARD_AC750:
		case SWI_AIRCARD_AC775:
		{
			memset(&sProfileStruct, 0, sizeof(SWI_STRUCT_Profile));
			sProfileStruct.sizeStruct = sizeof(SWI_STRUCT_Profile);

			//do a Get first so that we can retrieve all the values necessary
			//for a valid Profile
			eRcode = SwiGetProfile(&sProfileStruct, nIndex, TIMEOUT3);
			if (SWI_RCODE_OK != eRcode)
			{
				ProcessError(eRcode);
				m_btnSetProfile.EnableWindow(TRUE);
				return;
			}

			//now set the new information for this Profile
			_tcscpy((TCHAR*)sProfileStruct.szLabel, m_strProfileLabel);
			_tcscpy((TCHAR*)sProfileStruct.szPassword, m_strProfilePassword);
			_tcscpy((TCHAR*)sProfileStruct.szUserName, m_strProfileUserName);
			_tcscpy((TCHAR*)sProfileStruct.szAccessPoint, m_strProfileAPN);
		
			//setting information to selected Profile
			eRcode = SwiSetProfile(&sProfileStruct, nIndex, TIMEOUT3);
			if (SWI_RCODE_OK != eRcode)
			{
				ProcessError(eRcode);
				m_btnSetProfile.EnableWindow(TRUE);
				m_strStatusIndicator = _T("Failed to set Profile information");
				UpdateData(FALSE);
				return;
			}
		}
		break;
		default:
		{
			memset (&sProfileBasic, 0, sizeof(SWI_STRUCT_GsmProfileBasic));
			sProfileBasic.sizeStruct = sizeof(SWI_STRUCT_GsmProfileBasic);
			sProfileBasic.nProfileId = (U8)nIndex;

			eRcode = SwiGetGsmProfileBasic(&sProfileBasic, TIMEOUT3);
			if (SWI_RCODE_OK != eRcode)
			{
				ProcessError(eRcode);
				m_btnSetProfile.EnableWindow(TRUE);
				return;
			}

			//now set the new information for this Profile
			_tcscpy((TCHAR*)sProfileBasic.szLabel, m_strProfileLabel);
			_tcscpy((TCHAR*)sProfileBasic.szPassword, m_strProfilePassword);
			_tcscpy((TCHAR*)sProfileBasic.szUserName, m_strProfileUserName);
			_tcscpy((TCHAR*)sProfileBasic.szAccessPoint, m_strProfileAPN);
			sProfileBasic.bValid = true;
			sProfileBasic.eAuthentication = SWI_PDPAUTHENTICATION_Pap; //default
			sProfileBasic.bAutoActivation = FALSE;
			sProfileBasic.bPromptPassword = FALSE;

			//setting information to selected Profile
			eRcode = SwiSetGsmProfileBasic(sProfileBasic, TIMEOUT3);
			if (SWI_RCODE_OK != eRcode)
			{
				ProcessError(eRcode);
				m_btnSetProfile.EnableWindow(TRUE);
				m_strStatusIndicator = _T("Failed to set Profile information");
				UpdateData(FALSE);
				return;
			}
		}
		break;
	}

	//modify GUI to reflect a successful operation
	m_strStatusIndicator = _T("Profile Set Successfully!");
	m_btnSetProfile.EnableWindow(TRUE);

	//update profile state to screen
	if(!UpdateProfileStateToScreen(nIndex))
	{
		m_strStatusIndicator = _T("Failed to update Profile State");
	}

	//Update values to screen
	UpdateData(FALSE);
}


/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	ProcessError
//
//	Description	:	Helper function to process error codes
//
//	Arguments	:	[IN]: code - error code from the API
//
//	Returns		:	None
//
//	Comments	:
//
/////////////////////////////////////////////////////////////////////////////
void CProfileManipulateSampleDlg::ProcessError(SWI_RCODE code)
{
	CString strErrorString;

	strErrorString.Format(_T("Internal error - error code: %d"), code);

	MessageBox(strErrorString, _T("API Message"), MB_OK);
}


/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	NotificationCallback
//
//	Description	:	Callback that receives all event notifications
//
//	Arguments	:	[IN]: pNotify - pointer to notification variant
//
//	Returns		:	None
//
//	Comments	:	Even if no notifications are being processed,
//					this function still needs to be registered and declared
//					for calls to the API to function properly.
//
/////////////////////////////////////////////////////////////////////////////
void NotificationCallback(SwiNotifyVariant *pNotify)
{
	//Create a pointer to this object then send pNotify to 'HandleCallback'
	//to cache the data and then process the notification.  Note that notifications
	//should never be processed in the call back function because it will hold
	//up the thread while other notifications are trying to get in
	CProfileManipulateSampleDlg* pThisObject = CProfileManipulateSampleDlg::Instance();
	pThisObject->HandleCallback(pNotify);
}


/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	UpdateProfileStateToScreen
//
//	Description	:	Updates the currently selected Profile state to screen
//					(Active, Inactive, Deleted, Default)
//
//	Arguments	:	[IN]: Index - U32 index to indicate which profile to update
//
//	Returns		:	TRUE/FALSE - indicate success or failure of operation
//
//	Comments	:
//
/////////////////////////////////////////////////////////////////////////////
BOOL CProfileManipulateSampleDlg::UpdateProfileStateToScreen(U32 nIndex)
{

	SWI_RCODE eRcode;
	SWI_STRUCT_ProfileSummary sProfileSummary;
	SWI_STRUCT_GsmProfileSummary sGsmProfileSummary;
	U32 nProfileID;
	SWI_TYPE_ProfileState eProfileState;

	//resetting all Profile state flags
	m_ctrProfileInactiveFlag.EnableWindow(FALSE);
	m_ctrProfileActivatedFlag.EnableWindow(FALSE);
	m_ctrProfileDeletedFlag.EnableWindow(FALSE);
	m_ctrProfileDefaultFlag.EnableWindow(FALSE);

	//if index is the default value, return true by default, no state needs to be updated
	if(nIndex == DEFAULTINDEX)
		return TRUE;

	switch(m_sAirCardType.eAirCard)
	{
		case SWI_AIRCARD_AC710:
		case SWI_AIRCARD_AC750:
		case SWI_AIRCARD_AC775:
		{
			//retrieve the profile summary first
			memset(&sProfileSummary, 0, sizeof(SWI_STRUCT_ProfileSummary));
			sProfileSummary.sizeStruct = sizeof(SWI_STRUCT_ProfileSummary);
			eRcode = SwiGetProfileSummary (&sProfileSummary, TIMEOUT3);
			if (eRcode != SWI_RCODE_OK)
			{
				ProcessError(eRcode);
				return FALSE;
			}

			//Search through array until the index matches the Profile ID, then update
			//the Profile state accordingly
			for(int PID = 0; PID < MAX_NO_CONTEXT; PID++)
			{

				nProfileID = sProfileSummary.arrProfileList[PID].nProfileID;

				if(nIndex == nProfileID)
				{

					eProfileState = sProfileSummary.arrProfileList[PID].eProfileState;
				
					switch(eProfileState)
					{
						case SWI_PROFILE_STATE_Inactive:
							m_ctrProfileInactiveFlag.EnableWindow(TRUE); //enable Inactive flag
							break;
						case SWI_PROFILE_STATE_Activated:
							m_ctrProfileActivatedFlag.EnableWindow(TRUE); //enable Activated flag
							break;
						case SWI_PROFILE_STATE_Deleted:
							m_ctrProfileDeletedFlag.EnableWindow(TRUE); //enable Deleted flag
							break;
						default:
							break;
					}
					
					//checking if this Profile is the default Profile
					if(nIndex == sProfileSummary.nDefaultProfileID)
					{
						m_ctrProfileDefaultFlag.EnableWindow(TRUE); //enable Default flag
					}

					return TRUE;

				}

			}
		}
		break;
		default:
		{
			memset(&sGsmProfileSummary, 0, sizeof(SWI_STRUCT_GsmProfileSummary));
			sGsmProfileSummary.sizeStruct = sizeof(SWI_STRUCT_GsmProfileSummary);
			eRcode = SwiGetGsmProfileSummary (&sGsmProfileSummary, TIMEOUT3);
			if (eRcode != SWI_RCODE_OK)
			{
				ProcessError(eRcode);
				return FALSE; //returns deleted state if error occurs
			}

			//Index 0 of the 'arrState' array refers to Profile 1
			if(nIndex > 0)
			{
				eProfileState = sGsmProfileSummary.arrState[nIndex-1];
			}
			else
			{
				//An error has occurred
				return FALSE;
			}

			switch(eProfileState)
			{
				case SWI_PROFILE_STATE_Inactive:
					m_ctrProfileInactiveFlag.EnableWindow(TRUE); //enable Inactive flag
					break;
				case SWI_PROFILE_STATE_Activated:
					m_ctrProfileActivatedFlag.EnableWindow(TRUE); //enable Activated flag
					break;
				case SWI_PROFILE_STATE_Deleted:
					m_ctrProfileDeletedFlag.EnableWindow(TRUE); //enable Deleted flag
					break;
				default:
					break;
			}
					
			//checking if this Profile is the default Profile
			if(nIndex == sGsmProfileSummary.nDefaultProfileId)
			{
				m_ctrProfileDefaultFlag.EnableWindow(TRUE); //enable Default flag
			}

			return TRUE;
		}
		break;
	}

	//should never get here
	return FALSE;

}


/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	OnNotification
//
//	Description	:	Handler for received notifications
//
//	Arguments	:	[IN]: wParam - Contains the notification type
//					[IN]: lParam - Contains the data to be updated
//
//	Returns		:	None
//
//	Comments	:
//
/////////////////////////////////////////////////////////////////////////////
LRESULT CProfileManipulateSampleDlg::OnNotification(WPARAM wParam, LPARAM lParam)
{

	SwiNotifyVariant* pNotify = (SwiNotifyVariant*)wParam;

	SWI_STRUCT_PktSessionCall sPktSessionCall; //Used with HSDPA AC850
  	SWI_STRUCT_PktSessionStatus sPktSessionStatus; //structure used to store a SWI_STRUCT_PktSessionStatus
	SWI_STRUCT_GSM_NetworkStatus sNetworkStatus; //structure used to store a SWI_STRUCT_GSM_NetworkStatus

	memset(&sPktSessionCall, 0, sizeof(SWI_STRUCT_PktSessionCall));
	memset(&sPktSessionStatus, 0, sizeof(SWI_STRUCT_PktSessionStatus));

	switch(pNotify->eNotify) //add notifications here
	{
		case SWI_NOTIFY_PktSessionStatus:
			sPktSessionStatus = pNotify->_PktSessionStatus;

		case SWI_NOTIFY_PktSessionCall:
			sPktSessionCall = pNotify->_PktSessionCall;
			//if application just initialized, ignore this notificaiton
			switch(m_sAirCardType.eAirCard)
			{
				case SWI_AIRCARD_AC710:
				case SWI_AIRCARD_AC750:
				case SWI_AIRCARD_AC775:
					{
						if(m_bFlagAppInitialized)
						{
							m_bFlagAppInitialized = FALSE; //will not be true again until app reinitializes
							return NULL;
						}
					}
					break;
				default:
					break;
			}

			if(sPktSessionStatus.bPacketSessionActive ||
				sPktSessionCall.bPacketSessionActive) 
			{
				//active packet session detected
				m_strStatusIndicator = _T("Profile Activated! Deactivate before proceeding.");

				//update profile state to screen
				if(!UpdateProfileStateToScreen(m_iCurrentProfileIndex))
				{
					m_strStatusIndicator = _T("Failed to update Profile State");
				}
				
				//modify GUI to reflect successful Profile activation
				m_btnActivateProfile.SetWindowText(_T("Deactivate"));
				m_btnActivateProfile.EnableWindow(TRUE);
				m_btnDeleteProfile.EnableWindow(FALSE);
				m_btnSetProfile.EnableWindow(FALSE);

			}
			else
			{
				//If there is no active packet session, check if the inactivity reason
				//is normal, if so, then the Profile is just currently de-activated
				if(sPktSessionStatus.eInactivityReason == SWI_INACTIVITYREASON_Normal ||
					sPktSessionCall.eInactivityReason == SWI_INACTIVITYREASON_Normal)
				{
					m_strStatusIndicator = _T("Profile deactivated, proceed.");

					//update profile state to screen
					if(!UpdateProfileStateToScreen(m_iCurrentProfileIndex))
					{
						m_strStatusIndicator = _T("Failed to update Profile State");
					}

					//modify GUI to reflect successful Profile de-activation
					m_btnActivateProfile.SetWindowText(_T("Activate"));
					m_btnActivateProfile.EnableWindow(TRUE);
					m_comboSelectProfile.EnableWindow(TRUE);
					m_btnDeleteProfile.EnableWindow(TRUE);
					m_btnSetProfile.EnableWindow(TRUE);

				}
				else
				{	//If inactivity reason is not normal, something is wrong,
					//chances are, an invalid Profile has been detected.  More
					//error types are available, read the header files for more information
					m_strStatusIndicator = _T("Invalid Profile Detected.");

					//update profile state to screen
					if(!UpdateProfileStateToScreen(m_iCurrentProfileIndex))
					{
						m_strStatusIndicator = _T("Failed to update Profile State");
					}

					//modify GUI to reflect an invalid Profile detection
					m_btnActivateProfile.SetWindowText(_T("Activate"));
					m_btnActivateProfile.EnableWindow(TRUE);
					m_comboSelectProfile.EnableWindow(TRUE);
				}
			}

			//update values to screen
			UpdateData(FALSE);
			break;
		case SWI_NOTIFY_NetworkStatus:
			sNetworkStatus = pNotify->_NetworkStatus;
			//Checking if GPRS service is available
			if(SWI_SERVICE_STATUS_Normal == sNetworkStatus.eServiceStatus && 
				(SWI_SERVICE_TYPE_Combined == sNetworkStatus.eServiceType || 
				SWI_SERVICE_TYPE_PS == sNetworkStatus.eServiceType ||
				SWI_SERVICE_TYPE_CircuitSwitched == sNetworkStatus.eServiceType))
			{
				m_ctrGPRSAvailFlag.EnableWindow(TRUE);
			}
			else
			{
				m_ctrGPRSAvailFlag.EnableWindow(FALSE);
			}
			//Checking roaming state
			if(SWI_ROAMING_Home == sNetworkStatus.eRoaming)
			{
				m_ctrRoamingYes.EnableWindow(FALSE);
				m_ctrRoamingNo.EnableWindow(TRUE);

			}
			else
			{
				m_ctrRoamingYes.EnableWindow(TRUE);
				m_ctrRoamingNo.EnableWindow(FALSE);
			}
			break;
		default:
			break;
	}
	delete (SwiNotifyVariant*)wParam;
	return NULL;
}


/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	OnGetProfileInfo
//
//	Description	:	Retrieve information from the currently selected Profile
//
//	Arguments	:	None
//
//	Returns		:	None
//
//	Comments	:	
//
///////////////////////////////////////////////////////////////////////////
void CProfileManipulateSampleDlg::OnGetProfileInfo() 
{
	U32 nIndex;
	SWI_TYPE_ProfileState eCurrentProfileState;
	SWI_RCODE eRcode;

	//retrieve the index of the selected profile
	switch(m_sAirCardType.eAirCard)
	{
		case SWI_AIRCARD_AC710:
		case SWI_AIRCARD_AC750:
		case SWI_AIRCARD_AC775:
			{
				nIndex = m_comboSelectProfile.GetCurSel() - 1;
			}
			break;
		default:
			{
				nIndex = m_comboSelectProfile.GetCurSel();
			}
			break;
	}

	//if index is the default value, it means nothing has been selected
	//Just clear the text boxes
	if (DEFAULTINDEX == nIndex)
	{
		m_strStatusIndicator = _T("Please select a Profile");
		m_strProfileUserName.Empty();
		m_strProfilePassword.Empty();
		m_strProfileLabel.Empty();
		m_strProfileAPN.Empty();
		UpdateData(FALSE);
		return;
	}

	//update current profile index to keep track of what Profile is currently selected
	m_iCurrentProfileIndex = nIndex;

	//update profile state to screen
	if(!UpdateProfileStateToScreen(nIndex))
	{
		m_strStatusIndicator = _T("Failed to update Profile State");
		UpdateData(FALSE);
		return;
	}

	//Retrieve profile info
	switch(m_sAirCardType.eAirCard)
	{
		case SWI_AIRCARD_AC710:
		case SWI_AIRCARD_AC750:
		case SWI_AIRCARD_AC775:
		{
			SWI_STRUCT_Profile sProfileStruct;
			memset (&sProfileStruct, 0, sizeof(SWI_STRUCT_Profile));
			sProfileStruct.sizeStruct = sizeof(SWI_STRUCT_Profile);

			eRcode = SwiGetProfile(&sProfileStruct, nIndex, TIMEOUT3);
			if (SWI_RCODE_OK == eRcode)
			{
				// fill in the Profile Label box with the appropriate value
				m_strProfileLabel = (LPTSTR)sProfileStruct.szLabel;
				m_strProfileUserName = (LPTSTR)sProfileStruct.szUserName;
				m_strProfilePassword = (LPTSTR)sProfileStruct.szPassword;
				m_strProfileAPN = (LPTSTR)sProfileStruct.szAccessPoint;

			}
			else
			{
				ProcessError(eRcode);
				m_strStatusIndicator = _T("Failed to retrieve Profile Information");
				UpdateData(FALSE);
				return;
			}
		}
		break;
		default:
		{
			SWI_STRUCT_GsmProfileBasic sProfileBasic; //Used for AC850 to retrieve basic Profile info
	
			memset (&sProfileBasic, 0, sizeof(SWI_STRUCT_GsmProfileBasic));
			sProfileBasic.sizeStruct = sizeof(SWI_STRUCT_GsmProfileBasic);
			sProfileBasic.nProfileId = (U8)nIndex;

			eRcode = SwiGetGsmProfileBasic(&sProfileBasic, TIMEOUT3);
			if (SWI_RCODE_OK == eRcode)
			{
				// fill in the Profile Label box with the appropriate value
				m_strProfileLabel = (LPTSTR)sProfileBasic.szLabel;
				m_strProfileUserName = (LPTSTR)sProfileBasic.szUserName;
				m_strProfilePassword = (LPTSTR)sProfileBasic.szPassword;
				m_strProfileAPN = (LPTSTR)sProfileBasic.szAccessPoint;

			}
			else
			{
				ProcessError(eRcode);
				m_strStatusIndicator = _T("Failed to retrieve Profile Information");
				UpdateData(FALSE);
				return;
			}
		}
		break;
	}


	//Retrieving the current profile state (active, inactive, deleted)
	if(!GetProfileState(m_iCurrentProfileIndex, &eCurrentProfileState))
	{
		m_strStatusIndicator = _T("Failed to retrieve Profile state");
		UpdateData(FALSE);
		return;
	}

	if(eCurrentProfileState == SWI_PROFILE_STATE_Activated)
	{
		m_btnActivateProfile.SetWindowText(_T("Deactivate"));
	}
	else
	{
		m_btnActivateProfile.SetWindowText(_T("Activate"));
	}

	//modifying GUI to reflect a successful operation
	m_strStatusIndicator = _T("Profile Retrieved Successfully!");
	m_btnActivateProfile.EnableWindow(TRUE);
	m_btnSetProfile.EnableWindow(TRUE);
	m_btnDeleteProfile.EnableWindow(TRUE);

	//update the values to the screen
	UpdateData(FALSE);
}


/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	GetProfileState
//
//	Description	:	Retrieve Profile State (Activated, Inactive, Deleted)
//
//	Arguments	:	None
//
//	Returns		:	ProfileState - SWI_TYPE_ProfileState, indicates the Profile State
//								   of the currently selected Profile (Activated, Inactive, Deleted)						   	
//
//	Comments	:
//
///////////////////////////////////////////////////////////////////////////
BOOL CProfileManipulateSampleDlg::GetProfileState(U32 nIndex, SWI_TYPE_ProfileState* eProfileState)
{
	SWI_RCODE eRcode;
	SWI_STRUCT_ProfileSummary sProfileSummary;
	SWI_STRUCT_GsmProfileSummary sGsmProfileSummary;
	U32 nProfileID;

	//retrieve the profile summary
	switch(m_sAirCardType.eAirCard)
	{
		case SWI_AIRCARD_AC710:
		case SWI_AIRCARD_AC750:
		case SWI_AIRCARD_AC775:
		{
			memset(&sProfileSummary, 0, sizeof(SWI_STRUCT_ProfileSummary));
			sProfileSummary.sizeStruct = sizeof(SWI_STRUCT_ProfileSummary);
			eRcode = SwiGetProfileSummary (&sProfileSummary, TIMEOUT3);
			if (eRcode != SWI_RCODE_OK)
			{
				ProcessError(eRcode);
				return FALSE; //returns deleted state if error occurs
			}

			//search through array until index matches Profile ID, then return the Profile State
			for(int PID = 0; PID < MAX_NO_CONTEXT; PID++)
			{

				nProfileID = sProfileSummary.arrProfileList[PID].nProfileID;

				if(nIndex == nProfileID)
				{
					*eProfileState = sProfileSummary.arrProfileList[PID].eProfileState;
				}
			}
		}
		break;
		default:
		{
			memset(&sGsmProfileSummary, 0, sizeof(SWI_STRUCT_GsmProfileSummary));
			sGsmProfileSummary.sizeStruct = sizeof(SWI_STRUCT_GsmProfileSummary);
			eRcode = SwiGetGsmProfileSummary (&sGsmProfileSummary, TIMEOUT3);
			if (eRcode != SWI_RCODE_OK)
			{
				ProcessError(eRcode);
				return FALSE; //returns deleted state if error occurs
			}

			//Index 0 of the 'arrState' array refers to Profile 1
			if(nIndex > 0)
			{
				*eProfileState = sGsmProfileSummary.arrState[nIndex-1];
			}
			else
			{
				//An error has occurred
				return FALSE;
			}
		}
		break;
	}

	return TRUE; //returning Profile State (Activated, Inactive, Deleted)

}


/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	ConnectModem
//
//	Description	:	Start a Connection to the Modem
//
//	Arguments	:	None
//
//	Returns		:	TRUE/FALSE to indicate success of connection
//
//	Comments	:
//
///////////////////////////////////////////////////////////////////////////
BOOL CProfileManipulateSampleDlg::ConnectModem() 
{	
	SWI_RCODE rCode;
	SWI_TYPE_Device eDevice;
	BOOL bDisconnected; //checks if disconnection was successful

	if(m_bConnected == FALSE)
	{
		//Open a connection with the Modem
		SWI_STRUCT_ApiStartup sOpenParams;
		memset(&sOpenParams, 0, sizeof(SWI_STRUCT_ApiStartup));

		rCode = SwiApiStartup(&sOpenParams);
		if(SWI_RCODE_OK != rCode 
			&& SWI_RCODE_ALREADY_OPEN != rCode) // Bz13170
		{
			ProcessError(rCode);
			return FALSE;
		}

		eDevice = GetHighestPriorityDeviceType ();
		if (eDevice == SWI_DEVICE_None)
		{
			UpdateData(FALSE);
			return FALSE;
		}

		DECLARE_MacAny;
		SWI_STRUCT_AirServer sAirServer;
		sAirServer.sizeStruct = sizeof(SWI_STRUCT_AirServer);
		memcpy(sAirServer.ClientMac, MacAny, LENGTH_MacAddress);
		memcpy(sAirServer.ServerMac, MacAny, LENGTH_MacAddress);
		sAirServer.eDevice = eDevice;

		rCode = SwiSelectAirServer(sAirServer);
		if(SWI_RCODE_OK != rCode)
		{
			ProcessError(rCode);
			return FALSE;
		}

		//Register the Callback function
		rCode = SwiRegisterCallback(NotificationCallback, 0xFFFFFFFFFFFFFFFF);
		if(SWI_RCODE_OK != rCode)
		{
			ProcessError(rCode);
			return FALSE;
		}

		rCode = SwiGetAirCardType(&m_sAirCardType, TIMEOUT3);
		if(SWI_RCODE_OK != rCode)
		{
			ProcessError(rCode);
			return FALSE;
		}

		// Enable notifications
		switch(m_sAirCardType.eAirCard)
		{
			case SWI_AIRCARD_AC710:
			case SWI_AIRCARD_AC750:
			case SWI_AIRCARD_AC775:
			{
				rCode = SwiNotify(SWI_NOTIFY_PktSessionStatus, TIMEOUT3);
				if(SWI_RCODE_OK != rCode)
				{
					ProcessError(rCode);
					return FALSE;
				}
			}
			break;
			default:
				{
					rCode = SwiNotify(SWI_NOTIFY_PktSessionCall, TIMEOUT3);
					if(SWI_RCODE_OK != rCode)
					{
						ProcessError(rCode);
						return FALSE;
					}
				}
				break;
		}

		rCode = SwiNotify(SWI_NOTIFY_NetworkStatus, TIMEOUT3);
		if(SWI_RCODE_OK != rCode)
		{
			ProcessError(rCode);
			return FALSE;
		}

		//informing modem of host startup state
		//this function will attach the modem onto the network
		rCode = SwiSetHostStartup(TRUE, TIMEOUT3*20);
		if(SWI_RCODE_OK != rCode)
		{
			ProcessError(rCode);
			return FALSE;
		}


		//as we are here there are no errors
		//Initialize member variables and change GUI to reflect a successful connection
		//to the API
		m_bConnected = TRUE;
		m_strStatusIndicator = _T("Connected to device");
		m_comboSelectProfile.EnableWindow(TRUE);
		m_btnConnect.SetWindowText(_T("Disconnect"));
		m_btnConnect.EnableWindow(TRUE);

		//Update values to screen
		UpdateData(FALSE);
		return TRUE;

	}
	else
	{
		//Disconnect from modem5
		bDisconnected = DisconnectModem();

		//checking if disconnection was successful
		if(bDisconnected)
		{
			m_strStatusIndicator = _T("Disconnected from device");
		}
		else
		{
			m_strStatusIndicator = _T("Error occured while disconnecting");
		}

		//reset member variables and modify GUI to reflect a disconnection from the API
		m_bConnected = FALSE;
		m_comboSelectProfile.EnableWindow(FALSE);
		m_btnConnect.SetWindowText(_T("Connect"));
		m_btnConnect.EnableWindow(TRUE);

		m_btnActivateProfile.SetWindowText(_T("Activate"));
		m_btnActivateProfile.EnableWindow(FALSE);
		m_btnSetProfile.EnableWindow(FALSE);
		m_btnDeleteProfile.EnableWindow(FALSE);

		//Updating values to screen
		UpdateData(FALSE);
		return TRUE;
	}

	return FALSE;

}


/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	DisconnectModem
//
//	Description	:	Disconnects from the modem
//
//	Arguments	:	None
//
//	Returns		:	TRUE/FALSE to indicate success or failure of disconnection
//
//	Comments	:
//
///////////////////////////////////////////////////////////////////////////
BOOL CProfileManipulateSampleDlg::DisconnectModem()
{

	SWI_RCODE eRcode;
	SWI_TYPE_ProfileState eCurrentProfileState;

	//disconnect if a connection to the modem exists
	if(m_bConnected == TRUE)
	{
		// Disable notifications
		switch(m_sAirCardType.eAirCard)
		{
			case SWI_AIRCARD_AC710:
			case SWI_AIRCARD_AC750:
			case SWI_AIRCARD_AC775:
			{
				eRcode = SwiStopNotify(SWI_NOTIFY_PktSessionStatus, TIMEOUT3);
				if (SWI_RCODE_OK != eRcode)
				{
					ProcessError(eRcode);
					return FALSE;
				}
			}
			break;
			default:
				{
					eRcode = SwiStopNotify(SWI_NOTIFY_PktSessionCall, TIMEOUT3);
					if (SWI_RCODE_OK != eRcode)
					{
						ProcessError(eRcode);
						return FALSE;
					}
				}
				break;
		}

		eRcode = SwiStopNotify(SWI_NOTIFY_NetworkStatus, TIMEOUT3);
		if (SWI_RCODE_OK != eRcode)
		{
			ProcessError(eRcode);
			return FALSE;
		}

//		if(m_iCurrentProfileIndex != 0)
		if(m_iCurrentProfileIndex > 0)					// m_iCurrentProfileIndex might be -1
		{

			//Retrieving the current profile state (active, inactive, deleted)
			if(!GetProfileState(m_iCurrentProfileIndex, &eCurrentProfileState))
			{
				m_strStatusIndicator = _T("Failed to retrieve Profile state");
				UpdateData(FALSE);
				return FALSE;
			}

			//If a Profile has been activated, deactivate it first before exiting
			if(eCurrentProfileState == SWI_PROFILE_STATE_Activated)
			{

				eRcode = SwiActivateProfile(m_iCurrentProfileIndex, FALSE, TIMEOUT3*10);
				if(SWI_RCODE_OK != eRcode)
				{
					ProcessError(eRcode);
					return FALSE;
				}

			}

		}

		//detaching modem from network; this has been commented out because
		//it can sometimes take up to 20 seconds to detach from the network,
		//since it is not necessary to detach from the network,
		//it has been commented out for the SDK sample apps.
/*		eRcode = SwiSetHostStartup(FALSE, TIMEOUT3*20);
		if(SWI_RCODE_OK != eRcode)
		{
			ProcessError(eRcode);
			return FALSE;
		}
*/

		//close connection with modem
		eRcode = SwiApiShutdown();	
		if (SWI_RCODE_OK != eRcode)
		{

			ProcessError(eRcode);
			return FALSE;

		}

	}

	return TRUE;

}


/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	Instance
//
//	Description	:	A static function used to return a pointer to this object
//
//	Arguments	:	None
//
//	Returns		:	m_Instance - a pointer to this object
//
//	Comments	:
//
///////////////////////////////////////////////////////////////////////////
CProfileManipulateSampleDlg* CProfileManipulateSampleDlg::Instance()
{
	return m_instance;
}


/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	HandleCallback
//
//	Description	:	Caches data from NotificationCallback (therefore freeing the thread)
//					and posts a message for notification handling
//					
//	Arguments	:	[IN]: pNotify - pointer to notification variant
//
//	Returns		:	None
//
//	Comments	:
//
///////////////////////////////////////////////////////////////////////////
void CProfileManipulateSampleDlg::HandleCallback(SwiNotifyVariant *pNotify)
{
	//used for debugging purposes, displays the notifications received
	TRACE(_T("Got notif %i\n"), pNotify->eNotify);

	// For simplicity, we are allocating a copy of the notification from 
	// the heap. An industrial-strength app would allocate the copy from 
	// a fixed pool of objects to avoid memory fragmentation. 
	SwiNotifyVariant* pCopy = (SwiNotifyVariant*) new SwiNotifyVariant;
	
	if (pCopy)
	{
		*pCopy = *pNotify;
		m_instance->PostMessage(WM_NOTIFICATION, WPARAM(pCopy), NULL ); 
	}

}

/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	OnBtnConnect
//
//	Description	:	Connect/Disconnect to/from modem
//					
//	Arguments	:	None
//
//	Returns		:	None
//
//	Comments	:
//
///////////////////////////////////////////////////////////////////////////
void CProfileManipulateSampleDlg::OnBtnConnect() 
{
	ConnectModem();	
}
