/**
 *
 *	Name	:	ProfileManipulateSampleDlg.h
 *
 *	Purpose	:	main header file for the ProfileManipulateSample application
 *				This sample application demonstrates how to set, delete, 
 *				and activate a Profile.  It also demonstrates how to extract
 *				various types of information from a Profile.  Keep in mind
 *				that the Aircard supports 3 Profiles.  All functions dealing
 *				with Profiles are just used to manipulate these 3 Profiles
 *				in various ways.
 *
 *	History	:	Created June 27, 2003
 *
 *	Revision:	1.0
 *
 *	Copyright (c) 2003 Sierra Wireless, Inc. All rights reserved.
 *
 **/

#if !defined(AFX_ProfileManipulateSampleDLG_H__A8F29B8B_06AF_4618_A743_97DB2CD46AB5__INCLUDED_)
#define AFX_ProfileManipulateSampleDLG_H__A8F29B8B_06AF_4618_A743_97DB2CD46AB5__INCLUDED_

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000

#include "SwiStructsGsm.h"
#include "SwiApiCm.h"

#define TIMEOUT3 3000
#define DEFAULTINDEX -1

// user defined windows message identifier for notifications
#define WM_NOTIFICATION WM_USER + 400

/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	NotificationCallback
//
//	Description	:	Callback that receives all event notifications
//
//	Arguments	:	[IN]: pNotify - pointer to notification variant
//
//	Returns		:	None
//
//	Comments	:	Even if no notifications are being processed,
//					this function still needs to be registered and declared
//					for calls to the API to function properly.
//
/////////////////////////////////////////////////////////////////////////////
void NotificationCallback(SwiNotifyVariant *pNotify);

/////////////////////////////////////////////////////////////////////////////
// CProfileManipulateSampleDlg dialog

class CProfileManipulateSampleDlg : public CDialog
{
// Construction
public:
	CProfileManipulateSampleDlg(CWnd* pParent = NULL);	// standard constructor

// Dialog Data
	//{{AFX_DATA(CProfileManipulateSampleDlg)
	enum { IDD = IDD_ProfileManipulateSample_DIALOG };
	CButton	m_btnConnect;
	CStatic	m_ctrRoamingYes;
	CStatic	m_ctrRoamingNo;
	CStatic	m_ctrGPRSAvailFlag;
	CStatic	m_ctrProfileDefaultFlag;
	CStatic	m_ctrProfileInactiveFlag;
	CStatic	m_ctrProfileDeletedFlag;
	CStatic	m_ctrProfileActivatedFlag;
	CComboBox	m_comboSelectProfile;
	CButton	m_btnOK;
	CButton	m_btnDeleteProfile;
	CButton	m_btnSetProfile;
	CButton	m_btnActivateProfile;
	CString	m_strProfileAPN;
	CString	m_strProfilePassword;
	CString	m_strProfileUserName;
	CString	m_strProfileLabel;
	CString	m_strStatusIndicator;
	//}}AFX_DATA

	// ClassWizard generated virtual function overrides
	//{{AFX_VIRTUAL(CProfileManipulateSampleDlg)
	protected:
	virtual void DoDataExchange(CDataExchange* pDX);	// DDX/DDV support
	//}}AFX_VIRTUAL

// Implementation
public:

	BOOL UpdateProfileStateToScreen(U32 Index); //updates Profile State to screen
	BOOL ConnectModem(); //connects to modem
	BOOL DisconnectModem(); //disconnects from modem
	BOOL GetProfileState(U32 Index, SWI_TYPE_ProfileState* ProfileState); //retrieves Profile state
	LRESULT OnNotification(WPARAM wParam, LPARAM lParam); //handles notifications
	void ProcessError(SWI_RCODE code); //process API error codes
	void HandleCallback(SwiNotifyVariant* pNotify); //caches data from notificaiton callback
	static CProfileManipulateSampleDlg* Instance(); //returns a pointer to this object
	SWI_TYPE_Device GetHighestPriorityDeviceType ();

private:
	static CProfileManipulateSampleDlg* m_instance; //a pointer to this object

protected:
	HICON m_hIcon;
	BOOL m_bConnected;		// connection status indicator
	BOOL m_bFlagAppInitialized; // true if application has just been initialized
	int m_iCurrentProfileIndex; //current profile selected
	SWI_STRUCT_AirCardType m_sAirCardType; //structure used to store the AirCard type

	enum TYPE_Device
	{
		DEVICE_AC710_750_775_850,
		DEVICE_MC87xx,
	};

	// Generated message map functions
	//{{AFX_MSG(CProfileManipulateSampleDlg)
	virtual BOOL OnInitDialog();
	afx_msg HCURSOR OnQueryDragIcon();
	afx_msg void OnOK();
	afx_msg void OnActivateProfile();
	afx_msg void OnDeleteProfile();
	afx_msg void OnSetProfileInfo();
	afx_msg void OnGetProfileInfo();
	afx_msg void OnBtnConnect();
	//}}AFX_MSG
	DECLARE_MESSAGE_MAP()
};

//{{AFX_INSERT_LOCATION}}
// Microsoft Visual C++ will insert additional declarations immediately before the previous line.

#endif // !defined(AFX_ProfileManipulateSampleDLG_H__A8F29B8B_06AF_4618_A743_97DB2CD46AB5__INCLUDED_)
