/**
 *
 *	Name	:	ConnectAPISampleDlg.cpp
 *
 *	Purpose	:	Main dialog implementation file for ConnectAPISample
 *				This sample application demonstrates how to open a
 *				connection to the API.
 *
 *	History	:	created	Oct 23, 2001
 *				- initial version
 *				revised Feb 20 2002
 *				- different implementation with MFC objects
 *				revised	June 17, 2003
 *				- more usage of MFC objects
 *				- replaced obsolete functions
 *
 *	Revision:	2.0
 *
 *	Copyright (c) 2003 Sierra Wireless, Inc. All rights reserved.
 *
 **/

#include "stdafx.h"
#include "RadioOnOffSample.h"
#include "RadioOnOffSampleDlg.h"
#include "SwiApiGsm.h"

#ifdef _DEBUG
#define new DEBUG_NEW
#undef THIS_FILE
static char THIS_FILE[] = __FILE__;
#endif

void NotificationCallback(SwiNotifyVariant *pNotify); 
CRadioOnOffSampleDlg*	CRadioOnOffSampleDlg::m_instance = NULL; //initializing pointer to this object to NULL

/////////////////////////////////////////////////////////////////////////////
// CRadioOnOffSampleDlg dialog

CRadioOnOffSampleDlg::CRadioOnOffSampleDlg(CWnd* pParent /*=NULL*/)
	: CDialog(CRadioOnOffSampleDlg::IDD, pParent)
{
	//{{AFX_DATA_INIT(CRadioOnOffSampleDlg)
	m_instance = this;
	m_strStatusIndicator = _T("");
	//}}AFX_DATA_INIT
	// Note that LoadIcon does not require a subsequent DestroyIcon in Win32
	m_hIcon = AfxGetApp()->LoadIcon(IDR_MAINFRAME);
	m_bPoweredOff = FALSE;
}

void CRadioOnOffSampleDlg::DoDataExchange(CDataExchange* pDX)
{
	CDialog::DoDataExchange(pDX);
	//{{AFX_DATA_MAP(CRadioOnOffSampleDlg)
	DDX_Text(pDX, IDC_CONTEXT, m_strStatusIndicator);
	//}}AFX_DATA_MAP
}

BEGIN_MESSAGE_MAP(CRadioOnOffSampleDlg, CDialog)
	//{{AFX_MSG_MAP(CRadioOnOffSampleDlg)
	ON_WM_QUERYDRAGICON()
	ON_BN_CLICKED(IDC_BTN_OK, OnOK)
	ON_MESSAGE(WM_NOTIF_AIR_SERVER_DETECT, OnHandleProcessAirServerChangeNotification)
	ON_MESSAGE(WM_NOTIF_MODEM_DISABLED, OnModemDisabled)
//}}AFX_MSG_MAP
	ON_BN_CLICKED(IDC_RADIOCTRL, &CRadioOnOffSampleDlg::OnBnClickedRadioctrl)
END_MESSAGE_MAP()

/////////////////////////////////////////////////////////////////////////////
// CRadioOnOffSampleDlg message handlers

BOOL CRadioOnOffSampleDlg::OnInitDialog()
{
	CDialog::OnInitDialog();

	// Set the icon for this dialog.  The framework does this automatically
	//  when the application's main window is not a dialog
	SetIcon(m_hIcon, TRUE);			// Set big icon
	SetIcon(m_hIcon, FALSE);		// Set small icon
	
	// TODO: Add extra initialization here

	//initializing the main variables.
	m_strStatusIndicator = _T("Disconnected from device");
	m_bConnected = FALSE;

	ConnectModem();

	//update values to screen
	UpdateData(FALSE);
	
	return TRUE;  // return TRUE  unless you set the focus to a control
}

// The system calls this to obtain the cursor to display while the user drags
//  the minimized window.
HCURSOR CRadioOnOffSampleDlg::OnQueryDragIcon()
{
	return (HCURSOR) m_hIcon;
}

/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	ProcessError
//
//	Description	:	Helper function to process error codes
//
//	Arguments	:	[IN]: code - error code from the API
//
//	Returns		:	None
//
//	Comments	:
//
/////////////////////////////////////////////////////////////////////////////
void CRadioOnOffSampleDlg::ProcessError(SWI_RCODE code)
{
	CString strErrorString;

	strErrorString.Format(_T("Internal error - error code: %d"), code);

	MessageBox(strErrorString, _T("API Message"), MB_OK);
}

SWI_TYPE_Device CRadioOnOffSampleDlg::GetHighestPriorityDeviceType ()
{
	SWI_TYPE_Device				eTypeDevice = SWI_DEVICE_None;
	SWI_STRUCT_AirServerList	sAvailDevList;
	SWI_RCODE					rCode;

	//--------------------
	// Connect to ANY device
	//--------------------
	sAvailDevList.sizeStruct = sizeof(SWI_STRUCT_AirServerList);
	rCode = SwiGetAvailAirServers(sAvailDevList);
	if (SWI_RCODE_OK != rCode)
	{
		m_strStatusIndicator =  _T("GetAvailDev() Failed");
		return eTypeDevice;
	}

	// how many avail devices?
	if (0 == sAvailDevList.nNumber)
	{
		m_strStatusIndicator = _T("No available devices");
		return eTypeDevice;
	}

	return sAvailDevList.AirServers[0].eDevice;
}

/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	OnOK
//
//	Description	:	OK button has been pressed to exit the applications
//
//	Arguments	:	None
//
//	Returns		:	None
//
//	Comments	:
//
///////////////////////////////////////////////////////////////////////////
void CRadioOnOffSampleDlg::OnOK() 
{

	// if there is an open connection with the modem then it must be closed before
	// closing the window
	if (m_bConnected == TRUE)
	{
		//disconnect from modem then exit application
		DisconnectModem();

		//resetting variables
		m_bConnected = FALSE;
	}	
	CDialog::OnOK();
}


/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	DisconnectModem
//
//	Description	:	Disconnects from the modem
//
//	Arguments	:	IN: None	OUT: TRUE/FALSE
//
//	Returns		:	TRUE/FALSE to indicate success or failure of disconnection
//
//	Comments	:
//
///////////////////////////////////////////////////////////////////////////
BOOL CRadioOnOffSampleDlg::DisconnectModem()
{
	SWI_RCODE rcode;

	rcode = SwiApiShutdown();	//close connection with modem
	if (SWI_RCODE_OK != rcode)
	{	
		ProcessError(rcode);
		return FALSE;
	}
	
	return TRUE;
}

BOOL CRadioOnOffSampleDlg::ConnectModem()
{
	//Open a connection with the Modem
	SWI_STRUCT_ApiStartup sOpenParams;
	memset(&sOpenParams, 0, sizeof(SWI_STRUCT_ApiStartup));

	SWI_RCODE rCode = SwiApiStartup(&sOpenParams);
	if(SWI_RCODE_OK != rCode && SWI_RCODE_ALREADY_OPEN != rCode)
	{
		return FALSE;
	}

	__try
	{
		SWI_TYPE_Device eDevice = GetHighestPriorityDeviceType();
		if (eDevice == SWI_DEVICE_None)
		{
			GetDlgItem(IDC_RADIOCTRL)->EnableWindow(FALSE);
			__leave;
		}

		DECLARE_MacAny;
		SWI_STRUCT_AirServer sAirServer;
		sAirServer.sizeStruct = sizeof(SWI_STRUCT_AirServer);
		memcpy(sAirServer.ClientMac, MacAny, LENGTH_MacAddress);
		memcpy(sAirServer.ServerMac, MacAny, LENGTH_MacAddress);
		sAirServer.eDevice = eDevice;

		rCode = SwiSelectAirServer(sAirServer);
		if(SWI_RCODE_OK != rCode)
			__leave;

		m_bConnected = TRUE;

		rCode = SwiGetModemDisable(&m_bPoweredOff, TIMEOUT);
		if (rCode != SWI_RCODE_OK)
		{
			m_strStatusIndicator = _T("Failed to get modem status");
		}

		if (m_bPoweredOff == TRUE)
		{
			m_strStatusIndicator = _T("No available device");
			GetDlgItem(IDC_RADIOCTRL)->SetWindowText(_T("Turn Radio On"));
		}
		else
		{
			m_strStatusIndicator = _T("Connected to device");
			GetDlgItem(IDC_RADIOCTRL)->SetWindowText(_T("Turn Radio Off"));
		}

		rCode = SwiRegisterCallback((SWI_CALLBACK_EX)NotificationCallback, 0xFFFFFFFFFFFFFFFF);
		if (rCode != SWI_RCODE_OK)
		{
			m_strStatusIndicator = _T("SwiRegisterCallback failed");
		}

		rCode = SwiNotify(SWI_NOTIFY_ModemDisabled, 3000);
		if(SWI_RCODE_OK != rCode)
		{
			m_strStatusIndicator = _T("SwiNotify SWI_NOTIFY_ModemDisabled failed");
		}

		GetDlgItem(IDC_RADIOCTRL)->EnableWindow(TRUE);
	}
	__finally
	{
	}

	return m_bConnected;
}

void CRadioOnOffSampleDlg::OnBnClickedRadioctrl()
{
	// TODO: Add your control notification handler code here
	__try
	{
		if (m_bConnected == FALSE)
			__leave;

		bool bPoweredOff;
		SWI_RCODE rCode = SwiGetModemDisable(&bPoweredOff, TIMEOUT);
		if (rCode != SWI_RCODE_OK)
		{
			m_strStatusIndicator = _T("SwiGetModemDisable failed");
			__leave;
		}

		m_bPoweredOff = !m_bPoweredOff;
		if (bPoweredOff != m_bPoweredOff)
		{
			rCode = SwiSetModemDisable(m_bPoweredOff, TIMEOUT);
			if (rCode != SWI_RCODE_OK)
			{
				m_strStatusIndicator = _T("SwiSetModemDisable failed");
				__leave;
			}
		}
		else
		{
			m_strStatusIndicator = _T("Device is in wrong state");
		}

		if (bPoweredOff == FALSE)
		{
			GetDlgItem(IDC_RADIOCTRL)->SetWindowText(_T("Turn Radio On"));
			m_strStatusIndicator = _T("No available device");
		}
		else
		{
			GetDlgItem(IDC_RADIOCTRL)->SetWindowText(_T("Turn Radio Off"));
			GetDlgItem(IDC_RADIOCTRL)->EnableWindow(FALSE);
			m_strStatusIndicator = _T("Waiting for device reset");
		}
	}
	__finally
	{
		UpdateData(FALSE);
	}
}

void NotificationCallback(SwiNotifyVariant *pNotify)
{
	CRadioOnOffSampleDlg* pThisObject = CRadioOnOffSampleDlg::Instance();
	if (pThisObject == NULL)
		return;

	TRACE(_T("Got notif %i\n"), pNotify->eNotify);

	SWI_STRUCT_AirServer* pCopy = NULL;

	//Catch the info and post a message
	switch (pNotify->eNotify) //add notifications here
	{
	case SWI_NOTIFY_AirServerChange:
		// Make copy of air server, pass to handling thread so this call can return.
		pCopy = new SWI_STRUCT_AirServer;
		if (pCopy)
		{
			*pCopy = pNotify->_AirServerChange.AirServer;
			pThisObject->PostMessage(WM_NOTIF_AIR_SERVER_DETECT, pNotify->_AirServerChange.bInsert, (LPARAM)pCopy);
		}
		break;
	case SWI_NOTIFY_ModemDisabled:
		{
			pThisObject->PostMessage(WM_NOTIF_MODEM_DISABLED, (WPARAM)pNotify->_ModemDisabled.bModemDisabled, 0); 
			return;
		}
	default:
		break;
	}
}

LONG CRadioOnOffSampleDlg::OnHandleProcessAirServerChangeNotification(WPARAM wParam, LPARAM lParam)
{
	SWI_STRUCT_AirServer* pNotify = (SWI_STRUCT_AirServer*)lParam;

	__try
	{
		bool bInsert = (bool)wParam;
		if (bInsert == 0)
		{
			m_strStatusIndicator = _T("No available device");
			GetDlgItem(IDC_RADIOCTRL)->EnableWindow(FALSE);
			__leave;
		}

		ConnectModem();
	}
	__finally
	{
		UpdateData(FALSE);
		delete pNotify;
	}

	return TRUE;
}

LONG CRadioOnOffSampleDlg::OnModemDisabled(WPARAM wParam, LPARAM lParam)
{
	bool bDisabled = (bool)wParam;
	if (bDisabled == true)
	{
		m_strStatusIndicator = _T("No available device");
		GetDlgItem(IDC_RADIOCTRL)->SetWindowText(_T("Turn Radio On"));
	}
	else
	{
		m_strStatusIndicator = _T("Connected to device");
		GetDlgItem(IDC_RADIOCTRL)->SetWindowText(_T("Turn Radio Off"));
	}
	
	GetDlgItem(IDC_RADIOCTRL)->EnableWindow(TRUE);
	UpdateData(FALSE);

	return TRUE;
}

CRadioOnOffSampleDlg* CRadioOnOffSampleDlg::Instance()
{
	return m_instance;
}