/**
 *
 *	Name	:	SimLockSampleDlg.cpp
 *
 *	Purpose	:	main implementation file for the SimLockSample application
 *
 *	History	:	Created June 11th, 2003
 *				This sample application demonstrates how to lock a SIM (enable
 *				SIM security) as well as how to change the PIN1 of a SIM
 *
 *				Updated July 5th, 2005
 *				Fixed bug that occurred when launching the app with an Aircard that is already
 *				in a locked state.
 *
 *	Revision:	1.0
 *
 *	Copyright (c) 2003 Sierra Wireless, Inc. All rights reserved.
 *
 **/

#include "stdafx.h"
#include "SimLockSample.h"
#include "SimLockSampleDlg.h"
#include "SwiApiGsm.h"

#ifdef _DEBUG
#define new DEBUG_NEW
#undef THIS_FILE
static char THIS_FILE[] = __FILE__;
#endif

CSimLockSampleDlg*	CSimLockSampleDlg::m_instance = NULL; //initializing pointer to this object to NULL

/////////////////////////////////////////////////////////////////////////////
// CSimLockSampleDlg dialog

CSimLockSampleDlg::CSimLockSampleDlg(CWnd* pParent /*=NULL*/)
	: CDialog(CSimLockSampleDlg::IDD, pParent)
{
	//{{AFX_DATA_INIT(CSimLockSampleDlg)
	m_strStatusIndicator = _T("");
	m_iLockAttempts = 0;
	m_iChangeAttempts = 0;
	m_instance = this;
	//}}AFX_DATA_INIT
	// Note that LoadIcon does not require a subsequent DestroyIcon in Win32
	m_hIcon = AfxGetApp()->LoadIcon(IDR_MAINFRAME);
}

void CSimLockSampleDlg::DoDataExchange(CDataExchange* pDX)
{
	CDialog::DoDataExchange(pDX);
	//{{AFX_DATA_MAP(CSimLockSampleDlg)
	DDX_Control(pDX, IDC_BTN_CONNECT, m_btnConnect);
	DDX_Control(pDX, IDC_EDIT_VERIFYPIN, m_edtPINVerify);
	DDX_Control(pDX, IDC_EDIT_PINLOCK, m_edtPINLock);
	DDX_Control(pDX, IDC_EDIT_PINCHANGE, m_edtPINCurrent);
	DDX_Control(pDX, IDC_EDIT_NEWPIN, m_edtPINNew);
	DDX_Control(pDX, IDOK, m_btnOK);
	DDX_Control(pDX, IDC_BTN_LOCK, m_btnLockUnlockSIM);
	DDX_Control(pDX, IDC_BTN_APPLY, m_btnApplyChanges);
	DDX_Text(pDX, IDC_STATUS, m_strStatusIndicator);
	DDX_Text(pDX, IDC_EDIT_LOCKATTEMPTS, m_iLockAttempts);
	DDX_Text(pDX, IDC_CHANGEATTEMPTS, m_iChangeAttempts);
	//}}AFX_DATA_MAP
}

BEGIN_MESSAGE_MAP(CSimLockSampleDlg, CDialog)
	//{{AFX_MSG_MAP(CSimLockSampleDlg)
	ON_WM_QUERYDRAGICON()
	ON_BN_CLICKED(IDC_BTN_LOCK, OnSIMLock)
	ON_BN_CLICKED(IDC_BTN_APPLY, OnChangePIN)
	ON_BN_CLICKED(IDC_BTN_CONNECT, OnBtnConnect)
	//}}AFX_MSG_MAP
	ON_MESSAGE(WM_NOTIFICATION, OnNotification) //function to handle all event notifications
END_MESSAGE_MAP()

/////////////////////////////////////////////////////////////////////////////
// CSimLockSampleDlg message handlers

BOOL CSimLockSampleDlg::OnInitDialog()
{
	CDialog::OnInitDialog();

	// Set the icon for this dialog.  The framework does this automatically
	//  when the application's main window is not a dialog
	SetIcon(m_hIcon, TRUE);			// Set big icon
	SetIcon(m_hIcon, FALSE);		// Set small icon
	
	// TODO: Add extra initialization here

	//initializing variables.
	m_bConnected = FALSE;
	m_bSIMLocked = FALSE;
	m_bFlagPINChanging = FALSE;

	//update values to screen
	UpdateData(FALSE);

	return TRUE;  // return TRUE  unless you set the focus to a control
}

SWI_TYPE_Device CSimLockSampleDlg::GetHighestPriorityDeviceType ()
{
	SWI_TYPE_Device				eTypeDevice = SWI_DEVICE_None;
	SWI_STRUCT_AirServerList	sAvailDevList;
	SWI_RCODE					rCode;

	//--------------------
	// Connect to ANY device
	//--------------------
	sAvailDevList.sizeStruct = sizeof(SWI_STRUCT_AirServerList);
	rCode = SwiGetAvailAirServers(sAvailDevList);
	if (SWI_RCODE_OK != rCode)
	{
		m_strStatusIndicator =  _T("GetAvailDev() Failed");
		return eTypeDevice;
	}

	// how many avail devices?
	if (0 == sAvailDevList.nNumber)
	{
		m_strStatusIndicator = _T("No available devices");
		return eTypeDevice;
	}

	return sAvailDevList.AirServers[0].eDevice;
}

// The system calls this to obtain the cursor to display while the user drags
//  the minimized window.
HCURSOR CSimLockSampleDlg::OnQueryDragIcon()
{
	return (HCURSOR) m_hIcon;
}


/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	NotificationCallback
//
//	Description	:	Callback that receives all event notifications
//
//	Arguments	:	[IN]: pNotify - pointer to notification variant
//
//	Returns		:	None
//
//	Comments	:	Even if no notifications are being processed,
//					this function still needs to be registered and declared
//					for calls to the API to function properly.
//
/////////////////////////////////////////////////////////////////////////////
void NotificationCallback(SwiNotifyVariant *pNotify)
{
	//Create a pointer to this object then send pNotify to 'HandleCallback'
	//to cache the data and then process the notification.  Note that notifications
	//should never be processed in the call back function because it will hold
	//up the thread while other notifications are trying to get in
	CSimLockSampleDlg* pThisObject = CSimLockSampleDlg::Instance();
	pThisObject->HandleCallback(pNotify);

}


/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	ProcessError
//
//	Description	:	Helper function to process error codes
//
//	Arguments	:	[IN]: code - error code from the API
//
//	Returns		:	None
//
//	Comments	:
//
/////////////////////////////////////////////////////////////////////////////
void CSimLockSampleDlg::ProcessError(SWI_RCODE code)
{
	CString strErrorString;

	strErrorString.Format(_T("Internal error - error code: %d"), code);

	MessageBox(strErrorString, _T("API Message"), MB_OK);
}


/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	OnOK
//
//	Description	:	OK button has been pressed to exit the application
//
//	Arguments	:	None
//
//	Returns		:	None
//
//	Comments	:
//
///////////////////////////////////////////////////////////////////////////
void CSimLockSampleDlg::OnOK() 
{
	//disabling connection button for duration of disconnection
	m_btnOK.EnableWindow(FALSE);

	//disconnect from modem if there is a live connection
	DisconnectModem();

	CDialog::OnOK();
	
}


/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	OnNotification
//
//	Description	:	Handler for received notifications
//
//	Arguments	:	[IN]: wParam - Contains the notification type
//					[IN]: lParam - Contains the data to be updated
//
//	Returns		:	None
//
//	Comments	:
//
/////////////////////////////////////////////////////////////////////////////
LRESULT CSimLockSampleDlg::OnNotification(WPARAM wParam, LPARAM lParam)
{
	SWI_STRUCT_SIM_StatusExp sSimStatus; //structure to store a SWI_STRUCT_SIM_StatusExp
	SwiNotifyVariant* pNotify = (SwiNotifyVariant*)wParam;

	switch(pNotify->eNotify)
	{

		case SWI_NOTIFY_SimStatusExp:
			sSimStatus = pNotify->_SimStatusExp;

			//if SIM is blocked, use Watcher to unblock it, this sample app does not
			//demonstrate how to unblock a SIM, as it is similar to the SIM lock/unlock process
			if(sSimStatus.eStatus == SWI_SIMSTATUSEXP_PIN1Blocked)
			{
				MessageBox(_T("PIN1 is now blocked after too many failed attempts.  Please use Watcher to unblock the SIM."), _T("Application Message"), MB_OK);
				m_strStatusIndicator = _T("PIN1 is now blocked!");
				m_btnLockUnlockSIM.EnableWindow(FALSE);
				m_edtPINCurrent.EnableWindow(FALSE);
				m_edtPINNew.EnableWindow(FALSE);
				m_edtPINVerify.EnableWindow(FALSE);
				m_btnApplyChanges.EnableWindow(FALSE);				
			}
			else if(sSimStatus.eStatus == SWI_SIMSTATUSEXP_Locked)
			{
				m_strStatusIndicator = _T("SIM is currently locked");
				m_iLockAttempts = sSimStatus.nNumberRetries;
				m_iChangeAttempts = sSimStatus.nNumberRetries; //initializing change attempts once SIM is locked
				m_edtPINLock.SetWindowText(_T(""));
				m_btnLockUnlockSIM.SetWindowText(_T("Unlock"));
				m_btnLockUnlockSIM.EnableWindow(TRUE);
				m_edtPINCurrent.EnableWindow(TRUE);
				m_edtPINNew.EnableWindow(TRUE);
				m_edtPINVerify.EnableWindow(TRUE);
				m_btnApplyChanges.EnableWindow(TRUE);				
			}
			else if(sSimStatus.eStatus == SWI_SIMSTATUSEXP_OK)
			{

				//check if we are in the middle of a PIN change operation
				if(m_bFlagPINChanging)
				{
					//PIN change in progress, check result code of PIN change operation
					if(sSimStatus.ePreviousActionResult == SWI_PREVIOUSACTIONRESULT_Succeeded)
					{
						m_strStatusIndicator = _T("PIN1 changed successfully!");
						m_iChangeAttempts = sSimStatus.nNumberRetries;
						m_iLockAttempts = sSimStatus.nNumberRetries;
						m_btnApplyChanges.EnableWindow(TRUE);
						m_btnLockUnlockSIM.EnableWindow(TRUE);
						m_edtPINCurrent.SetWindowText(_T(""));
						m_edtPINNew.SetWindowText(_T(""));
						m_edtPINVerify.SetWindowText(_T(""));

					}
					else //PIN change failed
					{
						m_strStatusIndicator = _T("Failed to change PIN1");
						m_iChangeAttempts = sSimStatus.nNumberRetries;
						m_iLockAttempts = sSimStatus.nNumberRetries;
						m_btnApplyChanges.EnableWindow(TRUE);
						m_btnLockUnlockSIM.EnableWindow(TRUE);
						m_edtPINCurrent.SetWindowText(_T(""));
						m_edtPINNew.SetWindowText(_T(""));
						m_edtPINVerify.SetWindowText(_T(""));
					}

					m_bFlagPINChanging = FALSE;
				}

				//check if we are in the middle of a SIM Locking operation or
				//check if application has just been initialized
				if(m_bFlagPINLocking || m_bFlagAppInitialized)
				{
					//retrieve SIM lock status
					if(!GetSIMLockStatus(&m_bSIMLocked))
					{
						m_strStatusIndicator = _T("Failed to get SIM Lock Status");
						UpdateData(FALSE);
						return NULL;
					}
					
					//check if SIM is currently locked
					if(m_bSIMLocked)
					{
						m_strStatusIndicator = _T("SIM is currently locked");
						m_iLockAttempts = sSimStatus.nNumberRetries;
						m_iChangeAttempts = sSimStatus.nNumberRetries; 
						m_edtPINLock.SetWindowText(_T(""));
						m_btnLockUnlockSIM.SetWindowText(_T("Disable SIM Security"));
						m_btnLockUnlockSIM.EnableWindow(TRUE);
						m_edtPINCurrent.EnableWindow(TRUE);
						m_edtPINNew.EnableWindow(TRUE);
						m_edtPINVerify.EnableWindow(TRUE);
						m_btnApplyChanges.EnableWindow(TRUE);
					}
					else
					{
						m_strStatusIndicator = _T("SIM is currently unlocked");
						m_iChangeAttempts = sSimStatus.nNumberRetries;
						m_iLockAttempts = sSimStatus.nNumberRetries;
						m_edtPINLock.SetWindowText(_T(""));
						m_edtPINCurrent.SetWindowText(_T(""));
						m_edtPINNew.SetWindowText(_T(""));
						m_edtPINVerify.SetWindowText(_T(""));
						m_btnLockUnlockSIM.SetWindowText(_T("Enable SIM Security"));
						m_btnLockUnlockSIM.EnableWindow(TRUE);
						m_edtPINCurrent.EnableWindow(FALSE);
						m_edtPINNew.EnableWindow(FALSE);
						m_edtPINVerify.EnableWindow(FALSE);
						m_btnApplyChanges.EnableWindow(FALSE);
					}

					m_bFlagPINLocking = FALSE;

					//this flag won't be set to TRUE again until application is re-initialized
					m_bFlagAppInitialized = FALSE;
				}
			}
			else
			{
				m_strStatusIndicator = _T("Error occurred");
			}
			break;
		default:
			break;
	}

	delete (SwiNotifyVariant*)wParam;	
	//update the values to the screen
	UpdateData(FALSE);	
	return NULL;
}


/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	OnSIMLock
//
//	Description	:	Enable/Disables SIM security
//
//	Arguments	:	None
//
//	Returns		:	None
//
//	Comments	:	
//
///////////////////////////////////////////////////////////////////////////
void CSimLockSampleDlg::OnSIMLock() 
{
	
	SIMLock();
	
}


/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	SIMLock
//
//	Description	:	Enable/Disables SIM security
//
//	Arguments	:	None
//
//	Returns		:	None
//
//	Comments	:	Minimal error checking was done for this function to keep app simple
//
///////////////////////////////////////////////////////////////////////////
void CSimLockSampleDlg::SIMLock()
{

	SWI_RCODE eRcode;
	SWI_STRUCT_SIM_EnableLock sSIMEnableLock;
	CString strPIN;
	CString strBtnStatus(_T(""));

	memset(&sSIMEnableLock, 0, sizeof(SWI_STRUCT_SIM_EnableLock));
	sSIMEnableLock.sizeStruct = sizeof(SWI_STRUCT_SIM_EnableLock);

	//Checking minimum length of PIN
	if(m_edtPINLock.GetWindowTextLength() < MINPINLENGTH)
	{
		m_strStatusIndicator.Format(_T("A PIN requires more than %d characters"), MINPINLENGTH);
		UpdateData(FALSE);
		return;
	}

	//retrieving text from button, we will then use the text to determine
	//what state the SIM is in
	GetDlgItem(IDC_BTN_LOCK)->GetWindowText(strBtnStatus);

	//retrieving PIN from screen
	m_edtPINLock.GetWindowText(strPIN);

	//disable Lock/Unlock button and display 'processing' message for duration of operation
	m_btnLockUnlockSIM.EnableWindow(FALSE);
	m_strStatusIndicator = _T("Processing...");

	//update values to screen
	UpdateData(FALSE);


	if(strBtnStatus == "Unlock")
	{
		m_bFlagPINLocking = TRUE;

		SWI_STRUCT_SIM_Verify sSim;
		sSim.sizeStruct = sizeof(SWI_STRUCT_SIM_Verify);
		sSim.eType = SWI_SIMPASSWORD_CHV1;

		_tcscpy(sSim.szPassword, strPIN);
		eRcode = SwiSetSimVerify(&sSim, TIMEOUT3*10);
		if(SWI_RCODE_OK != eRcode)
		{
			m_strStatusIndicator = _T("Failed to Verify PIN.");
			m_btnLockUnlockSIM.EnableWindow(TRUE);
			ProcessError(eRcode);
			UpdateData(FALSE);
			return;
		}

	}
	else if(strBtnStatus == "Enable SIM Security")
	{

		m_bFlagPINLocking = TRUE; //indicates SIM locking operation in progress
		sSIMEnableLock.bEnable = TRUE;
		_tcscpy(sSIMEnableLock.szPassword, strPIN);

		//result of request will be received in the form of a notification later
		eRcode = SwiSetSimLock(&sSIMEnableLock, TIMEOUT3*10);
		if(SWI_RCODE_OK != eRcode)
		{
			m_strStatusIndicator = _T("Failed to Lock SIM");
			m_btnLockUnlockSIM.EnableWindow(TRUE);
			ProcessError(eRcode);
			UpdateData(FALSE);
			return;
		
		}


	}
	else if(strBtnStatus == "Disable SIM Security")
	{
		m_bFlagPINLocking = TRUE; //indicates SIM unlocking operation in progress
		sSIMEnableLock.bEnable = FALSE;
		_tcscpy(sSIMEnableLock.szPassword, strPIN);

		//result of request will be received in the form of a notification later
		eRcode = SwiSetSimLock(&sSIMEnableLock, TIMEOUT3*10);
		if(SWI_RCODE_OK != eRcode)
		{
			m_strStatusIndicator = _T("Failed to Unlock SIM");
			m_btnLockUnlockSIM.EnableWindow(TRUE);
			ProcessError(eRcode);
			UpdateData(FALSE);
			return;

		}
	}


}




/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	GetSIMLockStatus
//
//	Description	:	Function used to check if SIM Security is currently enabled/disabled
//
//	Arguments	:	[OUT]: LockStatus - pointer to a boolean to store the SIM Lock Status
//
//	Returns		:	TRUE/FALSE - indicate success or failure of operation
//
//	Comments	:
//
///////////////////////////////////////////////////////////////////////////
BOOL CSimLockSampleDlg::GetSIMLockStatus(BOOL* LockStatus)
{
	SWI_RCODE eRcode;
	SWI_STRUCT_SIM_LockStatus sSIMLockStatus;

	memset(&sSIMLockStatus, 0, sizeof(SWI_STRUCT_SIM_LockStatus));
	sSIMLockStatus.sizeStruct = sizeof(SWI_STRUCT_SIM_LockStatus);

	//retrieving SIM Lock status
	eRcode = SwiGetSimLock(&sSIMLockStatus, TIMEOUT3);
	if(SWI_RCODE_OK != eRcode)
	{
		ProcessError(eRcode);
		return FALSE;
	}

	*LockStatus = sSIMLockStatus.bEnabled;

	return TRUE;
}


/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	ConnectModem
//
//	Description	:	Start a Connection to the Modem
//
//	Arguments	:	None
//
//	Returns		:	TRUE/FALSE to indicate success of connection
//
//	Comments	:
//
///////////////////////////////////////////////////////////////////////////
BOOL CSimLockSampleDlg::ConnectModem() 
{	
	SWI_RCODE rCode;
	SWI_TYPE_Device eDevice;
	BOOL bDisconnected; //checks if disconnection was successful

	//connect if there is no connection to the modem
	if(m_bConnected == FALSE)
	{
		//Open a connection with the Modem
		SWI_STRUCT_ApiStartup sOpenParams;
		memset(&sOpenParams, 0, sizeof(SWI_STRUCT_ApiStartup));

		rCode = SwiApiStartup(&sOpenParams);
		if(SWI_RCODE_OK != rCode 
			&& SWI_RCODE_ALREADY_OPEN != rCode) // Bz13170
		{
			ProcessError(rCode);
			return FALSE;
		}

		eDevice = GetHighestPriorityDeviceType ();
		if (eDevice == SWI_DEVICE_None)
		{
			UpdateData(FALSE);
			return FALSE;
		}

		DECLARE_MacAny;
		SWI_STRUCT_AirServer sAirServer;
		sAirServer.sizeStruct = sizeof(SWI_STRUCT_AirServer);
		memcpy(sAirServer.ClientMac, MacAny, LENGTH_MacAddress);
		memcpy(sAirServer.ServerMac, MacAny, LENGTH_MacAddress);
		sAirServer.eDevice = eDevice;

		rCode = SwiSelectAirServer(sAirServer);
		if(SWI_RCODE_OK != rCode)
		{
			ProcessError(rCode);
			return FALSE;
		}

		//Register the Callback function
		rCode = SwiRegisterCallback(NotificationCallback, 0xFFFFFFFFFFFFFFFF);
		if(SWI_RCODE_OK != rCode)
		{
			ProcessError(rCode);
			return FALSE;
		}

		// Enable notifications
		rCode = SwiNotify(SWI_NOTIFY_SimStatusExp, TIMEOUT3);
		if(SWI_RCODE_OK != rCode)
		{
			ProcessError(rCode);
			return FALSE;
		}

		//informing modem of host startup state
		//this function will attach the modem onto the network
		rCode = SwiSetHostStartup(TRUE, TIMEOUT3*20);
		if(SWI_RCODE_OK != rCode)
		{
			ProcessError(rCode);
			return FALSE;
		}

		//as we are here there are no errors
		//Initialize member variables and change GUI to reflect a successful connection
		//to the API
		m_bConnected = TRUE;
		m_strStatusIndicator = _T("Connected to device");
		m_btnLockUnlockSIM.EnableWindow(TRUE);
		m_btnConnect.SetWindowText(_T("Disconnect"));
		m_btnConnect.EnableWindow(TRUE);

		//Update values to screen
		UpdateData(FALSE);
		return TRUE;
	}
	else
	{
		//Disconnect from modem
		bDisconnected = DisconnectModem();

		//checking if disconnection was successful
		if(bDisconnected)
		{
			m_strStatusIndicator = _T("Disconnected from device");
		}
		else
		{
			m_strStatusIndicator = _T("Error occured while disconnecting");
		}

		//reset member variables and modify GUI to reflect a disconnection from the API
		m_bConnected = FALSE;
		m_btnLockUnlockSIM.EnableWindow(FALSE);
		m_btnConnect.SetWindowText(_T("Connect"));
		m_btnConnect.EnableWindow(TRUE);

		//Updating values to screen
		UpdateData(FALSE);
		return TRUE;
	}

	return FALSE;

}


/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	DisconnectModem
//
//	Description	:	Disconnects from the modem
//
//	Arguments	:	None
//
//	Returns		:	TRUE/FALSE to indicate success or failure of disconnection
//
//	Comments	:
//
///////////////////////////////////////////////////////////////////////////
BOOL CSimLockSampleDlg::DisconnectModem()
{

	SWI_RCODE eRcode;

	//disconnect if a connection to the modem exists
	if(m_bConnected == TRUE)
	{

		// Disable notifications
		eRcode = SwiStopNotify(SWI_NOTIFY_SimStatusExp, TIMEOUT3);
		if (SWI_RCODE_OK != eRcode)
		{
			ProcessError(eRcode);
			return FALSE;
		}


		//close connection with modem
		eRcode = SwiApiShutdown();	
		if (SWI_RCODE_OK != eRcode)
		{

			ProcessError(eRcode);
			return FALSE;

		}


	}

	return TRUE;

}


/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	OnChangePIN
//
//	Description	:	Changes PIN1 of the SIM
//
//	Arguments	:	None
//
//	Returns		:	None
//
//	Comments	:	The CHV1 (PIN1) code can only be changed when enabled (using SwiSetSimLock). 
//					Emergency numbers cannot be used as CHV1 codes, or as the beginning of 
//					CHV1 codes.  PUK1 and PUK2 are not valid parameters, although the data 
//					structure includes them.  Error checking for these cases wasn't done here to 
//					keep this sample application as simple as possible.
///////////////////////////////////////////////////////////////////////////
void CSimLockSampleDlg::OnChangePIN() 
{

	SWI_RCODE eRcode;
	SWI_STRUCT_SIM_Password sSimPasswords;
	CString strCurrentPassword;
	CString strNewPassword;
	CString strNewPassVerify;

	if(!m_bConnected)
	{
		m_strStatusIndicator = _T("Operation failed.");
		UpdateData(FALSE);
		return;
	}

	//retrieving values from screen
	m_edtPINCurrent.GetWindowText(strCurrentPassword);
	m_edtPINNew.GetWindowText(strNewPassword);
	m_edtPINVerify.GetWindowText(strNewPassVerify);


	//Checking minimum length of PINs
	if(strCurrentPassword.GetLength() < MINPINLENGTH || strNewPassword.GetLength() < MINPINLENGTH || strNewPassVerify.GetLength() < MINPINLENGTH)
	{
		m_strStatusIndicator.Format(_T("All PINs require more than %d characters"), MINPINLENGTH);
		UpdateData(FALSE);
		return;
	}

	m_btnApplyChanges.EnableWindow(FALSE);
	m_btnLockUnlockSIM.EnableWindow(FALSE);


	//verifying PIN
	if(!(strNewPassword == strNewPassVerify))
	{
		m_strStatusIndicator = _T("New PIN and Verify PIN fields do not match!");
		m_btnApplyChanges.EnableWindow(TRUE);
		m_btnLockUnlockSIM.EnableWindow(TRUE);
		UpdateData(FALSE);
		return;
	}

	//copying old and new PIN to password structure
	sSimPasswords.sizeStruct = sizeof(SWI_STRUCT_SIM_Password);
	_tcscpy(sSimPasswords.szOldPassword, strCurrentPassword);
	_tcscpy(sSimPasswords.szNewPassword, strNewPassword);

	m_strStatusIndicator = _T("Processing...");

	m_bFlagPINChanging = TRUE; //indicate that a PIN change operation is in progress

	//result of request will be received later in the form of a notification
	eRcode = SwiSetSimPassword(&sSimPasswords, TIMEOUT3);
	if (SWI_RCODE_OK != eRcode)
	{
		m_strStatusIndicator = _T("PIN change error occurred");
		m_btnApplyChanges.EnableWindow(TRUE);
		m_btnLockUnlockSIM.EnableWindow(TRUE);
		ProcessError(eRcode);
		return;
	}
	
	//update values to screen
	UpdateData(FALSE);

}


/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	HandleCallback
//
//	Description	:	Caches data from NotificationCallback (therefore freeing the thread)
//					and posts a message for notification handling
//					
//	Arguments	:	[IN]: pNotify - pointer to notification variant
//
//	Returns		:	None
//
//	Comments	:
//
///////////////////////////////////////////////////////////////////////////
void CSimLockSampleDlg::HandleCallback(SwiNotifyVariant *pNotify)
{

	//used for debugging purposes, displays the notifications received
	TRACE(_T("Got notif %i\n"), pNotify->eNotify);

	SwiNotifyVariant* pCopy = (SwiNotifyVariant*) new SwiNotifyVariant;
	
	// For simplicity, we are allocating a copy of the notification from 
	// the heap. An industrial-strength app would allocate the copy from 
	// a fixed pool of objects to avoid memory fragmentation. 
	if (pCopy)
	{
		*pCopy = *pNotify;
		m_instance->PostMessage(WM_NOTIFICATION, WPARAM(pCopy), NULL ); 
	}


}


/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	Instance
//
//	Description	:	A static function used to return a pointer to this object
//
//	Arguments	:	None
//
//	Returns		:	m_Instance - a pointer to this object
//
//	Comments	:
//
///////////////////////////////////////////////////////////////////////////
CSimLockSampleDlg* CSimLockSampleDlg::Instance()
{
	return m_instance;
}

/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	OnBtnConnect
//
//	Description	:	Connect/Disconnect to/from modem
//
//	Arguments	:	None
//
//	Returns		:	None
//
//	Comments	:
//
///////////////////////////////////////////////////////////////////////////
void CSimLockSampleDlg::OnBtnConnect() 
{
	ConnectModem();
}
