/**
 *
 *	Name	:	SimLockSampleDlg.h
 *
 *	Purpose	:	main header file for the SimLockSample application
 *
 *	History	:	Created June 11th, 2003
 *				This sample application demonstrates how to lock/unlock a SIM (enable/disable
 *				SIM security) as well as how to change the PIN1 of a SIM
 *
 *				Updated July 5th, 2005
 *				Fixed bug that occurred when launching the app with an Aircard that is already
 *				in a locked state.
 *
 *	Revision:	1.0
 *
 *	Copyright (c) 2003 Sierra Wireless, Inc. All rights reserved.
 *
 **/

#if !defined(AFX_SimLockSampleDLG_H__8754D42C_9DB8_4453_8EE6_C53B4053A14F__INCLUDED_)
#define AFX_SimLockSampleDLG_H__8754D42C_9DB8_4453_8EE6_C53B4053A14F__INCLUDED_

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000

#include "SwiStructsGsm.h"
#include "SwiApiCm.h"


#define TIMEOUT3 3000
#define MINPINLENGTH 4
#define MAXATTEMPTS 3

// user defined windows message identifier for Rssi notification
#define WM_NOTIFICATION WM_USER + 400	//specific notification

/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	NotificationCallback
//
//	Description	:	Callback that receives all event notifications
//
//	Arguments	:	[IN]: pNotify - pointer to notification variant
//
//	Returns		:	None
//
//	Comments	:	Even if no notifications are being processed,
//					this function still needs to be registered and declared
//					for calls to the API to function properly.
//
/////////////////////////////////////////////////////////////////////////////
void NotificationCallback(SwiNotifyVariant *pNotify);

/////////////////////////////////////////////////////////////////////////////
// CSimLockSampleDlg dialog

class CSimLockSampleDlg : public CDialog
{
// Construction
public:
	CSimLockSampleDlg(CWnd* pParent = NULL);	// standard constructor

// Dialog Data
	//{{AFX_DATA(CSimLockSampleDlg)
	enum { IDD = IDD_SimLockSample_DIALOG };
	CButton	m_btnConnect;
	CEdit	m_edtPINVerify;
	CEdit	m_edtPINLock;
	CEdit	m_edtPINCurrent;
	CEdit	m_edtPINNew;
	CButton	m_btnOK;
	CButton	m_btnLockUnlockSIM;
	CButton	m_btnApplyChanges;
	CString	m_strStatusIndicator;
	UINT	m_iLockAttempts;
	UINT	m_iChangeAttempts;
	//}}AFX_DATA

	// ClassWizard generated virtual function overrides
	//{{AFX_VIRTUAL(CSimLockSampleDlg)
	protected:
	virtual void DoDataExchange(CDataExchange* pDX);	// DDX/DDV support
	//}}AFX_VIRTUAL

// Implementation
public:
	LRESULT OnNotification(WPARAM wParam, LPARAM lParam);
	BOOL GetSIMLockStatus(BOOL* LockStatus); //
	BOOL ConnectModem(); //connects to modem
	BOOL DisconnectModem(); //disconnects from modem
	void ProcessError(SWI_RCODE code); //handle error codes from the API
	void HandleCallback(SwiNotifyVariant* pNotify); //caches data from notificaiton callback
	static CSimLockSampleDlg* Instance(); //returns a pointer to this object
	void SIMLock();
	SWI_TYPE_Device GetHighestPriorityDeviceType ();

private:
	static CSimLockSampleDlg* m_instance; //a pointer to this object

protected:
	HICON m_hIcon;
	BOOL m_bConnected; //connection status indicator
	BOOL m_bSIMLocked; //true if the SIM is locked
	BOOL m_bFlagPINLocking; //true if a SIM Locking operation is in progress 
	BOOL m_bFlagPINChanging; //true if PIN1 is in the process of being changed
	BOOL m_bFlagAppInitialized; //true if application has just been initialized

	enum TYPE_Device
	{
		DEVICE_AC710_750_775_850,
		DEVICE_MC87xx,
	};

	// Generated message map functions
	//{{AFX_MSG(CSimLockSampleDlg)
	virtual BOOL OnInitDialog();
	afx_msg HCURSOR OnQueryDragIcon();
	afx_msg void OnOK();
	afx_msg void OnSIMLock();
	afx_msg void OnChangePIN();
	afx_msg void OnBtnConnect();
	//}}AFX_MSG
	DECLARE_MESSAGE_MAP()
};

//{{AFX_INSERT_LOCATION}}
// Microsoft Visual C++ will insert additional declarations immediately before the previous line.

#endif // !defined(AFX_SimLockSampleDLG_H__8754D42C_9DB8_4453_8EE6_C53B4053A14F__INCLUDED_)
