/**
 *
 *	Name	:	SMSInboxSampleDlg.cpp
 *
 *	Purpose	:	Main dialog implementation file, allows the user to get and delete 
 *				SMS messages stored on a Sim card
 *
 *	History	:	created	June 10, 2003
 *				- initial version, based on old SDK's SMS Sample Application
 *
 *	Revision:	1.0
 *
 *	Copyright (c) 2003 Sierra Wireless, Inc. All rights reserved.
 *
 **/

#include "stdafx.h"

#include "SMSInboxSample.h"
#include "SMSInboxSampleDlg.h"
#include "SwiApiGsm.h"
#include "SwiSmsGsm.h"

#ifdef _DEBUG
#define new DEBUG_NEW
#undef THIS_FILE
static char THIS_FILE[] = __FILE__;
#endif

#define GSM_CHARACTER_SET_SIZE          0x80
#define EXTEND	0x001B


const unsigned short ExtendedGsmToUcs2[GSM_CHARACTER_SET_SIZE] =
{         /*+0x0        +0x1        +0x2        +0x3        +0x4        +0x5        +0x6        +0x7*/
/*0x00*/    0,          0,           0,         0,          0 ,         0,          0,          0,
/*0x08*/    0,          0,           0x0A,      0,          0,          0,          0,          0,
/*0x10*/    0,          0,           0,         0,          0x005E,     0,          0,          0,
/*0x18*/    0,          0,           0,         0x20,       0,          0,          0,          0,
/*0x20*/    0,          0,           0,         0,          0,          0,          0,          0,
/*0x28*/    0x7B,       0x7D,        0,         0,          0,          0,          0,          0x5C,
/*0x30*/    0,          0,           0,         0,          0,          0,          0,          0,
/*0x38*/    0,          0,           0,         0,          0x5B,       0x7E,       0x5D,       0,
/*0x40*/    0x7C,       0,           0,         0,          0,          0,          0,          0,
/*0x48*/    0,          0,           0,         0,          0,          0,          0,          0,
/*0x50*/    0,          0,           0,         0,          0,          0,          0,          0,
/*0x58*/    0,          0,           0,         0,          0,          0,          0,          0,
/*0x60*/    0,          0,           0,         0,          0,         0x20AC,      0,          0,
/*0x68*/    0,          0,           0,         0,          0,          0,          0,          0,
/*0x70*/    0,          0,           0,         0,          0,          0,          0,          0,
/*0x78*/    0,          0,           0,         0,          0,          0,          0,          0
};
const unsigned short GsmToUcs2[GSM_CHARACTER_SET_SIZE] =
{         /*+0x0        +0x1        +0x2        +0x3        +0x4        +0x5        +0x6        +0x7*/
/*0x00*/    0x40,       0xa3,       0x24,       0xa5,       0xe8,       0xe9,       0xf9,       0xec,
/*0x07*/    0xf2,       0xc7,       0x0a,       0xd8,       0xf8,       0x0d,       0xc5,       0xe5,
/*0x10*/    0x0394,     0x5f,       0x03A6,     0x0393,     0x039b,     0x03a9,     0x03a0,     0x03a8,
/*0x18*/    0x03a3,     0x0398,     0x039e,     EXTEND,     0xc6,       0xe6,       0xdf,       0xc9,
/*0x20*/    0x20,       0x21,       0x22,       0x23,       0xA4,       0x25,       0x26,       0x27,
/*0x28*/    0x28,       0x29,       0x2a,       0x2b,       0x2c,       0x2d,       0x2e,       0x2f,
/*0x30*/    0x30,       0x31,       0x32,       0x33,       0x34,       0x35,       0x36,       0x37,
/*0x37*/    0x38,       0x39,       0x3a,       0x3b,       0x3c,       0x3d,       0x3e,       0x3f,
/*0x40*/    0xa1,       0x41,       0x42,       0x43,       0x44,       0x45,       0x46,       0x47,
/*0x48*/    0x48,       0x49,       0x4a,       0x4b,       0x4c,       0x4d,       0x4e,       0x4f,
/*0x50*/    0x50,       0x51,       0x52,       0x53,       0x54,       0x55,       0x56,       0x57,
/*0x58*/    0x58,       0x59,       0x5a,       0xc4,       0xd6,       0xd1,       0xdc,       0xa7,
/*0x60*/    0xbf,       0x61,       0x62,       0x63,       0x64,       0x65,       0x66,       0x67,
/*0x68*/    0x68,       0x69,       0x6a,       0x6b,       0x6c,       0x6d,       0x6e,       0x6f,
/*0x70*/    0x70,       0x71,       0x72,       0x73,       0x74,       0x75,       0x76,       0x77,
/*0x78*/    0x78,       0x79,       0x7a,       0xe4,       0xf6,       0xf1,       0xfc,       0xe0
};


CSMSInboxSampleDlg* CSMSInboxSampleDlg::m_instance = NULL;	// init pointer to this obj to null

/////////////////////////////////////////////////////////////////////////////
// CSMSInboxSampleDlg dialog

CSMSInboxSampleDlg::CSMSInboxSampleDlg(CWnd* pParent /*=NULL*/)
	: CDialog(CSMSInboxSampleDlg::IDD, pParent)
{
	//{{AFX_DATA_INIT(CSMSInboxSampleDlg)
	m_strReadSmsStatus = _T("");
	m_instance = this;
	m_szMessageBody = _T("");
	m_strCharCount = _T("");
	//}}AFX_DATA_INIT
	// Note that LoadIcon does not require a subsequent DestroyIcon in Win32
	m_hIcon = AfxGetApp()->LoadIcon(IDR_MAINFRAME);
}

void CSMSInboxSampleDlg::DoDataExchange(CDataExchange* pDX)
{
	CDialog::DoDataExchange(pDX);
	//{{AFX_DATA_MAP(CSMSInboxSampleDlg)
	DDX_Control(pDX, IDC_GETNEWSMS, m_btnGetSms);
	DDX_Control(pDX, IDC_DELETESMS, m_btnDelete);
	DDX_Control(pDX, ID_OK, m_btnOK);
	DDX_Control(pDX, IDC_SMSINBOXLIST, m_SmsInboxList);
	DDX_Text(pDX, IDC_READSMSSTATUS, m_strReadSmsStatus);
	DDX_Text(pDX, IDC_MESSAGEBODY, m_szMessageBody);
	DDX_Text(pDX, IDC_STA_SMSCharCnt, m_strCharCount);
	//}}AFX_DATA_MAP
}

BEGIN_MESSAGE_MAP(CSMSInboxSampleDlg, CDialog)
	//{{AFX_MSG_MAP(CSMSInboxSampleDlg)
	ON_WM_QUERYDRAGICON()
	ON_BN_CLICKED(IDC_GETNEWSMS, OnGetSms)
	ON_BN_CLICKED(IDC_DELETESMS, OnDeleteSms)
	ON_WM_SYSCOMMAND()
	ON_BN_CLICKED(ID_OK, OnOK)
	ON_NOTIFY(NM_CLICK, IDC_SMSINBOXLIST, OnClickSmsinboxlist)
	//}}AFX_MSG_MAP

	//function to handle all event notifications
	ON_MESSAGE(WM_NOTIFICATION, OnNotification)
END_MESSAGE_MAP()

/////////////////////////////////////////////////////////////////////////////
// CSMSInboxSampleDlg message handlers

BOOL CSMSInboxSampleDlg::OnInitDialog()
{
	CDialog::OnInitDialog();

	// Set the icon for this dialog.  The framework does this automatically
	//  when the application's main window is not a dialog
	SetIcon(m_hIcon, TRUE);			// Set big icon
	SetIcon(m_hIcon, FALSE);		// Set small icon
	
	// Initialize main member variables 
	m_bConnected = FALSE;

	// setup Sms list control columns
	CString strLabel;
	strLabel = _T("From");	// list label, SMS Sender Number
	m_SmsInboxList.InsertColumn(0, strLabel, LVCFMT_LEFT, COLUMN_WIDTH);	// assign label to ctrl
	strLabel = _T("Callback");	// list label, SMS's Destination Address Number (SME)
	m_SmsInboxList.InsertColumn(1, strLabel, LVCFMT_LEFT, COLUMN_WIDTH);	// assign label to ctrl
	strLabel = _T("Time");	// list label, Time on SMS header
	m_SmsInboxList.InsertColumn(2, strLabel, LVCFMT_LEFT, COLUMN_WIDTH);	// assign label to ctrl

	// open API on start of Dialog
	if (ConnectModem())
	{
		// flag boolean to indicated Connected 
		m_bConnected = TRUE;	// sets Connected bool to TRUE
		// update status box to inform user of connections
		m_strReadSmsStatus =  _T("Modem is connected, Initializing SMS...");
	}
	else
	{
		// close app if connection is unsuccessful
		OnOK();
	}
	
	// update data to screen
	UpdateData (FALSE);

	return TRUE;  // return TRUE  unless you set the focus to a control
}


// The system calls this to obtain the cursor to display while the user drags
//  the minimized window.
HCURSOR CSMSInboxSampleDlg::OnQueryDragIcon()
{
	return (HCURSOR) m_hIcon;
}


/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	ProcessError
//
//	Description	:	Helper function to process error codes, displays a 
//					message box indicating the error code that was returned
//
//	Arguments	:	[IN] - code - an error code returned from an API call
//
//	Returns		:	None
//
//	Comments	:	
//
/////////////////////////////////////////////////////////////////////////////
void CSMSInboxSampleDlg::ProcessError(SWI_RCODE code)
{
	CString strErrorString;
	
	// string to display internal error code
	strErrorString.Format(_T("Internal error - error code: %d"), code);
	
	// output to message box
	MessageBox(strErrorString, _T("API Message"), MB_OK);
}


/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	GetAddressNumber
//
//	Description	:	Helper function to convert address number to user-friendly
//					form
//
//	Arguments	:	[OUT] - strNumber - CString that will contain final form
//					[IN] - pBuffer - pointer to data in input buffer with address number
//					[IN] - iLength - length of the data pointed to by pBuffer
//
//	Returns		:	None
//
//	Comments	:	Formats an address number, inserts '-' between groups of numbers in address
//
/////////////////////////////////////////////////////////////////////////////
void CSMSInboxSampleDlg::GetAddressNumber (CString &strNumber,  BYTE *pBuffer, int iLength)
{
    strNumber = _T("");
    CHAR arrDigit[2];

	if (_tcsicmp((TCHAR*)pBuffer, _T("voicemail")) == 0)
	{
		strNumber = pBuffer;
		return;
	}

	// parse byte buffer
    for (int idx = 0; idx < iLength; ++idx)
    {
        _itoa( *pBuffer++, arrDigit, 10 );
        strNumber += arrDigit;
    }
	// inserts '-'
    strNumber.Insert(iLength - FIRST_HYPHEN_LOCATION, _T("-"));
    strNumber.Insert(iLength - SECOND_HYPHEN_LOCATION, _T("-"));
}


/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	GetTimeStamp
//
//	Description	:	Helper function to convert time stamp to user-friendly
//					form
//
//	Arguments	:	[OUT] - strTimeStamp - CString that will contain final form
//					[IN] - pBuffer - pointer to data in input buffer with time stamp
//
//	Returns		:	None
//
//	Comments	:	Formats a time, inserts '/' between date values, 
//					and ':' between the time values
//
/////////////////////////////////////////////////////////////////////////////
void CSMSInboxSampleDlg::GetTimeStamp (CString &strTimeStamp, BYTE *pBuffer)
{
    CHAR arrDigit[2];
    strTimeStamp = _T("");
    
	// parses byte buffer (date part)
    for (int idx1 = 0; idx1 < 3; ++idx1)
    {
        _itoa( *pBuffer++, arrDigit, 10 );
        strTimeStamp += arrDigit;
        _itoa( *pBuffer++, arrDigit, 10 );
        strTimeStamp += arrDigit;
        if (idx1 < 2)
            strTimeStamp += _T("/");
    }
	// inserts spaces to separate date and time values
    strTimeStamp += _T("  ");
	// parses byte buffer (time part)
    for (int idx2 = 0; idx2 < 3; ++idx2)
    {
        _itoa( *pBuffer++, arrDigit, 10 );
        strTimeStamp += arrDigit;
        _itoa( *pBuffer++, arrDigit, 10 );
        strTimeStamp += arrDigit;
        if (idx2 < 2)
            strTimeStamp += _T(":");
    }
}


/////////////////////////////////////////////////////////////////////////////
//
//	Event		:	OnOK
//
//	Description	:	Event triggered when the EXIT key is pressed, if API is 
//					open then close it and exit, else exit
//
//	Arguments	:	None
//
//	Returns		:	None
//
//	Comments	:	
//
/////////////////////////////////////////////////////////////////////////////
void CSMSInboxSampleDlg::OnOK() 
{
	// disable the OK button
	m_btnOK.EnableWindow(FALSE);

	// run disconnect modem function
	DisconnectModem();

	CDialog::OnOK();
}


////////////////////////////////////////////////////////////////////////////
//
//	Function	:	NotificationCallback
//
//	Description	:	Callback that receives all event notifications
//
//	Arguments	:	[IN] - pNotify	- pointer to notification variant
//
//	Returns		:	None
//
//	Comments	:	Even if no notifications are being processed, this 
//					function still needs to be registered and declared for 
//					calls to the API to function properly
//
/////////////////////////////////////////////////////////////////////////////
void NotificationCallback(SwiNotifyVariant *pNotify)
{
	CSMSInboxSampleDlg* pThisObject = CSMSInboxSampleDlg::Instance();
	pThisObject->HandleCallback(pNotify);
}


/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	GetSms
//
//	Description	:	Function to get all stored SMS
//
//	Arguments	:	None
//
//	Returns		:	None
//
//	Comments	:	
//
/////////////////////////////////////////////////////////////////////////////
void CSMSInboxSampleDlg::GetSms()
{
	SWI_RCODE eRcode;	// define eRcode for error handling
	SWI_STRUCT_GSM_SMS_Status sSmsStatus;	// struct to store SMS Status
	SWI_STRUCT_GSM_SMS_RetrieveSms sSms;	// struct to store retrieved SMS

	// initialize structures and arrays
	memset(&sSmsStatus, 0, sizeof(SWI_STRUCT_GSM_SMS_Status));
	memset(&sSms, 0, sizeof(SWI_STRUCT_GSM_SMS_RetrieveSms));
	sSmsStatus.sizeStruct = sizeof(SWI_STRUCT_GSM_SMS_Status);
	sSms.sizeStruct = sizeof(SWI_STRUCT_GSM_SMS_RetrieveSms);
	sSms.sHeader.sizeStruct = sizeof(SWI_STRUCT_SMS_RetrieveHeader);
	m_arraySMSMessage.RemoveAll();

	// display downloading msg on status
	m_strReadSmsStatus = _T("Retrieving SMS...");
	
	// update data to screen
	UpdateData (FALSE);

	//
	// NOTE: 
	// It usually takes 30 seconds for SIM to be ready
	// 

	// get the number of read/unread messages and SIM status
	eRcode = SwiGetSMSMessageStatus(&sSmsStatus, TIMEOUT);
	// check error code, output if operation failed
	if (SWI_RCODE_OK != eRcode)
	{
		ProcessError(eRcode);
		// return false, since failed
		return;
	}

	if (!sSmsStatus.cntUsedRec)
	{
		// no messages stored on SIM
		m_strReadSmsStatus = _T("No messages to read!");
		
		// if any messages in list control, delete them all to update list ctrl
		m_SmsInboxList.DeleteAllItems();
		m_szMessageBody = _T("");

		//update screen
		UpdateData (FALSE);

		return;
	}

	// read the saved messages
	if ( (sSmsStatus.cntUsedRec - sSmsStatus.cntUnreadRec) > 0)
	{
		// for read messages bUnreadSMS is set to false
		sSms.bUnreadSMS = false;
		do
		{
			// retrieve the message
			eRcode = SwiRetrieveSMSMessage(&sSms, TIMEOUT);
			// check error code, output if operation failed
			if(SWI_RCODE_OK == eRcode)
			{
			
			// circular buffer - stop if head == tail (exit criterion)
			if (m_arraySMSMessage.GetSize() > 0 &&
				m_arraySMSMessage[0].nSMSId == sSms.nSMSId)
			{
				break;
			}
			// add message to array of messages (CArray storage)
			m_arraySMSMessage.Add(sSms);

			}
		}while (SWI_RCODE_OK == eRcode); // assuming 1 record SMS
	}

	// index into the array of messages where to start with unread messages
	I32 nEndReadSMSIndex = static_cast<I32>(m_arraySMSMessage.GetSize());

	// unread messages (loop until no more unread records)
	if (sSmsStatus.cntUnreadRec > 0)
	{
		// for unread messages bUnreadSMS is set to true
		sSms.bUnreadSMS = true;
		do
		{
			// retrieve the message
			eRcode = SwiRetrieveSMSMessage(&sSms, TIMEOUT);
			// check error code, output if operation failed
			if(SWI_RCODE_OK == eRcode)
			{
			
			// decrement the number of unread messages
			sSmsStatus.cntUnreadRec--;

			// add message to array of messages (CArray storage)
			m_arraySMSMessage.Add(sSms);

			}

		//}while (sSmsStatus.cntUnreadRec); // assuming 1 record SMS
		}while(eRcode == SWI_RCODE_OK);
	}

	// load all SMS to list control
	LoadSmsToListCtrl();

	if (m_SmsInboxList.GetItemCount())
	{
		// set the selected item in list control to have index 0 (arbitrary)
		//m_szMessageBody = m_arraySMSMessage[0].byMessage;

		SmsMsgToString (m_arraySMSMessage[0].sHeader.eDataCodingScheme,
                        m_arraySMSMessage[0].byMessage,
                        m_arraySMSMessage[0].nMsgLength,
                        m_szMessageBody);

		m_SmsInboxList.SetItemState(0, LVIS_SELECTED, LVIS_SELECTED);
		// Update Character Counter		
		m_strCharCount.Format(_T("%i"), m_szMessageBody.GetLength());	
	}

	m_strReadSmsStatus = _T("Operation completed.");

	// update data to screen
	UpdateData (FALSE);
}


/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	LoadSmsToListCtrl
//
//	Description	:	Function to load all SMS messages to list control
//
//	Arguments	:	None
//
//	Returns		:	None
//
//	Comments	:
//
/////////////////////////////////////////////////////////////////////////////
void CSMSInboxSampleDlg::LoadSmsToListCtrl()
{
	CString strText;	// string to write to fields of entries in the list control

	m_SmsInboxList.DeleteAllItems();	// clear list control
	m_szMessageBody.Format(_T(""));	// clear SMS body msg string

	for (I32 c = 0; c < m_arraySMSMessage.GetSize(); c++)
	{
		m_SmsInboxList.InsertItem (c, _T("Unknown"));
		GetAddressNumber (strText, m_arraySMSMessage[c].sHeader.SME, m_arraySMSMessage[c].sHeader.nAddressNumLength);
		m_SmsInboxList.SetItemText (c, 1, (LPTSTR)(LPCTSTR)strText);
		GetTimeStamp (strText, m_arraySMSMessage[c].sHeader.Timestamp);
		m_SmsInboxList.SetItemText (c, 2, (LPTSTR)(LPCTSTR)strText);
	}

	//update values to the screen
	UpdateData(FALSE);
}


/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	DeleteSms
//
//	Description	:	Function to delete SMS
//
//	Arguments	:	None
//
//	Returns		:	None
//
//	Comments	:	
//
/////////////////////////////////////////////////////////////////////////////
void CSMSInboxSampleDlg::DeleteSms()
{
	SWI_RCODE eRcode;	// define eRcode for error handling

	m_strReadSmsStatus = _T("");
	
	if (m_arraySMSMessage.GetSize() == 0)
	{
		m_strReadSmsStatus = _T("No SMS to delete");
		
		// update to screen
		UpdateData (FALSE);

		return;
	}

	// get the selected item in list control
	POSITION pos = m_SmsInboxList.GetFirstSelectedItemPosition();
	
	if ( !pos )
	{
		MessageBox(_T("Please select the message to delete"), MB_OK);
		return;
	}

	// conversion to an index
	int nSelIdx = m_SmsInboxList.GetSelectionMark();
	U32 nIndex	= (U32)nSelIdx;
	
	if (nIndex >= (U32)m_arraySMSMessage.GetSize())
	{
		return;
	}

	// Note: deletion with an invalid SMS ref. id as an argument could cause 
	//		 unexpected modem behaviour

	eRcode = SwiDeleteSMS((U16)m_arraySMSMessage[nIndex].nSMSId, TIMEOUT);
	if (SWI_RCODE_OK != eRcode)
	{
		ProcessError(eRcode);
	}
	else
	{
		// update the array of sms => call to GetSms
		GetSms();
		m_strReadSmsStatus = _T("Deleted");
	}

	LoadSmsToListCtrl();

	// update data to screen
	UpdateData (FALSE);
}


/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	OnGetSms
//
//	Description	:	Handler for Get All Sms control button
//
//	Arguments	:	None
//
//	Returns		:	None
//
//	Comments	:
//
/////////////////////////////////////////////////////////////////////////////
void CSMSInboxSampleDlg::OnGetSms() 
{
	// call to worker function
	GetSms();	
}


/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	OnDeleteSms
//
//	Description	:	Handler for Delete Sms control button
//
//	Arguments	:	None
//
//	Returns		:	None
//
//	Comments	:
//
/////////////////////////////////////////////////////////////////////////////
void CSMSInboxSampleDlg::OnDeleteSms() 
{
	// call to worker function
	DeleteSms();
}

SWI_TYPE_Device CSMSInboxSampleDlg::GetHighestPriorityDeviceType()
{
	SWI_TYPE_Device				eTypeDevice = SWI_DEVICE_None;
	SWI_STRUCT_AirServerList	sAvailDevList;
	SWI_RCODE					rCode;

	//--------------------
	// Connect to ANY device
	//--------------------
	sAvailDevList.sizeStruct = sizeof(SWI_STRUCT_AirServerList);
	rCode = SwiGetAvailAirServers(sAvailDevList);
	if (SWI_RCODE_OK != rCode)
		return eTypeDevice;

	// how many avail devices?
	if (0 == sAvailDevList.nNumber)
		return eTypeDevice;

	return sAvailDevList.AirServers[0].eDevice;
}

////////////////////////////////////////////////////////////////////////////
//
//	Function	:	ConnectModem
//
//	Description	:	Starts a Connection to the Modem
//
//	Arguments	:	None
//
//	Returns		:	BOOL (True/False), to indicate success of connection
//
//	Comments	:
//
/////////////////////////////////////////////////////////////////////////////
BOOL CSMSInboxSampleDlg::ConnectModem()
{
	SWI_RCODE rCode;	// define eRcode for error handling

	if (!m_bConnected) // if API is NOT connected, select and open AC710 API
	{
		// if not connected, open the API
		SWI_STRUCT_ApiStartup sOpenParams;
		memset(&sOpenParams, 0, sizeof(SWI_STRUCT_ApiStartup));

		rCode = SwiApiStartup(&sOpenParams);
		if(SWI_RCODE_OK != rCode)
		{
			ProcessError(rCode);
			return FALSE;
		}

		SWI_TYPE_Device eDeviceType = GetHighestPriorityDeviceType ();
		if (eDeviceType == SWI_DEVICE_None)
			return FALSE;

		DECLARE_MacAny;
		SWI_STRUCT_AirServer sAirServer;
		sAirServer.sizeStruct = sizeof(SWI_STRUCT_AirServer);
		memcpy(sAirServer.ClientMac, MacAny, LENGTH_MacAddress);
		memcpy(sAirServer.ServerMac, MacAny, LENGTH_MacAddress);
		sAirServer.eDevice = eDeviceType;

		rCode = SwiSelectAirServer(sAirServer);
		if(SWI_RCODE_OK != rCode)
		{
			ProcessError(rCode);
			return FALSE;
		}

		// register the Callback function
		rCode = SwiRegisterCallback(NotificationCallback, 0xFFFFFFFFFFFFFFFF);	
		// check error code, output if operation failed
		if (SWI_RCODE_OK != rCode)
		{
			ProcessError(rCode);
			// return false, since failed
			return FALSE;
		}

		// enable SmsReady notification
		rCode = SwiNotify(SWI_NOTIFY_SmsReady, TIMEOUT);
		// check error code, output if operation failed
		if (SWI_RCODE_OK != rCode)
		{
			ProcessError(rCode);
			// return false, since failed
			return FALSE;
		}

		// enable SmsStatus notification
		rCode = SwiNotify(SWI_NOTIFY_SmsStatus, TIMEOUT);
		// check error code, output if operation failed
		if (SWI_RCODE_OK != rCode)
		{
			ProcessError(rCode);
			// return false, since failed
			return FALSE;
		}

		// enable SmsSimFull notification
		rCode = SwiNotify(SWI_NOTIFY_SmsSimFull, TIMEOUT);
		// check error code, output if operation failed
		if (SWI_RCODE_OK != rCode)
		{
			ProcessError(rCode);
			// return false, since failed
			return FALSE;
		}

		// informing modem of host startup state
		// this function will attach the modem onto the Network (in the event it's not)
		// modem needs to be on mobile network to send SMS
		rCode = SwiSetHostStartup (TRUE, (TIMEOUT * 20));
		// check error code, output if operation failed
		if (SWI_RCODE_OK != rCode)
		{
			ProcessError(rCode);
			// return false, since failed
			return FALSE;
		}

		// when all the above statments are executed without error, API is opened
		// so return true
		return TRUE;
		
	}

	// modem is already connected, API already opened, return false
	// since this is called only once on startup, there should be no connection to modem
	return FALSE;

}


////////////////////////////////////////////////////////////////////////////
//
//	Function	:	DisconnectModem
//
//	Description	:	Ends a Connection to the Modem
//
//	Arguments	:	None
//
//	Returns		:	BOOL (True/False), to indicate success of disconnection
//
//	Comments	:
//
/////////////////////////////////////////////////////////////////////////////
BOOL CSMSInboxSampleDlg::DisconnectModem()
{
	SWI_RCODE eRcode;	// define eRcode for error handling
	
	//disconnect if a connection to the modem exists
	if(m_bConnected)
	{

		// Disable SmsStatus notifications
		eRcode = SwiStopNotify(SWI_NOTIFY_SmsStatus, TIMEOUT);
		// check error code, output if operation failed
		if (SWI_RCODE_OK != eRcode)
		{
			ProcessError(eRcode);
			// return false, since failed
			return FALSE;
		}

		// Disable SmsSimFull notifications
		eRcode = SwiStopNotify(SWI_NOTIFY_SmsSimFull, TIMEOUT);
		// check error code, output if operation failed
		if (SWI_RCODE_OK != eRcode)
		{
			ProcessError(eRcode);
			// return false, since failed
			return FALSE;
		}

		// detaching modem from network; this has been commented out because
		// it can sometimes take up to 20 seconds to detach from the network,
		// since it is not absolutely necessary to detach from the network,
		// it has been commented out for the SDK sample apps.
		//
		// rcode = SwiSetHostStartup(FALSE, TIMEOUT*20);
		// if(SWI_RCODE_OK != rcode)
		// {
		//		ProcessError(rcode);
		//		return FALSE;
		// }

		//close connection with modem
		eRcode = SwiApiShutdown();	
		// check error code, output if operation failed
		if (SWI_RCODE_OK != eRcode)
		{
			ProcessError(eRcode);
			// return false, since failed
			return FALSE;
		}

		// when all the above statments are executed without error, API is closed
		// so return true
		return TRUE;

	}

	// modem is already disconnected, API already closed, return true since closed
	// since this is called only once on startup, there should be no connection to modem
	return TRUE;

}


/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	OnClickSmsinboxlist
//
//	Description	:	Handler function for list control (selected items)
//
//	Arguments	:	[IN] - input notify struct for handler
//					[OUT] - pResult, result from this notification handler
//
//	Returns		:	None
//
//	Comments	:
//
/////////////////////////////////////////////////////////////////////////////
void CSMSInboxSampleDlg::OnClickSmsinboxlist(NMHDR* pNMHDR, LRESULT* pResult) 
{
	NM_LISTVIEW* pNMListView = (NM_LISTVIEW*)pNMHDR;
	if ( (pNMListView->iItem >= 0) && pNMListView->iItem < m_arraySMSMessage.GetSize())
	{
		//m_szMessageBody = m_arraySMSMessage[pNMListView->iItem].byMessage;
		SmsMsgToString (m_arraySMSMessage[pNMListView->iItem].sHeader.eDataCodingScheme,
                        m_arraySMSMessage[pNMListView->iItem].byMessage,
                        m_arraySMSMessage[pNMListView->iItem].nMsgLength,
                        m_szMessageBody);

		// Update Character Counter		
		m_strCharCount.Format(_T("%i"), m_szMessageBody.GetLength());	

	}

	*pResult = 0;

	UpdateData(FALSE);
}


/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	Instance
//
//	Description	:	A static function used to return a pointer to this object
//
//	Arguments	:	None
//
//	Returns		:	m_Instance - a pointer to this object
//
//	Comments	:
//
///////////////////////////////////////////////////////////////////////////
CSMSInboxSampleDlg* CSMSInboxSampleDlg::Instance()
{
	return m_instance;
}


/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	HandleCallback
//
//	Description	:	Caches data from NotificationCallback (therefore freeing the thread)
//					and posts a message for notification handling
//					
//	Arguments	:	[IN]: pNotify - pointer to notification variant
//
//	Returns		:	None
//
//	Comments	:
//
///////////////////////////////////////////////////////////////////////////
void CSMSInboxSampleDlg::HandleCallback(SwiNotifyVariant *pNotify)
{

	//used for debugging purposes, displays the notifications received
	TRACE(_T("Got notif %i\n"), pNotify->eNotify);

	SwiNotifyVariant* pCopy = (SwiNotifyVariant*) new SwiNotifyVariant;
	
	// For simplicity, we are allocating a copy of the notification from 
	// the heap. An industrial-strength app would allocate the copy from 
	// a fixed pool of objects to avoid memory fragmentation. 
	if (pCopy)
	{
		*pCopy = *pNotify;
		m_instance->PostMessage(WM_NOTIFICATION, WPARAM(pCopy), NULL ); 
	}
}


/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	OnNotification
//
//	Description	:	Handler for received notifications
//
//	Arguments	:	[IN] - wParam - Contains the notification type
//					[IN] - lParam - Contains the data to be updated
//
//	Returns		:	None
//
//	Comments	:
//
/////////////////////////////////////////////////////////////////////////////
LRESULT CSMSInboxSampleDlg::OnNotification(WPARAM wParam, LPARAM lParam)
{

	SWI_STRUCT_GSM_SMS_Status    sSmsStatus;   // cache memory for SMS status notification +-     
    SWI_STRUCT_SMS_SimFull   sSimFull; // cache memory for Sim Full status notification       
    SWI_STRUCT_SmsReady  sSmsReady; 
	SwiNotifyVariant* pNotify = (SwiNotifyVariant*)wParam;

	switch(pNotify->eNotify)
	{
	case SWI_NOTIFY_SmsReady:
		{
			sSmsReady = pNotify->_SmsReady;
			if (!sSmsReady.bReady)
			{
				// SMS not ready, disable buttons
				m_strReadSmsStatus = _T("Modem is connected, Initializing SMS...");
				m_btnDelete.EnableWindow(FALSE);
				m_btnGetSms.EnableWindow(FALSE);
			}
			else if (sSmsReady.bReady)
			{
				// enable buttons as SMS is ready
				m_strReadSmsStatus = _T("Modem is connected and SMS is ready");
				m_btnDelete.EnableWindow(TRUE);
				m_btnGetSms.EnableWindow(TRUE);
				// get all SMS (desired operation on initialization)
				GetSms();
			}

			break;
		}
	case SWI_NOTIFY_SmsStatus:
		{
			sSmsStatus = pNotify->_GsmSmsStatus;
			//Message waiting in Service Centre
			if (sSmsStatus.bMsgInSC)
 			{
				m_strReadSmsStatus = _T("You have awaiting SMS @ the Service Centre...");
 			}
 			
			//New SMS message			
			if (sSmsStatus.cntUnreadRec)
 			{
				m_strReadSmsStatus = _T("You have new unread SMS...");
 			}
		
			break;
		}
	case SWI_NOTIFY_SmsSimFull:
		{
			sSimFull = pNotify->_SmsSimFull;
			// check if sim full boolean is marked as FULL
			if (sSimFull.bSimFull)
			{
				m_strReadSmsStatus = _T("Your SIM Card is full");
			}
			
			break;
		}
	default:
		break;
	}

	delete (SwiNotifyVariant*)wParam;	
	// update screen
	UpdateData (FALSE);

	return TRUE;
}

void CSMSInboxSampleDlg::SmsMsgToString (SWI_TYPE_SMS_CodingScheme eDataCodingScheme,  //in
										 unsigned char             *pMsgBuffer,        //in
										 UINT                      nSMSSize,           //in
										 CString                   &strMsg             //out
										 )
{

	// if the SMS Message is zero length then return from this function immediately
	if(!nSMSSize)
	{
		strMsg = _T("");
		return;
	}

	// if the SMS message is using the user defined 8 bit character set
	if(eDataCodingScheme == SWI_SMS_CODINGSCHEME_8bit)
	{
		// NULL terminate the resultant string
		pMsgBuffer [nSMSSize] = 0;

		// copy SMS message 
        strMsg = _T("Binary Data");
	}
	// else if the SMS messsage uses the 7 bit SMS Default character set
	else if(eDataCodingScheme == SWI_SMS_CODINGSCHEME_Default)
	{
		// this block will convert the 7 bit character string to 
		// unicode in a temporary buffer and then based on the operating
		// system...convert the unicode string to multibyte or leave it as
		// unicode.

		// temporary unicode buffer 
		unsigned short *pucs2string = new unsigned short [nSMSSize*2];

		// moving pointer to the unicode buffer
		unsigned short *pucs2;

		// number of unicode characters stored in the unicode buffer
		UINT ucs2num = 0;

		// current reading an extended SMS character flag
		boolean extendedchar = FALSE;

		// a single 7 bit SMS character
		U8 nSmsCode;

		// a single unicode character
		unsigned short ch1;

		// initiatize moving unicode string pointer
		pucs2 = pucs2string;

		// loop through the entire SMS message
		for (UINT idx = 0; idx < nSMSSize; ++idx)
		{
			// get next SMS character from input buffer
			nSmsCode = *pMsgBuffer++;

			// is this the second part of an extended SMS character
			if(extendedchar)
			{
				// get unicode character from the extended SMS character table
				ch1 = ExtendedGsmToUcs2[nSmsCode];

				// if character does not exist in the extended SMS character table
				if(0 == ch1)
					ch1 = GsmToUcs2[nSmsCode];
			}
			else
			{
				// get unicode charater from the regular SMS character table
				ch1 = GsmToUcs2[nSmsCode];
			}

			// if unicode character indicates that this is an extended SMS character
			if(nSmsCode == EXTEND)
			{
				// set extended character flag
				extendedchar = TRUE;
			}
			else 
			{
				// if the unicode character is \n or \r then
				if(ch1 == 0x000A && *pMsgBuffer != 0x000D)
			    {
					// put a \r followed by a \n in the output buffer
					*pucs2++ = 0x000D;
                    ++ucs2num;
				}
			
				// clear the extended character flag
				extendedchar = FALSE;

				// put unicode charater in the output buffer
				*pucs2++ = ch1;

				// increment the number of stored unicode characters
				ucs2num++;
			}
		}
		// NULL terminate the output buffer
		*pucs2++ = 0x00;
#if(defined(UNDER_CE)||defined(_UNICODE))
		// copy the unicode string from the temporary buffer to the output string
        strMsg = (TCHAR *)(pucs2string);
#else
		// convert the unicode string to multibyte and store it in the output string
		int iLength = WideCharToMultiByte ( CP_ACP, //CP_UTF8,
											0, 
											(LPCWSTR)(pucs2string), 
											ucs2num,
											strMsg.GetBufferSetLength (ucs2num*2), 
                                            ucs2num, 
                                            NULL, 
											NULL);

		strMsg.SetAt (iLength, 0);
		strMsg.ReleaseBuffer();
#endif
		delete [] pucs2string;
	
	}
	// if the SMS message is encoded in unicode
	else if(eDataCodingScheme == SWI_SMS_CODINGSCHEME_UCS2)
	{
		unsigned short *pMsg = (unsigned short *)pMsgBuffer;
#if(defined(UNDER_CE)||defined(_UNICODE))
		// copy the received SMS message directly to the output string
        strMsg = (unsigned char*)(pMsg);
#else
		// convert the SMS message to multibyte and copy it to the output string
		int iLength = WideCharToMultiByte ( CP_ACP, //CP_UTF8,
                                                    0, 
                                                    (LPCWSTR)pMsg, 
                                                    nSMSSize/2,
                                                    strMsg.GetBufferSetLength (nSMSSize), 
                                                    nSMSSize, 
                                                    NULL, NULL);
         strMsg.SetAt (iLength, 0);
         strMsg.ReleaseBuffer();
#endif

	}
}
