/**
 *
 *	Name	:	SMSInboxSampleDlg.h
 *
 *	Purpose	:	Header file for SMSInboxSample Dialog, Dialog will get and delete  
 *				SMS messages stored on a Sim card
 *
 *	History	:	created	June 10, 2003
 *				- initial version, based on old SDK's SMS Sample Application
 *
 *	Revision:	1.0
 *
 *	Copyright (c) 2003 Sierra Wireless, Inc. All rights reserved.
 *
 **/

#if !defined(AFX_SMSInboxSampleDLG_H__7B3F53BF_79B9_4AE4_BF0A_04FFBB9E69EB__INCLUDED_)
#define AFX_SMSInboxSampleDLG_H__7B3F53BF_79B9_4AE4_BF0A_04FFBB9E69EB__INCLUDED_

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000

#include "afxtempl.h"

#include "SwiApiCm.h"
#include "SwiStructsGsm.h"

const U32 TIMEOUT	= 3000;	// Default Timeout value
const U32 ONE_LINE_LENGTH	= 34;	// length of one line of text in Sms outbox


// user message identifiers for SMS status and SIM full notifications
#define WM_NOTIFICATION WM_USER + 400	//specific notification

#define COLUMN_WIDTH 100	// dfines the widths for the colums in the SMS listing box
#define FIRST_HYPHEN_LOCATION 4	// defines where to insert first hypen in a 10 digit phone number
#define SECOND_HYPHEN_LOCATION 7// defines where to insert second hypen in a 10 digit phone number

/////////////////////////////////////////////////////////////////////////////
// CSMSInboxSampleDlg dialog

class CSMSInboxSampleDlg : public CDialog
{
// Construction
public:
	CSMSInboxSampleDlg(CWnd* pParent = NULL);	// standard constructor

// Dialog Data
	//{{AFX_DATA(CSMSInboxSampleDlg)
	enum { IDD = IDD_SMSINBOXSAMPLE_DIALOG };
	CButton	m_btnGetSms;	// Get SMS button
	CButton	m_btnDelete;	// Delete SMS button
	CButton	m_btnOK;	// OK button to exit dialog
	CListCtrl	m_SmsInboxList;	// holds list of stored SMS
	CString	m_strReadSmsStatus;	// holds status string
	CString	m_szMessageBody;	// holds selected SMS' body
	CString	m_strCharCount;
	//}}AFX_DATA

	// ClassWizard generated virtual function overrides
	//{{AFX_VIRTUAL(CSMSInboxSampleDlg)
	protected:
	virtual void DoDataExchange(CDataExchange* pDX);	// DDX/DDV support
	//}}AFX_VIRTUAL

// Implementation
public:
	static CSMSInboxSampleDlg* Instance();	// returns a pointer to this object
	void ProcessError (SWI_RCODE code);	// process API error codes
	LRESULT OnNotification (WPARAM wparam, LPARAM lparam);	// handles notifications
	void HandleCallback (SwiNotifyVariant* pNotify);	// caches data from notifications
	BOOL ConnectModem();	// connects to modem/API
	BOOL DisconnectModem();	// disconnects from modem/API

private:
	static CSMSInboxSampleDlg* m_instance;	// a pointer back to this object

protected:
	HICON m_hIcon;
	
	BOOL m_bConnected;	// "Connected or Disconnected" boolean value
	CArray <SWI_STRUCT_GSM_SMS_RetrieveSms, SWI_STRUCT_GSM_SMS_RetrieveSms> m_arraySMSMessage;	//array structure to store SMS read from Sim card

	void GetSms();	// GetSms, member function to perform work, gets SMS
	void DeleteSms();	// DeleteSms, member function to perform work, deletes SMS
	void LoadSmsToListCtrl();	// loads SMS from array to list control
	void GetAddressNumber(CString &strNumber,  BYTE *pBuffer, int iLength);	// formats address numbers
	void GetTimeStamp (CString &strTimeStamp, BYTE *pBuffer);	// formats time stamp
	void OnClickSmsinboxlist(NMHDR* pNMHDR, LRESULT* pResult);	// Event triggered when list control is clicked

	void SmsMsgToString (SWI_TYPE_SMS_CodingScheme eDataCodingScheme,  //in
						 unsigned char             *pMsgBuffer,        //in
						 UINT                      nSMSSize,           //in
						 CString                   &strMsg             //out
						 );
	SWI_TYPE_Device GetHighestPriorityDeviceType ();

	// Generated message map functions
	//{{AFX_MSG(CSMSInboxSampleDlg)
	virtual BOOL OnInitDialog();
	afx_msg HCURSOR OnQueryDragIcon();
	afx_msg void OnOK();	// Event triggered when the OK button is pressed
	afx_msg void OnGetSms();	// Event triggered when Get SMS button is pressed 
	afx_msg void OnDeleteSms();	// Event triggered when Delete SMS button is pressed 
	//}}AFX_MSG
	DECLARE_MESSAGE_MAP()
};

//{{AFX_INSERT_LOCATION}}
// Microsoft Visual C++ will insert additional declarations immediately before the previous line.

#endif // !defined(AFX_SMSInboxSampleDLG_H__7B3F53BF_79B9_4AE4_BF0A_04FFBB9E69EB__INCLUDED_)
