/**
 *
 *	Name	:	SMSOutboxSampleDlg.cpp
 *
 *	Purpose	:	Main dialog implementation file, allows the user to send an 
 *				SMS to a entered mobile number
 *
 *	History	:	created	June 10, 2003
 *				- initial version, based on old SDK's SMS Sample Application
 *
 *	Revision:	1.0
 *
 *	Copyright (c) 2003 Sierra Wireless, Inc. All rights reserved.
 *
 **/

#include "stdafx.h"

#include "SMSOutboxSample.h"
#include "SMSOutboxSampleDlg.h"
#include "SwiApiGsm.h"
#include "SwiSmsGsm.h"

#ifdef _DEBUG
#define new DEBUG_NEW
#undef THIS_FILE
static char THIS_FILE[] = __FILE__;
#endif

#define UCS2_TO_GSM_LOOKUP_TABLE_SIZE   0x100
#define NON_GSM							0x80 
#define UCS2_GCL_RANGE                  31
#define UCS2_GREEK_CAPITAL_LETTER_GAMMA 0x0393
#define EXTEND						0x001B

// note that the ` character is mapped to ' so that all characters that can be typed on
// a standard north american keyboard can be converted to the GSM default character set
const unsigned char  Ucs2ToGsm[UCS2_TO_GSM_LOOKUP_TABLE_SIZE] =
{           /*+0x0      +0x1        +0x2        +0x3        +0x4        +0x5        +0x6        +0x7*/
/*0x00*/    NON_GSM,    NON_GSM,    NON_GSM,    NON_GSM,    NON_GSM,    NON_GSM,    NON_GSM,	NON_GSM,
/*0x08*/    NON_GSM,    NON_GSM,    0x0a,       NON_GSM,    NON_GSM,    0x0d,       NON_GSM,    NON_GSM,
/*0x10*/    NON_GSM,    NON_GSM,    NON_GSM,    NON_GSM,    NON_GSM,    NON_GSM,    NON_GSM,    NON_GSM,
/*0x18*/    NON_GSM,    NON_GSM,    NON_GSM,    NON_GSM,    NON_GSM,    NON_GSM,    NON_GSM,    NON_GSM,
/*0x20*/    0x20,       0x21,       0x22,       0x23,       0x02,       0x25,       0x26,       0x27,
/*0x28*/    0x28,       0x29,       0x2a,       0x2b,       0x2c,       0x2d,       0x2e,       0x2f,
/*0x30*/    0x30,       0x31,       0x32,       0x33,       0x34,       0x35,       0x36,       0x37,
/*0x38*/    0x38,       0x39,       0x3a,       0x3b,       0x3c,       0x3d,       0x3e,       0x3f,
/*0x40*/    0x00,       0x41,       0x42,       0x43,       0x44,       0x45,       0x46,       0x47,
/*0x48*/    0x48,       0x49,       0x4a,       0x4b,       0x4c,       0x4d,       0x4e,       0x4f,
/*0x50*/    0x50,       0x51,       0x52,       0x53,       0x54,       0x55,       0x56,       0x57,
/*0x58*/    0x58,       0x59,       0x5a,       EXTEND,    	EXTEND,	    EXTEND,   	EXTEND,		0x11,
/*0x60*/    0x27,		0x61,       0x62,       0x63,       0x64,       0x65,       0x66,       0x67,
/*0x68*/    0x68,       0x69,       0x6a,       0x6b,       0x6c,       0x6d,       0x6e,       0x6f,
/*0x70*/    0x70,       0x71,       0x72,       0x73,       0x74,       0x75,       0x76,       0x77,
/*0x78*/    0x78,       0x79,       0x7a,       EXTEND,		EXTEND,		EXTEND,		EXTEND,		NON_GSM,
/*0x80*/    NON_GSM,    NON_GSM,    NON_GSM,    NON_GSM,    NON_GSM,    NON_GSM,    NON_GSM,    NON_GSM,
/*0x88*/    NON_GSM,    NON_GSM,    NON_GSM,    NON_GSM,    NON_GSM,    NON_GSM,    NON_GSM,    NON_GSM,
/*0x90*/    NON_GSM,    NON_GSM,    NON_GSM,    NON_GSM,    NON_GSM,    NON_GSM,    NON_GSM,    NON_GSM,
/*0x98*/    NON_GSM,    NON_GSM,    NON_GSM,    NON_GSM,    NON_GSM,    NON_GSM,    NON_GSM,    NON_GSM,
/*0xa0*/    NON_GSM,    0x40,       NON_GSM,    0x01,       0x24,       0x03,       NON_GSM,    0x5f,
/*0xa8*/    NON_GSM,    NON_GSM,    NON_GSM,    NON_GSM,    NON_GSM,    NON_GSM,    NON_GSM,    NON_GSM,
/*0xb0*/    NON_GSM,    NON_GSM,    NON_GSM,    NON_GSM,    NON_GSM,    NON_GSM,    NON_GSM,    NON_GSM,
/*0xb8*/    NON_GSM,    NON_GSM,    NON_GSM,    NON_GSM,    NON_GSM,    NON_GSM,    NON_GSM,    0x60,
/*0xc0*/    NON_GSM,    NON_GSM,    NON_GSM,    NON_GSM,    0x5b,       0x0e,       0x1c,       0x09,
/*0xc8*/    NON_GSM,    0x1f,       NON_GSM,    NON_GSM,    NON_GSM,    NON_GSM,    NON_GSM,    0x60,
/*0xd0*/    NON_GSM,    0x5d,       NON_GSM,    NON_GSM,    NON_GSM,    NON_GSM,    0x5c,       NON_GSM,
/*0xd8*/    0x0b,       NON_GSM,    NON_GSM,    NON_GSM,    0x5e,       NON_GSM,    NON_GSM,    0x1e,
/*0xe0*/    0x7f,       NON_GSM,    NON_GSM,    NON_GSM,    0x7b,       0x0f,       0x1d,       NON_GSM,
/*0xe8*/    0x04,       0x05,       NON_GSM,    NON_GSM,    0x07,       NON_GSM,    NON_GSM,    NON_GSM,
/*0xf0*/    NON_GSM,    0x7d,       0x08,       NON_GSM,    NON_GSM,    NON_GSM,    0x7c,       NON_GSM,
/*0xf8*/    0x0c,       0x06,       NON_GSM,    NON_GSM,    0x7e,       NON_GSM,    NON_GSM,    NON_GSM
};

const unsigned char Ucs2GclToGsm[UCS2_GCL_RANGE + 1] =
{
/*0x0393*/  0x13,       0x10,       NON_GSM,    NON_GSM,
/*0x0397*/  NON_GSM,    0X19,       NON_GSM,    NON_GSM,
/*0x039b*/  0x14,       NON_GSM,    NON_GSM,    0x1a,
/*0x039f*/  NON_GSM,    0X16,       NON_GSM,    NON_GSM,
/*0x03a3*/  0x18,       NON_GSM,    NON_GSM,    0X12,
/*0x03a7*/  NON_GSM,    0X17,       0x15,		NON_GSM,
/*0x03ab*/  NON_GSM,    NON_GSM,    NON_GSM,	NON_GSM,
/*0x03af*/  NON_GSM,    NON_GSM,    NON_GSM,	0x1E
};


CSMSOutboxSampleDlg*	CSMSOutboxSampleDlg::m_instance = NULL; //initializing pointer to this object to NULL

/////////////////////////////////////////////////////////////////////////////
// CSMSOutboxSampleDlg dialog

CSMSOutboxSampleDlg::CSMSOutboxSampleDlg(CWnd* pParent /*=NULL*/)
	: CDialog(CSMSOutboxSampleDlg::IDD, pParent)
{
	//{{AFX_DATA_INIT(CSMSOutboxSampleDlg)
	m_strSmsSendTo = _T("");	// initialize member variable
	m_strSMSBody = _T("");	// initialize member variable
	m_strSendSmsStatus = _T("");
	m_instance = this;	// initialize object
	m_strSendingTo = _T("");
	m_strCharCount = _T("");
	//}}AFX_DATA_INIT
	// Note that LoadIcon does not require a subsequent DestroyIcon in Win32
	m_hIcon = AfxGetApp()->LoadIcon(IDR_MAINFRAME);
}

void CSMSOutboxSampleDlg::DoDataExchange(CDataExchange* pDX)
{
	CDialog::DoDataExchange(pDX);
	//{{AFX_DATA_MAP(CSMSOutboxSampleDlg)
	DDX_Control(pDX, IDOK, m_btnOK);
	DDX_Control(pDX, IDC_SENDSMS, m_btnSend);
	DDX_Text(pDX, IDC_SENDSMSTO, m_strSmsSendTo);	// on UpdateData(), sync control data and string data
	DDX_Text(pDX, IDC_COMPOSEMSGBODY, m_strSMSBody);	// on UpdateData(), sync control data and string data
	DDX_Text(pDX, IDC_SENDSMSSTATUS, m_strSendSmsStatus);
	DDX_Control(pDX, IDC_PROGRESS_SmsOut, m_ctrlProgress);
	DDX_Text(pDX, IDC_STA_SendingTo, m_strSendingTo);
	DDX_Text(pDX, IDC_STA_SMSCharCnt, m_strCharCount);
	//}}AFX_DATA_MAP
}

BEGIN_MESSAGE_MAP(CSMSOutboxSampleDlg, CDialog)
	//{{AFX_MSG_MAP(CSMSOutboxSampleDlg)
	ON_BN_CLICKED(IDC_SENDSMS, OnSendSms)	// links event associated /w SEND button clicked
	ON_WM_SYSCOMMAND()
	ON_EN_CHANGE(IDC_COMPOSEMSGBODY, OnChangeEditCompose)
	//}}AFX_MSG_MAP
	
	//function to handle all event notifications
	ON_MESSAGE(WM_NOTIFICATION, OnNotification)
END_MESSAGE_MAP()

/////////////////////////////////////////////////////////////////////////////
// CSMSOutboxSampleDlg message handlers

BOOL CSMSOutboxSampleDlg::OnInitDialog()
{
	CDialog::OnInitDialog();

	// Set the icon for this dialog.  The framework does this automatically
	//  when the application's main window is not a dialog
	SetIcon(m_hIcon, TRUE);			// Set big icon
	SetIcon(m_hIcon, FALSE);		// Set small icon
	
	// initialize member variable, connected boolean
	m_bConnected = FALSE;

	// connect to modem
	if (ConnectModem())
	{
		// flag boolean to indicated Connected
		m_bConnected = TRUE;
		// update status box to inform user of connections
		m_strSendSmsStatus = _T("Connected to modem, waiting for SMS Ready...");
	}
	else
	{
		// close dialog if unable to open API
		OnOK();
	}
	
	m_btnSend.EnableWindow(FALSE);

	// update values to screen 
	((CEdit*)GetDlgItem(IDC_COMPOSEMSGBODY))->SetLimitText(250);
	UpdateData (FALSE);

	return TRUE;  // return TRUE  unless you set the focus to a control
}

void CSMSOutboxSampleDlg::OnChangeEditCompose() 
{
    UpdateData (true);
	// Update Character Counter		
	m_strCharCount.Format(_T("%i"), m_strSMSBody.GetLength());	
    UpdateData (false);
}


/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	ProcessError
//
//	Description	:	Helper function to process error codes, displays a 
//					message box indicating the error code that was returned
//
//	Arguments	:	[IN] - code - an error code returned from an API call
//
//	Returns		:	None
//
//	Comments	:	
//
/////////////////////////////////////////////////////////////////////////////
void CSMSOutboxSampleDlg::ProcessError(SWI_RCODE code)
{
	CString strErrorString;

	// internal error code
	strErrorString.Format(_T("Internal error - error code: %d"), code);

	// output to message box
	MessageBox(strErrorString, _T("API Message"), MB_OK);
}


/////////////////////////////////////////////////////////////////////////////
//
//	Event		:	OnOK
//
//	Description	:	Event triggered when the OK button is pressed, disables OK 
//					button calls DisconnectModem and renables OK button
//
//	Arguments	:	None
//
//	Returns		:	None
//
//	Comments	:	
//
/////////////////////////////////////////////////////////////////////////////
void CSMSOutboxSampleDlg::OnOK() 
{
	// Disable the OK button
	m_btnOK.EnableWindow(FALSE);
	
	// run Disconnect Modem function
	DisconnectModem();

	CDialog::OnOK();
}


////////////////////////////////////////////////////////////////////////////
//
//	Function	:	OnSendSms
//
//	Description	:	Button event, event called when Send SMS button is 
//					pressed, Function sends an SMS message
//
//	Arguments	:	None
//
//	Returns		:	None
//
//	Comments	:
//
/////////////////////////////////////////////////////////////////////////////
void CSMSOutboxSampleDlg::OnSendSms() 
{
	StoreSms();
}

////////////////////////////////////////////////////////////////////////////
//
//	Function	:	NotificationCallback
//
//	Description	:	Callback that receives all event notifications
//
//	Arguments	:	[IN] - pNotify	- pointer to notification variant
//
//	Returns		:	None
//
//	Comments	:	Even if no notifications are being processed, this 
//					function still needs to be registered and declared for 
//					calls to the API to function properly
//
/////////////////////////////////////////////////////////////////////////////
void NotificationCallback(SwiNotifyVariant *pNotify)
{
	CSMSOutboxSampleDlg* pThisObject = CSMSOutboxSampleDlg::Instance();
	pThisObject->HandleCallback(pNotify);
}

SWI_TYPE_Device CSMSOutboxSampleDlg::GetHighestPriorityDeviceType()
{
	SWI_TYPE_Device				eTypeDevice = SWI_DEVICE_None;
	SWI_STRUCT_AirServerList	sAvailDevList;
	SWI_RCODE					rCode;

	//--------------------
	// Connect to ANY device
	//--------------------
	sAvailDevList.sizeStruct = sizeof(SWI_STRUCT_AirServerList);
	rCode = SwiGetAvailAirServers(sAvailDevList);
	if (SWI_RCODE_OK != rCode)
		return eTypeDevice;

	// how many avail devices?
	if (0 == sAvailDevList.nNumber)
		return eTypeDevice;

	return sAvailDevList.AirServers[0].eDevice;
}

////////////////////////////////////////////////////////////////////////////
//
//	Function	:	ConnectModem
//
//	Description	:	Starts a Connection to the Modem
//
//	Arguments	:	None
//
//	Returns		:	BOOL (True/False), to indicate success of connection
//
//	Comments	:
//
/////////////////////////////////////////////////////////////////////////////
BOOL CSMSOutboxSampleDlg::ConnectModem()
{
	// define eRcode for error handling
	SWI_RCODE rCode;

	if (!m_bConnected) // if API is NOT connected, select and open AC710 API
	{
		// if not connected, open the API
		SWI_STRUCT_ApiStartup sOpenParams;
		memset(&sOpenParams, 0, sizeof(SWI_STRUCT_ApiStartup));

		rCode = SwiApiStartup(&sOpenParams);
		if(SWI_RCODE_OK != rCode)
		{
			ProcessError(rCode);
			return FALSE;
		}

		SWI_TYPE_Device eDevice = GetHighestPriorityDeviceType();
		if (eDevice == SWI_DEVICE_None)
			return FALSE;

		DECLARE_MacAny;
		SWI_STRUCT_AirServer sAirServer;
		sAirServer.sizeStruct = sizeof(SWI_STRUCT_AirServer);
		memcpy(sAirServer.ClientMac, MacAny, LENGTH_MacAddress);
		memcpy(sAirServer.ServerMac, MacAny, LENGTH_MacAddress);
		sAirServer.eDevice = eDevice;

		rCode = SwiSelectAirServer(sAirServer);
		if(SWI_RCODE_OK != rCode)
		{
			ProcessError(rCode);
			return FALSE;
		}

		// register the Callback function
		rCode= SwiRegisterCallback(NotificationCallback, 0xFFFFFFFFFFFFFFFF);	
		// check error code, output if operation failed
		if (SWI_RCODE_OK != rCode)
		{
			ProcessError(rCode);
			// return false, since failed
			return FALSE;
		}

		rCode = SwiNotify(SWI_NOTIFY_SmsReady, VALUE_WAIT*3);
		// check error code, output if operation failed
		if (SWI_RCODE_OK != rCode)
		{
			ProcessError(rCode);
			// return false, since failed
			return FALSE;
		}

		//enable SmsSimFull notification
		rCode = SwiNotify(SWI_NOTIFY_SmsSimFull, VALUE_WAIT*3);
		// check error code, output if operation failed
		if (SWI_RCODE_OK != rCode)
		{
			ProcessError(rCode);
			// return false, since failed
			return FALSE;
		}

		//enable SmsSimFull notification
		rCode = SwiNotify(SWI_NOTIFY_SmsStoreExp, VALUE_WAIT*3);
		// check error code, output if operation failed
		if (SWI_RCODE_OK != rCode)
		{
			ProcessError(rCode);
			// return false, since failed
			return FALSE;
		}
		//enable SmsSimFull notification
		rCode = SwiNotify(SWI_NOTIFY_SmsSendExp, VALUE_WAIT*3);
		// check error code, output if operation failed
		if (SWI_RCODE_OK != rCode)
		{
			ProcessError(rCode);
			// return false, since failed
			return FALSE;
		}

		
		// informing modem of host startup state
		// this function will attach the modem onto the Network (in the event it's not)
		// modem needs to be on mobile network to send SMS
		rCode = SwiSetHostStartup (TRUE, (VALUE_WAIT * 100));
		// check error code, output if operation failed
		if (SWI_RCODE_OK != rCode)
		{
			ProcessError(rCode);
			// return false, since failed
			return FALSE;
		}

		// when all the above statments are executed without error, API is opened
		// so return true
		return TRUE;
		
	}

	// modem is already connected, API already opened, return false
	// since this is called only once on startup, there should be no connection to modem
	return FALSE;

}


////////////////////////////////////////////////////////////////////////////
//
//	Function	:	DisconnectModem
//
//	Description	:	Ends a Connection to the Modem
//
//	Arguments	:	None
//
//	Returns		:	BOOL (True/False), to indicate success of disconnection
//
//	Comments	:
//
/////////////////////////////////////////////////////////////////////////////
BOOL CSMSOutboxSampleDlg::DisconnectModem()
{
	SWI_RCODE eRcode;
	
	//disconnect if a connection to the modem exists
	if(m_bConnected)
	{

		// Disable notifications
		eRcode = SwiStopNotify(SWI_NOTIFY_SmsSimFull, VALUE_WAIT*3);
		// check error code, output if operation failed
		if (SWI_RCODE_OK != eRcode)
		{
			ProcessError(eRcode);
			// return false, since failed
			return FALSE;
		}

		// detaching modem from network; this has been commented out because
		// it can sometimes take up to 20 seconds to detach from the network,
		// since it is not absolutely necessary to detach from the network,
		// it has been commented out for the SDK sample apps.
		//
		// rcode = SwiSetHostStartup(FALSE, TIMEOUT*20);
		// if(SWI_RCODE_OK != rcode)
		// {
		//		ProcessError(rcode);
		//		return FALSE;
		// }

		//close connection with modem
		eRcode = SwiApiShutdown();	
		// check error code, output if operation failed
		if (SWI_RCODE_OK != eRcode)
		{
			ProcessError(eRcode);
			// return false, since failed
			return FALSE;
		}

		// when all the above statments are executed without error, API is closed
		// so return true
		return TRUE;

	}

	// modem is already disconnected, API already closed, return true for is disconnected
	// since this is called only once on startup, there should be no connection to modem
	return TRUE;

}


/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	Instance
//
//	Description	:	A static function used to return a pointer to this object
//
//	Arguments	:	None
//
//	Returns		:	m_Instance - a pointer to this object
//
//	Comments	:
//
///////////////////////////////////////////////////////////////////////////
CSMSOutboxSampleDlg* CSMSOutboxSampleDlg::Instance()
{
	return m_instance;
}


/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	HandleCallback
//
//	Description	:	Caches data from NotificationCallback (therefore freeing the thread)
//					and posts a message for notification handling
//					
//	Arguments	:	[IN]: pNotify - pointer to notification variant
//
//	Returns		:	None
//
//	Comments	:
//
///////////////////////////////////////////////////////////////////////////
void CSMSOutboxSampleDlg::HandleCallback(SwiNotifyVariant *pNotify)
{
	//used for debugging purposes, displays the notifications received
	TRACE(_T("Got notif %i\n"), pNotify->eNotify);

	// For simplicity, we are allocating a copy of the notification from 
	// the heap. An industrial-strength app would allocate the copy from 
	// a fixed pool of objects to avoid memory fragmentation. 
	SwiNotifyVariant* pCopy = (SwiNotifyVariant*) new SwiNotifyVariant;
	
	if (pCopy)
	{
		*pCopy = *pNotify;
		m_instance->PostMessage(WM_NOTIFICATION, WPARAM(pCopy), NULL ); 
	}


}


/////////////////////////////////////////////////////////////////////////////
//
//	Function	:	OnNotification
//
//	Description	:	Handler for received notifications
//
//	Arguments	:	[IN] - wParam - Contains the notification type
//					[IN] - lParam - Contains the data to be updated
//
//	Returns		:	None
//
//	Comments	:
//
/////////////////////////////////////////////////////////////////////////////
LRESULT CSMSOutboxSampleDlg::OnNotification(WPARAM wParam, LPARAM lParam)
{
	SwiNotifyVariant* pNotify = (SwiNotifyVariant*)wParam;
	switch(pNotify->eNotify)
	{
	case SWI_NOTIFY_SmsSimFull:
		m_sSimFull = pNotify->_SmsSimFull;
	// check if sim full boolean is marked as FULL
		if (m_sSimFull.bSimFull)
		{
			m_strSendSmsStatus = _T("Your SIM Card is full");
		}
		// update screen
		UpdateData (FALSE);
	break;
	case SWI_NOTIFY_SmsReady:
		m_sSmsReady = pNotify->_SmsReady;
	    UpdateData(TRUE);
		if(m_sSmsReady.bReady)
		{
			m_strSendSmsStatus = _T("SMS Ready");
			m_btnSend.EnableWindow(TRUE);
		}
		UpdateData(FALSE);
	break;
	case SWI_NOTIFY_SmsStoreExp:
        m_SmsStoreExp  = pNotify->_SmsStoreExp;
		ProcessSmsStoreNotification ();
	break;
	case SWI_NOTIFY_SmsSendExp:
		m_SmsSendExp  = pNotify->_SmsSendExp;
		ProcessSmsSendNotification ();
	break;
	case SWI_NOTIFY_SmsStatusReport:
		m_SmsStatusReport = pNotify->_SmsStatusReport;
		ProcessSmsStatusReport();
	break;
	default:
	break;
	}

	delete (SwiNotifyVariant*)wParam;
	return TRUE;
}

////////////////////////////////////////////////////////////////////////////
//
//	Function	:	ProcessSmsStoreNotification 
//
//	Description	:	Notification handler for SMS store
//
//	Arguments	:	None
//
//	Returns		:	
//
//	Comments	:
//
/////////////////////////////////////////////////////////////////////////////
void CSMSOutboxSampleDlg::ProcessSmsStoreNotification ()
{
    m_ctrlProgress.StepIt ();
    if (m_iSequence < m_cntSegments)
    {
        SWI_RCODE rCode = SwiStoreSMSMessageExp (&m_smsOutgoing, &m_cntSegments, &m_iSequence, VALUE_WAIT*30);
        if (rCode != SWI_RCODE_OK)
        {
            AfxMessageBox (_T("Unable to store SMS."));
            m_ctrlProgress.ShowWindow (SW_HIDE);
            ScreenLock (false);
        }
    }
    else
        SendSms ();
}

void CSMSOutboxSampleDlg::ProcessSmsSendNotification()
{    
    switch(m_SmsSendExp.SmsSendStatus)
    {
    case SWI_SMS_STORE_Success:
        m_ctrlProgress.StepIt ();
        //Swap back the bytes for wide character codes
        if (m_smsOutgoing.sSMSHeader.eDataCodingScheme == SWI_SMS_CODINGSCHEME_UCS2)
        {
            U8 temp;
            for (UINT idx = 0; idx < m_smsOutgoing.sSMSHeader.nOverallMsgBody; idx = idx + 2)
            {
                temp = m_smsOutgoing.byMessage [idx];
                m_smsOutgoing.byMessage [idx] = m_smsOutgoing.byMessage [idx + 1];
                m_smsOutgoing.byMessage [idx + 1] = temp;
            }
        }
    
        ScreenLock (false);
		m_strSendingTo.Format (_T("Sending text message to %s was successfull"), m_strSmsSendTo);
		//AfxMessageBox (m_strSendingTo);

		//OnOK();
    break;
    case SWI_SMS_STORE_NotReady:
        m_strSendingTo = _T("SMS not ready.");
    break;
    case SWI_SMS_STORE_FDNMismatch:
        m_strSendingTo = _T("FDN mismatch.");
    break;
    case SWI_SMS_STORE_UnkownError:
        m_strSendingTo = _T("Unrecognized error.");
    break;
    default:
    //case SWI_SMS_STORE_InProgress:
    //case SWI_SMS_STORE_RecordNotFound:
    //case SWI_SMS_STORE_SimError:
    //case SWI_SMS_STORE_PSError:
    //case SWI_SMS_STORE_NoMessageID:
    //case SWI_SMS_STORE_InvalidRecord:
    //case SWI_SMS_STORE_ConcatLinkError:
    //case SWI_SMS_STORE_RecordNotSubmitted:
    //case SWI_SMS_STORE_NRAMError:
        m_strSendingTo = _T("System error.");
    break;
    }

    if (m_SmsSendExp.SmsSendStatus != SWI_SMS_STORE_Success)
    {
        AfxMessageBox (m_strSendingTo);
        //OnOK ();
    }
	UpdateData(FALSE);
}

void CSMSOutboxSampleDlg::ProcessSmsStatusReport()
{
	switch(m_SmsStatusReport.eSmsStatus)
	{
	case SWI_SMSMSGSTATUS_RECEIVED_OK:
		break;

	case SWI_SMSMSGSTATUS_UNABLE_TO_CONFIRM_DELIVERY:
	case SWI_SMSMSGSTATUS_REPLACED:
	case SWI_SMSMSGSTATUS_TRYING_CONGESTION:
	case SWI_SMSMSGSTATUS_TRYING_SME_BUSY:
	case SWI_SMSMSGSTATUS_TRYING_NO_RESPONSE_FROM_SME:
	case SWI_SMSMSGSTATUS_TRYING_SERVICE_REJECTED:
	case SWI_SMSMSGSTATUS_TRYING_QOS_NOT_AVAILABLE:
	case SWI_SMSMSGSTATUS_TRYING_SME_ERROR:
		//Received Unconfirmed No change;
		break;
	case SWI_SMSMSGSTATUS_PERM_REMOTE_PROCEDURE_ERROR:
	case SWI_SMSMSGSTATUS_PERM_INCOMPATIBLE_DEST:
	case SWI_SMSMSGSTATUS_PERM_REJECTED_BY_SME:
	case SWI_SMSMSGSTATUS_PERM_NOT_OBTAINABLE:
	case SWI_SMSMSGSTATUS_PERM_QOS_NOT_AVAILABLE:
	case SWI_SMSMSGSTATUS_PERM_NO_INTERWORKING:
	case SWI_SMSMSGSTATUS_PERM_VP_EXPIRED:
	case SWI_SMSMSGSTATUS_PERM_DELETED_BY_ORIG_SME:
	case SWI_SMSMSGSTATUS_PERM_DELETED_BY_SC_ADMIN:
	case SWI_SMSMSGSTATUS_PERM_SM_NO_EXISTING:
	case SWI_SMSMSGSTATUS_TEMP_CONGESTION:
	case SWI_SMSMSGSTATUS_TEMP_SME_BUSY:
	case SWI_SMSMSGSTATUS_TEMP_NO_RESPONSE_FROM_SME:
	case SWI_SMSMSGSTATUS_TEMP_SERVICE_REJECTED:
	case SWI_SMSMSGSTATUS_TEMP_QOS_NOT_AVAILABLE:
	case SWI_SMSMSGSTATUS_TEMP_SME_ERROR:
		//failed;
		break;
	}			
}
////////////////////////////////////////////////////////////////////////////////
//
//   Function   :	ScreenLock
//
//   Description:	Locks the screen
//
//   Arguments  :	bEnable - true to lock, false to unlock
//
//   Returns:   :	none
//
////////////////////////////////////////////////////////////////////////////////
void CSMSOutboxSampleDlg::ScreenLock(bool bEnable)
{
	bEnable = !bEnable;

	GetDlgItem(IDOK)->EnableWindow(bEnable);
	GetDlgItem(IDC_SENDSMS)->EnableWindow(bEnable);
	GetDlgItem(IDC_SENDSMSTO)->EnableWindow(bEnable);
	GetDlgItem(IDC_COMPOSEMSGBODY)->EnableWindow(bEnable);
	GetDlgItem(IDC_SENDSMSSTATUS)->EnableWindow(bEnable);
	m_ctrlProgress.ShowWindow (bEnable ? SW_HIDE : SW_SHOW);    
	GetDlgItem(IDC_STA_SendingTo)->ShowWindow(bEnable ? SW_HIDE : SW_SHOW);
}

////////////////////////////////////////////////////////////////////////////
//
//	Function	:	ComposeOutgoingSms
//
//	Description	:	Prepares the SWI_STRUCT_GSM_SMS_StoreSms structure
//
//	Arguments	:	None
//
//	Returns		:	
//
//	Comments	:
//
/////////////////////////////////////////////////////////////////////////////
bool CSMSOutboxSampleDlg::ComposeOutgoingSms() 
{
    UpdateData (true);
    bool bDesInternational;

	//Validate the number
	if (IsGsmNumber (m_strSmsSendTo, bDesInternational) == false)
	{
		AfxMessageBox (_T("Invalid number"));
		m_strSmsSendTo = _T("");
		UpdateData (false);
		return false;
	}
    UINT nPlusSign = (bDesInternational == true) ? 1 : 0;    
	
    SWI_STRUCT_SMS_Param sSmsParam;
    ::memset (&sSmsParam, 0, sizeof(SWI_STRUCT_SMS_Param));
    sSmsParam.sizeStruct = sizeof(SWI_STRUCT_SMS_Param);
    SWI_RCODE rCode = SwiGetSmsParam(&sSmsParam, (VALUE_WAIT * 2)); // obtains Service Centre info from modem
    if (rCode != SWI_RCODE_OK)
	{
		AfxMessageBox(_T("Unable to get SMS parameters."));
        return false;
    }

    ::memset (&m_smsOutgoing, 0, sizeof (SWI_STRUCT_GSM_SMS_StoreSms));
    m_smsOutgoing.sizeStruct			= sizeof (SWI_STRUCT_GSM_SMS_StoreSms);
    m_smsOutgoing.sSMSHeader.sizeStruct = sizeof (SWI_STRUCT_SMS_StoreHeader);
    
    UINT   nOverallMsgBody;
    StringToSmsMsg (m_strSMSBody,
                    m_smsOutgoing.sSMSHeader.eDataCodingScheme,
                    m_smsOutgoing.byMessage,
                    nOverallMsgBody);
    m_smsOutgoing.sSMSHeader.nOverallMsgBody = nOverallMsgBody;


    if (bDesInternational == true)
        m_smsOutgoing.sSMSHeader.eAddress = SWI_SMS_ADDRESS_International;
    else
        m_smsOutgoing.sSMSHeader.eAddress = SWI_SMS_ADDRESS_Unknown;
    m_smsOutgoing.sSMSHeader.eAddressNumberingPlan  = SWI_SMS_ADDNUMBERING_ISDN;
    m_smsOutgoing.sSMSHeader.eProtocol              = SWI_SMS_PROTOCOL_AppLayer;
    m_smsOutgoing.sSMSHeader.eDataCodingClass       = SWI_SMS_CODINGCLASS_NotGiven;
    m_smsOutgoing.sSMSHeader.eProtocolID            = SWI_SMS_PROTOCOLID_Implicit;
    m_smsOutgoing.sSMSHeader.ValidityPeriod [0]     = 2;
    m_smsOutgoing.sSMSHeader.ValidityPeriod [1]     = 167;

    m_smsOutgoing.sSMSHeader.eSCAddress              = sSmsParam.eSCAddressType;
    m_smsOutgoing.sSMSHeader.eSCAddressNumberingPlan = SWI_SMS_ADDNUMBERING_ISDN;

    m_smsOutgoing.sSMSHeader.nAddressNumLength       = m_strSmsSendTo.GetLength () - nPlusSign;    
    for (int idx = 0; idx < m_strSmsSendTo.GetLength (); ++idx)
    {
        if (idx > 0 || nPlusSign == 0)
            m_smsOutgoing.sSMSHeader.SME [idx-nPlusSign] = (U8) (m_strSmsSendTo.GetAt(idx) - _T('0'));
    }
    if (sSmsParam.bSCAddressPresent == true)
    {
        m_smsOutgoing.sSMSHeader.nSCAddressNumLength     = sSmsParam.nSCAddressLength;    
        for (int idx = 0; idx < (int)sSmsParam.nSCAddressLength; ++idx)
            m_smsOutgoing.sSMSHeader.SCAddressNumber [idx] = sSmsParam.SCAddressNumber[idx];
    }    
    m_strSMSBody.ReleaseBuffer ();

    return true;
}

////////////////////////////////////////////////////////////////////////////
//
//	Function	:	StoreSms
//
//	Description	:	Store the SMS to be sent
//
//	Arguments	:	None
//
//	Returns		:	
//
//	Comments	:
//
/////////////////////////////////////////////////////////////////////////////
void CSMSOutboxSampleDlg::StoreSms()
{
    ScreenLock(true);

    ZeroMemory (&m_smsOutgoing, sizeof(SWI_STRUCT_GSM_SMS_StoreSms));

    m_cntSegments = -1;
    m_iSequence   = 0;

    if (ComposeOutgoingSms () == true)
    {
        //Make sur service center number is not blanck
        if (m_smsOutgoing.sSMSHeader.nSCAddressNumLength == 0)
        {
            AfxMessageBox (_T("Blank address number."));
            ScreenLock(false);
            return;
        }

        //Truncate the SMS body to 800
        m_smsOutgoing.sSMSHeader.nOverallMsgBody = (m_smsOutgoing.sSMSHeader.nOverallMsgBody > 800) ? 800 : m_smsOutgoing.sSMSHeader.nOverallMsgBody;

        //Swap the bytes for wide character codes
        if (m_smsOutgoing.sSMSHeader.eDataCodingScheme == SWI_SMS_CODINGSCHEME_UCS2)
        {
            U8 temp;
            for (UINT idx = 0; idx < m_smsOutgoing.sSMSHeader.nOverallMsgBody; idx = idx + 2)
            {
                temp = m_smsOutgoing.byMessage [idx];
                m_smsOutgoing.byMessage [idx] = m_smsOutgoing.byMessage [idx + 1];
                m_smsOutgoing.byMessage [idx + 1] = temp;
            }
        }

        SWI_RCODE rCode = SwiStoreSMSMessageExp (&m_smsOutgoing, &m_cntSegments, &m_iSequence, VALUE_WAIT*30);
        if (rCode == SWI_RCODE_OK)
        {
            m_strSendingTo.Format (_T("Sending text message to %s ..."), m_strSmsSendTo);
            UpdateData (FALSE);

            m_ctrlProgress.SetRange32 (0, (m_cntSegments+2));
            m_ctrlProgress.SetStep(1);
            m_ctrlProgress.SetPos(0);

        }
        else
        {
            AfxMessageBox (_T("Unable to store SMS."));
            ScreenLock(false);
        }
    }
    else
        OnOK();
}

////////////////////////////////////////////////////////////////////////////
//
//	Function	:	SendSms
//
//	Description	:	Send an already stored SMS
//
//	Arguments	:	None
//
//	Returns		:	
//
//	Comments	:
//
/////////////////////////////////////////////////////////////////////////////

void CSMSOutboxSampleDlg::SendSms ()
{
    SWI_RCODE rCode = SwiSendSMSExp(VALUE_WAIT*30);
    if (rCode != SWI_RCODE_OK)
	{
        AfxMessageBox (_T("Unable to send SMS."));
        m_ctrlProgress.ShowWindow (SW_HIDE);
    }
}


/////Helper functions
bool CSMSOutboxSampleDlg::IsGsmNumber (CString &strNumber, bool &bInternational)
{
    TCHAR ch;
    int   iLength = strNumber.GetLength ();
    if (iLength == 0)
        return false;
    int idx = (strNumber.GetAt(0) == _T('+'))? 1 : 0;
    if (iLength == 1 && idx == 1)
        return false;
    bInternational = (idx == 1) ? true : false;

    for (idx; idx < iLength; ++idx)
    {
        ch = strNumber.GetAt(idx);
        if (ch > _T('9') || ch < _T('0'))
            return false;
    }
    return true;
}

void CSMSOutboxSampleDlg::StringToSmsMsg(CString                   &strSms,             //in
										 SWI_TYPE_SMS_CodingScheme &eDataCodingScheme,  //out
										 unsigned char             *pMsgData,           //out
										 UINT                      &nSMSSize            //out
										 )
{


#if(defined(UNDER_CE)||defined(_UNICODE))
	// get a pointer to the inputted SMS string
	unsigned short *ucs2stringp = (unsigned short *)(LPCTSTR)strSms;

	// determine the number of characters in the inputted SMS string
	int iSize = strSms.GetLength();
#else
	// allocate a temporary buffer the unicode version of the inputted SMS string
	unsigned short *ucs2stringp = new unsigned short [LENGTH_MAX_Sms + 1];

	// convert the multibyte SMS string to unicode and determine the 
	// number of unicode characters in the string
	int iSize = MultiByteToWideChar (	CP_ACP,	
										0, 
										strSms, 
										-1, 
										(LPWSTR)ucs2stringp, 
										LENGTH_MAX_Sms) - 1;
#endif
    // moving pointer to the output string       
    unsigned char *pMsgBuffer = pMsgData;

	// a single unicode character
	unsigned short ch1;

	// a single 7 bit SMS character
	unsigned char smschar;

	// initialize the coding scheme to the 7 bit SMS default alphabet
	eDataCodingScheme = SWI_SMS_CODINGSCHEME_Default;

	// reset the number of 8 bit bytes in the resultant SMS message string
    nSMSSize = 0;

	// loop through the entire unicode character
	// check to see if the unicode character can be encoded using the SMS Default alphabet
	for (int idx = 0; idx < iSize; ++idx)
    {
		// get the next unicode character
        ch1 = *(ucs2stringp + idx);
        
        // assume that the unicode character will not translate to a 7 bit character
		smschar = NON_GSM;

		// if the unicode character is NULL
		if(ch1 == 0x0000)
		{
			// break out of the loop
			break;
		}    
		// if the unicode character is of the form 0x00XX then 
		else if(ch1 < UCS2_TO_GSM_LOOKUP_TABLE_SIZE)
		{
			// attempt to convert the character from unicode to a 7 bit character
			smschar = Ucs2ToGsm[ch1];

			// if the character exists in the extended SMS Default table
			if(smschar == EXTEND)
			{
				// store the escape character in the output string
				*pMsgBuffer++ = smschar;

				// increment number of bytes in the output string
				nSMSSize++;

				// map the unicode character to one of the extend SMS characters
				switch(ch1)
				{
				case WCHAR('['):
					smschar = 0x3C;
					break;
				case WCHAR(0x5C):
					smschar = 0x2F;
					break;
				case WCHAR(']'):
					smschar = 0x3E;
					break;
				case WCHAR('^'):
					smschar = 0x14;
					break;
				case WCHAR('{'):
					smschar = 0x28;
					break;
				case WCHAR('|'):
					smschar = 0x40;
					break;
				case WCHAR('}'):
					smschar = 0x29;
					break;
				case WCHAR('~'):
					smschar = 0x3D;
					break;
				default:
					smschar = NON_GSM;
				}
			}
			
		}
		// if the unicode character is one of the Greek characters
		else if ((ch1 >= UCS2_GREEK_CAPITAL_LETTER_GAMMA) &&
				 (ch1 <= (UCS2_GREEK_CAPITAL_LETTER_GAMMA + UCS2_GCL_RANGE)))
		{
			// attempt to map the unicode character to a 7 bit character
			smschar = Ucs2GclToGsm[(ch1) - UCS2_GREEK_CAPITAL_LETTER_GAMMA];
		}
		// the EURO character is a special case
		else if (0x20ac == ch1)
		{
			// must put 0x1b65 to represent the EURO character
			*pMsgBuffer++ = 0x1b;
			nSMSSize++;
			smschar = 0x65;
		}

		// if the unicode character could not be mapped
		if(smschar == NON_GSM)
		{
			// change the coding scheme to unicode and break out of this loop
			eDataCodingScheme = SWI_SMS_CODINGSCHEME_UCS2;
			break;
		}
		
		// store the successfully converted 7 bit character in the output string
        //ignore the cr
        if (smschar != 0x000D)
        {
		    *pMsgBuffer++ = smschar;

		    // increment the number of bytes stored in the output string
		    nSMSSize++;
        }
	}

	// if the string could not be converted to a 7 bit alphabet then
	if (eDataCodingScheme == SWI_SMS_CODINGSCHEME_UCS2)
    {
        iSize = (iSize > LENGTH_MAX_Sms/2) ? LENGTH_MAX_Sms/2 : iSize;
		// copy the previously converted unicode character string to the output string
		unsigned short *pShort = (unsigned short *)pMsgData;
        for (int idx2 = 0; idx2 < iSize; ++idx2)
			*pShort++ = *(ucs2stringp + idx2);

		// calculate the number of bytes in the output string
        nSMSSize = iSize*2;

		// NULL terminate the output string
		*pShort++ = 0x00;
	}

#if(defined(UNDER_CE)||defined(_UNICODE))
#else
	// free temporary unicode buffer
	delete [] ucs2stringp; 
#endif
           
}

//6047243275
//6043385021