/**
 *
 *	Name	:	SMSOutboxSampleDlg.h
 *
 *	Purpose	:	Header file for SMSOutboxSample Dialog, Dialog will send an entered 
 *				SMS to a user entered number
 *
 *	History	:	created	June 10, 2003
 *				- initial version, based on old SDK's SMS Sample Application
 *
 *	Revision:	1.0
 *
 *	Copyright (c) 2003 Sierra Wireless, Inc. All rights reserved.
 *
 **/

#if !defined(AFX_SMSOutboxSampleDLG_H__B58B3718_4F5E_41FC_8612_472E6B1F9125__INCLUDED_)
#define AFX_SMSOutboxSampleDLG_H__B58B3718_4F5E_41FC_8612_472E6B1F9125__INCLUDED_

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000

#include "SwiApiCm.h"
#include "SwiStructsGsm.h"

const U32 VALUE_WAIT = 1000;
const int MAX_TRIES  = 3;

// user message identifiers for SMS status and SIM full notifications
#define WM_NOTIFICATION WM_USER + 400	//specific notification

/////////////////////////////////////////////////////////////////////////////
// CSMSOutboxSampleDlg dialog

class CSMSOutboxSampleDlg : public CDialog
{
// Construction
public:
	CSMSOutboxSampleDlg(CWnd* pParent = NULL);	// standard constructor

// Dialog Data
	//{{AFX_DATA(CSMSOutboxSampleDlg)
	enum { IDD = IDD_SMSOUTBOXSAMPLE_DIALOG };
	CButton	m_btnOK;
	CButton	m_btnSend;	// Send button
	CString	m_strSmsSendTo;	// holds SMS destination number
	CString	m_strSMSBody;	// holds SMS message body
	CString	m_strSendSmsStatus;	// holds status string
	CProgressCtrl	m_ctrlProgress;
	CString	m_strSendingTo;
	CString	m_strCharCount;
	//}}AFX_DATA

	// ClassWizard generated virtual function overrides
	//{{AFX_VIRTUAL(CSMSOutboxSampleDlg)
	protected:
	virtual void DoDataExchange(CDataExchange* pDX);	// DDX/DDV support
	//}}AFX_VIRTUAL

// Implementation
public:
	static CSMSOutboxSampleDlg* Instance();	// returns a pointer to this object
	void ProcessError(SWI_RCODE code);	// processes API error codes
	LRESULT OnNotification(WPARAM wParam, LPARAM lParam);	// handles notifications recieved
	void HandleCallback (SwiNotifyVariant* pNotify);	// caches data data from callbacks, avoid congestion

private:
	static CSMSOutboxSampleDlg* m_instance;	//a pointer back to this object

protected:
    int							m_cntSegments;
    int							m_iSequence;

    SWI_STRUCT_SmsStoreExp      m_SmsStoreExp;
    SWI_STRUCT_SmsSendExp       m_SmsSendExp;
	SWI_STRUCT_GSM_SMS_StoreSms	m_smsOutgoing;
	SWI_STRUCT_SMS_StatusReport m_SmsStatusReport;

protected:
	bool ComposeOutgoingSms();
	void SendSms();
	void StoreSms();
	void ProcessSmsStoreNotification();
    void ProcessSmsSendNotification();
	void ProcessSmsStatusReport();
	void ScreenLock(bool bEnable);
	bool IsGsmNumber (CString &strNumber, bool &bInternational);
	void StringToSmsMsg(CString					  &strSms,             //in
						SWI_TYPE_SMS_CodingScheme &eDataCodingScheme,  //out
						unsigned char             *pMsgData,           //out
						UINT                      &nSMSSize            //out
						);


protected:
	HICON m_hIcon;
	BOOL m_bConnected;	// "Connected or Disconnected" boolean value
	SWI_STRUCT_SmsReady	m_sSmsReady;

	SWI_STRUCT_SMS_SimFull	m_sSimFull; // cache memory for Sim Full status notification
	BOOL  ConnectModem();// Connects to the modem/API
	BOOL  DisconnectModem();	//Disconnects from the modem/API
	SWI_TYPE_Device GetHighestPriorityDeviceType();

	// Generated message map functions
	//{{AFX_MSG(CSMSOutboxSampleDlg)
	virtual BOOL OnInitDialog();
	afx_msg void OnOK();// Event triggered when the OK button is pressed
	afx_msg void OnSendSms();	// Event triggered when SEND button is pressed
	afx_msg void OnChangeEditCompose();
	//}}AFX_MSG
	DECLARE_MESSAGE_MAP()
};

//{{AFX_INSERT_LOCATION}}
// Microsoft Visual C++ will insert additional declarations immediately before the previous line.

#endif // !defined(AFX_SMSOutboxSampleDLG_H__B58B3718_4F5E_41FC_8612_472E6B1F9125__INCLUDED_)
