///////////////////////////////////////////////////////////////////////////////
//                                                                              
//	$Revision: 29 $																
//																				
//	Name       : SwiStructs.h													
//                                                                             
//  Purpose    : SWI GPRS specific enumerated types and structures             
//					                                                            
//	Copyright (c) 2008 Sierra Wireless, Inc.  All rights reserved			    
//                                                                              
///////////////////////////////////////////////////////////////////////////////
#ifndef __SWI_STRUCTS_GSM_H
#define __SWI_STRUCTS_GSM_H

#include "SwiDataTypes.h"
#include "SwiStructsMp.h"
#include "SwiDefinesCm.h"

///constants
#define MAX_NO_CONTEXT              3
#define MAX_3G_GSM_PROFILES			16
#define NUMBER_PLMN                 14
#define NUMBER_Band                 5
#define LENGTH_IPAddress		    16
#define LENGTH_AccessPointName		101
#define LENGTH_UserName		        128
#define LENGTH_MP_UserName		    33
#define LENGTH_Label				31
#define LENGTH_Password				128
#define LENGTH_MP_Password			33
#define LENGTH_AddressNumber        20
#define LENGTH_SME                  20
#define LENGTH_SMSTimestamp         14
#define LENGTH_SMSValidityPeriod    16
#define LENGTH_MaxCHV				9
#define LENGTH_MaxPhone				20
#define LENGTH_CallerName			82
#define MAX_CALLS					7
#define LENGTH_MaxDebugString		201
#define LENGTH_DcsMsgInd			3
#define LENGTH_Timestamp			14
#define LENGTH_Validity				16
#define LENGTH_SPN		            17
#define	LENGTH_PLMN		            32
#define LENGTH_AbvPLMN				14
#define	LENGTH_MAX_Sms		        1024
#define LENGTH_MAX_SmsMsgData		161
#define LENGTH_MsgWaiting			3
#define	LENGTH_EntryName			31
#define	LENGTH_GSM_PhoneNumber		40
#define	LENGTH_EmergencyPhoneNumber	6
#define LENGTH_MEPCode				13
#define LENGTH_ForwardNumber		38
#define LENGTH_ForwardInfo			18
#define LENGTH_SSPassword			4
#define VERSION_SuppService			0x0001
#define MAX_FWD_INFO_ENTRIES		8
#define MAX_CALL_BARR_ENTRIES		8
#define MAX_INFO_DATA				70
#define MAX_BS_LIST					70
#define LENGTH_RawData				229
#define LENGTH_SSString				40
#define LENGTH_STKCommand           119
#define LENGTH_STKRespInput         120
#define LENGTH_SSString				40
#define LENGTH_SetFeaturesKey		21
#define LENGTH_RandNum              16
#define LENGTH_Kc                   8
#define LENGTH_USSDInput            100
#define LENGTH_CommandData			157
#define LENGTH_USSDInputExp         200
#define LENGTH_ErrorString			33
#define LENGTH_IccId				10
#define LENGTH_Imei					16 
#define LENGTH_Tac					7
#define LENGTH_Fac					3
#define LENGTH_Snr					7
#define LENGTH_ChkByte				2
#define LENGTH_Fsn					16
#define LENGTH_Signature			9
#define LENGTH_Country				4
#define LENGTH_Network				9
#define MAX_CELLS					6
#define LENGTH_MCCMNC_BUFFER		3
#define LENGTH_MCCMNC_TEXT			6
#define LENGTH_UnlockKey			11
///////////////////////////////////////////////////////////////////////////////
///
/// An enumeration of GSM device types.
///
///	These definitions are obsolete and should not be used.  SWI_TYPE_Device
/// should be used instead as it contains a complete list of all supported
/// devices (both GSM and CDMA).
///
/// See SwiGetAvailAirServers for information on how to get a list of available
/// devices.
///
///	\sa	SWI_STRUCT_AirCardType
/// \sa SwiGetAvailAirServers
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_AirCard
{
	SWI_AIRCARD_None	= -1,	/*!< Invalid device */
	SWI_AIRCARD_AC710,			/*!< AirCard 710 */
	SWI_AIRCARD_AC720,			/*!< AirCard 720 */
    SWI_AIRCARD_AC750,			/*!< AirCard 750 */
	SWI_AIRCARD_SB750,			/*!< SingleBoard 750 */
	SWI_AIRCARD_SB750A,			/*!< SingleBoard 750A */
	SWI_AIRCARD_AC755,			/*!< AirCard 755 */
	SWI_AIRCARD_AC775,			/*!< AirCard 775 */
	SWI_AIRCARD_AC77,			/*!< AirCard 77 */
	SWI_AIRCARD_PC7000,			/*!< PC7000 */
	SWI_AIRCARD_PC7200,			/*!< PC7200 */
	SWI_AIRCARD_AC850,			/*!< AirCard 850 */
	SWI_AIRCARD_AC860,			/*!< AirCard 860 */
	SWI_AIRCARD_MC8755,			/*!< MC8755 */
	SWI_AIRCARD_MC8765,			/*!< MC8765 */
	SWI_AIRCARD_MC5720,			/*!< MC5720 */
	SWI_AIRCARD_EM5625,			/*!< EM5625 */
	SWI_AIRCARD_AC595	= 0x10,	/*!< AirCard 595 */
	SWI_AIRCARD_MC5725,			/*!< MC5725 */
	SWI_AIRCARD_AC595E,			/*!< AirCard 595E */
	SWI_AIRCARD_AC875,			/*!< AirCard 875 */
	SWI_AIRCARD_MC8775,			/*!< MC8775 */
	SWI_AIRCARD_MC8775V,		/*!< MC8775V */
	SWI_AIRCARD_EM5725,			/*!< EM5725 */
	SWI_AIRCARD_AC597,			/*!< AC597 */
	SWI_AIRCARD_AC880,			/*!< AirCard 880 */
	SWI_AIRCARD_AC881,			/*!< AirCard 881 */
	SWI_AIRCARD_MC8780,			/*!< MC8780 */
	SWI_AIRCARD_MC8781,			/*!< MC8781 */
	SWI_AIRCARD_MC8780V,		/*!< MC8780V */
	SWI_AIRCARD_MC8781V,		/*!< MC8781V */
	SWI_AIRCARD_EC880,			/*!< AirCard 880E */
	SWI_AIRCARD_EC881,			/*!< AirCard 881E */
	SWI_AIRCARD_EM8780	= 0x20,	/*!< EM8780 */
	SWI_AIRCARD_EM8781,			/*!< EM8781 */
	SWI_AIRCARD_M81A,			/*!< M81A */
	SWI_AIRCARD_M81B,			/*!< M81B */
	SWI_AIRCARD_MC8785 = 0x27,	/*!< MC8785 */
	SWI_AIRCARD_MC8785V,		/*!< MC8785V */
	SWI_AIRCARD_AC885E,			/*!< AirCard 885E */
	SWI_AIRCARD_AC885,			/*!< Compass 885 */
	SWI_AIRCARD_MC8790,			/*!< MC8790 */
	SWI_AIRCARD_MC8790V,		/*!< MC8790V */
	SWI_AIRCARD_AC890E,			/*!< AirCard 890E */
	SWI_AIRCARD_C888,			/*!< Compass 888 */
	SWI_AIRCARD_C889,			/*!< Compass 889 */
	SWI_AIRCARD_K888	= 0x30,	/*!< Karbon 888 */
	SWI_AIRCARD_K889,			/*!< Karbon 889 */
	SWI_AIRCARD_MC8791V,		/*!< MC8791V */
	SWI_AIRCARD_MC8792V,		/*!< MC8792V */
	SWI_AIRCARD_C22,			/*!< Compass 22 */
	SWI_AIRCARD_C23,			/*!< Compass 23 */
	SWI_AIRCARD_T598,			/*!< Tiger 598 */
	SWI_AIRCARD_T11,			/*!< Tiger 11 */
	SWI_AIRCARD_AC402 = 0x39,	/*!< AirCard 402 */
	SWI_AIRCARD_MC5727V,		/*!< MC5727V */
	SWI_AIRCARD_MC5728,			/*!< MC5728 */
	SWI_AIRCARD_MC5728V,		/*!< MC5728 */
	SWI_AIRCARD_K22,			/*!< Karbon 22 */
	SWI_AIRCARD_K23,			/*!< Karbon 23 */
	SWI_AIRCARD_USB305,			/*!< USB 305 */
	SWI_AIRCARD_C25 = 0x40,		/*!< C25 */
	SWI_AIRCARD_USB303,			/*!< USB 303 */
	SWI_AIRCARD_USB304,			/*!< USB 304 */
	SWI_AIRCARD_USB306,			/*!< USB 306 */
	SWI_AIRCARD_MC8777V,		/*!< MC8777V */
	SWI_AIRCARD_MC8700,			/*!< MC8700 */
	SWI_AIRCARD_AC502,			/*!< AirCard 502 */
	SWI_AIRCARD_USB301,			/*!< USB 301 */
	SWI_AIRCARD_USB307,			/*!< USB 307 */
	SWI_AIRCARD_USB308,			/*!< USB308 */
	SWI_AIRCARD_USB309,			/*!< USB309 */
	SWI_AIRCARD_USB311,			/*!< USB311 */
	SWI_AIRCARD_USB312,			/*!< USB312 */
	SWI_AIRCARD_AC503,			/*!< USB503 */
	SWI_AIRCARD_USB302,			/*!< USB302 */
	SWI_AIRCARD_USB340,			/*!< USB340 */
	SWI_AIRCARD_MC8795V = 0x50,	/*!< MC8795V */
	SWI_AIRCARD_USB310,			/*!< USB310 */
	SWI_AIRCARD_USB315,			/*!< USB315 */
	SWI_AIRCARD_USB316,			/*!< USB316 */
	SWI_AIRCARD_USB300,			/*!< USB300 */
	SWI_AIRCARD_END = 0xFF		/*!< All other products.  
									 Use of this definition is deprecated */
};

///////////////////////////////////////////////////////////////////////////////
///
/// This structure contains the modem's disabled state.
///
///	This structure is returned with SWI_NOTIFY_ModemDisable to indicate a
/// change in the modem's disabled state.
///
///	\sa SWI_NOTIFY_ModemDisable
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_ModemDisabled
{
	/*! The size, in bytes, of this structure.  */
    U32  sizeStruct;
    
    /*! True is returned if modem is disabled.  Otherwise, false is returned.*/		
    bool bModemDisabled;	
};

///////////////////////////////////////////////////////////////////////////////
///
/// This structure contains the International Mobile Equipment Identity (IMEI).
///
/// The IMEI is a number unique to every GSM mobile phone.  This structure is 
/// used as output by the SwiGetImei function. 
///
/// \sa SwiGetImei
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_Imei
{
	/*! The size, in bytes, of this structure.  This value must always be 
		populated by the calling application. */
	U32 sizeStruct;     
	
	/*! A NULL terminated string containing the IMEI. */
    WCHAR szImei[LENGTH_Imei]; 
    
    /*! A 6 character, NULL terminated string representing the Type Approval 
		Code. */
    WCHAR szTac[LENGTH_Tac];
    
    /*! A 2 character, NULL terminated string representing the Assembly Code. */
	WCHAR szFac[LENGTH_Fac];
	
	/*! A 6 character, NULL terminated string representing the Serial Number. */
	WCHAR szSnr[LENGTH_Snr];
	
	/*! Check byte */
	WCHAR szCheckByte[LENGTH_ChkByte];
};

///////////////////////////////////////////////////////////////////////////////
///
/// This structure contains factory serial number information.
/// 
/// This structure is used as output by the SwiGetSerialNumber function. 
///
/// \sa SwiGetSerialNumber
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_Fsn
{
	/*! The size, in bytes, of this structure.  This value must always be 
		populated by the calling application. */
	U32		sizeStruct;
	
	/*! A 15 character NULL terminated string representing the factory serial
		number. */
    WCHAR   szFsn[LENGTH_Fsn];
};

///////////////////////////////////////////////////////////////////////////////
///
/// This structure contains test history byte information.
/// 
/// This structure is used as output by the SwiGetTestHistoryByte function. 
///
/// \sa SwiGetTestHistoryByte
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_Thb
{
	/*! The size, in bytes, of this structure.  This value must always be 
		populated by the calling application. */
	U32 sizeStruct;  
	
	/*! True is returned if initial tests passed.  Otherwise, false is 
		returned. */         
    bool bInitialTest;   
    
	/*! True is returned if RF screen tests passed.  Otherwise,
		false is returned. */ 
    bool bRFScreen;     
    
	/*! True is returned if calibration tests passed.  Otherwise, false is 
		returned. */ 
    bool bCalibration;   
    
	/*! True is returned if system tests passed.  Otherwise, false is 
		returned. */ 
    bool bSystem;        
};

///////////////////////////////////////////////////////////////////////////////
///
/// Structure containing the card type.
///
/// This structure is used as output by the SwiGetAirCardType function. 
///
/// This structure is obsolete.  See SwiGetAvailAirServers for information on
/// how to get a list of available devices.
///
/// \sa SwiGetAirCardType
/// \sa SwiGetAvailAirServers
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_AirCardType
{
	/*! The size, in bytes, of this structure.  This value must always be 
		populated by the calling application. */
    U32 sizeStruct;    
    
    /*! An SWI_TYPE_AirCard enumeration representing the card type. */
	SWI_TYPE_AirCard eAirCard;
};

///////////////////////////////////////////////////////////////////////////////
///
/// This structure contains feature customizations.
///
/// This structure is used as output by the SwiGetFeatureCustomizations 
/// function.
///
/// \sa SwiGetFeatureCustomizations
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_FeatureCustomizations
{
	/*! The size, in bytes, of this structure.  This value must always be 
		populated by the calling application. */
	U32 sizeStruct;
	
	/*! True is returned if auto connection is allowed, false otherwise. */
	bool bAutoConnect;
	
	/*! True is returned if advanced profile configuration is permitted, false
		otherwise. */
	bool bAdvanceProfile;
	
	/*! True is returned if the host application should hide byte counters.  
		False is returned if the host application should display byte counter 
		information. */
	bool bHideByteCounters;
	
	/*! True is returned if circuit switch connections are supported, false
		otherwise. */
	bool bAllowCsd;
	
	/*! True is returned if HSDPA test channel is supported, false 
		otherwise. */
	bool bHSDPASupport;
	
	/*! True is returned if profile scanning is enabled in the firmware.  
		Otherwise, false is returned and software is free to do profile 
		scanning. */
	bool bScanProfile;
	
	/*! True is returned if bluetooth is supported, false otherwise. */
	bool bBluetooth;
	
	/*! True is returned if GPS is supported, false otherwise. */
	bool bGps;

	/*! Internal customer ID */
	U32 nCustomerId;
};

///////////////////////////////////////////////////////////////////////////////
///
/// An enumeration of PDP connection types. 
///
/// \sa SWI_STRUCT_Profile
/// \sa SWI_STRUCT_GsmProfileBasic
/// \sa SWI_STRUCT_AvailFeatures
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_PDP
{
    SWI_PDP_IP,		/*!< IPV4 */		
    SWI_PDP_PPP,	/*!< PPP */
	SWI_PDP_IPV6	/*!< IPV6 */
};

///////////////////////////////////////////////////////////////////////////////
///
/// An enumeration of quality of service precedence types.
///
/// \sa SWI_STRUCT_PktSessionStatus
/// \sa SWI_STRUCT_Profile
/// \sa SWI_STRUCT_GsmProfileQos
/// \sa SWI_STRUCT_PktSessionCall
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_Precedence
{
    SWI_PRECED_Subscribed,		/*!< Subscribed precedence */	
    SWI_PRECED_HighPriority,	/*!< High priority */
    SWI_PRECED_MediumPriority,	/*!< Medium priority */
    SWI_PRECED_LowPriority		/*!< Low priority */
};

///////////////////////////////////////////////////////////////////////////////
///
/// An enumeration of quality of service delay types.
///
/// \sa SWI_STRUCT_PktSessionStatus
/// \sa SWI_STRUCT_Profile
/// \sa SWI_STRUCT_GsmProfileQos
/// \sa SWI_STRUCT_PktSessionCall
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_Delay
{
    SWI_DELAY_Subscribed,	/*!< Subscribed delay */		
    SWI_DELAY_Low,			/*!< Low delay */
    SWI_DELAY_Medium,		/*!< Medium delay */
    SWI_DELAY_High,			/*!< High delay */
    SWI_DELAY_BestEffort	/*!< Best effort delay */	
};

///////////////////////////////////////////////////////////////////////////////
///
/// An enumeration of quality of service reliability types.
///
/// \sa SWI_STRUCT_PktSessionStatus
/// \sa SWI_STRUCT_Profile
/// \sa SWI_STRUCT_GsmProfileQos
/// \sa SWI_STRUCT_PktSessionCall
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_Reliability
{
    SWI_RELI_Subscribed,				/*!< Default reliability class */ 
    SWI_RELI_GTPAcknowledged,			/*!< GTP reliability class */
    SWI_RELI_LLCFrameAcknowledged,		/*!< LCC frame reliability class */
    SWI_RELI_RLCBlockModeAcknowledged,  /*!< RLC acknowledged reliability
											 class */
    SWI_RELI_LLCDataProtected,			/*!< LCC data protected reliability
											 class */
    SWI_RELI_UnackUnprotected			/*!< Unacknowledged reliability 
											 class */
};

///////////////////////////////////////////////////////////////////////////////
///
/// An enumeration of quality of service peak throughput types.
///
/// \sa SWI_STRUCT_PktSessionStatus
/// \sa SWI_STRUCT_Profile
/// \sa SWI_STRUCT_GsmProfileQos
/// \sa SWI_STRUCT_PktSessionCall
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_PeakThroughput
{
    SWI_THROUGHPUT_Subscribed,	/*!< Default to peak throughput class */
    SWI_THROUGHPUT_1000,		/*!< Up to 1000 bytes (8 kbit/s) */
    SWI_THROUGHPUT_2000,        /*!< up to 2000 bytes (16 kbit/s) */
    SWI_THROUGHPUT_4000,		/*!< Up to 4000 bytes (32 kbit/s) */
    SWI_THROUGHPUT_8000,		/*!< Up to 8000 bytes (64 kbit/s) */
    SWI_THROUGHPUT_16000,		/*!< Up to 16000 bytes (128 kbit/s) */
    SWI_THROUGHPUT_32000,		/*!< Up to 32000 bytes (256 kbit/s) */
    SWI_THROUGHPUT_64000,		/*!< up to 64000 bytes (512 kbit/s) */
    SWI_THROUGHPUT_128000,		/*!< Up to 128000 bytes (1024 kbit/s) */
    SWI_THROUGHPUT_256000		/*!< Up to 256000 bytes (2048 kbit/s) */
};

///////////////////////////////////////////////////////////////////////////////
///
/// An enumeration of quality of service mean throughput types.
///
/// \sa SWI_STRUCT_PktSessionStatus
/// \sa SWI_STRUCT_Profile
/// \sa SWI_STRUCT_GsmProfileQos
/// \sa SWI_STRUCT_PktSessionCall
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_MeanThroughput
{
    SWI_MEANTHROUGH_Subscribed,		/*!< Subscribed */
    SWI_MEANTHROUGH_100,			/*!< 100 octets/hr (~0.22 bit/s) */
    SWI_MEANTHROUGH_200,			/*!< 200 octets/hr (~0.44 bit/s) */
    SWI_MEANTHROUGH_500,			/*!< 500 octets/hr (~1.11 bit/s) */
    SWI_MEANTHROUGH_1K,				/*!< 1000 octets/hr (~2.2 bit/s) */
    SWI_MEANTHROUGH_2K,				/*!< 2000 octets/hr (~4.4 bit/s) */
    SWI_MEANTHROUGH_5K,				/*!< 5000 octets/hr (~11.1 bit/s) */
    SWI_MEANTHROUGH_10K,			/*!< 10000 octets/hr (~22 bit/s) */
    SWI_MEANTHROUGH_20K,			/*!< 20000 octets/hr (~44 bit/s) */
    SWI_MEANTHROUGH_50K,			/*!< 50000 octets/hr (~111 bit/s) */
    SWI_MEANTHROUGH_100K,			/*!< 100000 octets/hr (~0.22 kbit/s) */
    SWI_MEANTHROUGH_200K,			/*!< 200000 octets/hr (~0.44 kbit/s) */
    SWI_MEANTHROUGH_500K,			/*!< 500000 octets/hr (~1.11 kbit/s) */
    SWI_MEANTHROUGH_1M,				/*!< 1000000 octets/hr (~2.2 kbit/s) */
    SWI_MEANTHROUGH_2M,				/*!< 2000000 octets/hr (~4.4 kbit/s) */
    SWI_MEANTHROUGH_5M,				/*!< 5000000 octets/hr (~11.1 kbit/s) */
    SWI_MEANTHROUGH_10M,			/*!< 10000000 octets/hr (~22 kbit/s) */
    SWI_MEANTHROUGH_20M,			/*!< 20000000 octets/hr (~44 kbit/s) */
    SWI_MEANTHROUGH_50M,			/*!< 50000000 octets/hr (~111 kbit/s) */
    SWI_MEANTHROUGH_BestEffort		/*!< Best effort */
};

///////////////////////////////////////////////////////////////////////////////
///
/// An enumeration of packet session inactivity reason types.
///
/// \sa SWI_STRUCT_PktSessionStatus
/// \sa SWI_STRUCT_PktSessionCall
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_InactivityReason
{
	/*! Operator determined barring */
	SWI_INACTIVITYREASON_OperatorBarring,
	
	/*! LCC */
    SWI_INACTIVITYREASON_LLC,
    
    /*! Insufficient resources */
    SWI_INACTIVITYREASON_InsufficientResources,
    
    /*! APN unknown or missing */
    SWI_INACTIVITYREASON_MissingOrUnknownAPN,
    
    /*! PDP address unknown or missing */
    SWI_INACTIVITYREASON_UnknownPDPAddressOrType,
    
    /*! User authentication failed */
    SWI_INACTIVITYREASON_UserAuthenticationFailed,
    
    /*! GGSN rejection */
    SWI_INACTIVITYREASON_ActivationRejectedByGGSN,
    
    /*! Service not supported */
    SWI_INACTIVITYREASON_ServiceOptionNotSupported,
    
    /*! Not subscribed for that service */
    SWI_INACTIVITYREASON_ServiceOptionNotSubscribed,
    
    /*! Service out of order */
    SWI_INACTIVITYREASON_ServiceOptionTemporarilyOutOfOrder,	
    
    /*! Regular deactivation */
    SWI_INACTIVITYREASON_RegularDeactivation,
    
    /*! QoS not accepted */
    SWI_INACTIVITYREASON_QosNotAccepted,
    
    /*! Network failure */
    SWI_INACTIVITYREASON_NetworkFailure,
    
    /*! Reactivation required */
    SWI_INACTIVITYREASON_ReactivationRequired,
    
    /*! Feature not supported */
	SWI_INACTIVITYREASON_FeatureNotSup,
	
	/*! Semantic error in the TFT operation */
	SWI_INACTIVITYREASON_SemErrTftOper,
	
	/*! Syntactical error in the TFT operation */
	SWI_INACTIVITYREASON_SynErrTftOper,
	
	/*! Unknown PDP context */
	SWI_INACTIVITYREASON_UnknownPdpContext,
	
	/*! PDP context without TFT already activated */
	SWI_INACTIVITYREASON_TftActive,
	
	/*! Semantic error in packet filter(s) */
	SWI_INACTIVITYREASON_SemErrPktFilter,
	
	/*! Syntactical error in the packet filter(s) */
	SWI_INACTIVITYREASON_SynErrPktFilter,
	
	/*! Invalid transaction identifier value */
	SWI_INACTIVITYREASON_InvalidTransId,
	
	/*! Semantically incorrect message */
	SWI_INACTIVITYREASON_SemIncMsg,
	
	/*! Invalid mandatory information */
	SWI_INACTIVITYREASON_InvalidInfo,
	
	/*! Message type non-existent or not implemented */
	SWI_INACTIVITYREASON_MsgNonExist,
	
	/*! Message type not compatible with the protocol state */
	SWI_INACTIVITYREASON_MsgTypeNotComp,
	
	/*! Information element non-existent or not implemented */
	SWI_INACTIVITYREASON_InfoNonExist,
	
	/*! Conditional IE error */
	SWI_INACTIVITYREASON_IeErr,
	
	/*! Message not compatible with the protocol state */
	SWI_INACTIVITYREASON_MsgNotComp,
	
	/*! Protocol error, unspecified */					
	SWI_INACTIVITYREASON_ProtErr,
	
	/*! Normal */					
    SWI_INACTIVITYREASON_Normal
};

///////////////////////////////////////////////////////////////////////////////
///
/// An enumeration of network service status types.
///
/// \sa SWI_STRUCT_GSM_NetworkStatus
/// \sa SWI_STRUCT_GsmSystemStatus
/// \sa SWI_STRUCT_GsmCellMeasure
/// \sa SwiGetServiceStatusEx
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_ServiceStatus
{
	/*! The modem has acquired normal GPRS service and can use all available 
		features. */
    SWI_SERVICE_STATUS_Normal,
    
	/*! Full service is not available but there is coverage permitting 911 
		emergency voice calls.  The reasons full service is not available vary
		and can include: security lock, account activation, and others. */
    SWI_SERVICE_STATUS_Emergency,
    
	/*! The modem has not acquired GSM GPRS service, or the modem is security
		locked preventing service. */
    SWI_SERVICE_STATUS_NoService,
    
	/*! The network reports this fault. The modem is unable to register. The 
		user should check their signal strength or contact their carrier. */
	SWI_SERVICE_STATUS_AccessDifficulty,
	
	/*! The network indicates that you do not have permission to use it. */
	SWI_SERVICE_STATUS_ForbiddenPLMN,
	
	/*! The modem is in a geographic area where use of the service is not
		permitted. */
	SWI_SERVICE_STATUS_ForbiddenArea,
	
	/*! The modem is not in its home coverage area and is not permitted to roam
		in the current coverage area. */
	SWI_SERVICE_STATUS_ForbiddenRoaming,
	
	/*! The user's account is not permitted on the network. */
	SWI_SERVICE_STATUS_IllegalMobStation,
	
	/*! The modem is not permitted on the network, possibly for regulatory 
		reasons. */
	SWI_SERVICE_STATUS_IllegalMobEquip,
	
	/*! The SIM Card's identifier is unrecognized (or disqualified) by 
		carrier. */
	SWI_SERVICE_STATUS_UnknownIMSI,
	
	/*! The user name and/or password associated with the account profile 
		failed to authenticate. */
	SWI_SERVICE_STATUS_AuthenticationFailure,	
	
	/*! GPRS service is not available. */
	SWI_SERVICE_STATUS_GPRSFailed
};

///////////////////////////////////////////////////////////////////////////////
///
/// An enumeration of service types.
///
/// For modems capable of both circuit switched(GSM) as well as packet (GPRS) 
/// data operations, this enumerated type identifies the type of service 
/// currently available.
///
/// \sa SWI_STRUCT_GSM_NetworkStatus
/// \sa SWI_STRUCT_GsmSystemStatus
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_ServiceType
{
	SWI_SERVICE_TYPE_CircuitSwitched,	/*!< Circuit switched */
	SWI_SERVICE_TYPE_PS,				/*!< Packet switched */
	SWI_SERVICE_TYPE_Combined,			/*!< Combined circuit and packet
											 switched */
	SWI_SERVICE_TYPE_InvalidService		/*!< Invalid service */		
};

///////////////////////////////////////////////////////////////////////////////
///
/// An enumeration of GPRS icon states.
///
/// \sa SWI_STRUCT_IconGprsState
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_IconGprsState
{
    SWI_ICONGPRSSTATE_NoIcon,		/*!< GPRS icon should not be shown */
    SWI_ICONGPRSSTATE_FadedIcon,	/*!< GPRS icon should be faded */
    SWI_ICONGPRSSTATE_lightedIcon	/*!< GPRS icon should be lit */
};

///////////////////////////////////////////////////////////////////////////////
///
/// An enumeration of roaming icon states.
///
/// \sa SWI_STRUCT_IconRoamState
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_IconRoamState
{
    SWI_ICONROAMSTATE_NoIcon,		/*1< Roaming icon should be hidden */
    SWI_ICONROAMSTATE_FadedIcon,	/*!< Roaming icon should be faded */
    SWI_ICONROAMSTATE_lightedIcon	/*!< Roaming icon should be lit */
};

///////////////////////////////////////////////////////////////////////////////
///
/// An enumeration of temperature states.
///
/// \sa SWI_STRUCT_Temperature
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_Temperature
{
    SWI_TEMPERATURE_NotHot,		/*!< Radio is not over heating */		
    SWI_TEMPERATURE_Overheat	/*!< Radio is over heating */		
};

/** 
*	\addtogroup GroupNetwork Network Management and Status
*/
/*@{*/

///////////////////////////////////////////////////////////////////////////////
///
/// An enumeration of transmit speed types based on number of transmit slots.
///
/// \sa SwiGetTransmitSpeed
/// \sa SwiSetTransmitSpeed
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_TransmitSpeed
{
	SWI_SPPED_1x,	/*!< One slot */	
	SWI_SPPED_2x,	/*!< Two slots */
	SWI_SPPED_3x	/*!< Four slots */
};

///////////////////////////////////////////////////////////////////////////////
///
/// This structure is used by the SWI_NOTIFY_TransmitAlert notification. 
///
/// \sa SWI_NOTIFY_TransmitAlert
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_TransmitAlert
{
	U32 sizeStruct;     /*!	The size, in bytes, of this structure. */
};

///////////////////////////////////////////////////////////////////////////////
///
/// An enumeration of currently selected network selection modes.
///
/// \sa SWI_STRUCT_GSM_NetworkStatus
/// \sa SWI_STRUCT_GsmSystemStatus
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_ModeSelection
{
    SWI_MODE_SELECTION_Automatic,	/*!< Automatic network selection */
    SWI_MODE_SELECTION_Manual		/*!< Manual network selection */
};

///////////////////////////////////////////////////////////////////////////////
///
/// An enumeration of frequency bands.
///
/// This enumeration is only used with AC710/AC750/AC775/AC850/AC860 devices.
/// Newer devices should use SWI_TYPE_RadioBand.
///
/// The AC710 is a single band card.  It only supports PCS.  The AC750 is a 
/// tri-band card.  It supports EGSM, EGSM_DCS, PCS and Auto.
///
/// \sa SWI_STRUCT_Band
/// \sa SWI_STRUCT_SetBand
/// \sa SWI_TYPE_RadioBand
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_Band
{
    SWI_BAND_None,				/*!< None */
    SWI_BAND_PGSM,				/*!< 900MHz (not supported) */
    SWI_BAND_EGSM,				/*!< Extended 900MHz */
    SWI_BAND_DCS,				/*!< 1800MHz (not supported) */
    SWI_BAND_PGSM_DCS,			/*!< 900MHz and 1800MHz (not supported) */
    SWI_BAND_EGSM_DCS,			/*!< Extended 900MHz and 1800MHz */
    SWI_BAND_PCS,				/*!< 1900MHz */
    SWI_BAND_PGSM_PCS,			/*!< 900 and 1900 MHz */
    SWI_BAND_EGSM_PCS,			/*!< 900e and 1900 MHz */
	SWI_BAND_GSM850,			/*!< 850MHz (not supported) */
	SWI_BAND_GSM850_PCS,		/*!< 850 and 1900 MHz (not supported) */
	SWI_BAND_GSM_ALL,			/*!< All GSM bands */
	SWI_BAND_WCDMA_EU,			/*!< EU band: WCDMA 2100 */
	SWI_BAND_WCDMA_NA,			/*!< NA band:  WCDMA 850/1900 */
	SWI_BAND_WCDMA_GSM_NA,		/*!< NA bands: WDMA 850/1900 & GSM 850/1900 */
	SWI_BAND_WCDMA_GSM_EU,		/*!< EU bands:  WCDMA 2100 & GSM 900/1800 */
	SWI_BAND_WCDMA_ALL = 0x0010,	/*!< All WCDMA bands */
	SWI_BAND_WCDMA_AU,			/*!< Australia bands: WCDMA 2100/850 */
	SWI_BAND_WCDMA_JAP,			/*!< Japan bands: WCDMA 2100/800 */
	SWI_BAND_WCDMA_GSM_AU,		/*!< Australia bands: WCDMA 2100/850 
													  GSM 900/1800 */
	SWI_BAND_WCDMA_GSM_AU_2,	/*!< Australia bands: WCDMA 850 GSM 900/1800 */
	SWI_BAND_WCDMA_GSM_AU_3,	/*!< Australia bands: WCDMA 850 */
	SWI_BAND_WCDMA_EMEA,		/*!< EMEA (urope Middle East Africa) band: WCDMA 2100 */
	SWI_BAND_WCDMA_GSM_EU2,		/*!< EU band: WCDMA 2100/900 & GSM 900/1800 */
	SWI_BAND_WCDMA_EU_2,		/*!< EU band: WCDMA 900 */
	SWI_BAND_WCDMA_NA2,			/*!< NA band: WCDMA 1900 */
	SWI_BAND_WCDMA_EU_3,		/*!< EU band: WCDMA 2100/900 */
	SWI_BAND_AUTO = 0xffff,		/*!< Auto band selection */
};

/*@}*/	// End of network management and status

///////////////////////////////////////////////////////////////////////////////
///
/// An enumeration of available configurable network selection modes
///
/// \sa SwiGetPLMNMode
/// \sa SWI_STRUCT_PlmnSelection
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_PLMN_Mode
{
	SWI_PLMNMODE_Automatic,		/*!< Automatic PLMN selection */
	SWI_PLMNMODE_Manual,		/*!< Manual PLMN selection (3G preferred) */
	SWI_PLMNMODE_Manual_2G,		/*!< Manual PLMN selection (2G preferred) */
};

///////////////////////////////////////////////////////////////////////////////
///
/// An enumeration of result codes for a network selection.
///
/// \sa SWI_STRUCT_PlmnMode
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_PLMN_Result
{
	SWI_PLMNRESULT_Success,				/*!< Succeeded in selecting the
											 requested PLMN */
	SWI_PLMNRESULT_AttemptFailed,		/*!< Attempt to select requested PLMN
											 failed */
	SWI_PLMNRESULT_InProgress,			/*!< PLMN selection is underway */
	SWI_PLMNRESULT_GeneralFail,			/*!< General failure */
	SWI_PLMNRESULT_InternalErr,			/*!< Internal failure */
	SWI_PLMNRESULT_InvalidSelection,	/*!< Invalid PLMN selection */
};

///////////////////////////////////////////////////////////////////////////////
///
/// An enumeration of network types.
///
/// \sa SWI_STRUCT_PlmnSelection
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_Network
{
    SWI_NETWORK_Unknown,    /*!< No network */
    SWI_NETWORK_GSM,        /*!< GSM network */
    SWI_NETWORK_DCS,        /*!< DCS network */
    SWI_NETWORK_GSMDCS,		/*!< GSM and DCS network */
    SWI_NETWORK_PCS,		/*!< PCS network */
    SWI_NETWORK_GSM_PCS,	/*!< GSM and PCS network */
    SWI_NETWORK_IO,			/*!< IO network */
	SWI_NETWORK_UMTS,		/*!< UMTS */
};

///////////////////////////////////////////////////////////////////////////////
///
/// This structure contains information pertaining to the current network
/// status. 
///
/// \sa SWI_TYPE_ServiceStatus
/// \sa SWI_TYPE_ServiceType
/// \sa SWI_TYPE_RoamingState
/// \sa SWI_TYPE_ModeSelection
/// \sa SWI_NOTIFY_NetworkStatus
/// \sa SwiGetNetworkStatus
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_GSM_NetworkStatus
{
	/*!	The size, in bytes, of this structure. */
    U32 sizeStruct;		
    
    /*! Current service status. */
	SWI_TYPE_ServiceStatus eServiceStatus;	
		
	/*! Current service type. */
    SWI_TYPE_ServiceType eServiceType;	
    
    /*! Device roaming state. */
    SWI_TYPE_RoamingState eRoaming;			
    
    /*! Current network selection mode. */
    SWI_TYPE_ModeSelection eModeSelection;
    
    /*! A NULL terminated string representing the country name. */		
    WCHAR szCountry[5];		
    
    /*! A NULL terminated string representing the network name. */
    WCHAR szNetwork[9];		
    
    /*! Mobile Country Code */
    U32 nMCC;
    
    /*! Mobile Network Code */				
    U32 nMNC;		
    
    /*! Local Area Code */		
    U32 nLAC;		
    
    /*! Cell ID */		
    U32 nCellID;			
};

///////////////////////////////////////////////////////////////////////////////
///
/// With 3G products, the following set of band related objects should be used:
///		- SWI_STRUCT_RadioBandList
///		- SWI_STRUCT_RadioBandConfig
///		- SwiGetCurrentRadioBand
///		- SwiSetRadioBandCfg
///		- SwiGetRadioBandCfg
///
/// The following set of band related objects should only be used with AC710,
/// AC750, AC775, AC850, AC860.
///		- SWI_STRUCT_Band
///		- SwiGetBandInfo
///		- SwiSetBandInfo.
/// 
/// This structure contains the current frequency band and a list of  
/// frequency bands that the modem supports.  The bChangeSuccess field should 
/// not be used.  
///
/// This structure is used by the SwiGetBandInfo function and the 
/// SWI_NOTIFY_Band and SWI_NOTIFY_BandWrite notifications.  
///
/// \sa SWI_STRUCT_RadioBandList
/// \sa SWI_STRUCT_RadioBandConfig
/// \sa SwiGetCurrentRadioBand
/// \sa SwiSetRadioBandCfg
/// \sa SwiGetRadioBandCfg
/// \sa SWI_TYPE_Band
/// \sa SWI_NOTIFY_Band
/// \sa SWI_NOTIFY_BandWrite
/// \sa SwiGetBandInfo
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_Band
{
	/*!	The size, in bytes, of this structure.  This value must be supplied
		when calling SwiGetBandInfo. */
    U32 sizeStruct;
    
    /*! Number of valid bands in the array */
    U32 cntValidBands;	
    
    /*! Current band. */	
	SWI_TYPE_Band eBandType;
	
	/*! List of available bands */
    SWI_TYPE_Band arrBand[NUMBER_Band];
    
    /*! Unused parameter */
	bool bChangeSuccess;			
};

///////////////////////////////////////////////////////////////////////////////
///
/// With 3G products, the following set of band related objects should be used:
///		- SWI_STRUCT_RadioBandList
///		- SWI_STRUCT_RadioBandConfig
///		- SwiGetCurrentRadioBand
///		- SwiSetRadioBandCfg
///		- SwiGetRadioBandCfg
///
/// The following set of band related objects should only be used with AC710,
/// AC750, AC775, AC850, AC860.
///		- SWI_STRUCT_Band
///		- SwiGetBandInfo
///		- SwiSetBandInfo.
///
/// This structure is used with SwiSetBandInfo to set the current frequency 
/// band.  
///
/// \sa SWI_STRUCT_RadioBandList
/// \sa SWI_STRUCT_RadioBandConfig
/// \sa SwiGetCurrentRadioBand
/// \sa SwiSetRadioBandCfg
/// \sa SwiGetRadioBandCfg
/// \sa SWI_TYPE_Band
/// \sa SwiSetBandInfo
/// \sa SWI_NOTIFY_BandWrite
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_SetBand
{
	/*!	The size, in bytes, of this structure.  This value must always be
		populated by the calling application. */
	U32 sizeStruct;	
	
	/*! New band to use. */
	SWI_TYPE_Band eBandType;		
};

///////////////////////////////////////////////////////////////////////////////
///
/// This structure contains packet session status information.  
///
/// \sa SWI_TYPE_Precedence
/// \sa SWI_TYPE_Delay
/// \sa SWI_TYPE_Reliability
/// \sa SWI_TYPE_MeanThroughput
/// \sa SWI_TYPE_PeakThroughput
/// \sa SWI_TYPE_InactivityReason
/// \sa SWI_NOTIFY_PktSessionStatus
/// \sa SwiGetPktSessionStatus
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_PktSessionStatus
{
	/*!	The size, in bytes, of this structure.  This value must be provided
		when calling SwiGetPktSessionStatus.  */
	U32 sizeStruct;
	
	/*! True is returned if a packet session is active.  Otherwise, false is 
		returned. */
    bool bPacketSessionActive;	
    
    /*! True is returned of the following QoS fields are valid.  Otherwise, 
		false is returned. */
    bool bValidQos;
    
	/*! Current QoS precedence.  Only valid if bValidQos is true. */		
    SWI_TYPE_Precedence eNegoPrecedence;
    
	/*! Current QoS delay.  Only valid if bValidQos is true.   */		
    SWI_TYPE_Delay eNegoDelay;
    
	/*! Current QoS reliability.  Only valid if bValidQos is true. */			
    SWI_TYPE_Reliability eNegoReliability;	
    
	/*! Current QoS mean throughput.  Only valid if bValidQos is true. */	
    SWI_TYPE_MeanThroughput eNegoMeanThroughput;	
    
	/*! Current QoS peak throughput.  Only valid if bValidQos is true. */
    SWI_TYPE_PeakThroughput eNegoPeakThroughput;	
    
    /*! Inactivity reason code.  Only valid if bPacketSessionActive is false.*/
    SWI_TYPE_InactivityReason eInactivityReason;		
};

///////////////////////////////////////////////////////////////////////////////
///
/// This structure contains name strings to be displayed to the user to
/// indicate what network the modem is registered on.  The service provider 
/// name and network name (PLMN) are given.
///
/// \sa SWI_NOTIFY_Registration
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_Registration
{
	/*!	The size, in bytes, of this structure.  This value must always be
		populated by the calling application. */
	U32 sizeStruct;

	/*! True indicates the home string should be displayed in place of the 
		service provider name.  Otherwise, false is returned.  This flag is 
		present for historical reasons and can be ignored. */
	bool bDisplayHomeString; 
	
	/*! True indicates the home country roaming should be displayed.  
		Otherwise, false is returned.  This flag is present for historical 
		reasons and can be ignored. */
	bool bDisplayHCR;
	
	/*! A NULL terminated string representing the service provider name. */
    WCHAR szSPN [LENGTH_SPN];
    
    /*! A NULL terminated string representing the PLMN. */
    WCHAR szPLMN[LENGTH_PLMN];
    
    /*! A NULL terminated string representing the abbreviated PLMN name. */
	WCHAR szAbvPLMN[LENGTH_AbvPLMN];	
};

///////////////////////////////////////////////////////////////////////////////
///
/// This structure is used to convey the result of a PLMN search.  
///
/// \sa SWI_NOTIFY_PlmnAvailable
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_PlmnAvailable
{
	/*!	The size, in bytes, of this structure. */
	U32 sizeStruct;	
	
	/*! True is returned if the PLMN list is available, false otherwise. */		
	bool bAvailable;			
};

///////////////////////////////////////////////////////////////////////////////
///
/// This structure is used to indicate if the modem is ready to conduct a
/// PLMN network search.  		
///
/// No PLMN searches should be initiated by the SwiStartPLMNSearch API
/// until the modem is ready.
///
/// \sa SWI_NOTIFY_PlmnReady
/// \sa SwiStartPLMNSearch
///			
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_PlmnReady
{
	/*!	The size, in bytes, of this structure. */
	U32 sizeStruct;	
	
	/*! True is returned if the modem is ready to conduct a PLMN search, 
		false otherwise. */	
	bool bReady;				
};

///////////////////////////////////////////////////////////////////////////////
///
/// This structure is used to indicate if the modem PLMN selection change
/// was successful.
///			
/// \sa SWI_NOTIFY_PlmnMode
/// \sa SwiSetPLMNMode
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_PlmnMode
{
	/*!	The size, in bytes, of this structure. */
	U32 sizeStruct;	
	
	/*! Result of a PLMN mode change request. */
	SWI_TYPE_PLMN_Result eResult;	
};

///////////////////////////////////////////////////////////////////////////////
///
/// This structure contains information regarding a specific PLMN.
/// 
/// This structure is used as output by the SwiGetPLMNSelection function and
/// SWI_NOTIFY_PlmnMode notification as well as input by the SwiSetPLMNMode 
/// function.   
/// 
/// \sa SWI_TYPE_PLMN_Mode
/// \sa SWI_TYPE_Network
/// \sa SwiGetPLMNSelection
/// \sa SwiSetPLMNMode
/// \sa SWI_NOTIFY_PlmnMode
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_PlmnSelection
{
	/*!	The size, in bytes, of this structure.  This value must be supplied
		when calling SwiSetPLMNMode or SwiGetPLMNSelection. */
    U32 sizeStruct;  
    
    /*! Network selection mode to use.  This field is only applicable when used
		with SwiSetPLMNMode. */
	SWI_TYPE_PLMN_Mode eMode;
	
	/*! A NULL terminated string representing the PLMN name. This field is only
		applicable when used with SwiGetPLMNSelection. */		
    WCHAR szName[LENGTH_PLMN];
    
	/*! A NULL terminated string representing the abbreviated PLMN name. This 
		field is only applicable when used with SwiGetPLMNSelection. */
	WCHAR szAbvPLMN[LENGTH_AbvPLMN];
	
	/*! Mobile Country Code.  This value must be supplied when used with 
		SwiSetPLMNMode to configure manual mode. */
    U32 nMCC;
    
	/*! Mobile Network Code.  This value must be supplied when used with 
		SwiSetPLMNMode to configure manual mode. */
    U32 nMNC;
    
    /*! Network type of this PLMN.  This field is only applicable when used 
		with SwiGetPLMNSelection. */
    SWI_TYPE_Network eNetwork;
    
    /*! True is returned if the modem is registered with this PLMN, otherwise 
		false is returned.  This field is only applicable when used with 
		SwiGetPLMNSelection. */
	bool bRegistered;
	
	/*! True is returned if this PLMN is forbidden, otherwise false is 
		returned.  This field is only applicable when used with 
		SwiGetPLMNSelection. */
	bool bForbidden;
	
	/*! True is returned if this is the home PLMN, otherwise false is returned.
		This field is only applicable when used with SwiGetPLMNSelection. */
	bool bHome;
	
	/*! True is returned if this PLMN is weak (signal is not of high quality), 
		otherwise false is returned.  This field is only applicable when used 
		with SwiGetPLMNSelection. */
	bool bWeak;
	
	/*! True is returned if GPRS is supported on this PLMN, otherwise false is 
		returned. This field is only applicable when used with 
		SwiGetPLMNSelection. */
	bool bGprsSupport;
	
	/*! True is returned if there are more PLMNs to be fetched from the modem.  
		False is returned if this is the last item in the list. This field is 
		only applicable when used with SwiGetPLMNSelection.*/
    bool bMorePlmn;
};

///////////////////////////////////////////////////////////////////////////////
///
/// This structure is used to indicate the current GPRS status.  
///		
/// \sa SWI_TYPE_IconGprsState
/// \sa SWI_NOTIFY_IconGprsState
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_IconGprsState
{
	/*!	The size, in bytes, of this structure. */
	U32 sizeStruct;	
	
	/*! GPRS icon state. */
    SWI_TYPE_IconGprsState  eIconGprsState;		
};

///////////////////////////////////////////////////////////////////////////////
///
/// This structure is used to indicate the current roaming status.  
///
/// \sa SWI_TYPE_IconRoamState
/// \sa SWI_NOTIFY_IconRoamState
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_IconRoamState
{
	/*!	The size, in bytes, of this structure. */
	U32 sizeStruct;
	
	/*! Roaming state. */
    SWI_TYPE_IconRoamState eIconRoamState;		
};

///////////////////////////////////////////////////////////////////////////////
///
/// This structure contains the modem's temperature information.  It is
/// used to convey the modem's current temperature and its temperature state. 
///
/// \sa SWI_TYPE_Temperature
/// \sa SWI_NOTIFY_Temperature
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_Temperature
{
	/*!	The size, in bytes, of this structure.  This value must be supplied
		when calling SwiGetTemperatureBer. */
    U32 sizeStruct;    
    
    /*! Temperature in degrees Celsius. */
    I32 iTemperature;  
    
    /*! An enumeration of type SWI_TYPE_Temperature indicating if the modem
		has passed the critical temperature threshold. */
	SWI_TYPE_Temperature eStatus;        
};

///////////////////////////////////////////////////////////////////////////////
///
/// This structure is used read and write the data counter information.  
///
/// \sa SwiGetDataCounters
/// \sa SwiClearDataCounters
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_DataCounters
{
	/*!	The size, in bytes, of this structure.  This value must always be
		populated by the calling application. */
	U32	sizeStruct;	
	
	/*! Total bytes sent since the data counters were last reset. */
	U32	nTotalSent;
	
	/*! Total bytes received since the data counters were last reset. */				
	U32	nTotalReceived;	
	
	/*! Total lifetime bytes sent. */
	U64	nLifeTimeSent;	
	
	/*! Total lifetime bytes received. */		
	U64	nLifeTimeReceived;	
	
	/*! The year of the last data counter reset (1-255	, 0 if not 
		initialized. */
	U32	nClearYear;	
	
	/*! The month of the last data counter reset (1-12, 0 if not 
		initialized). */
	U32	nClearMonth;
	
	/*! The day of the last data counter reset (1-31, 0 if not initialized). */		
	U32	nClearDay;
	
	/*! The hour of the last data counter reset (0-23). */
	U32	nClearHour;	
	
	/*! The minute of the last data counter reset (0-59). */			
	U32	nClearMinute;
	
	/*! The second of the last data counter reset (0-59). */
	U32	nClearSecond;			
};

///////////////////////////////////////////////////////////////////////////////
///
/// This structure is contains current data rate information and is used by the 
/// SWI_NOTIFY_DataRate notification.
///
/// \sa SWI_NOTIFY_DataRate
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_DataRate
{
	U32	sizeStruct;		/*!	The size, in bytes, of this structure.  */		    
    U32 nCurrentTxRateBitsPerSec;	/*! Current transmit data rate */
    U32 nCurrentRxRateBitsPerSec;	/*! Current receive data rate */
    U32 nTopTxRateBitsPerSec;		/*! Top transmit data rate */
    U32 nTopRxRateBitsPerSec;		/*! Top received data rate */
    U32 nCurrentTxByteCnt;			/*! Current transmit byte count */
    U32 nCurrentRxByteCnt;			/*! Current received byte count */
};

///////////////////////////////////////////////////////////////////////////////
///
/// This structure contains total number of bytes transmitted and received 
/// since the counter was last reset.  
/// 
/// This structure is used by SwiGetTrafficStatistics.  
/// SwiResetTrafficStatistics can be called to reset byte counters.
/// 
/// Byte counter info is persistent across connections.
///
/// \sa SWI_NOTIFY_ByteCounter
/// \sa SwiGetTrafficStatistics
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_ByteCounter
{
	/*!	The size, in bytes, of this structure.  This value must always be
		populated by the calling application. */
	U32	sizeStruct;
	
	/*! Bytes transmitted */								
	U32	TransmitBytes;		
	
	/*! Bytes received */					
	U32	ReceiveBytes;						
};

///////////////////////////////////////////////////////////////////////////////
//
// 2G GSM Profiles
//
///////////////////////////////////////////////////////////////////////////////

///////////////////////////////////////////////////////////////////////////////
///
/// An enumeration of profile states
///
/// \sa SWI_STRUCT_ProfileStatus
/// \sa SWI_STRUCT_GsmProfileSummary
///
///////////////////////////////////////////////////////////////////////////////
enum  SWI_TYPE_ProfileState
{
	/*! Indicates the account profile has a valid account definition but is not 
		currently being used in a session. */
    SWI_PROFILE_STATE_Inactive,
    
	/*! The account has a valid definition and is in use with the current
		session. */
    SWI_PROFILE_STATE_Activated,
    
	/*! The profile is empty-without a valid account definition. In fact, the 
		profile contains default values but cannot be made active. This profile
		can be used to store a new account definition. */
    SWI_PROFILE_STATE_Deleted			
};

///////////////////////////////////////////////////////////////////////////////
///
/// Profile data structure used to read and store account information.
/// 
/// This structure should only be used with 2G devices.
///
/// \sa SWI_TYPE_PDP
/// \sa SWI_TYPE_Precedence
/// \sa SWI_TYPE_Delay
/// \sa SWI_TYPE_Reliability
/// \sa SWI_TYPE_PeakThroughput
/// \sa SWI_TYPE_MeanThroughput
/// \sa SwiGetProfile
/// \sa SwiSetProfile
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_Profile
{
	/*!	The size, in bytes, of this structure.  This value must always be
		populated by the calling application. */
    U32 sizeStruct;
    
    /*! A NULL terminated string representing a user-supplied "handle" to help
		them identify the account. */                           
    WCHAR szLabel[LENGTH_Label];
    
    /*! A NULL terminated string representing the carrier assigned account
		name for carrier authentication. */					
	WCHAR szUserName[LENGTH_UserName];
	
	/*! A NULL terminated string representing the account password for carrier
		authentication. */		   
	WCHAR szPassword[LENGTH_Password];
	
	/*! A NULL terminated string representing the access point name provided by
		the carrier. */	       
	WCHAR szAccessPoint[LENGTH_AccessPointName];
	
	/*! True indicates V.42bis is to be used for data, false indicates data 
		compression is off.  The carrier indicates if this is supported.  It is
		always safe to leave as "false", although throughput may be reduced. */	
	bool bDataCompression;
	
	/*! True indicates TCP header compression is on, false indicates header 
		compression is off.  The carrier indicates if this is supported.  It is
		always safe to leave as "false", although throughput may be reduced. */					  
	bool bHeaderCompression;
	
	/*! True indicates that this account should be automatically connected if 
		the profile is designated as default (see SwiSetDefaultProfile).  
		False indicates the host software must manually request to connect 
		with this account. */
	bool bAutoActivation;
	
	/*! True indicates the IP address is to be manually assigned 
		(dwPDPAddress), false indicates the IP address is to be dynamically 
		assigned by the network.  Note that DHCP is not necessarily exchanged 
		over the air. */					   
	bool bAutomaticIP;
	
	/*! PDP type (either IP or PPP). */					
    SWI_TYPE_PDP ePDP;
    
	/*! Requested QoS precedence value. */						          
	SWI_TYPE_Precedence eReqPrecedence;	
	
	/*! Requested QoS delay value. */ 					   
	SWI_TYPE_Delay eReqDelay;
	
	/*! Requested QoS reliability value. */  						       
	SWI_TYPE_Reliability eReqReliability;
	
	/*! Requested QoS peak throughput. */ 						
	SWI_TYPE_PeakThroughput eReqPeakThroughput;
	
	/*! Requested QoS mean throughput. */ 						
	SWI_TYPE_MeanThroughput eReqMeanThroughput;
	
	/*! Minimum QoS precedence value. */                   
	SWI_TYPE_Precedence eMinPrecedence;
	
	/*! Minimum QoS delay value. */                        
	SWI_TYPE_Delay eMinDelay;
	
	/*! Minimum QoS reliability value. */                             
	SWI_TYPE_Reliability eMinReliability;
	
	/*! Minimum QoS peak throughput. */                     
	SWI_TYPE_PeakThroughput eMinPeakThroughput;
	
	/*! Minimum QoS mean throughput. */                     
	SWI_TYPE_MeanThroughput eMinMeanThroughput;
	
	/*! Primary DNS can be defined, or if set to 0.0.0.0, obtained from the 
		network (where the network supports automatic assignment). */
	DWORD dwPrimaryDns;
	
	/*! Secondary DNS can be defined, or if set to 0.0.0.0, obtained from the 
		network (where the network supports automatic assignment).	*/
	DWORD dwSecondaryDns;
	
	/*! The modem's dedicated IP address in cases where bAutomaticIP is set to
		false. */
	DWORD dwPDPAddress;
	
	/*! True is returned if the profile is read only.  Otherwise, false is 
		returned.  Note that the read only attribute is a host software 
		enforced restriction.  The modem will simply save any information 
		the host software sends down. */
	bool bReadOnly;
	
	/*! True is returned if the user should be prompted to enter a password.  
		Otherwise, false is returned. */								
	bool bPromptPassword;
	
	/*! True indicates to the host application a VPN client should be ran 
		automatically after a successful connection is made.  Otherwise, false 
		is returned. */		
    bool bAutoRunVPN;                           
};

///////////////////////////////////////////////////////////////////////////////
///
/// This structures contains the status of a profile.
///
/// \sa SWI_STRUCT_ProfileSummary
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_ProfileStatus
{
	/*! Profile ID */
 	U32 nProfileID;	
 	
 	/*! Current state of the profile (activated, inactive, or deleted). */  
	SWI_TYPE_ProfileState eProfileState;		
};

///////////////////////////////////////////////////////////////////////////////
///
/// This structure contains a summary of all the profiles on the modem. 
///
/// This structure should only be used with 2G devices.
/// 
/// \sa SwiGetProfileSummary
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_ProfileSummary
{
	/*!	The size, in bytes, of this structure.  This value must always be
		populated by the calling application. */
	U32 sizeStruct;
	
	/*! Default profile ID used by the modem for automatic connection to the 
		GPRS network. */
	U32 nDefaultProfileID;
	
	/*! The profile ID currently in use and connected. */	
	U32 nCurrentProfileID;
	
	/*! State of each profile.  Index 0 is associated with profile 1. */
	SWI_STRUCT_ProfileStatus arrProfileList[MAX_NO_CONTEXT];	
};

///////////////////////////////////////////////////////////////////////////////
//
// 3G GSM Profiles
//
///////////////////////////////////////////////////////////////////////////////

///////////////////////////////////////////////////////////////////////////////
///
/// This structure contains a summary of all the profiles on the modem.
/// 
/// This structure is used with 3G and newer devices.
///
/// \sa SwiGetGsmProfileSummary
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_GsmProfileSummary
{
	/*!	The size, in bytes, of this structure.  This value must always be
		populated by the calling application. */
	U32 sizeStruct;
	
	/*! Maximum number of profiles supported by the modem. */						
	U32 nMaxProfiles;
	
	/*! Maximum number of TFTs per profile. */	
	U32 nMaxTft;
	
	/*! Default profile ID used by the modem for automatic connection to the 
		GPRS network.  Note that the automatic flag must be enabled on the
		profile before an automatic connection is attempted by the modem. */	
	U32 nDefaultProfileId;
	
	/*! State of each profile.  Index 0 is associated with profile 1. */
	SWI_TYPE_ProfileState arrState[MAX_3G_GSM_PROFILES];	
};

///////////////////////////////////////////////////////////////////////////////
///
/// An enumeration of PDP initiated types.
///
/// \sa SWI_STRUCT_GsmProfileBasic
///
///////////////////////////////////////////////////////////////////////////////
enum  SWI_TYPE_PdpInitiated
{
    SWI_PDP_INITIATED_PrimaryMobile,	/*!< Primary context */
    SWI_PDP_INITIATED_SecondaryMobile,	/*!< Secondary context */
    SWI_PDP_INITIATED_Network,			/*!< Currently not supported */
	SWI_PDP_INITIATED_None,				/*!< Currently not supported */
};

///////////////////////////////////////////////////////////////////////////////
///
/// An enumeration of authentication types.
///
/// \sa SWI_STRUCT_GsmProfileBasic
///
///////////////////////////////////////////////////////////////////////////////
enum  SWI_TYPE_Authentication
{
    SWI_PDPAUTHENTICATION_None,		/*!< No authentication */
    SWI_PDPAUTHENTICATION_Pap,		/*!< PAP authentication (default) */
    SWI_PDPAUTHENTICATION_Chap,		/*!< CHAP authentication */
};

///////////////////////////////////////////////////////////////////////////////
///
/// An enumeration of profile configuration status codes
///
/// \sa SWI_STRUCT_GsmProfileBasic
/// \sa SwiGetGsmProfileBasic
/// \sa SwiSetGsmProfileBasic
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_ProfileAuthResult
{
	/*! Request successful */
	PROFILEAUTHRESULT_Success,

	/*! Device does not support the specified username/password string length.
		See nMaxUsernameLength and nMaxPasswordLength fields from
		SWI_STRUCT_GsmProfileBasic for more information. */
	PROFILEAUTHRESULT_ExtendedLengthNotSupported,

	/*! General failure */
	PROFILEAUTHRESULT_GeneralFailure = 0xFF
};

///////////////////////////////////////////////////////////////////////////////
///
/// This object contains basic 3G GSM profile settings
/// 
/// This structure is used with 3G and newer devices.
///
/// \sa SWI_TYPE_PDP
/// \sa SWI_TYPE_PdpInitiated
/// \sa SWI_TYPE_Authentication
/// \sa SWI_TYPE_ProfileAuthResult
/// \sa SwiGetGsmProfileBasic
/// \sa SwiSetGsmProfileBasic
/// \sa SWI_NOTIFY_GsmProfileChange
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_GsmProfileBasic
{
	/*!	The size, in bytes, of this structure. */
	U32 sizeStruct;
	
	/*! Profile ID.  Valid range is 1-16. */			
	U8 nProfileId;
	
	/*! True indicates if the basic profile info is valid, false otherwise. */
	bool bValid;
	
	/*! PDP type (either IPV4, PPP, or IPV6). */						
	SWI_TYPE_PDP ePdpType;	
	
	/*! True indicates V.42bis is to be used for data, false indicates data 
		compression is off.  The carrier indicates if this is supported.  
		It is always safe to leave as "false", although throughput may be 
		reduced. */	
	bool bDataCompression;

	/*! True indicates TCP header compression is on, false indicates header 
		compression is off.  The carrier indicates if this is supported.  It is
		always safe to leave as "false", although throughput may be reduced. */					  
	bool bHeaderCompression;

	/*! True indicates the IP address is to be manually assigned 
		(dwPDPAddress), false indicates the IP address is to be dynamically 
		assigned by the network.  Note that DHCP is not necessarily exchanged 
		over the air. */		   
	bool bAutomaticIP;
	
	/*! Length of PDP address (0-16).  0 indicates dynamic addressing. */							
	U32 nLengthPdp;
	
	/*! IP or PDP address when using static PDP address configuration.
		Example of an IPV4 address is 0x7F000201 which means 127.0.2.1. */							
	BYTE byPdp[LENGTH_IPAddress];
	
	/*! A NULL terminated string representing the access point name provided by
		the carrier. */				
	WCHAR szAccessPoint[LENGTH_AccessPointName];
	
	/*! PDP initiated type */	
	SWI_TYPE_PdpInitiated ePdpInitiated;
	
	/*! This field is only valid if ePdpInitiated is set to Secondary Mobile 
		Initiated. */
	U32 nPrimaryProfileId;
	
	/*! Authentication type.  Default should be PAP.*/				
	SWI_TYPE_Authentication	eAuthentication;
		       
	/*! A NULL terminated string representing the carrier assigned account
		name for carrier authentication. */			
	WCHAR szUserName[LENGTH_UserName];
	
	/*! A NULL terminated string representing the account password for carrier
		authentication. */		    
	WCHAR szPassword[LENGTH_Password];
	
	/*! A NULL terminated string representing a user-supplied "handle" to help
		them identify the account.  The modem will accept up to 30 ASCII
		characters or 14 USC2 characters.  */	       
	WCHAR szLabel[LENGTH_Label];

	/*! Indicates the maximum username string length that is supported by
		the device.  Valid values from this field will be from 32 to 127
		inclusive. */
	U32	nMaxUsernameLength;

	/*! Indicates the maximum password string length that is supported by
		the device.  Valid values from this field will be from 32 to 127
		inclusive. */
	U32 nMaxPasswordLength;
	
	/*! True indicates that this account should be automatically connected if 
		the profile is designated as default (see SwiSetDefaultProfile).  
		False indicates the host software must manually request to connect 
		with this account. */					
	bool bAutoActivation;						
    
	/*! True is returned if the profile is read only.  Otherwise, false is 
		returned.  Note that the read only attribute is a host software 
		enforced restriction.  The modem will simply save any information 
		the host software sends down. */
	bool bReadOnly;

	/*! True is returned if the user should be prompted to enter a password.  
		Otherwise, false is returned. */								
	bool bPromptPassword;

	/*! True indicates to the host application a VPN client should be ran 
		automatically after a successful connection is made.
		Otherwise, false is returned. */		
	bool bAutoRunVPN; 
    
	/*! Linger timer in minutes (1-32767).  A value of 0 means disabled. */                         
	U32 nLingerTimer;
	
	/*! Bitsets to store software options
		- 00000001	: HSDPA profile */
	U8 nSoftwareOptions;
	
	/*! Three bytes to store MCC/MNC value */
	U8 MccMnc[LENGTH_MCCMNC_BUFFER];
	
	/*! Reserved for future use */  
	U8 Reserved[11];	

	/*! Status of request returned from modem */
	SWI_TYPE_ProfileAuthResult	nResult;
};

///////////////////////////////////////////////////////////////////////////////
///
/// An enumeration of UMTS quality of service traffic class types.
///
/// \sa SWI_STRUCT_GsmProfileQos
/// \sa SWI_STRUCT_PktSessionCall
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_QOSUMTS_TrafficClass
{
    SWI_QOSUMTS_TRAFFCLS_Subscribed,	/*!< Subscribed */
	SWI_QOSUMTS_TRAFFCLS_Conver,		/*!< Conversational */
	SWI_QOSUMTS_TRAFFCLS_Stream,		/*!< Streaming */
	SWI_QOSUMTS_TRAFFCLS_Interact,		/*!< Interactive */
	SWI_QOSUMTS_TRAFFCLS_Backgnd		/*!< Background */
};

///////////////////////////////////////////////////////////////////////////////
///
/// An enumeration of UMTS bit rate values.
///
/// \sa SWI_STRUCT_GsmProfileQos
/// \sa SWI_STRUCT_PktSessionCall
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_QOSUMTS_Bitrate
{
    SWI_QOSUMTS_BITRATE_Subscribed,		/*!< subscribed */
	SWI_QOSUMTS_BITRATE_16Kbps,			/*!< 16 Kbps */
	SWI_QOSUMTS_BITRATE_32Kbps,			/*!< 32 Kbps */
	SWI_QOSUMTS_BITRATE_64Kbps,			/*!< 64 Kbps */
	SWI_QOSUMTS_BITRATE_128Kbps,		/*!< 128 Kbps */
	SWI_QOSUMTS_BITRATE_256Kbps,		/*!< 256 Kbps */
	SWI_QOSUMTS_BITRATE_384Kbps,		/*!< 384 Kbps */
	SWI_QOSUMTS_BITRATE_1_8Mbps,		/*!< 1.8 Mbps */
	SWI_QOSUMTS_BITRATE_3_6Mbps,		/*!< 3.6 Mbps */
	SWI_QOSUMTS_BITRATE_7_2Mbps,		/*!< 7.2 Mbps */
	SWI_QOSUMTS_BITRATE_14_4Mbps,		/*!< 14.4 Mbps */
	SWI_QOSUMTS_BITRATE_2048kbps,		/*!< 2048 kbps */
	SWI_QOSUMTS_BITRATE_5760kbps,		/*!< 5760 kbps */
	SWI_QOSUMTS_BITRATE_11_5Mbps,		/*!< 11.5 Mbps */
	SWI_QOSUMTS_BITRATE_16Mbps,			/*!< 16 Mbps */
	SWI_QOSUMTS_BITRATE_21Mbps,			/*!< 21 Mbps */
	SWI_QOSUMTS_BITRATE_28Mbps,			/*!< 28 Mbps */
	SWI_QOSUMTS_BITRATE_42Mbps,			/*!< 42 Mbps */
	SWI_QOSUMTS_BITRATE_84Mbps,			/*!< 84 Mbps */
};

///////////////////////////////////////////////////////////////////////////////
///
/// An enumeration of UMTS delivery order values.
///
/// \sa SWI_STRUCT_GsmProfileQos
/// \sa SWI_STRUCT_PktSessionCall
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_QOSUMTS_DelOrder
{
    SWI_QOSUMTS_DELORDER_Subscribed,	/*!< Subscribed */
	SWI_QOSUMTS_DELORDER_With,			/*!< With delivery order */
	SWI_QOSUMTS_DELORDER_Without		/*!< Without delivery order */
};

///////////////////////////////////////////////////////////////////////////////
///
/// An enumeration of UMTS delivery of erroneous SDU values.
///
/// \sa SWI_STRUCT_GsmProfileQos
/// \sa SWI_STRUCT_PktSessionCall
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_QOSUMTS_DelErrSdu
{
    SWI_QOSUMTS_DELERRSDU_Subscribed,	/*!< Subscribed */
	SWI_QOSUMTS_DELERRSDU_NoDetect,		/*!< No detect */
	SWI_QOSUMTS_DELERRSDU_Del,			/*!< Erroneous SDUs are delivered */
	SWI_QOSUMTS_DELERRSDU_NotDel	/*!< Erroneous SDUs are not delivered */
};

///////////////////////////////////////////////////////////////////////////////
///
/// An enumeration of UMTS SDU error ratio values.
///
/// \sa SWI_STRUCT_GsmProfileQos
/// \sa SWI_STRUCT_PktSessionCall
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_QOSUMTS_SduErrRatio
{
    SWI_QOSUMTS_SDUERRRATIO_Subscribed,	/*!< subscribed */
	SWI_QOSUMTS_SDUERRRATIO_1E2,		/*!< 1E-2 */
	SWI_QOSUMTS_SDUERRRATIO_7E3,		/*!< 7E-3 */
	SWI_QOSUMTS_SDUERRRATIO_1E3,		/*!< 1E-3 */
	SWI_QOSUMTS_SDUERRRATIO_1E4,		/*!< 1E-4 */
	SWI_QOSUMTS_SDUERRRATIO_1E5,		/*!< 1E-5 */
	SWI_QOSUMTS_SDUERRRATIO_1E6,		/*!< 1E-6 */
	SWI_QOSUMTS_SDUERRRATIO_1E1			/*!< 1E-1 */
};

///////////////////////////////////////////////////////////////////////////////
///
/// An enumeration of UMTS residual bit error ratio values.
///
/// \sa SWI_STRUCT_GsmProfileQos
/// \sa SWI_STRUCT_PktSessionCall
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_QOSUMTS_ResBitErrRatio
{
    SWI_QOSUMTS_RESBITERRRATIO_Subscribed,	/*!< subscribed */
	SWI_QOSUMTS_RESBITERRRATIO_5E2,			/*!< 5E-2 */
	SWI_QOSUMTS_RESBITERRRATIO_1E2,			/*!< 1E-2 */
	SWI_QOSUMTS_RESBITERRRATIO_5E3,			/*!< 5E-3 */
	SWI_QOSUMTS_RESBITERRRATIO_4E3,			/*!< 4E-3 */
	SWI_QOSUMTS_RESBITERRRATIO_1E3,			/*!< 1E-3 */
	SWI_QOSUMTS_RESBITERRRATIO_1E4,			/*!< 1E-4 */
	SWI_QOSUMTS_RESBITERRRATIO_1E5,			/*!< 1E-5 */
	SWI_QOSUMTS_RESBITERRRATIO_1E6,			/*!< 1E-6 */
	SWI_QOSUMTS_RESBITERRRATIO_6E8			/*!< 6E-8 */
};

///////////////////////////////////////////////////////////////////////////////
///
/// An enumeration of UMTS traffic handling priority values.
///
/// \sa SWI_STRUCT_GsmProfileQos
/// \sa SWI_STRUCT_PktSessionCall
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_QOSUMTS_TraffHandPri
{
    SWI_QOSUMTS_TRAFFHANDPRI_Subscribed,	/*!< Subscribed */
	SWI_QOSUMTS_TRAFFHANDPRI_PriLvl1,		/*!< Priority level 1 */
	SWI_QOSUMTS_TRAFFHANDPRI_PriLvl2,		/*!< Priority level 2 */
	SWI_QOSUMTS_TRAFFHANDPRI_PriLvl3		/*!< Priority level 3 */
};

///////////////////////////////////////////////////////////////////////////////
///
/// An enumeration of UMTS source statistics descriptor values.
///
/// \sa SWI_STRUCT_GsmProfileQos
/// \sa SWI_STRUCT_PktSessionCall
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_QOSUMTS_SrcStatDesc
{
    SWI_QOSUMTS_SRCSTATDESC_Unknown,		/*!< Unknown */
	SWI_QOSUMTS_SRCSTATDESC_Speech			/*!< Speech */
};

///////////////////////////////////////////////////////////////////////////////
///
/// An enumeration of UMTS signaling indication values.
///
/// \sa SWI_STRUCT_GsmProfileQos
/// \sa SWI_STRUCT_PktSessionCall
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_QOSUMTS_SignInd
{
    SWI_QOSUMTS_SIGNIND_NotOpt,	/*!< Not optimized for signaling traffic. */
	SWI_QOSUMTS_SIGNIND_Opt		/*!< Optimized for signaling traffic. */
};

///////////////////////////////////////////////////////////////////////////////
///
/// This structure contains 3G GSM QoS profile settings.
/// 
/// This structure should only be used with 3G devices or newer.
///
/// \sa SWI_TYPE_QOSUMTS_TrafficClass
/// \sa SWI_TYPE_QOSUMTS_Bitrate
/// \sa SWI_TYPE_QOSUMTS_DelOrder
/// \sa SWI_TYPE_QOSUMTS_DelErrSdu
/// \sa SWI_TYPE_QOSUMTS_SduErrRatio
/// \sa SWI_TYPE_QOSUMTS_ResBitErrRatio
/// \sa SWI_TYPE_QOSUMTS_TraffHandPri
/// \sa SWI_TYPE_QOSUMTS_SrcStatDesc
/// \sa SWI_TYPE_QOSUMTS_SignInd
/// \sa SWI_TYPE_Precedence
/// \sa SWI_TYPE_Delay
/// \sa SWI_TYPE_Reliability
/// \sa SWI_TYPE_PeakThroughput
/// \sa SWI_TYPE_MeanThroughput
/// \sa SWI_NOTIFY_GsmProfileChange
/// \sa SwiGetGsmProfileQos
/// \sa SwiSetGsmProfileQos
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_GsmProfileQos
{
	/*!	The size, in bytes, of this structure. */
	U32 sizeStruct;

	/*! Profile ID.  Valid range is 1-16. */		
	U8 nProfileId;	
	
	/*! True indicates the requested UMTS QoS values are valid,
		false otherwise. */			
	bool bValidUmtsReq;
	
	/*! Requested UMTS QoS traffic class. */		
	SWI_TYPE_QOSUMTS_TrafficClass eReqTrafficClass;
	
	/*! Requested UMTS QoS maximum upload bit rate. */		
	SWI_TYPE_QOSUMTS_Bitrate eReqMaxBitrateUl;
	
	/*! Requested UMTS QoS maximum download bit rate. */		
	SWI_TYPE_QOSUMTS_Bitrate eReqMaxBitrateDl;
	
	/*! Requested UMTS QoS guaranteed upload bit rate. */
	SWI_TYPE_QOSUMTS_Bitrate eReqGuarBitrateUl;
	
	/*! Requested UMTS QoS guaranteed download bit rate. */		
	SWI_TYPE_QOSUMTS_Bitrate eReqGuarBitrateDl;
	
	/*! Requested UMTS QoS delivery order. */		
	SWI_TYPE_QOSUMTS_DelOrder eReqDelOrder;
	
	/*! Requested UMTS QoS delivery of erroneous SDU. */		
	SWI_TYPE_QOSUMTS_DelErrSdu eReqDelErrSdu;
	
	/*! Requested UMTS QoS maximum SDU size	(0-1520). */			
	U32 nReqMaxSdu;
	
	/*! Requested UMTS QoS SDU error ratio. */				
	SWI_TYPE_QOSUMTS_SduErrRatio eReqSduErrRatio;
	
	/*! Requested UMTS QoS residual bit error ratio. */		
	SWI_TYPE_QOSUMTS_ResBitErrRatio	eReqResBitErrRatio;
	
	/*! Requested UMTS QoS transfer delay (0-4000) */
	U32 nReqTransDelay;
	
	/*! Requested UMTS QoS traffic handling priority. */			
	SWI_TYPE_QOSUMTS_TraffHandPri eReqTraffHandPri;
	
	/*! Requested UMTS QoS source statistics descriptor. */		
	SWI_TYPE_QOSUMTS_SrcStatDesc eReqSrcStatDesc;
	
	/*! Requested UMTS QoS signal indication. */		
	SWI_TYPE_QOSUMTS_SignInd eReqSignInd;
	
	/*! True indicates the minimum UMTS QoS values are valid, false 
		otherwise. */
	bool bValidUmtsMin;
	
	/*! Minimum UMTS QoS traffic class. */
	SWI_TYPE_QOSUMTS_TrafficClass eMinTrafficClass;
	
	/*! Minimum UMTS QoS maximum upload bit rate. */	
	SWI_TYPE_QOSUMTS_Bitrate eMinMaxBitrateUl;
	
	/*! Minimum UMTS QoS maximum download bit rate. */		
	SWI_TYPE_QOSUMTS_Bitrate eMinMaxBitrateDl;
	
	/*! Minimum UMTS QoS guaranteed upload bit rate. */	
	SWI_TYPE_QOSUMTS_Bitrate eMinGuarBitrateUl;
	
	/*! Minimum UMTS QoS guaranteed download bit rate. */
	SWI_TYPE_QOSUMTS_Bitrate eMinGuarBitrateDl;
	
	/*! Minimum UMTS QoS delivery order. */		
	SWI_TYPE_QOSUMTS_DelOrder eMinDelOrder;
	
	/*! Minimum UMTS QoS delivery of erroneous SDU. */			
	SWI_TYPE_QOSUMTS_DelErrSdu eMinDelErrSdu;
	
	/*! Minimum UMTS QoS maximum SDU size (0-1520). */			
	U32 nMinMaxSdu;	
	
	/*! Minimum UMTS QoS SDU error ratio. */			
	SWI_TYPE_QOSUMTS_SduErrRatio eMinSduErrRatio;
	
	/*! Minimum UMTS QoS residual bit error ratio. */
	SWI_TYPE_QOSUMTS_ResBitErrRatio	eMinResBitErrRatio;
	
	/*! Minimum UMTS QoS transfer delay (0-4000). */	
	U32 nMinTransDelay;
	
	/*! Minimum UMTS QoS traffic handling priority. */
	SWI_TYPE_QOSUMTS_TraffHandPri eMinTraffHandPri;
	
	/*! Minimum UMTS QoS source statistics descriptor. */
	SWI_TYPE_QOSUMTS_SrcStatDesc eMinSrcStatDesc;
	
	/*! Minimum UMTS QoS signal indication. */		
	SWI_TYPE_QOSUMTS_SignInd eMinSignInd;
	
	/*! True indicates if the following requested QoS values are valid, false 
		otherwise. */
	bool bValidGprsReq;			
	
	/*! Requested QoS precedence value. */						          
	SWI_TYPE_Precedence eReqPrecedence;	

	/*! Requested QoS delay value. */ 					   
	SWI_TYPE_Delay eReqDelay;

	/*! Requested QoS reliability value. */  						       
	SWI_TYPE_Reliability eReqReliability;

	/*! Requested QoS peak throughput. */ 						
	SWI_TYPE_PeakThroughput eReqPeak;

	/*! Requested QoS mean throughput. */ 						
	SWI_TYPE_MeanThroughput eReqMean;
	
	/*! True indicates the minimum QoS values are valid, false otherwise. */
	bool bValidGprsMin;								
	
	/*! Minimum QoS precedence value. */                   
	SWI_TYPE_Precedence eMinPrecedence;

	/*! Minimum QoS delay value. */                        
	SWI_TYPE_Delay eMinDelay;

	/*! Minimum QoS reliability value. */                             
	SWI_TYPE_Reliability eMinReliability;

	/*! Minimum QoS peak throughput. */                     
	SWI_TYPE_PeakThroughput eMinPeak;

	/*! Minimum QoS mean throughput. */                     
	SWI_TYPE_MeanThroughput eMinMean;			
};

///////////////////////////////////////////////////////////////////////////////
///
/// This structure contains 3G GSM DNS profile settings.
///
/// \sa SWI_NOTIFY_GsmProfileChange
/// \sa SwiGetGsmProfileDns
/// \sa SwiSetGsmProfileDns
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_GsmProfileDns
{
	/*!	The size, in bytes, of this structure. */
	U32 sizeStruct;

	/*! Profile ID.  Valid range is 1-16. */						
	U8 nProfileId;	
	
	/*! Length of the primary DNS address.  Valid range is 0-16.  0 indicates 
		no DNS address present and in this case the modem will solicit a 
		network-supplied DNS address.	*/	
	U32	nLengthPriDns;
	
	/*! A binary representation of the primary DNS.
		Ex. 0x7F000201 is 127.0.2.1. */				
	BYTE byPriDns[LENGTH_IPAddress];	
	
	/*! Length of the primary DNS address.  Valid range is 0-16.  0 indicates 
		no DNS address present and in this case the modem will solicit a 
		network-supplied DNS address. */
	U32 nLengthSecDns;
	
	/*! A binary representation of the secondary DNS 
		(Ex. 0x7F000201 is 127.0.2.1.) */			
	BYTE bySecDns[LENGTH_IPAddress];	
};

///////////////////////////////////////////////////////////////////////////////
///
/// This structure contains 3G GSM TFT profile settings.
///
/// \sa SWI_NOTIFY_GsmProfileChange
/// \sa SwiGetGsmProfileTft
/// \sa SwiSetGsmProfileTft
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_GsmProfileTft
{
	/*!	The size, in bytes, of this structure. */
	U32 sizeStruct;

	/*! Profile ID.  Valid range is 1-16. */						
	U8 nProfileId;	
	
	/*! TFT filter ID.  Only 2 filters are currently supported (1-2). */						
	U32 nFilterId;
	
	/*! True indicates the TFT information is valid, false otherwise. */						
	bool bValid;
	
	/*! Evaluation precedence index.  Valid range is 0-255. */
	U32 nEpi;
	
	/*! IP length, where 4 indicates IPV4 while 16 indicates IPV6. */							
	U32 nLengthIp;
	
	/*! A binary value representing the source address.
		Ex. 0xFFFFFF00 is 255.255.255.0. */						
	BYTE bySrcIp[LENGTH_IPAddress];	
	
	/*! A binary value representing the source address mask.  
		Ex. 0xFFFFFF00 is 255.255.255.0. */
	BYTE bySrcIpMask[LENGTH_IPAddress];	
	
	/*! Protocol number (IPV4) / next header (IPV6). */
	U32 nProtoNum;	
	
	/*! Destination port range "from".  Valid values range from 0-65535). */						
	U32 nDestPortFrom;
	
	/*! Destination port range "to".  Valid values range from 0-65535). */						
	U32 nDestPortTo;
	
	/*! Source port range "from".  Valid values range from 0-65535). */					
	U32 nSrcPortFrom;
	
	/*! Source port range "to".  Valid values range from 0-65535). */
	U32 nSrcPortTo;	
	
	/*! Security parameter index.  Valid values range from 
		0x00000000-0xFFFFFFFF. */
	U32 nSecurParamInd;	
	
	/*! Type of service (IPV4) / traffic class (IPV6). */				
	U32	nTypeServ;
	
	/*! Type of service mask (IPV4) / traffic class mask (IPV6). */					
	U32 nTypeServMask;
	
	/*! Flow label (IPV6).  Valid values range from 0x00000 - 0xFFFFF. */					
	U32 nFlowLabel;						
};

///////////////////////////////////////////////////////////////////////////////
///
/// An enumeration of GSM profile information types.
///
/// \sa SWI_STRUCT_GsmProfileChange
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_ProfileInfo
{
	SWI_PROFILEINFO_Basic,	/*! Basic */
	SWI_RPOFILEINFO_Qos,	/*! Quality of service */
	SWI_RPOFILEINFO_Dns,	/*! Domain name service */
	SWI_RPOFILEINFO_Tft		/*! Traffic flow template */
};

///////////////////////////////////////////////////////////////////////////////
///
/// This structure is sent to the host to indicate when a profile has changed.
///
/// \sa SWI_TYPE_ProfileInfo
/// \sa SWI_NOTIFY_GsmProfileChange
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_GsmProfileChange
{
	/*! The size, in bytes, of this structure. */
	U32 sizeStruct;
	
	/*! A numerical value indicating which profile has changed.  Valid range
		is between 1-16. */						
	U8 nProfileId;
	
	/*! An enumeration of type SWI_TYPE_ProfileInfo indicating the type of
		profile information which has changed. */				
	SWI_TYPE_ProfileInfo eType;
	
	/*! TFT filter ID.  Only 2 filters are currently supported (1-2).  Only 
		valid if eType is SWI_PROFILEINFO_Tft.  */				
	U32 nFilterId;								
};

////////////////////////////////////////////////////////////////////////////////
///
/// This structure is contains the default Profile ID.
///
/// \sa SWI_NOTIFY_GsmDefaultChange
///
////////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_GsmDefaultChange
{
   /*! The size, in bytes, of this structure. */
   U32 sizeStruct;                     

   /*! The new default Profile ID. 0  if no profiles defined ,	1 to 16  one of the defined profiles. */
   U8 nProfileId;                                              
};

///////////////////////////////////////////////////////////////////////////////
//
// SMS Messages
//
///////////////////////////////////////////////////////////////////////////////

///////////////////////////////////////////////////////////////////////////////
///
/// An enumeration of SMS message status. 
///
/// \sa SWI_STRUCT_SMS_RetrieveHeader
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_SMS_Status
{
    SWI_SMSSTATUS_Unread,       /*!< SMS never been read. */
    SWI_SMSSTATUS_Read          /*!< SMS has been read before. */
};

///////////////////////////////////////////////////////////////////////////////
///
/// An enumeration of results for sending an SMS
///
/// \sa SWI_STRUCT_SMS_SendReference
/// \sa SWI_STRUCT_GSM_SMS_SendStatus
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_SMS_ResultCode
{
    SWI_RESULTCODE_OK,				/*!< Success */
    SWI_RESULTCODE_Error,			/*!< General error */
	SWI_RESULTCODE_FdnMismatch		/*!< FDN (fixed dialing number) mismatch */
};

///////////////////////////////////////////////////////////////////////////////
///
/// An enumeration of SMS received status. 
///
/// \sa SWI_STRUCT_GSM_SMS_SendStatus
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_SMS_ReceiveStatus
{
    SWI_RECEIVESTATUS_OK,		/*!< SMS arrived at its destination. */
    SWI_RECEIVESTATUS_Error		/*!< SMS didn't arrive at its destination. */
};

///////////////////////////////////////////////////////////////////////////////
///
/// An enumeration of the SMS packet types.
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_SMS_PacketType
{
	SWI_SMS_PACKET_First,				/*!< First */
	SWI_SMS_PACKET_Intermediate,		/*!< Intermediate */
	SWI_SMS_PACKET_Last,				/*!< Last */
	SWI_SMS_PACKET_None,				/*!< None */
};

///////////////////////////////////////////////////////////////////////////////
///
/// This structure is used to indicate the ready state of SMS.
///
/// \sa SWI_NOTIFY_SmsReady
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_SmsReady
{
	/*! The size, in bytes, of this structure. */
    U32 sizeStruct;
    
    /*! True indicates SMS is ready, false otherwise. */     
	bool bReady;				
};

///////////////////////////////////////////////////////////////////////////////
///
/// This structure defines the header of mobile-terminated SMS messages. 
///
/// \sa SWI_STRUCT_GSM_SMS_RetrieveSms
/// \sa SWI_TYPE_SMS_Status 
/// \sa SWI_TYPE_SMS_Address
/// \sa SWI_TYPE_SMS_AddressNumbering
/// \sa SWI_TYPE_SMS_Protocol
/// \sa SWI_TYPE_SMS_ProtocolId
/// \sa SWI_TYPE_SMS_CodingScheme
/// \sa SWI_TYPE_SMS_CodingClass
/// \sa SWI_TYPE_SMS_CodingCompression
///	\sa See sample code, Gsm_SMSInbox
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_SMS_RetrieveHeader
{
    /*!	The size, in bytes, of this structure.  This value should always be
		populated by the calling application. */
    U32 sizeStruct;                            

    /*!	The result of the SMS retrieve 
	    - A value of 0x00 indicates success.
		- A value of 0x01 indicates that the message is not available 
		  (SIM error, message not found or message segmentation error) */
	U32	nResultCode;                           

    /*! Record status indicates if the message is unread or has been
	    previously read.
		- A value of 0x00 indicates that the message is NEW
		- A value of 0x01 indicates that the message has been previously
		  read. */
	SWI_TYPE_SMS_Status recordStatus;

    /*! Service Centre Address Type */
	SWI_TYPE_SMS_Address eSCAddress;                            

    /*! Service centre Address Numbering Plan */ 
	SWI_TYPE_SMS_AddressNumbering eSCAddressNumberingPlan;                

    /*! Service Centre Address Length.
        Valid range for this field is from 0 to 20 */ 
    U32 nSCAddressNumLength;                  

	/*! Service Centre Address.
	    This field is in 8-bit binary-coded decimal. */
	U8 SCAddressNumber[LENGTH_AddressNumber];  

    /*! Destination Address Type */
	SWI_TYPE_SMS_Address eAddress;                               

    /*! Destination Address Numbering Plan */ 
	SWI_TYPE_SMS_AddressNumbering eAddressNumberingPlan;                 

    /*! Destination Address Length.
        Valid range for this field is from 0 to 20 */ 
    U32 nAddressNumLength;                     

	/*! Destination Address.
	    This field is in 8-bit binary-coded decimal. */
	U8 SME[LENGTH_SME];			       

    /*! Protocol Type */
	SWI_TYPE_SMS_Protocol eProtocol;

    /*! Protocol ID */
    SWI_TYPE_SMS_ProtocolId eProtocolID;						

	/*! Data Coding Scheme */
	SWI_TYPE_SMS_CodingScheme eDataCodingScheme;					

    /*! Data Coding Class */
    SWI_TYPE_SMS_CodingClass eDataCodingClass;					

    /*! Data Coding Compression */
	SWI_TYPE_SMS_CodingCompression eDataCodingCompression;				

    /*! Reserved for future use */
    U8 byWaiting[3];                         

    /*! Reserved for future use */
    bool bMoreMessage;                          

    /*! Time of Originating SMS.
	    This field is in 8-bit binary-coded decimal in the following format: 
	    yy,mm,dd,hh,mm,ss,tz.  Where tz is timezone */
	U8 Timestamp[LENGTH_SMSTimestamp];	       
};

///////////////////////////////////////////////////////////////////////////////
///
/// This structure is used to provide input to and receive output from 
///	the SwiRetrieveSMSMessage API.  This structure holds an entire 
///	SMS message - not just one SIM record.
///
/// \sa SwiRetrieveSMSMessage
/// \sa SWI_STRUCT_SMS_RetrieveHeader 
///	\sa See sample code, Gsm_SMSInbox
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_GSM_SMS_RetrieveSms
{
    /*!	The size, in bytes, of this structure.  This value should always be
		populated by the calling application. */
    U32 sizeStruct;   

    /*! Message Identifier of the retrieved message.  This identifier is 
		assigned to a particular message by the device. */
    U32 nSMSId;                    

    /*! Unread Message Flag. 
	    This flag should always be set by the calling application. 
	    To read an UNREAD message this field should be set to TRUE.
		To read a previously READ message this field should be set to FALSE. */
    bool bUnreadSMS;		           

    /*! SMS header for the retrieve message */ 
    SWI_STRUCT_SMS_RetrieveHeader sHeader;				   

	/*! Reserved for future use */
    U32 reserved;                  

    /*! Length of the retrieve message body, in bytes */
    U32 nMsgLength;                

    /*! Body of the retrieved message */
    U8 byMessage[LENGTH_MAX_Sms];	
};

///////////////////////////////////////////////////////////////////////////////
///
/// This structure defines the header of mobile-originated SMS messages. 
///
///	\sa SwiSendSMSExp
/// \sa	SWI_NOTIFY_SmsStoreExp
///	\sa SWI_STRUCT_GSM_SMS_StoreSms
/// \sa SWI_TYPE_SMS_Address
/// \sa SWI_TYPE_SMS_AddressNumbering
/// \sa SWI_TYPE_SMS_Protocol
/// \sa SWI_TYPE_SMS_ProtocolId
/// \sa SWI_TYPE_SMS_CodingScheme
/// \sa SWI_TYPE_SMS_CodingClass
/// \sa SWI_TYPE_SMS_CodingCompression
///	\sa See sample code, Gsm_SMSOutbox
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_SMS_StoreHeader
{
    /*!	The size, in bytes, of this structure.  This value should always be
		populated by the calling application. */
    U32 sizeStruct;

    /*! Overall message body size in bytes */ 
    U32 nOverallMsgBody;

    /*! Service Centre Address Type */
	SWI_TYPE_SMS_Address eSCAddress;                            

    /*! Service centre Address Numbering Plan */ 
	SWI_TYPE_SMS_AddressNumbering eSCAddressNumberingPlan;                

    /*! Service Centre Address Length.
        Valid range for this field is from 0 to 20 */ 
    U32 nSCAddressNumLength;                  

	/*! Service Centre Address.
	    This field is in 8-bit binary-coded decimal. */
	U8 SCAddressNumber[LENGTH_AddressNumber];  

    /*! Destination Address Type */
	SWI_TYPE_SMS_Address eAddress;                               

    /*! Destination Address Numbering Plan */ 
	SWI_TYPE_SMS_AddressNumbering eAddressNumberingPlan;                 

    /*! Destination Address Length.
        Valid range for this field is from 0 to 20 */ 
    U32 nAddressNumLength;                     

	/*! Destination Address
	    This field is in 8-bit binary-coded decimal. */
	U8 SME[LENGTH_SME];			       

    /*! Protocol Type */
	SWI_TYPE_SMS_Protocol eProtocol;

    /*! Protocol ID */
    SWI_TYPE_SMS_ProtocolId eProtocolID;						

	/*! Data Coding Scheme */
	SWI_TYPE_SMS_CodingScheme eDataCodingScheme;					

    /*! Data Coding Class */
    SWI_TYPE_SMS_CodingClass eDataCodingClass;					

    /*! Data Coding Compression */
	SWI_TYPE_SMS_CodingCompression eDataCodingCompression;				

    /*! Reserved for future use */
    U8 ValidityPeriod[LENGTH_SMSValidityPeriod];	
};

///////////////////////////////////////////////////////////////////////////////
///
/// This enumeration contains the status of a SMS store or send
///
/// \sa SWI_STRUCT_SmsStoreExp 
/// \sa SWI_STRUCT_SmsSendExp 
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_SmsStoreSendStatus
{
    SWI_SMS_STORE_Success,              /*!< Operation is successful */
    SWI_SMS_STORE_NotReady,             /*!< SMS not ready */
    SWI_SMS_STORE_RecordNotFound,       /*!< SMS record not found */
    SWI_SMS_STORE_SimError,             /*!< SIM error */
    SWI_SMS_STORE_PSError,              /*!< Network error */
    SWI_SMS_STORE_NoMessageID,          /*!< No message ID */
    SWI_SMS_STORE_InvalidRecord,        /*!< Invalid record ID */
    SWI_SMS_STORE_ConcatLinkError,      /*!< Concatenated link error */
    SWI_SMS_STORE_RecordNotSubmitted,   /*!< Record not submitted */
    SWI_SMS_STORE_InProgress,           /*!< SIM already busy sending */
    SWI_SMS_STORE_NRAMError,            /*!< NRAM error */
    SWI_SMS_STORE_FDNMismatch,          /*!< FDN mismatch */
    SWI_SMS_STORE_UnkownError           /*!< Unknown error */
};

///////////////////////////////////////////////////////////////////////////////
///
/// This structure is used to provide input to and receive output from 
///	the SwiStoreSMSMessage API. This structure holds an entire 
///	SMS message-not just one SIM Card record.
///
/// \sa SwiStoreSMSMessageExp 
/// \sa	SWI_NOTIFY_SmsStoreExp
///	\sa See sample code, Gsm_SMSOutbox
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_GSM_SMS_StoreSms
{
    /*!	The size, in bytes, of this structure.  This value should always be
		populated by the calling application. */
    U32 sizeStruct;                 

    /*! Reserved for future use */
    U16	nSMSId; 			       

    /*! SMS header of the message to be stored. 
	    The header must be populated by the calling application. */
    SWI_STRUCT_SMS_StoreHeader sSMSHeader;					

    /*! Body of the message to be stored. 
        The body must be populated by the calling application */
    U8 byMessage[LENGTH_MAX_Sms];

    /*! Flag indicating the result of the store.  This flag will be returned 
		to the caller by the API.  A value of TRUE will indicate that the 
		message was copied to the SIM successfully and it is ready to be sent.
		FALSE will indicate that the copy failed. */
    bool bStoreStatus;	           
};

///////////////////////////////////////////////////////////////////////////////
///
/// This structure provides a reference number to be used to track
///	the status of the mobile-originated SMS message.  The reference 
///	number will uniquely identify the sent SMS message.  
///
/// \sa SWI_NOTIFY_SmsSendReference
/// \sa SWI_TYPE_SMS_ResultCode
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_SMS_SendReference
{
    /*!	The size, in bytes, of this structure.  This value should always be
		populated by the calling application. */
    U32 sizeStruct;

    /*! Message Reference Number.
	    The API will return this value.
	    The valid range is from 0 to 255 */
    U32 nMsgReference;

    /*! Result of the sending the mobile-terminated message.
	    The API will return this value.  */
    SWI_TYPE_SMS_ResultCode	eResultCode; 	   
};

///////////////////////////////////////////////////////////////////////////////
///
/// This structure provides an update on the delivery status of a 
///	mobile originated SMS message previously sent by the device.  
///
/// \sa SWI_TYPE_SMS_ResultCode 
/// \sa SWI_TYPE_SMS_ReceiveStatus
/// \sa SWI_NOTIFY_SmsSendStatus 
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_GSM_SMS_SendStatus
{
    /*!	The size, in bytes, of this structure.  This value should always be
		populated by the calling application. */
    U32 sizeStruct;                          

    /*! Message Reference Number.
	    The valid range is from 0 to 255.
	    The API will return this value. */
    U32 nMsgReference;	                      

    /*! Result of the sending the mobile-terminated message.
	    The API will return this value.  */
    SWI_TYPE_SMS_ResultCode	eResultCode;                         

    /*! End destination delivery status of the sent the mobile-terminated 
		message.  The API will return this value.  */
    SWI_TYPE_SMS_ReceiveStatus eReceive;                            

    /*! Time when the service centre received the mobile-terminated message.
	    This field is in 8-bit binary coded decimal in the following format: 
	    yy,mm,dd,hh,mm,ss,tz, where tz is timezone.
	    The API will return this value.  */
    WCHAR szReceptionTime[LENGTH_SMSTimestamp]; 
};

///////////////////////////////////////////////////////////////////////////////
///
/// This structure conveys the number of the mobile-terminated SMS message
/// records on the SIM and how many are currently use.  It will also 
/// indicate the record number of newly received messages.
///
/// \sa SWI_TYPE_SMS_Routing 
/// \sa SWI_NOTIFY_SmsStatus
///	\sa See sample code, Gsm_SMSInbox
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_GSM_SMS_Status
{
	/*!	The size, in bytes, of this structure.  This value should always be
	populated by the calling application. */
	U32 sizeStruct;     

	/*! Messages waiting in the service centre flag.  This flag is TRUE then 
	there are mobile-terminated messages waiting in the service centre that
	can not be received by the SIM because there are no free records.
	This flag is FALSE otherwise.
	\sa SWI_NOTIFY_SmsSimFull */
	bool bMsgInSC;       

	/*! SMS Routing Option */
	SWI_TYPE_SMS_Routing eRoutingOption; 

	/*! Received message record number.  This is the record number of a just 
	received mobile-terminated message.*/
	U32 nRecNumber;

	/*! Used record count.  This is the number of internal records on the SIM
	that can be used to store all mobile-terminated messages. */
	U32 cntUsedRec;    

	/*! Unread record count
	This is the number of internal records on the SIm that have been used
	to store unread mobile-terminated messages */
	U32 cntUnreadRec;   

	/*! Maximum record count.  The total number of internal records on the SIM
	that can be used to store mobile-terminated messages.
	The maximum record count is SIM-dependent */
	U32 cntMaxRecord;   
};

///////////////////////////////////////////////////////////////////////////////
///
/// This enumeration contains all possible results of SMS request.
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_SMS_RequestStatus 
{
	SWI_SMSREQUESTSTATUS_RequestOk = 0x00,  /*!< Successful request */
	SWI_SMSREQUESTSTATUS_NotReady,			/*!< Device not yet SMS ready */ 
	SWI_SMSREQUESTSTATUS_SendReady,         /*!< SMS send ready */
	SWI_SMSREQUESTSTATUS_SendReceiveReady,  /*!< SMS receive ready */
	SWI_SMSREQUESTSTATUS_RecordNotFound,    /*!< SMS record id not found */
	SWI_SMSREQUESTSTATUS_SimError,          /*!< SIM error */
	SWI_SMSREQUESTSTATUS_PsError,           /*!< Network error */
	SWI_SMSREQUESTSTATUS_NoMessageId,       /*!< Missing message id */
	SWI_SMSREQUESTSTATUS_InvalidRecord,     /*!< Invalid record id */
	SWI_SMSREQUESTSTATUS_LinkError,         /*!< Link error */
	SWI_SMSREQUESTSTATUS_SubmitRecord,      /*!< Submit record */
	SWI_SMSREQUESTSTATUS_SendInProgress,    /*!< SMS send in progress */
	SWI_SMSREQUESTSTATUS_RecordBusy,        /*!< SMS record busy */
	SWI_SMSREQUESTSTATUS_NRamError,         /*!< Non-volatile RAM error */
	SWI_SMSREQUESTSTATUS_InvalidCommand,    /*!< Invalid SMS command */
	SWI_SMSREQUESTSTATUS_FdnFail,           /*!< FDN mismatch */
	SWI_SMSREQUESTSTATUS_NoMoreRecords = 0x71,	/*!< No more SMS records */
	SWI_SMSREQUESTSTATUS_DataInvalid = 0x72     /*!< Invalid data */
};

///////////////////////////////////////////////////////////////////////////////
///
/// This structure is used by the SWI_NOTIFY_SmsSimFull notification to 
/// indicate the SIM's SMS full state.  If the SIM is full then no further
/// SMS messages can be received until the user deletes some of the previously
/// received messages.    
///
/// \sa SWI_NOTIFY_SmsSimFull
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_SMS_SimFull
{
	/*! The size, in bytes, of this structure. */
    U32 sizeStruct;
    
    /*! True indicates the SIM is full and can no longer send or receive SMS 
		messages, false otherwise. */           
	bool bSimFull;			
};

///////////////////////////////////////////////////////////////////////////////
///
/// Enumeration of SMS status report result codes
///
/// \sa SWI_STRUCT_SmsStatusReportCfg	
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_SmsStsResult
{
	SWI_SMSSTSRESULT_Success,  /*!< Request successful */
	SWI_SMSSTSRESULT_ReadOnly, /*!< Status report settings can not be 
							   modified. */
};

///////////////////////////////////////////////////////////////////////////////
///
/// This structure contains SMS status report configuration.
///
/// \sa SWI_TYPE_SmsStsResult 
/// \sa SwiGetSmsStatusReportCfg 
/// \sa SwiSetSmsStatusReportCfg 
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_SmsStatusReportCfg
{
	/*! The size, in bytes, of this structure.  This value must always be 
		populated by the calling application. */
	U32	sizeStruct;

	/*! SMS status reports enabled flag.  TRUE means enabled.  False disabled.
		When using this structure with the SwiSetSmsStatusReportCfg API
		this flag should be populated by the calling application.
		When this structure is used with the SwiGetSmsStatusReportCfg API 
		this flag value will be return by the API. */
	bool bEnabled;

	/*! SMS status reports configuration read-only setting
		- 0x00 indicates that the SMS status report enable flag can be modified
		- 0x01 indicates that the SMS status report enable flag is read only
		This flag is always returned by the API. */
	bool bReadOnly;

	/*! Result of an attempt to modify the SMS status report enable flag
		using the SwiSetSmsStatusReportCfg API. 
		This value is returned by the API. */
	SWI_TYPE_SmsStsResult eResult;
};

///////////////////////////////////////////////////////////////////////////////
//
// Call Management and Voice Features
//
///////////////////////////////////////////////////////////////////////////////

///////////////////////////////////////////////////////////////////////////////
///
/// This enumeration contains all possible call restriction settings.
///
/// \sa SWI_STRUCT_CALL_Create
/// \sa SWI_STRUCT_CLIR_Setting
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_CallRestrict
{
    SWI_CALL_RESTRICT_Default,    /*!< default */  
    SWI_CALL_RESTRICT_Allowed,    /*!< caller id allowed */
    SWI_CALL_RESTRICT_Restricted, /*!< caller id restricted */
    SWI_CALL_RESTRICT_Unknown     /*!< unknown CLIR setting */
};

///////////////////////////////////////////////////////////////////////////////
///
/// This enumeration contains the actions that can be performed on a call.
///
/// \sa  SWI_STRUCT_CALL_Control
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_CallControl
{
    SWI_CALL_CONTROL_ActiveOne,            /*!< activate one call */				
    SWI_CALL_CONTROL_ActiveAll,            /*!< activate all calls */
    SWI_CALL_CONTROL_HoldOne,              /*!< put one call on hold */
    SWI_CALL_CONTROL_HoldAll,              /*!< put all calls on hold */
    SWI_CALL_CONTROL_SwapCall,             /*!< swap active and held calls */
    SWI_CALL_CONTROL_Connect,              /*!< answer a call */
    SWI_CALL_CONTROL_Disconnect,           /*!< end a call */
    SWI_CALL_CONTROL_DisconnectAll,        /*!< end all calls */
    SWI_CALL_CONTROL_DisconnectAllActive,  /*!< end all active calls */
    SWI_CALL_CONTROL_DisconnectAllHeld     /*!< end all held calls */
};

///////////////////////////////////////////////////////////////////////////////
///
/// This enumeration contains the actions that can be performed on a call. 
///
/// \sa SWI_STRUCT_CALL_UMTS_Control
/// \sa GSM 02.30
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_UMTS_CallControl
{
   SWI_CALL_CONTROL_UMTS_RelAllHeld,            /*!< 0 <send> */				
   SWI_CALL_CONTROL_UMTS_RelAllActAccHeldWait,  /*!< 1 <send> */
   SWI_CALL_CONTROL_UMTS_ReleaseCallX,          /*!< 1X <send> */
   SWI_CALL_CONTROL_UMTS_HoldAllActAccHeldWait, /*!< 2 <send> */
   SWI_CALL_CONTROL_UMTS_HoldAllActExceptCallX,	/*!< 2X <send> */
   SWI_CALL_CONTROL_UMTS_AddHeldCall,           /*!< 3 <send> */
   SWI_CALL_CONTROL_UMTS_ConTwoCallsAndDiscon,  /*!< 4 send> */
   SWI_CALL_CONTROL_UMTS_DisconnectAll,         /*!< <end> */
};

///////////////////////////////////////////////////////////////////////////////
///
/// This enumeration contains the tone lengths used for DTMF over-dial
/// digits.
///
/// \sa SWI_STRUCT_NVToneStore
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_ToneLength
{
    SWI_TONELENGTH_Short,      /*!< short DTMF tone length */	
    SWI_TONELENGTH_Medium,     /*!< medium DTM tone length */
    SWI_TONELENGTH_Long,       /*!< long DTMF tone length */
    SWI_TONELENGTH_UserDefined /*!< user-defined DTMF tone length */	
};

///////////////////////////////////////////////////////////////////////////////
///
/// This enumeration contains all the call progress states.
///
/// \sa SWI_STRUCT_CALL_EXP_Progress
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_CallProgress
{
    /*! call has failed */
    SWI_CALL_PROGRESS_Failed,

    /*! call is connecting */						
    SWI_CALL_PROGRESS_Connecting,

    /*! outgoing call is a waiting call for the called party */		
    SWI_CALL_PROGRESS_Queued,

    /*! incoming call is waiting */	
    SWI_CALL_PROGRESS_Waiting,

    /*! incoming call (not the same as waiting) */					
    SWI_CALL_PROGRESS_Incoming,

    /*! incoming call is ring */					
    SWI_CALL_PROGRESS_Ringing,

    /*! call is connected */								
    SWI_CALL_PROGRESS_Connected,

    /*! call is disconnected */					
    SWI_CALL_PROGRESS_Disconnecting,

    /*! call is disconnected */						
    SWI_CALL_PROGRESS_Disconnected,

    /*! incoming call has been forwarded to us */						
    SWI_CALL_PROGRESS_Forwarded							  
};

///////////////////////////////////////////////////////////////////////////////
///
/// This enumeration contains all the call error states.
///
/// \sa SWI_STRUCT_CALL_EXP_Progress 
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_GSM_CallError
{
    SWI_CALL_ERROR_OK,                  /*!< success (no error) */
    SWI_CALL_ERROR_SubsciberBusy,       /*!< subscriber busy */	
    SWI_CALL_ERROR_Congestions,         /*!< congestion */					
    SWI_CALL_ERROR_RadioPathUnavail,    /*!< radio path unavailable */						
    SWI_CALL_ERROR_Error,               /*!< error */	
    SWI_CALL_ERROR_NumberUnobtain,      /*!< number unobtainable */		
    SWI_CALL_ERROR_AuthFailure,         /*!< authentication failure */
    SWI_CALL_ERROR_NoNumber,            /*!< no number present */
    SWI_CALL_ERROR_BckgndCallCtrlFail,  /*!< background call control failure */				
    SWI_CALL_ERROR_BckgndMMFail,        /*!< background mobility management 
											 failure */
    SWI_CALL_ERROR_ChannelBusy,         /*!< channel busy */
    SWI_CALL_ERROR_FDNMismatch,         /*!< FDN mismatch */								
    SWI_CALL_ERROR_BCFail,              /*!< BC failure */
    SWI_CALL_ERROR_EmergencyOnly,       /*!< emergency calls only */
    SWI_CALL_ERROR_ACMExceeded,         /*!< ACM limit exceeded */
    SWI_CALL_ERROR_HoldError,           /*!< hold error */
    SWI_CALL_ERROR_BusyProcReq,         /*!< busy processing request */
    SWI_CALL_ERROR_ChannelUnavail,      /*!< active channel unavailable */
    SWI_CALL_ERROR_OutgoingBarred,      /*!< outgoing calls barred */ 
    SWI_CALL_ERROR_NumberBlacklisted,   /*!< number blacklisted */
    SWI_CALL_ERROR_BlackListFull,       /*!< black list full */
    SWI_CALL_ERROR_RedialNotTimedOut,   /*!< redial not timed out */
    SWI_CALL_ERROR_ModifyFail,          /*!< modify failed */
    SWI_CALL_ERROR_NotInControl,        /*!< not in control */
    SWI_CALL_ERROR_NoCauseCode,         /*!< no cause code */
    SWI_CALL_ERROR_CallBarred           /*!< call barred */
};

///////////////////////////////////////////////////////////////////////////////
///
///	This enumeration contains all possible call presentation settings. 
///
/// \sa SWI_STRUCT_CALL_EXP_Progress 
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_CallPresentation
{
    SWI_CALL_PRESENTATION_Number,     /*!< display number to called party */
    SWI_CALL_PRESENTATION_Restricted, /*!< hide number from called party */
    SWI_CALL_PRESENTATION_NoAvail     /*!< number not available */
};

///////////////////////////////////////////////////////////////////////////////
///
/// This enumeration contains all possible call screening settings. 
///
/// \sa SWI_STRUCT_CALL_EXP_Progress 
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_CallScreening
{
    SWI_CALL_SCREENING_NotScreened, /*!< user not screened */
    SWI_CALL_SCREENING_Passed,      /*!< user passed screening */
    SWI_CALL_SCREENING_Failed,      /*!< user failed screening */
    SWI_CALL_SCREENING_Network,     /*!< network screening */
};

///////////////////////////////////////////////////////////////////////////////
///
/// This enumeration contains all possible call types.
///
/// \sa SWI_STRUCT_CALL_EXP_Progress 
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_GSM_CallType
{
    SWI_CALL_TYPE_VoiceCallLine1,  /*!< voice call line 1 */
    SWI_CALL_TYPE_VoiceCallLine2,  /*!< voice call line 2 */
    SWI_CALL_TYPE_CSD,             /*!< circuit switched data */
    SWI_CALL_TYPE_FAX              /*!< facsimile */
};

///////////////////////////////////////////////////////////////////////////////
///
/// This enumeration contains call information states.
///
/// \sa SWI_STRUCT_CALL_EXP_Progress 
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_CallValid
{
    SWI_CALL_VALID_NoInfo,   /*!< no number information */
    SWI_CALL_VALID_InfoValid /*!< number information valid */
};

///////////////////////////////////////////////////////////////////////////////
///
/// This enumeration contains all possible call states.
///
/// \sa SWI_STRUCT_CALL_State 
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_GSM_CallState
{
    SWI_CALLSTATE_Null,         /*!< null state */
    SWI_CALLSTATE_Connecting,   /*!< call connecting */
    SWI_CALLSTATE_Queued,       /*!< outgoing call waiting for called party */
    SWI_CALLSTATE_Waiting,      /*!< incoming call waiting */
    SWI_CALLSTATE_Alerting,     /*!< call ringing */
    SWI_CALLSTATE_Connected,    /*!< call connected */
    SWI_CALLSTATE_Disconnecting /*!< call disconnecting */
};

///////////////////////////////////////////////////////////////////////////////
///
/// An enumeration of GSM phonebooks. 
///
/// \sa SWI_NOTIFY_PhonebookEntry
/// \sa SwiDeletePhonebookLastNum
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_Phonebook
{
	SWI_PHONEBK_Adn,	/*!< Abbreviated dialing numbers */
	SWI_PHONEBK_Fdn,	/*!< Fixed dialing numbers */
	SWI_PHONEBK_Lnd,	/*!< Last numbers dialed */
	SWI_PHONEBK_Msisdn,	/*!< Mobile subscriber international subscriber
							 identity numbers */
	SWI_PHONEBK_Lnm,	/*!< Last numbers missed */
	SWI_PHONEBK_Lnr,	/*!< Last numbers received */
    SWI_PHONEBK_Sdn,	/*!< Service dialing numbers */
	SWI_PHONEBK_Cphsmn,	/*!< CPHS mailing numbers */
};

///////////////////////////////////////////////////////////////////////////////
///
/// An enumeration of phonebook operation results. 
///
/// \sa SWI_STRUCT_PHONEBK_Entry
/// \sa SWI_STRUCT_PHONEBK_DeleteEntry
/// \sa SWI_STRUCT_FdnMode
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_PHONEBOOK_Result
{
	/*!	The phonebook operation was successful. */
	SWI_PHONEBOOKRESULT_Success,
	
	/*! Extended number field not available.*/
	SWI_PHONEBOOKRESULT_Ext1NotAvail,
	
	/*! Too many phonebook entries greater than 20 digits. */	
	SWI_PHONEBOOKRESULT_TooManyEntries,	
	
	/*! CHV2 validation error. */
	SWI_PHONEBOOKRESULT_CHV2NotValid,
	
	/*! Phonebook entry does not exist. */
	SWI_PHONEBOOKRESULT_NotExist,
	
	/*! General operation failure. */		
	SWI_PHONEBOOKRESULT_Failed			
};

///////////////////////////////////////////////////////////////////////////////
///
/// This structure is used as input by the SwiSetCallOriginate function.  
///
/// \sa SwiSetCallOriginate 
/// \sa SWI_TYPE_CallRestrict
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_CALL_Create
{
	/*! The size, in bytes, of this structure.  This value must always be 
		populated by the calling application. */
    U32	sizeStruct;

    /*! call restriction setting to be used for this outgoing call */
    SWI_TYPE_CallRestrict eCallRestrict;
   
    /*! international number flag.  - TRUE for '+' number - FALSE otherwise */
    bool bInternational;

    /*! length of number to be called */
    U32 nNumberLength;

    /*! number to call.  - 8-bit BCD */
    U8 bcdPhone[LENGTH_MaxPhone];
};

///////////////////////////////////////////////////////////////////////////////
///
/// This structure is used as input by the SwiSetCallControl function.  
///
/// \sa SwiSetCallControl
/// \sa SwiSetCallControlExp
/// \sa SWI_TYPE_CallControl 
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_CALL_Control
{
	/*! The size, in bytes, of this structure.  This value must always be 
		populated by the calling application. */
    U32 sizeStruct;

    /*! call id of the call to be acted on */
    U32 nCallID;
	 
	/*! action to take on the specified call */
    SWI_TYPE_CallControl eCallAction;
};

///////////////////////////////////////////////////////////////////////////////
///
/// This structure is used as input by the SwiSetCallUMTSControl function.  
///
/// \sa SwiSetCallControlUMTS 
/// \sa SWI_TYPE_UMTS_CallControl 
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_CALL_UMTS_Control
{
	/*! The size, in bytes, of this structure.  This value must always be 
		populated by the calling application. */
    U32 sizeStruct;

	/*! unused member */
    U32 nVersion;						

    /*! call id of the call to be acted on */
    U32 nCallID;
	 
	/*! action to take on the specified call */
    SWI_TYPE_UMTS_CallControl eCallAction;
};

///////////////////////////////////////////////////////////////////////////////
///
/// This structure is as input for the SwiSetContDtmf function.  
///
/// \sa SwiSetContDtmf 
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_ContDtmf
{
	/*! The size, in bytes, of this structure.  This value must always be 
		populated by the calling application. */
    U32 sizeStruct;

    /*! DTMF tone type */
    U32 nDtmfTone;

    /*! DTMF continuous tone start flag 
        - TRUE if the tone is to be started
		- FALSE is the tone is to be stopped */
    bool bStart;
};

///////////////////////////////////////////////////////////////////////////////
///
/// This structure is used as input by the SwiSetDTMFSend function.
///
/// \sa SwiSetDTMFSend 
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_DTMFSend
{
	/*! The size, in bytes, of this structure.  This value must always be 
		populated by the calling application. */
    U32 sizeStruct;

    /*! number of DTMF digits in the byDigits buffer */ 
    U32 nNumberOfDigits;

    /*! list of DTMF digits to be played in order
	    - valid digits are ',' '*' '#' '0'-'9' 'A'-'D' 
		- digits are in ASCII
		- ',' indicates a 3-second pause */
    U8 byDigits[20];

    /*! the length of time in milliseconds that a DTMF will sound 
	    - valid range is: 80ms < Range < 3000ms */
    U32 nToneOnDuration;

    /*! the length of time in milliseconds between DTMF tones
	    - valid range is: 80ms < Range < 3000ms */
    U32 nToneOffDuration;

    /*! earpiece feedback flag 
	    - TRUE if DTMF is to be played to earpiece
		- FALSE otherwise */
    bool bEarpieceFeedback;
};

///////////////////////////////////////////////////////////////////////////////
///
/// This structure is used as input by the SwiSetNVToneStore function and
/// output by the SwiGetNVToneStore function.
///
/// \sa SwiSetNVToneStore 
/// \sa SwiGetNVToneStore 
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_NVToneStore
{
	/*! The size, in bytes, of this structure.  This value must always be 
		populated by the calling application. */
    U32 sizeStruct;          

    /*! tone length time: short, medium, long or user defined */
    SWI_TYPE_ToneLength eToneLength;

    /*! user defined tone on duration.
	    - length of time in milliseconds that a DTMF will sound for
        - 80ms < Range < 3000ms */
    U32 nUserDefinedToneOnDuration;  

    /*! user defined tone off duration.
	    - length of time in milliseconds between DTMF tones 
        - 80ms < Range < 3000ms */
    U32 nUserDefinedToneOffDuration; 

    /*! unused member */
    U32 nComfortToneOnDuration;      

    /*! unused member */
    U32 nComfortToneOffDuration;

    /*! earpiece feedback sound
	    - TRUE if DTMF will be sounded in the earpiece
		- FALSE otherwise */
    bool bEarpieceFeedback;           
};

///////////////////////////////////////////////////////////////////////////////
///
/// This structure is used as input by the SwiSetSpeakerVolume function 
///	and output by the SwiGetSpeakerVolume function.
///
/// \sa SwiSetGsmSpeakerVolume 
/// \sa SwiGetGsmSpeakerVolume 
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_GSM_SpeakerVolume
{
	/*! The size, in bytes, of this structure.  This value must always be 
		populated by the calling application. */
    U32 sizeStruct;  

    /*! percentage of maximum value
	    - valid range 0% to 100% */
    U32 nVolume;        
};

///////////////////////////////////////////////////////////////////////////////
///
/// This structure is used as input by the SwiSetSpeakerMute function 
///	and output by the SwiGetSpeakerMute function.
///
/// \sa SwiSetSpeakerMute 
/// \sa SwiGetSpeakerMute
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_GSM_SpeakerMute
{
	/*! The size, in bytes, of this structure.  This value must always be 
		populated by the calling application. */
    U32	                  sizeStruct; 

    /*! speaker mute flag
	    - TRUE indicates mute
		- FALSE otherwise */
    bool                  bMute;
};

///////////////////////////////////////////////////////////////////////////////
///
/// This structure is used as input by the SwiSetMicMute function 
/// and output by the SwiGetMicMute function.
///
/// \sa SwiSetMicMute 
/// \sa SwiGetMicMute 
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_MicMute
{
	/*! The size, in bytes, of this structure.  This value must always be 
		populated by the calling application. */
    U32 sizeStruct;

    /*! microphone mute flag
	    - TRUE indicates mute
		- FALSE otherwise */
    bool bMute;
};

///////////////////////////////////////////////////////////////////////////////
///
/// This structure contains the message waiting flags on the SIM 
///
/// \sa SwiGetVoiceMessage 
/// \sa SWI_NOTIFY_VoiceMessage 
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_VoiceMessage
{
	/*! The size, in bytes, of this structure.  This value must always be 
		populated by the calling application. */
    U32	 sizeStruct;

    /*! SIM supports these waiting message flags
	    - true is supported by SIM (meaning the below flags are valid) 
		- false otherwise */
    bool bVoiceMailWaitingFeature;

    /*! message waiting for line 1 flag 
	    - true voice mail is waiting for line 1 
		- false otherwise */
    bool bVoiceMailWaitingLine1;

    /*! message waiting for line 2 flag 
	    - true voice mail is waiting for line 2
		- false otherwise */
    bool bVoiceMailWaitingLine2;

    /*! FAX message waiting flag 
	    - true FAX message is waiting 
		- false otherwise */
    bool bFaxMssageWaiting1;

    /*! data message waiting flag 
	    - true data message is waiting
		- false otherwise */
    bool bFaxMssageWaiting2;
};

///////////////////////////////////////////////////////////////////////////////
///
/// This structure is indicates the number of incoming calls that have
/// done unanswered since the last time the missed call counter was 
/// cleared.
///
/// \sa SwiAcknowledgeMissedCall 
/// \sa SWI_NOTIFY_MissedCall 
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_MissedCall
{
	/*! The size, in bytes, of this structure.  This value must always be 
		populated by the calling application. */
    U32 sizeStruct; 

    /*! number of missed calls */
    U32 nCount;    
};

///////////////////////////////////////////////////////////////////////////////
///
/// This structure contains the activation state of 
/// unconditional call forwarding.
///
/// \sa SWI_NOTIFY_CFIcon
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_CFIcon
{
	/*! The size, in bytes, of this structure. */
    U32 sizeStruct;		

	/*! unconditional call forwarding active (call forwarding icon is on) */
    bool bIconOn;		
};

///////////////////////////////////////////////////////////////////////////////
///
/// This structure is used by the SWI_NOTIFY_CallProgress to report the 
/// the progress of an individual call.
///
/// \sa SWI_NOTIFY_CallProgress 
/// \sa SWI_TYPE_CallProgress 
/// \sa SWI_TYPE_GSM_CallError
/// \sa SWI_TYPE_CallValid
/// \sa SWI_TYPE_CallPresentation
/// \sa SWI_TYPE_CallScreening
/// \sa SWI_TYPE_GSM_CallType
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_CALL_EXP_Progress
{
	/*! The size, in bytes, of this structure. */
    U32 sizeStruct;

    /*! call id */
    U32 CallID;

    /*! call progress state */
    SWI_TYPE_CallProgress eCallProgress;

    /*! call error code */
    SWI_TYPE_GSM_CallError eCallError;

    /*! call information below valid flag */
    SWI_TYPE_CallValid eCallValid;

    /*! call presentation setting */
    SWI_TYPE_CallPresentation eCallPresentation;

    /*! call screening setting */
    SWI_TYPE_CallScreening eCallScreening;

    /*! international number flag.  - TRUE for '+' number - FALSE otherwise */
    bool bInternational;

    /*! length of phone number */
    U32 nNumberLength;

    /*! phone number of party connected to */
    U8 bcdPhone[LENGTH_MaxPhone];

    /*! call type: line1, line2, CSD or FAX */
    SWI_TYPE_GSM_CallType eCallType;

    /*! name of party connected to */
    WCHAR szCallerName[LENGTH_CallerName];
};

///////////////////////////////////////////////////////////////////////////////
///
/// This structure contains the call state of a single call.   
///
/// \sa SWI_STRUCT_CALL_Status
/// \sa SWI_TYPE_GSM_CallState 
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_CALL_State
{
	/*! The size, in bytes, of this structure. */
    U32 sizeStruct;				

    /*! call id */
    U32 CallID;    

    /*! call state */
    SWI_TYPE_GSM_CallState eCallState;

    /*! call information */
    U32 CallInfo;   
};

///////////////////////////////////////////////////////////////////////////////
///
/// This structure is used by the SWI_NOTIFY_CallStatus notifications 
///	to report changes to the calls list. 
///
/// \sa SWI_NOTIFY_CallStatus 
/// \sa SWI_STRUCT_CALL_State 
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_CALL_Status
{
	/*! The size, in bytes, of this structure. */
    U32 sizeStruct;

    /*! total number of calls */
    U32 nCallSum;

    /*! number of outgoing calls */
    U32 nCallOutgoing;

    /*! number of held calls */
    U32 nCallHeld;

    /*! number of calls waiting */
    U32 nCallWaiting;

    /*! number of calls queued */
    U32 nCallQueued;

    /*! number of multi-party calls */
    U32 nCallMultiparty;

    /*! number of calls in the call list
	   - valid range: 0 to 7 */
    U8 nNumberCalls;

    /*! list of all call present calls */
    SWI_STRUCT_CALL_State CallList[MAX_CALLS];
};

///////////////////////////////////////////////////////////////////////////////
///
/// This structure is used as input by the SwiSetCLIRSetting function and as
///	output by the SwiGetCLIRSetting function.  	
/// 
/// \sa SWI_TYPE_CallRestrict 
/// \sa SwiSetCLIRSetting 
/// \sa SwiGetCLIRSetting 
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_CLIR_Setting
{
	/*! The size, in bytes, of this structure.  This value must always be 
		populated by the calling application. */
    U32 sizeStruct;

    /*! call restriction setting */
    SWI_TYPE_CallRestrict eCallRestrict;				   
};

///////////////////////////////////////////////////////////////////////////////
///
/// This structure contains phonebook size information and is used as output 
/// for the SwiGetPhonbookSize function.
///
/// \sa SwiGetPhonebookSize
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_PHONEBK_Size
{
	/*! The size, in bytes, of this structure.  This value must always be 
		populated by the calling application. */
	U32 sizeStruct;
	
	/*! Number of free entries in the ADN phonebook. */					
	U32 nADNFreeEntries;
	
	/*! Total number of entries in the ADN phonebook. */			
	U32 nADNTotalEntries;
	
	/*! Number of free entries in the FDN phonebook. */			
	U32 nFDNFreeEntries;
	
	/*! Total number of entries in the FDN phonebook. */			
	U32 nFDNTotalEntries;
	
	/*! Number of free entries in the LND phonebook. */			
	U32 nLNDFreeEntries;
	
	/*! Total number of entries in the LND phonebook. */			
	U32 nLNDTotalEntries;
	
	/*! Number of free entries in the MSISDN phonebook. */			
	U32 nMSISDNFreeEntries;
	
	/*! Total number of entries in the MSISDN phonebook. */			
	U32 nMSISDNTotalEntries;
	
	/*! Number of free entries in the LNM phonebook. */		
	U32 nLNMFreeEntries;
	
	/*! Total number of entries in the LNM phonebook. */		
	U32 nLNMTotalEntries;
	
	/*! Number of free entries in the LNR phonebook. */			
	U32 nLNRFreeEntries;
	
	/*! Total number of entries in the LNR phonebook. */		
	U32 nLNRTotalEntries;
	
	/*! Number of free entries in the SDN phonebook. */			
	U32 nSDNFreeEntries;
	
	/*! Total number of entries in the SDN phonebook. */			
	U32 nSDNTotalEntries;
	
	/*! Number of free entries in the CPHS mailbox phonebook. */			
	U32 nCPHSMNFreeEntries;
	
	/*! Total number of entries in the CPHS mailbox phonebook. */			
	U32 nCPHSMNTotalEntries;		
};

///////////////////////////////////////////////////////////////////////////////
///
/// This structure contains phone book entry information. 
///
/// \sa SWI_TYPE_Phonebook
/// \sa SWI_TYPE_PHONEBOOK_Result
/// \sa SwiGetPhonebookEntry
/// \sa SwiAddPhonebookEntry
/// \sa SwiEditPhonebookEntry
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_PHONEBK_Entry
{
	/*! The size, in bytes, of this structure. */
	U32 sizeStruct;	
	
	/*! Entry ID. */						
	U32 nID;
	
	/*! Phone book type. */							   
	SWI_TYPE_Phonebook ePhoneBookType;
	
	/*! A NULL terminated string representing the phonebook entry name. */						
	WCHAR szEntryName[LENGTH_EntryName];
	
	/*! Phone number length; minimum 1 digit, maximum 20 digits. */
    U32 nPhoneNumberLength;
    
	/*! A binary number representing the phone number. */
	U8 byPhoneNumber[LENGTH_GSM_PhoneNumber];
	
	/*! True indicates the phonebook data is valid, false otherwise. */	
	bool bValid;	
	
	/*! True indicates the phone number is international, false otherwise. */					       
	bool bInternational;
	
	/*! True is passed to the modem to read from the start of the phonebook.  
		False is passed to read from the current position. */						
	bool bReadFromStart;
	
	/*! True is returned if there are more entries, false otherwise.  This 
		field is only valid when reading from a phonebook. */					
	bool bMoreEntries;
	
	/*! Result of the phonebook operation. */ 				
	SWI_TYPE_PHONEBOOK_Result eResultCode;					
};

///////////////////////////////////////////////////////////////////////////////
///
/// This structure contains information used to delete a phonebook entry.  
///
/// \sa SWI_TYPE_PHONEBOOK_Result
/// \sa SWI_TYPE_Phonebook
/// \sa SwiDeletePhonebookEntry
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_PHONEBK_DeleteEntry
{
	/*! The size, in bytes, of this structure.  This value must always be 
		populated by the calling application. */
	U32 sizeStruct;	
	
	/*! Phonebook to delete from. */			
	SWI_TYPE_Phonebook ePhoneBookType;	
	
	/*! Entry ID to be deleted. */		
	U32 nID;
	
	/*! Result of delete operation.  This value is returned after calling 
		SwiDeletePhonebookEntry. */
	SWI_TYPE_PHONEBOOK_Result eResultCode;			
};

///////////////////////////////////////////////////////////////////////////////
///
/// This structure is used to indicate when phonebook operations are 
/// permitted.
///
/// \sa SWI_NOTIFY_PhonebookReady
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_PhonebookReady
{
	/*! The size, in bytes, of this structure. */
    U32 sizeStruct;
    
    /*! True if phonebook operations are permitted, false otherwise. */          
    bool bReady;              
};

///////////////////////////////////////////////////////////////////////////////
///
/// This structure contains phonebook availability information.
///
/// \sa SwiGetPhonebookAvailable
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_PHONEBK_Available
{
	/*! The size, in bytes, of this structure.  This value must always be 
		populated by the calling application. */
	U32	sizeStruct;
	
	/*! ADN phonebook available flag.  True if available, false otherwise. */			
	bool bADN_Available;
	
	/*! FDN phonebook available flag.  True if available, false otherwise. */
    bool bFDN_Available;
    
    /*! LND phonebook available flag.  True if available, false otherwise. */
    bool bLND_Available;
    
    /*! MSISDN phonebook available flag.  True if available, false otherwise.*/
    bool bMSISDN_Available;
    
    /*! LNM phonebook available flag.  True if available, false otherwise. */
    bool bLNM_Available;
    
    /*! LNR phonebook available flag.  True if available, false otherwise. */
    bool bLNR_Available;
    
    /*! SDN phonebook available flag.  True if available, false otherwise. */
    bool bSDN_Available;
    
    /*! CPHS mailbox phonebook available flag.  True if available, false
		otherwise. */
	bool bCPHSMN_Available;
};

///////////////////////////////////////////////////////////////////////////////
///
/// This structure is used as output of the SwiGetEmergencyEntry function.   
///
/// \sa SwiGetEmergencyEntry 
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_Emergency_Number
{
	/*! The size, in bytes, of this structure.  This value must always be 
		populated by the calling application. */
	U32 sizeStruct;

	/*! emergency number length
		- valid range: 1 to 4 digits */
	U32 nPhoneNumberLength;

	/*! emergency phone number
		- 8-bit BCD */
	U8 byPhoneNumber[LENGTH_EmergencyPhoneNumber];	

	/*! more entries flag indicates if there are more emergency
		numbers to be read */
	bool bMoreEntries;	                                
};

///////////////////////////////////////////////////////////////////////////////
///
/// This structure contains information used to configure the FDN mode.
///
/// \sa SWI_TYPE_PHONEBOOK_Result
/// \sa SetFdnMode
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_FdnMode
{
	/*! The size, in bytes, of this structure.  This value must always be 
		populated by the calling application. */
	U32 sizeStruct;
	
	/*! FDN enable flag.  Set to true to enable, false to disable. */
	bool bEnabled;
	
	/*! Result of FDN mode change request. */			
	SWI_TYPE_PHONEBOOK_Result eResultCode;		
};

///////////////////////////////////////////////////////////////////////////////
///
/// Call forward notification information.
///
/// \sa SWI_NOTIFY_CallForwarded
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_CallForwarded
{	
	/*! The size, in bytes, of this structure. */
	U32	sizeStruct;
	
	/*! Call ID */
	U32	nCallID;
	
	/*! True if notification status present, false otherwise. */
	bool bNotificationStatusPresent;
	
	/*! Notification status bitmask
		- 0x01: Incoming is a forwarded call
		- 0x02: Incoming call was forwarded
		- 0x04: Outgoing call was forwarded */
    U32 nNotificationStatus;			
};

///////////////////////////////////////////////////////////////////////////////
///
/// SIM Data Structures
///
///////////////////////////////////////////////////////////////////////////////

///////////////////////////////////////////////////////////////////////////////
///
/// An enumeration of SIM password types.
///
/// \sa SWI_STRUCT_SIM_Verify
/// \sa SWI_STRUCT_SIM_Password
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_SIM_Password
{
	/*! Unused password enumeration. */
	SWI_SIMPASSWORD_Reserved,
	
	/*! CHV1 (Card Holder Verification 1) is commonly referred to as PIN1.  
		This code cannot match or begin with an emergency number. */				
	SWI_SIMPASSWORD_CHV1,
	
	/*! CHV2 (Card Holder Verification 2) is commonly referred to as PIN2. */
	SWI_SIMPASSWORD_CHV2,
	
	/*! The unblocking code for CHV1 is commonly referred to as PUK1. */					
	SWI_SIMPASSWORD_UnblockingCHV1,	
	
	/*! The unblocking code for CHV2 is commonly referred to as PUK2. */		
	SWI_SIMPASSWORD_UnblockingCHV2			
};

///////////////////////////////////////////////////////////////////////////////
///
/// An enumeration of SIM status codes.
///
/// \sa SWI_STRUCT_SIM_StatusExp
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_SIM_StatusExp
{
	SWI_SIMSTATUSEXP_OK,				/*!< Success. */	
	SWI_SIMSTATUSEXP_NotInserted,		/*!< The SIM is not inserted. */
	SWI_SIMSTATUSEXP_Removed,			/*!< The SIM has been removed. */	
	SWI_SIMSTATUSEXP_InitializeFailure,	/*!< The SIM has failed to initialize*/
	SWI_SIMSTATUSEXP_GeneralFailure,	/*!< General SIM failure. */	
    SWI_SIMSTATUSEXP_Locked,			/*!< SIM is locked. */
	SWI_SIMSTATUSEXP_PIN1Blocked,		/*!< PIN1 is blocked. */
	SWI_SIMSTATUSEXP_PIN2Blocked,		/*!< PIN2 is blocked. */
	SWI_SIMSTATUSEXP_PIN1Rejected,		/*!< PIN1 is rejected. */
	SWI_SIMSTATUSEXP_PIN2Rejected,		/*!< PIN2 is rejected. */
	SWI_SIMSTATUSEXP_MEPLocked,			/*!< MEP check failed. */
	SWI_SIMSTATUSEXP_NetworkReject,		/*!< The SIM is rejected by the 
											 network. */
};

///////////////////////////////////////////////////////////////////////////////
///
/// An enumeration of required SIM operations.
///
/// \sa SWI_STRUCT_SIM_StatusExp
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_SIM_RequiredOperation
{
    SWI_REQUIREDOPERATON_NoOperation,	/*!< No operation required. */
    SWI_REQUIREDOPERATON_EnterPIN,		/*!< Enter PIN1. */
    SWI_REQUIREDOPERATON_EnterPIN2,		/*!< Enter PIN2. */
    SWI_REQUIREDOPERATON_EnterPUK,		/*!< Enter PIN1 unblocking code. */
    SWI_REQUIREDOPERATON_EnterPUK2,		/*!< Enter PIN2 unblocking code. */
    SWI_REQUIREDOPERATON_EnterMEP,		/*!< Enter MEP unlocking code. */
};

///////////////////////////////////////////////////////////////////////////////
///
/// An enumeration of previous SIM operations.
///
/// \sa SWI_STRUCT_SIM_StatusExp
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_SIM_PreviousOperation
{
    SWI_PREVIOUSOPERATION_None,			/*!< No previous operation. */
    SWI_PREVIOUSOPERATION_ChangePIN,	/*!< Change PIN1 operation. */
    SWI_PREVIOUSOPERATION_ChangePIN2,	/*!< Change PIN2 operation. */
	/*! Enable/disable PIN1 verification */
    SWI_PREVIOUSOPERATION_EnableDisablePINVerification,	
    SWI_PREVIOUSOPERATION_VerifyPIN,	/*!< Verify PIN1 operation. */
    SWI_PREVIOUSOPERATION_VerifyPIN2,	/*!< Verify PIN2 operation. */
    SWI_PREVIOUSOPERATION_VerifyPUK,	/*!< Verify PIN1 unblocking code. */
    SWI_PREVIOUSOPERATION_VerifyPUK2,	/*!< Verify PIN2 unblocking code. */
    SWI_PREVIOUSOPERATION_MEPUnlock,	/*!< Verify MEP unlocking code. */
    SWI_PREVIOUSOPERATION_EnablePIN,	/*!< Enable PIN1. */
    SWI_PREVIOUSOPERATION_DisablePIN	/*!< Disable PIN1. */
};

///////////////////////////////////////////////////////////////////////////////
///
/// An enumeration of SIM previous operation results.
///
/// \sa SWI_STRUCT_SIM_StatusExp
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_SIM_PreviousActionResult
{
	/*! Operation succeeded. */
    SWI_PREVIOUSACTIONRESULT_Succeeded,
    
    /*! Operation failed. */
    SWI_PREVIOUSACTIONRESULT_Failed,
    
    /*! Operation failed because PIN1 is not enabled. */
    SWI_PREVIOUSACTIONRESULT_PINVerifyDisabled,
    
    /*! Operation failed because the new PIN1 starts with an emergency 
		number. */
    SWI_PREVIOUSACTIONRESULT_PINStartsEmergency,
};

///////////////////////////////////////////////////////////////////////////////
///
/// An enumeration of SIM code retry information types.
///
/// \sa SWI_STRUCT_SIM_StatusExp
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_SIM_RetryInformation
{
    SWI_TYPE_RETRYINFORMATION_Pin,	/*!< PIN1 retry count. */
    SWI_TYPE_RETRYINFORMATION_Pin2,	/*!< PIN2 retry count. */
    SWI_TYPE_RETRYINFORMATION_Puk,	/*!< PIN1 unblocking code retry count. */
	SWI_TYPE_RETRYINFORMATION_Puk2,	/*!< PIN2 unblocking code retry count. */
};

///////////////////////////////////////////////////////////////////////////////
///
/// An enumeration of PIN2 kick types.
///
/// \sa SwiChv2StatusKick
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_SIM_Chv2KickType
{
	SWI_TYPE_CHV2KICKTYPE_Verify,	/*!< Verifying PIN2. */
	SWI_TYPE_CHV2KICKTYPE_Change	/*!< Changing PIN2. */
};

///////////////////////////////////////////////////////////////////////////////
///
/// This structure contains information used to unlock or unblock the SIM.
///
/// \sa SWI_TYPE_SIM_Password
/// \sa SwiSetSimVerify
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_SIM_Verify
{
	/*! The size, in bytes, of this structure.  This value must always be 
		populated by the calling application. */
	U32 sizeStruct;
	
	/*! Password type. */							
	SWI_TYPE_SIM_Password eType;
	
	/*! NULL terminated password. */								
	WCHAR szPassword[LENGTH_MaxCHV];
	
	/*! NULL terminated unblocking password. */			
	WCHAR szUnblockPassword[LENGTH_MaxCHV];	
};

///////////////////////////////////////////////////////////////////////////////
///
/// This structure contains information used to change SIM passwords.
///
/// \sa SwiSetSimPassword
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_SIM_Password
{
	/*! The size, in bytes, of this structure.  This value must always be 
		populated by the calling application. */
	U32 sizeStruct;
	
	/*! Password type. */					
	SWI_TYPE_SIM_Password eType;
	
	/*! NULL terminated old password. */								
	WCHAR szOldPassword[LENGTH_MaxCHV];	
	
	/*! NULL terminated new password. */	
	WCHAR szNewPassword[LENGTH_MaxCHV];		
};	

///////////////////////////////////////////////////////////////////////////////
///
/// This structure contains information required to enable PIN1.
///
/// \sa SwiSetSimLock
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_SIM_EnableLock
{
	/*! The size, in bytes, of this structure.  This value must always be 
		populated by the calling application. */
	U32 sizeStruct;
	
	/*! Set to true to enable PIN1, false to disable. */				
	bool bEnable;							
	
	/*! NULL terminated password. */
	WCHAR szPassword[LENGTH_MaxCHV];			
};

///////////////////////////////////////////////////////////////////////////////
///
/// This structure contains PIN1 lock state information.
///
/// \sa SwiGetSimLock
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_SIM_LockStatus
{
	/*! The size, in bytes, of this structure.  This value must always be 
		populated by the calling application. */
	U32 sizeStruct;	
	
	/*! True is returned if PIN1 enabled, false otherwise. */						
	bool bEnabled;							
};

///////////////////////////////////////////////////////////////////////////////
///
/// This structure contains the status of the SIM and lists operations that may
/// be required.  If a previous SIM operation was performed, the status of that
/// operation is also presented. 
///
/// \sa SWI_TYPE_SIM_StatusExp
/// \sa SWI_TYPE_SIM_RequiredOperation
/// \sa SWI_TYPE_SIM_PreviousOperation
/// \sa SWI_TYPE_SIM_PreviousActionResult
/// \sa SWI_TYPE_SIM_RetryInformation
/// \sa SWI_NOTIFY_SimStatusExp
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_SIM_StatusExp
{
	/*! The size, in bytes, of this structure.  */
	U32 sizeStruct;	
	
	/*! Status of the SIM. */
	SWI_TYPE_SIM_StatusExp eStatus;
	
	/*! Required SIM operation. */					
    SWI_TYPE_SIM_RequiredOperation eRequiredOperation;
    
    /*! Previous SIM operation. */
    SWI_TYPE_SIM_PreviousOperation ePreviousOperation;
    
    /*! Previous SIM operation result. */
    SWI_TYPE_SIM_PreviousActionResult ePreviousActionResult;
    
    /*! Retry information present. */
    bool bRetryInformationPresent;
    
    /*! Retry information type. */
    SWI_TYPE_SIM_RetryInformation eRetryInformation;
    
    /*! Retry count. */
	U32 nNumberRetries;			
};

///////////////////////////////////////////////////////////////////////////////
///
/// This structure contains information required to perform an MEP unlock.
///
/// \sa SwiSetMEPUnlock
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_MEP_Unlock
{
	/*! The size, in bytes, of this structure.  This value must always be 
		populated by the calling application. */
	U32 sizeStruct;	
	
	/*! NULL terminated MEP unlock code. */						
	WCHAR szUnLockCode[LENGTH_MEPCode];		
};

///////////////////////////////////////////////////////////////////////////////
//
// Supplementary Services
//
///////////////////////////////////////////////////////////////////////////////

///////////////////////////////////////////////////////////////////////////////
///
/// This enumeration  contains all of the supplementary service codes.
///
/// \sa SWI_STRUCT_SS_Request
/// \sa SWI_STRUCT_SS_PasswordReg
/// \sa SWI_STRUCT_SS_RespFwdInfo
/// \sa SWI_STRUCT_SS_RespCallBar
/// \sa SWI_STRUCT_SS_RespInfoData
/// \sa SWI_STRUCT_SS_RespError
/// \sa SWI_STRUCT_SSNotify 
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_SS_ServiceCode
{
    /*! all supplementary services */
    SWI_SERVCODE_AllServices,

    /*! all call line id services */
    SWI_SERVCODE_AllLineIdServices = 0x10,

    /*! CLIP */
    SWI_SERVCODE_CallerIdPresent,

    /*! CLIR */
    SWI_SERVCODE_CallerIdRestrict,

	/*! COLP */
    SWI_SERVCODE_ConnectIdPresent,

    /*! COLR */
    SWI_SERVCODE_ConnectIdRestrict,

    /*! MCI */
    SWI_SERVCODE_MCI,

    /*! CNAP */
    SWI_SERVCODE_CallingNamePresent = 0x19,

    /*! all call forwarding services */
    SWI_SERVCODE_CallFwdAllServices = 0x20,

    /*! CFU */
    SWI_SERVCODE_CallFwdUnconditional,

    /*! all conditional call forwarding */
    SWI_SERVCODE_CallFwdAllConditional = 0x28,

    /*! CF busy */
    SWI_SERVCODE_CallFwdBusy,

    /*! CF no reply */
    SWI_SERVCODE_CallFwdNoReply = 0x2A,

    /*! CF not reachable */
    SWI_SERVCODE_CallFwdNotReachable,

    /*! call call offering */
    SWI_SERVCODE_AllCallOffering = 0x30,

    /*! CT */
    SWI_SERVCODE_CT,

    /*! MAH */
    SWI_SERVCODE_MAH,

    /*! all call complete */
    SWI_SERVCODE_AllCallComplete = 0x40,

    /*! WAIT */
    SWI_SERVCODE_CallWaiting,

    /*! HOLD */
    SWI_SERVCODE_CallHold,

    /*! CCBS */
    SWI_SERVCODE_CompletionBusySubsciber,

    /*! all multiparty */
    SWI_SERVCODE_AllMultiparty = 0x50,

    /*! multiply */
    SWI_SERVCODE_Multiply,

    /*! all community of interest */
    SWI_SERVCODE_ALL_COMM_OF_INT = 0x60,

    /*! CUG */
    SWI_SERVCODE_ClosedUserGroup,

    /*! All charging */
    SWI_SERVCODE_AllCharging = 0x70,

    /*! AoC */
    SWI_SERVCODE_AdviceChargeInfo,

    /*! AoCC */
    SWI_SERVCODE_AdviceChargeCharging,

    /*! all additional info */
    SWI_SERVCODE_AllAdditionalInfo = 0x80,

    /*! UUS */
    SWI_SERVCODE_UserToUserSignalling,

    /*! all call restriction */
    SWI_SERVCODE_AllCallRestriction = 0x90,

    /*! all outgoing call barring */
    SWI_SERVCODE_BarrOutgoing,

    /*! BAOC */
    SWI_SERVCODE_BarrAllOutgoing,

    /*! BAOIC */
    SWI_SERVCODE_BarrOutgoingInter,

    /*! BAOIC except home*/
    SWI_SERVCODE_BarrOutgoingInterExcept,

    /*! all incoming call barring */
    SWI_SERVCODE_BarrIncoming = 0x99,

    /*! BAIC */
    SWI_SERVCODE_BarrAllIncoming,

    /*! BAIC roaming*/
    SWI_SERVCODE_BarrIncomingRoam,

    /*! all PLMN specific */
    SWI_SERVCODE_PLMNAllSpecific = 0xF0,

    /*! PLMN specific #1 */
    SWI_SERVCODE_PLMNSpecific1,

    /*! PLMN specific #2 */
    SWI_SERVCODE_PLMNSpecific2,

    /*! PLMN specific #3 */
    SWI_SERVCODE_PLMNSpecific3,

    /*! PLMN specific #4 */
    SWI_SERVCODE_PLMNSpecific4,

    /*! PLMN specific #5 */
    SWI_SERVCODE_PLMNSpecific5,

    /*! PLMN specific #6 */
    SWI_SERVCODE_PLMNSpecific6,

    /*! PLMN specific #7 */
    SWI_SERVCODE_PLMNSpecific7,

    /*! PLMN specific #8 */
    SWI_SERVCODE_PLMNSpecific8,

    /*! PLMN specific #9 */
    SWI_SERVCODE_PLMNSpecific9,

    /*! PLMN specific #A */
    SWI_SERVCODE_PLMNSpecificA,

    /*! PLMN specific #B */
    SWI_SERVCODE_PLMNSpecificB,

    /*! PLMN specific #C */
    SWI_SERVCODE_PLMNSpecificC,

    /*! PLMN specific #D */
    SWI_SERVCODE_PLMNSpecificD,

    /*! PLMN specific #E */
    SWI_SERVCODE_PLMNSpecificE,

    /*! PLMN specific #F */
    SWI_SERVCODE_PLMNSpecificF,
};

///////////////////////////////////////////////////////////////////////////////
///
/// This enumeration contains the basic service group types.
///
/// \sa SWI_STRUCT_SS_Request
/// \sa STRUCT_SS_FwdInfo
/// \sa STRUCT_SS_CALL_BAR
/// \sa STRUCT_SS_BasicServiceGroup
/// \sa SWI_STRUCT_SS_RespError
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_SS_BasicServGrpType
{
	SWI_BASICSERVGRPTYPE_TeleServices,   /*!< tele services */
	SWI_BASICSERVGRPTYPE_BearerServices  /*!< bearer services */
};

///////////////////////////////////////////////////////////////////////////////
///
/// This enumeration contains all tele services basic service groups.
///
/// \sa SWI_STRUCT_SS_Request
/// \sa STRUCT_SS_FwdInfo
/// \sa STRUCT_SS_CALL_BAR
/// \sa STRUCT_SS_BasicServiceGroup
/// \sa SWI_STRUCT_SS_RespError
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_SS_TeleBasicServGrpCode
{
	/*! all tele services */
    SWI_BASICSERVGRPCODE_TeleAllServices,
    
    /*! all speech tele services */
    SWI_BASICSERVGRPCODE_TeleAllSpeechTx = 0x10,
    
    /*! telephony */
    SWI_BASICSERVGRPCODE_TeleTelephony,
    
     /*! emergency */
    SWI_BASICSERVGRPCODE_TeleEmergency,
    
    /*! all SMS */
    SWI_BASICSERVGRPCODE_TeleAllSms = 0x20,
    
     /*! short message MT PP */
    SWI_BASICSERVGRPCODE_TeleShortMsgMTPP,
    
    /*! short message MO PP */
    SWI_BASICSERVGRPCODE_TeleShortMsgMOPP,
    
    /*! video text */
    SWI_BASICSERVGRPCODE_TeleVideoTex = 0x40,
    
    /*! tele text */
    SWI_BASICSERVGRPCODE_TeleTeleTex = 0x50,
    
    /*! all facsimile services */
    SWI_BASICSERVGRPCODE_TeleAllFaxTxServ = 0x60,
    
    /*! facsimile group 3 and alternative speech */
    SWI_BASICSERVGRPCODE_TeleFaxG3AltSpeech,
    
    /*! auto facsimile group 3 */
    SWI_BASICSERVGRPCODE_TeleAutoFaxGrp3,
    
    /*! facsimile group 4 */
    SWI_BASICSERVGRPCODE_TeleFaxGrp4,
    
    /*! all data services */
    SWI_BASICSERVGRPCODE_TeleAllDataTeleserv = 0x70, 
    
    /*! all teleservice except SMS */
    SWI_BASICSERVGRPCODE_TeleAllExceptSms = 0x80,
    
    /*! auxiliary speech */
    SWI_BASICSERVGRPCODE_TeleAuxSpeech = 0xD0,
    
    /*! auxiliary telephony */
    SWI_BASICSERVGRPCODE_TeleAuxTelephony,
    
    /*! PLMN specific teleservice 2 */
    SWI_BASICSERVGRPCODE_TelePLMNSpecBasicServ2,
    
    /*! PLMN specific teleservice 3 */
    SWI_BASICSERVGRPCODE_TelePLMNSpecBasicServ3,
    
    /*! PLMN specific teleservice 4 */
    SWI_BASICSERVGRPCODE_TelePLMNSpecBasicServ4,
    
    /*! PLMN specific teleservice 5 */
    SWI_BASICSERVGRPCODE_TelePLMNSpecBasicServ5,
    
    /*! PLMN specific teleservice 6 */
    SWI_BASICSERVGRPCODE_TelePLMNSpecBasicServ6,
    
    /*! PLMN specific teleservice 7 */
    SWI_BASICSERVGRPCODE_TelePLMNSpecBasicServ7,
    
    /*! PLMN specific teleservice 8 */
    SWI_BASICSERVGRPCODE_TelePLMNSpecBasicServ8,
    
     /*! PLMN specific teleservice 9 */
    SWI_BASICSERVGRPCODE_TelePLMNSpecBasicServ9,
    
    /*! PLMN specific teleservice 10 */
    SWI_BASICSERVGRPCODE_TelePLMNSpecBasicServA,
    
    /*! PLMN specific teleservice 11 */
    SWI_BASICSERVGRPCODE_TelePLMNSpecBasicServB,
    
    /*! PLMN specific teleservice 12 */
    SWI_BASICSERVGRPCODE_TelePLMNSpecBasicServC,
    
    /*! PLMN specific teleservice 13 */
    SWI_BASICSERVGRPCODE_TelePLMNSpecBasicServD,
    
    /*! PLMN specific teleservice 14 */
    SWI_BASICSERVGRPCODE_TelePLMNSpecBasicServE,
    
    /*! PLMN specific teleservice 15 */
    SWI_BASICSERVGRPCODE_TelePLMNSpecBasicServF,    
};
///////////////////////////////////////////////////////////////////////////////
///
/// This enumeration contains all bearer services basic service groups.
///
/// \sa SWI_STRUCT_SS_Request
/// \sa STRUCT_SS_FwdInfo
/// \sa STRUCT_SS_CALL_BAR
/// \sa STRUCT_SS_BasicServiceGroup
/// \sa SWI_STRUCT_SS_RespError
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_SS_BearerBasicServGrpCode
{
    /*! all bearer services */
    SWI_BASICSERVGRPCODE_BearAllServices = 0x00,

    /*! all data CDA services */
    SWI_BASICSERVGRPCODE_BearAllDataCDAServ	= 0x10,

    /*! data CDA 300bps */
    SWI_BASICSERVGRPCODE_BearDataCDA300,

    /*! data CDA 1200bps */
    SWI_BASICSERVGRPCODE_BearDataCDA1200,

    /*! data CDA 1200_75 */
    SWI_BASICSERVGRPCODE_BearDataCDA1200_75,

    /*! data CDA 2400bps */
    SWI_BASICSERVGRPCODE_BearDataCDA2400,

    /*! data CDA 4800bps */
    SWI_BASICSERVGRPCODE_BearDataCDA4800,

    /*! data CDA 9600bps */
    SWI_BASICSERVGRPCODE_BearDataCDA9600,

    /*! all data CDS services */
    SWI_BASICSERVGRPCODE_BearAddDataCDSServ	= 0x18,

    /*! data CDS 1200bps */
    SWI_BASICSERVGRPCODE_BearDataCDS1200 = 0x1A,

    /*! data CDS 2400bps */
    SWI_BASICSERVGRPCODE_BearDataCDS2400 = 0x1C,

    /*! data CDS 4800bps */
    SWI_BASICSERVGRPCODE_BearDataCDS4800 = 0x1D,

    /*! data CDS 9600bps */
    SWI_BASICSERVGRPCODE_BearDataCDS9600 = 0x1E,

    /*! all PAD services */
    SWI_BASICSERVGRPCODE_BearAllPADServ = 0x20,

    /*! PAD 300bps*/
    SWI_BASICSERVGRPCODE_BearPAD300,

    /*! PAD 1200bps*/
    SWI_BASICSERVGRPCODE_BearPAD1200,

    /*! PAD 1200_75bps*/
    SWI_BASICSERVGRPCODE_BearPAD1200_75,

    /*! PAD 2400bps */
    SWI_BASICSERVGRPCODE_BearPAD2400,

    /*! PAD 4800bps */
    SWI_BASICSERVGRPCODE_BearPAD4800,

    /*! PAD 9600bps */
    SWI_BASICSERVGRPCODE_BearPAD9600,

    /*! all PDS services */
    SWI_BASICSERVGRPCODE_BearAllDataPDSServ	= 0x28,

    /*! PDS 2400bps */
    SWI_BASICSERVGRPCODE_BearDataPDS2400,

    /*! PDS 4800bps */
    SWI_BASICSERVGRPCODE_BearDataPDS4800,

    /*! PDS 9600bps */
    SWI_BASICSERVGRPCODE_BearDataPDS9600,

    /*! alternate speech data CDA */
    SWI_BASICSERVGRPCODE_BearAllAltSpeechDataCDA = 0x30,

    /*! alternate speech data CDS */
    SWI_BASICSERVGRPCODE_BearAllAltSpeechDataCDS = 0x38,

    /*! all speech followed by data CDA */
    SWI_BASICSERVGRPCODE_BearAllSpeechThenDataCDA = 0x40,

    /*! all speech followed by data CDS */
    SWI_BASICSERVGRPCODE_BearAllSpeechThenDataCDS = 0x48,

    /*! all data circuit asynchronous */
    SWI_BASICSERVGRPCODE_BearAllDataCircuitAsync = 0x50,

    /*! all asynchronous services */
    SWI_BASICSERVGRPCODE_BearAllAsyncServ = 0x60,

    /*! all data circuit synchronous */ 
    SWI_BASICSERVGRPCODE_BearAllDataCircuitSync		= 0x58,

    /*! all synchronous services */
    SWI_BASICSERVGRPCODE_BearAllSyncServ = 0x68,

    /*! all PLMN specific basic services */
    SWI_BASICSERVGRPCODE_BearAllPLMNSpecBasicServ = 0xD0,

    /*! PLMN specific service 1 */
    SWI_BASICSERVGRPCODE_BearPLMNSpecBasicServ1,

    /*! PLMN specific service 2 */
    SWI_BASICSERVGRPCODE_BearPLMNSpecBasicServ2,

    /*! PLMN specific service 3 */
    SWI_BASICSERVGRPCODE_BearPLMNSpecBasicServ3,

    /*! PLMN specific service 4 */
    SWI_BASICSERVGRPCODE_BearPLMNSpecBasicServ4,

    /*! PLMN specific service 5 */
    SWI_BASICSERVGRPCODE_BearPLMNSpecBasicServ5,

    /*! PLMN specific service 6 */
    SWI_BASICSERVGRPCODE_BearPLMNSpecBasicServ6,

    /*! PLMN specific service 7 */
    SWI_BASICSERVGRPCODE_BearPLMNSpecBasicServ7,

    /*! PLMN specific service 8 */
    SWI_BASICSERVGRPCODE_BearPLMNSpecBasicServ8,

    /*! PLMN specific service 9 */
    SWI_BASICSERVGRPCODE_BearPLMNSpecBasicServ9,

    /*! PLMN specific service A */
    SWI_BASICSERVGRPCODE_BearPLMNSpecBasicServA,

    /*! PLMN specific service B */
    SWI_BASICSERVGRPCODE_BearPLMNSpecBasicServB,

    /*! PLMN specific service C */
    SWI_BASICSERVGRPCODE_BearPLMNSpecBasicServC,

    /*! PLMN specific service D */
    SWI_BASICSERVGRPCODE_BearPLMNSpecBasicServD,

    /*! PLMN specific service E */
    SWI_BASICSERVGRPCODE_BearPLMNSpecBasicServE,

    /*! PLMN specific service F */
    SWI_BASICSERVGRPCODE_BearPLMNSpecBasicServF,
};
///////////////////////////////////////////////////////////////////////////////
///
/// This enumeration represents a bitmask of different service properties.
///
/// \sa STRUCT_SS_FwdInfo 
/// \sa SWI_STRUCT_SS_RespInfoData
/// \sa SWI_STRUCT_SS_RespStatus
/// \sa SWI_STRUCT_SS_RespClir
/// \sa SWI_STRUCT_SS_RespError
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_SS_ServiceStatus
{
    SWI_STATUS_ServActiveMask = 0x01,     /*!< service is activated */
    SWI_STATUS_ServRegisteredMask = 0x02, /*!< service is registered */
    SWI_STATUS_ServProvMask = 0x04,       /*!< service is provisioned */
    SWI_STATUS_ServQuiescentMask = 0x08   /*!< service is dormant */
};
///////////////////////////////////////////////////////////////////////////////
///
/// This enumeration represents a bitmask of different call forwarding
/// options associated with the subscriber's account.
///
/// \sa STRUCT_SS_FwdInfo 
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_SS_ForwardOption
{   
    /*! notify forwarding party */
    SWI_FORWARDOPTION_NotifyFwdParyMask = 0x80,

    /*! notify called party */
    SWI_FORWARDOPTION_NotifyCalledPartyMask = 0x20,

    /*! mobile not reachable */
    SWI_FORWARDOPTION_MobileNotReachMask = 0x00,

    /*! forward when mobile is busy */
    SWI_FORWARDOPTION_FwdBusyMask = 0x04,

    /*! forward when not reachable */
    SWI_FORWARDOPTION_FwdNotReach = 0x08, 

    /*! forward all calls */
    SWI_FORWARDOPTION_FwdAllCalls = 0x0C,
};

///////////////////////////////////////////////////////////////////////////////
///
/// This enumeration contains subscription options types.
///
/// \sa SWI_TYPE_SS_SubsOptionCode
/// \sa SWI_STRUCT_SS_RespInfoData
/// \sa SWI_STRUCT_SS_RespError
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_SS_SubsOptionType
{
    SWI_SUBSOPTIONTYPE_Override = 0x01,  /*!< override */
    SWI_SUBSOPTIONTYPE_CLIR,             /*!< caller line id restriction */
};

///////////////////////////////////////////////////////////////////////////////
///
/// This enumeration contains subscription options codes.
///
/// \sa SWI_TYPE_SS_SubsOptionType
/// \sa SWI_STRUCT_SS_RespInfoData
/// \sa SWI_STRUCT_SS_RespError
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_SS_SubsOptionCode
{
	/*! Override enabled */
    SWI_SUBSOPTIONCODE_OverrideEnabled = 0x00,
    
    /*! Override disabled */ 
    SWI_SUBSOPTIONCODE_OverrideDisabled = 0x01,
    
    /*! CLIR setting permanent */
    SWI_SUBSOPTIONCODE_ClirPermanent = 0x00,
    
    /*! CLIR by default restricted */
    SWI_SUBSOPTIONCODE_TempCallIdRestrict = 0x01, 

	/*! CLIR by default allowed */
    SWI_SUBSOPTIONCODE_TempCallIdAllow = 0x02     
};

///////////////////////////////////////////////////////////////////////////////
///
/// This enumeration contains all possible CLIR settings.
///
/// \sa SWI_STRUCT_SS_RespClir 
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_SS_CLIRSetting
{
    SWI_CLIRSETTING_Permanent,          /*!< permanent */
    SWI_CLIRSETTING_TempCallIdRestrict, /*!< temporarily restricted */
    SWI_CLIRSETTING_TempCallIdAllow     /*!< temporarily allowed */
};

///////////////////////////////////////////////////////////////////////////////
///
/// This enumeration contains supplementary services error codes.
///
/// \sa SWI_STRUCT_SS_RespError 
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_SS_ErrorCode
{
    /*! unknown subscriber */
    SWI_ERRORCODE_UnknownSubs = 0x01,

    /*! illegal subscriber */ 
    SWI_ERRORCODE_IllegalSubs	= 0x09,

    /*! bearer service not provisioned */
    SWI_ERRORCODE_BearServNotProv,

    /*! teleservice not provisioned */
    SWI_ERRORCODE_TellServNotProv,

    /*! illegal device */
    SWI_ERRORCODE_IllegalEquip,

    /*! call barred */
    SWI_ERRORCODE_CallBarred,

    /*! illegal operation */
    SWI_ERRORCODE_IllegalOper	= 0x10,

    /*! error status */
    SWI_ERRORCODE_ErrorStatus,

    /*! not available */
    SWI_ERRORCODE_NotAvail,

    /*! subscription violation */
    SWI_ERRORCODE_SubsViolate,

    /*! incompatible */
    SWI_ERRORCODE_Incompatible,

    /*! facility not supported */
    SWI_ERRORCODE_FacilityNotSup,

    /*! absent subscriber */
    SWI_ERRORCODE_AbsentSubs = 0x1B,

    /*! system failed */
    SWI_ERRORCODE_SystemFail = 0x22,

    /*! data missing */
    SWI_ERRORCODE_DataMissing,

    /*! unexpected value */
    SWI_ERRORCODE_UnexpectValue,

    /*! password registration failed */
    SWI_ERRORCODE_PasswdRegFail,

    /*! incorrect password */
    SWI_ERRORCODE_NegPasswdChk,

    /*! entered incorrect password too many times */
    SWI_ERRORCODE_NumPasswdViolate = 0x2B,

    /*! unknown alphabet */
    SWI_ERRORCODE_UnknownAlphabet = 0x47,

    /*! unstructured supplementary services busy */
    SWI_ERRORCODE_UssdBusy,

    /*! maximum supplementary services option exceeded */
    SWI_ERRORCODE_MaxMultiExceed = 0x7E,

    /*! resources not available */
    SWI_ERRORCODE_ResourceNotAvail,
};

///////////////////////////////////////////////////////////////////////////////
///
/// This enumeration contains supplementary services error types.
///
/// \sa SWI_STRUCT_SS_RespError 
/// \sa SWI_TYPE_SS_CallBar
/// \sa SWI_TYPE_SS_SystemFail
/// \sa SWI_TYPE_SS_PasswdRegFail
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_SS_ErrorType
{
    SWI_ERRORTYPE_NoInfo,        /*!< no information */
    SWI_ERRORTYPE_CallBarring,   /*!< call barring */
    SWI_ERRORTYPE_Status,        /*!< status */
    SWI_ERRORTYPE_SubsViolate,   /*!< subscription violation */
    SWI_ERRORTYPE_AbsentSubs,    /*!< absent subscriber */
    SWI_ERRORTYPE_SystemFail,    /*!< system failure */
    SWI_ERRORTYPE_PasswdRegFail, /*!< password registration failed */
    SWI_ERRORTYPE_Incompatible,  /*!< incompatible */
};

///////////////////////////////////////////////////////////////////////////////
///
/// This enumeration contains the call barring reason for a 
/// SWI_ERRORTYPE_CallBarring error type.
///
/// \sa SWI_TYPE_SS_ErrorType
/// \sa SWI_STRUCT_SS_RespError
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_SS_CallBar
{
    SWI_CALLBAR_Active,          /*!< call barring is activated */
    SWI_CALLBAR_OperatorBarring, /*!< operator barred */ 
};

///////////////////////////////////////////////////////////////////////////////
///
/// This enumeration contains reason information for the occurrence of a  
/// SWI_ERRORTYPE_SystemFail error.
///
/// \sa SWI_TYPE_SS_ErrorType
/// \sa SWI_STRUCT_SS_RespError
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_SS_SystemFail
{
    SWI_SYSTEMFAIL_Plmn,
    SWI_SYSTEMFAIL_Hlr,
    SWI_SYSTEMFAIL_Vlr,
    SWI_SYSTEMFAIL_Pvlr,
    SWI_SYSTEMFAIL_ControlMsc,
    SWI_SYSTEMFAIL_VisitMsc,
    SWI_SYSTEMFAIL_Eir,
    SWI_SYSTEMFAIL_Rss,
};

///////////////////////////////////////////////////////////////////////////////
///
/// This enumeration contains reason information for the occurrence of a  
/// SWI_ERRORTYPE_PasswdRegFail error.
///
/// \sa SWI_TYPE_SS_ErrorType
/// \sa SWI_STRUCT_SS_RespError
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_SS_PasswdRegFail
{
    SWI_PASSWDFAILREASON_Undetermined,
    SWI_PASSWDFAILREASON_InvalidFormat,
    SWI_PASSWDFAILREASON_NewMismatch,
};

///////////////////////////////////////////////////////////////////////////////
///
/// This enumeration contains all supplementary services problem types.
///
/// \sa SWI_STRUCT_SS_RespReject 
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_SS_ProblemType
{
    SWI_PROBLEMTYPE_General,
    SWI_PROBLEMTYPE_Invoke,
    SWI_PROBLEMTYPE_ReturnResult,
    SWI_PROBLEMTYPE_ReturnError,
};

///////////////////////////////////////////////////////////////////////////////
///
/// This enumeration contains all supplementary services reject codes.
///
/// \sa SWI_STRUCT_SS_RespReject 
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_SS_RejectCode
{
    SWI_REJECTCODE_GeneralUnrecognize = 0x00,
    SWI_REJECTCODE_GeneralMistype = 0x01,
    SWI_REJECTCODE_GeneralBadStruct = 0x02,
    SWI_REJECTCODE_InvokeDupId = 0x00,
    SWI_REJECTCODE_InvokeUnrecognizeId = 0x01,
    SWI_REJECTCODE_InvokeMistype = 0x02,
    SWI_REJECTCODE_InvokeResource = 0x03,
    SWI_REJECTCODE_InvokeInitRelease = 0x04,
    SWI_REJECTCODE_InvokeUnrecognizeLink = 0x05,
    SWI_REJECTCODE_InvokeLinkRspUnexpect = 0x06,
    SWI_REJECTCODE_InvokeLinkOpUnexpect = 0x07,
    SWI_REJECTCODE_ResultUnrecognizeId = 0x00,
    SWI_REJECTCODE_ResultUnexpected = 0x01,
    SWI_REJECTCODE_ResultMistype = 0x02,
    SWI_REJECTCODE_ErrorUnrecognizeId = 0x00,
    SWI_REJECTCODE_ErrorUnexpected = 0x01,
    SWI_REJECTCODE_ErrorUnrecognizedErr = 0x02,
    SWI_REJECTCODE_ErrorUnexpectedErr = 0x03,
    SWI_REJECTCODE_ErrorMistype = 0x04,
};

///////////////////////////////////////////////////////////////////////////////
///
/// This enumeration contains all supplementary services cancel reasons.
///
/// \sa SWI_STRUCT_SS_RespCancel 
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_SS_CancelReason
{
    SWI_CANCELREASON_NoPipes,
    SWI_CANCELREASON_OngoingTrans,
    SWI_CANCELREASON_MnssReject,
    SWI_CANCELREASON_NoControl,
    SWI_CANCELREASON_InvalidId,
};

///////////////////////////////////////////////////////////////////////////////
///
/// This enumeration contains supplementary services password guidance.
///
/// \sa SWI_STRUCT_SS_PasswordStatus 
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_SS_PasswordGuidance
{
    SWI_SSPASSWORDGUIDANCE_Password,
    SWI_SSPASSWORDGUIDANCE_NewPassword,
    SWI_SSPASSWORDGUIDANCE_NewPasswordAgain,
    SWI_SSPASSWORDGUIDANCE_BadPassword,
    SWI_SSPASSWORDGUIDANCE_BadPasswordFormat
};

///////////////////////////////////////////////////////////////////////////////
///
/// This enumeration contains supplementary services request types.
///
/// \sa SWI_STRUCT_SS_Request 
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_SS_RequestType
{
    SWI_SSREQUESTTYPE_Erase = 0x01,
    SWI_SSREQUESTTYPE_Activate,
    SWI_SSREQUESTTYPE_Deactivate,
    SWI_SSREQUESTTYPE_Interrogate,
    SWI_SSREQUESTTYPE_Register
};

///////////////////////////////////////////////////////////////////////////////
///
/// This enumeration contains supplementary services request status.
///
/// \sa SWI_STRUCT_SS_Request 
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_SS_RequestStatus
{
    /*! request proceeding */
    SWI_SSREQUESTSTATUS_Processing = 0x00,

    /*! request rejected due to FDN mismatch */
    SWI_SSREQUESTSTATUS_Fdn
};

///////////////////////////////////////////////////////////////////////////////
///
/// This structure is used to send a supplementary service request to 
/// the device.  The caller must fill in all members in this structure
/// with the exception of the nHandle and the eRequestStatus.  The nHandle 
/// and eRequestStatus values are returned to the caller.
///
/// \sa SwiSetSSRequest 
/// \sa SWI_TYPE_SS_RequestType
/// \sa SWI_TYPE_SS_ServiceCode
/// \sa SWI_TYPE_SS_BasicServGrpType
/// \sa SWI_TYPE_SS_RequestStatus 
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_SS_Request
{
    /*! The size, in bytes, of this structure.  This value must always be 
		populated by the calling application. */
    U32 sizeStruct;

    /*! Unused member */
    U32 nVersion;

    /*! Supplementary services handle for this request. 
        This handle is returned by the device */
    U32 nHandle;

    /*! Supplementary services request type */
    SWI_TYPE_SS_RequestType eRequestType;

    /*! Supplementary service code */
    SWI_TYPE_SS_ServiceCode eSuppServiceCode;

    /*! Basic service group information */
    bool bBasicServGrpInfo;

    /*! Basic service group type */
    SWI_TYPE_SS_BasicServGrpType eBasicServGrpType;

    /*! Basic service group code */
    UINT eBasicServGrpCode;

    /*! International number flag.  True for '+' number, false otherwise. */
    bool bInternationalNumFlag;

    /*! Length of number to be forwarded to */
    U32 nLengthFwdNum;

    /*! Forwarding number.  8-bit BCD */
    U8 byFwdNum[LENGTH_ForwardNumber];

    /*! No reply info present flag */
    bool bNoReplyInfoPresent;

    /*! No reply time in seconds.  Valid range from 5 seconds to 30 seconds. */
    INT nNoReplyTime;

    /*! Supplementary services string present.  The string should be included
        if FDN is supported. */
    bool bStringPresent;

    /*! Length of the supplementary services string */
    U32 nLengthSSString;

    /*! Supplementary services string entered by user.  8-bit BCD.  
		- '*' represented by 0x0A 
		- '#' represented by 0x0B 
        For example: "*#21#"  would be sent as 0x0A 0x0b 0x02 0x01 0x0A */
    U8 bySSString[LENGTH_SSString];

    /*! Request status  */
    SWI_TYPE_SS_RequestStatus eRequestStatus;
};

///////////////////////////////////////////////////////////////////////////////
///
/// This structure is used to abort an outstanding supplementary service 
/// request.
///
/// \sa SwiAbortRequest 
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_SS_Abort
{
    /*! The size, in bytes, of this structure.  This value must always be 
		populated by the calling application. */
    U32 sizeStruct;

    /*! unused member */
    U32 nVersion;

    /*! supplementary services handle of the request to be aborted. */ 
    U32 nHandle;
};

///////////////////////////////////////////////////////////////////////////////
///
/// This structure is used to initiate the registration of a supplementary
/// services password
///
/// \sa SwiStartSSPassReg
/// \sa SWI_TYPE_SS_ServiceCode
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_SS_PasswordReg
{
    /*! The size, in bytes, of this structure.  This value must always be 
		populated by the calling application. */
    U32 sizeStruct;

    /*! Unused member */
    U32 nVersion;

    /*! Supplementary service handle returned by API */ 
    U32 nHandle;

    /*! The supplementary service code of the kind of password to be registered.  
        Valid codes are:  SWI_SERVCODE_AllServices and 
        SWI_SERVCODE_AllCallRestriction. */
    SWI_TYPE_SS_ServiceCode eSuppServiceCode;
};

///////////////////////////////////////////////////////////////////////////////
///
/// This structure is used as part of the supplementary services password
/// registration process.  The process includes the entering of the old
/// password, a new password and then new password again.  This structure
/// is used to send a single one of these passwords to the network when 
/// it has been requested in a SWI_NOTIFY_SSPasswordStatus notification.
///
/// \sa SwiSetSSPassword 
/// \sa SWI_NOTIFY_SSPasswordStatus 
/// \sa SWI_TYPE_SS_PasswordGuidance
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_SS_PasswordStatus
{
    /*! The size, in bytes, of this structure.  This value must always be 
        populated by the calling application. */
    U32 sizeStruct;

    /*! Unused member */
    U32 nVersion;

    /*! The supplementary services handle returned by either
        the SwiStartSSPassReg or SwiStartSSPassReg API */
    U32 nHandle;

    /*! Length of password.  Valid length is from 1 to 4 */
    U32 nPasswordLength;

    /*! Password.  8-bit BCD */
    U8 byPassword[LENGTH_SSPassword];

    /*! Kind of password */
    SWI_TYPE_SS_PasswordGuidance ePasswordGuidance; 
};

///////////////////////////////////////////////////////////////////////////////
///
/// This structure is used in the SWI_NOTIFY_SSRespOK notification 
///
/// \sa SWI_NOTIFY_SSRespOK 
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_SS_RespOK
{
    /*! The size, in bytes, of this structure */
    U32 sizeStruct;

    /*! unused member */
    U32 nVersion;

    /*! the supplementary services handle of the completed request */
    U32 nHandle;
};

///////////////////////////////////////////////////////////////////////////////
///
/// This structure gives forwarding information.
///
/// \sa SWI_STRUCT_SS_RespFwdInfo
/// \sa SWI_TYPE_SS_BasicServGrpType
/// \sa SWI_TYPE_SS_ServiceStatus
/// \sa SWI_TYPE_SS_ForwardOption
///
///////////////////////////////////////////////////////////////////////////////
struct STRUCT_SS_FwdInfo
{
    /*! basic service group information present flag */
    bool bBasicServGrpInfoPresent;

    /*! basic service group type */
    SWI_TYPE_SS_BasicServGrpType eBasicServGrpType;

    /*! basic service group code */
    UINT eBasicServGrpCode;

    /*! service status information present flag */
    bool bServStatusInfoPresent;

    /*! service status */
    SWI_TYPE_SS_ServiceStatus eServStatus;

    /*! international number flag.  - TRUE for '+' number - FALSE otherwise */
    bool bInternational;

    /*! length of the forwarding number */
    U32 nLengthFwdNum;

    /*! forwarding number.  - 8-bit BCD */
    U8 byFwdNum[LENGTH_ForwardInfo];

    /*! forward options information present flag */
    bool bFwdOptionsInfoPresent;

    /*! forwarding options */
    SWI_TYPE_SS_ForwardOption eFwdOptions;

    /*! no reply time information present flag */
    bool bNoReplyTimePresent;

    /*! no reply time.  valid range is between 5 and 30 seconds */
    U32 NoReplyTime;
};

///////////////////////////////////////////////////////////////////////////////
///
/// This structure is used in the SWI_NOTIFY_SSRespFwdInfo notification 
///
/// \sa SWI_NOTIFY_SSRespFwdInfo 
/// \sa SWI_TYPE_SS_ServiceCode
/// \sa STRUCT_SS_FwdInfo
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_SS_RespFwdInfo
{
    /*! The size, in bytes, of this structure */
    U32 sizeStruct;

    /*! unused member */
    U32 nVersion;

    /*! the supplementary services handle of the completed request */
    U32 nHandle;

    /*! service code present flag */
    bool bServiceCodePresent;

    /*! service code */
    SWI_TYPE_SS_ServiceCode eServiceCode;

    /*! number of entries in the list */
    U32 nNumEntries;

    /*! list of forwarding number information  */
    STRUCT_SS_FwdInfo sList[MAX_FWD_INFO_ENTRIES];
};

///////////////////////////////////////////////////////////////////////////////
///
/// This structure is used in the SWI_NOTIFY_SSRespFwdList notification. 
///
/// \sa SWI_NOTIFY_SSRespFwdList
/// \sa STRUCT_SS_FwdInfo
///
////////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_SS_RespListFwdInfo
{
    /*! The size, in bytes, of this structure */
    U32 sizeStruct;

    /*! unused member */
    U32 nVersion;

    /*! the supplementary services handle of the completed request */
    U32 nHandle;

    /*! number of entries in the list */
    U32 nNumEntries;

    /*! list of forwarding number information */
    STRUCT_SS_FwdInfo sList[MAX_FWD_INFO_ENTRIES];
};

///////////////////////////////////////////////////////////////////////////////
///
/// This structure is gives call barring informaiton. 
///
/// \sa SWI_STRUCT_SS_RespCallBar
///
///////////////////////////////////////////////////////////////////////////////
struct STRUCT_SS_CALL_BAR
{
    /*! basic service group information present flag */
    bool bBasicServGrpInfoPresent;

    /*! basic service group type */
    SWI_TYPE_SS_BasicServGrpType eBasicServGrpType;

    /*! basic service group code */
    UINT eBasicServGrpCode;

    /*! service status information present */
    bool bServStatusInfoPresent;

    /*! service status */
    UINT nServStatus;
};

///////////////////////////////////////////////////////////////////////////////
///
/// This structure is use in the SWI_NOTIFY_SSRespCallBar notification.
///
/// \sa SWI_NOTIFY_SSRespCallBar
/// \sa SWI_TYPE_SS_ServiceCode
/// \sa STRUCT_SS_CALL_BAR
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_SS_RespCallBar
{
    /*! The size, in bytes, of this structure */
    U32 sizeStruct;

    /*! unused member */
    U32 nVersion;

    /*! the supplementary services handle of the completed request */
    U32 nHandle;

    /*! service code present flag */
    bool bServiceCodePresent;

    /*! service code */
    SWI_TYPE_SS_ServiceCode eServiceCode;

    /*! number of entries in the list */
    U32 nNumEntries;

    /*! list of call barring information */
    STRUCT_SS_CALL_BAR sList[MAX_FWD_INFO_ENTRIES];
};

///////////////////////////////////////////////////////////////////////////////
///
/// This structure is contains basic servic group information.
///
/// \sa SWI_TYPE_SS_BasicServGrpType
/// \sa SWI_STRUCT_SS_RespInfoData
/// \sa SWI_STRUCT_SS_RespBSList
///
///////////////////////////////////////////////////////////////////////////////
struct STRUCT_SS_BasicServiceGroup
{
    /*! basic service group type */
    SWI_TYPE_SS_BasicServGrpType eBasicServGrpType;

    /*! basic service group code */
    UINT eBasicServGrpCode;
};

///////////////////////////////////////////////////////////////////////////////
///
/// This structure is used for the SWI_NOTIFY_SSRespInfoData notification.
///
/// \sa SWI_NOTIFY_SSRespInfoData 
/// \sa SWI_TYPE_SS_ServiceCode
/// \sa SWI_TYPE_SS_ServiceStatus
/// \sa SWI_TYPE_SS_SubsOptionType
/// \sa SWI_TYPE_SS_SubsOptionCode
/// \sa STRUCT_SS_BasicServiceGroup
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_SS_RespInfoData
{
    /*! The size, in bytes, of this structure */
    U32 sizeStruct;

    /*! unused member */
    U32 nVersion;

    /*! the supplementary services handle of the completed request */
    U32 nHandle;

    /*! service code present flag */
    bool bServiceCodePresent;

    /*! service code */
    SWI_TYPE_SS_ServiceCode eServiceCode;

    /*! service status present flag */
    bool bServStatusPresent;

    /*! service status */
    SWI_TYPE_SS_ServiceStatus eServStatus;

    /*! subscription option information present flag */
    bool bOptionInfoPresent;

    /*! subscription option type */
    SWI_TYPE_SS_SubsOptionType eSubsOptionType;

    /*! subscription option code */
    SWI_TYPE_SS_SubsOptionCode eSubsOptionCode;

    /*! number of entries in the list */
    U32 nNumEntries;

    /*! list of basic service groups */
    STRUCT_SS_BasicServiceGroup sList[MAX_INFO_DATA];
};

///////////////////////////////////////////////////////////////////////////////
///
/// This structure is used for the SWI_NOTIFY_SSRespStatus notification.
///
/// \sa SWI_NOTIFY_SSRespStatus 
/// \sa SWI_TYPE_SS_ServiceStatus 
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_SS_RespStatus
{
    /*! The size, in bytes, of this structure */
    U32 sizeStruct;

    /*! unused member */
    U32 nVersion;

    /*! the supplementary services handle of the completed request */
    U32 nHandle;

    /*! service status */
    SWI_TYPE_SS_ServiceStatus eServStatus;
};

///////////////////////////////////////////////////////////////////////////////
///
/// This structure is used for the SWI_NOTIFY_SSRespFwdNum notification.
///
/// \sa SWI_NOTIFY_SSRespFwdNum
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_SS_RespFwdNum
{
    /*! The size, in bytes, of this structure */
    U32 sizeStruct;

    /*! Unused member */
    U32 nVersion;

    /*! The supplementary services handle of the completed request */
    U32 nHandle;

    /*! International number flag.  True for '+' number, false otherwise */
    bool bInternational;

    /*! Length of number to be forwarded to */
    U32 nLengthFwdNum;

    /*! Forwarding number.  8-bit BCD */
    U8 byFwdNum[LENGTH_ForwardNumber];
};

///////////////////////////////////////////////////////////////////////////////
///
/// This structure is used for the SWI_NOTIFY_SSRespFwdNum notification.
///
/// \sa SWI_NOTIFY_SSRespFwdNum
/// \sa STRUCT_SS_BasicServiceGroup 
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_SS_RespBSList
{
    /*! The size, in bytes, of this structure */
    U32 sizeStruct;

    /*! unused member */
    U32 nVersion;

    /*! the supplementary services handle of the completed request */
    U32 nHandle;

    /*! number of entries in the list */
    U32 nNumEntries;

    /*! list of basic service groups */
    STRUCT_SS_BasicServiceGroup sList[MAX_BS_LIST];
};

///////////////////////////////////////////////////////////////////////////////
///
/// This structure is used for the SWI_NOTIFY_SSRespRaw notification.
///
/// \sa SWI_NOTIFY_SSRespRaw
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_SS_RespRaw
{
    /*! The size, in bytes, of this structure */
    U32 sizeStruct;

    /*! unused member */
    U32 nVersion;

    /*! the supplementary services handle of the completed request */
    U32 nHandle;

    /*! length of raw data */
    U32 nLength;

    /*! raw binary data */
    U8 byData[LENGTH_RawData];
};

///////////////////////////////////////////////////////////////////////////////
///
/// This structure is used for the SWI_NOTIFY_SSRespPassword notification.
///
/// \sa SWI_NOTIFY_SSRespPassword
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_SS_RespPassword
{
    /*! The size, in bytes, of this structure */
    U32 sizeStruct;

    /*! Unused member */
    U32 nVersion;

    /*! The supplementary services handle of the completed request */
    U32 nHandle;

    /*! Length of the password.  Valid range is from 1 to 4 digits. */
    U32 nPasswordLength;

    /*! Password.  8bit BCD */
    U8 byPassword[LENGTH_SSPassword];
};

///////////////////////////////////////////////////////////////////////////////
///
/// This structure is used for the SWI_NOTIFY_SSRespClir notification.
///
/// \sa SWI_NOTIFY_SSRespClir
/// \sa SWI_TYPE_SS_ServiceStatus 
/// \sa SWI_TYPE_SS_CLIRSetting 
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_SS_RespClir
{
    /*! The size, in bytes, of this structure */
    U32 sizeStruct;

    /*! unused member */
    U32 nVersion;

    /*! the supplementary services handle of the completed request */
    U32 nHandle;

    /*! service status */
    SWI_TYPE_SS_ServiceStatus	eServStatus;

    /*! CLIR setting */
    SWI_TYPE_SS_CLIRSetting eClir;
};

///////////////////////////////////////////////////////////////////////////////
///
/// This structure is used for the SWI_NOTIFY_SSRespError notification.
///
/// \sa SWI_NOTIFY_SSRespError
/// \sa SWI_TYPE_SS_ErrorCode
/// \sa SWI_TYPE_SS_ErrorType
/// \sa SWI_TYPE_SS_SubsOptionType
/// \sa SWI_TYPE_SS_SubsOptionCode
/// \sa SWI_TYPE_SS_ServiceCode
/// \sa SWI_TYPE_SS_BasicServGrpType
/// \sa SWI_TYPE_SS_ServiceStatus
/// \sa SWI_TYPE_SS_CallBar
/// \sa SWI_TYPE_SS_SystemFail 
/// \sa SWI_TYPE_SS_PasswdRegFail 
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_SS_RespError
{
    /*! The size, in bytes, of this structure */
    U32 sizeStruct;

    /*! unused member */
    U32 nVersion;

    /*! the supplementary services handle of the completed request */
    U32 nHandle;

    /*! error code */
    SWI_TYPE_SS_ErrorCode eErrorCode;

    /*! error type */
    SWI_TYPE_SS_ErrorType eErrorType;
	
    struct SubscriptionViolation
    {
        /*! subscription option type */
        SWI_TYPE_SS_SubsOptionType eSubsOptionType;

        /*! subscription option code */
        SWI_TYPE_SS_SubsOptionCode eSubsOptionCode;
    };

    struct IncompatibilityReason
    {
        /*! service code present flag */
        bool bServiceCodePresent;

        /*! service code */
        SWI_TYPE_SS_ServiceCode eServiceCode;

        /*! basic service group present flag */
        bool bBasicServGrpPresent;

        /*! basic service group type */
        SWI_TYPE_SS_BasicServGrpType eBasicServGrpType;

        /*! basic service group code */
        UINT eBasicServGrpCode;

        /*! service status information present */
        bool bServStatusInfoPresent;

        /*! service status */
        SWI_TYPE_SS_ServiceStatus eServStatusErr;
    };

    union ErrorCause
    {
        /*! call barring error cause info */
        SWI_TYPE_SS_CallBar eCallBarring;

        /*! service status error cause info */					
        SWI_TYPE_SS_ServiceStatus eServStatus;

        /*! absent subscriber flag */
        bool bAbsentSubs;

        /*! system failure error cause info */
        SWI_TYPE_SS_SystemFail eSystemFail;

        /*! password registration failure reason */
        SWI_TYPE_SS_PasswdRegFail ePasswdRegFail;

        /*! subscription violation error cause */
        SubscriptionViolation sSubscripViolation;

        /*! incompatibility reason */
        IncompatibilityReason sIncompatibilityReason;
    };

    /*! error cause type */
    ErrorCause uErrorCause;
};

///////////////////////////////////////////////////////////////////////////////
///
/// This structure is used for the SWI_NOTIFY_SSRespReject notification.
///
/// \sa SWI_NOTIFY_SSRespError
/// \sa SWI_TYPE_SS_RejectCode
/// \sa SWI_TYPE_SS_ProblemType
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_SS_RespReject
{
    /*! The size, in bytes, of this structure */
    U32 sizeStruct;

    /*! unused member */
    U32 nVersion;

    /*! the supplementary services handle of the completed request */
    U32 nHandle;

    /*! problem type */
    SWI_TYPE_SS_ProblemType eProblemType;
	
    /*! reject code */
    SWI_TYPE_SS_RejectCode eRejectCode;
};

///////////////////////////////////////////////////////////////////////////////
///
/// This structure is used for the SWI_NOTIFY_SSRespCancel notification.
///
/// \sa SWI_NOTIFY_SSRespCancel
/// \sa SWI_TYPE_SS_CancelReason
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_SS_RespCancel
{
   /*! The size, in bytes, of this structure */
    U32 sizeStruct;

    /*! unused member */
    U32 nVersion;

    /*! the supplementary services handle of the completed request */
    U32 nHandle;

    /*! cancel reason */
    SWI_TYPE_SS_CancelReason eCancelReason;
};

///////////////////////////////////////////////////////////////////////////////
///
/// This structure is used for the SWI_NOTIFY_SSRespRelease notification.
///
/// \sa SWI_NOTIFY_SSRespRelease
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_SS_RespRelease
{
   /*! The size, in bytes, of this structure */
    U32 sizeStruct;

    /*! unused member */
    U32 nVersion;

    /*! the supplementary services handle of the completed request */
    U32 nHandle;
};

///////////////////////////////////////////////////////////////////////////////
///
/// This structure is used for the SWI_NOTIFY_SSNotify notification.
///
/// \sa SWI_NOTIFY_SSNotify
/// \sa SWI_TYPE_SS_ServiceCode 
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_SSNotify
{	
   /*! The size, in bytes, of this structure */
    U32 sizeStruct;

    /*! unused member */
    U32 nVersion;

    /*! service code */
    SWI_TYPE_SS_ServiceCode eServiceCode;
};

///////////////////////////////////////////////////////////////////////////////
///
/// The notification delivers unstructured supplementary service information 
/// to the application.
/// 
/// This structure is used in the SWI_NOTIFY_SuplementryServiceReq 
/// notification.
///
/// \sa SWI_NOTIFY_SuplementryServiceReq
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_UnstructSupplServiceExp
{
	/*! The size, in bytes, of this structure */
    U32 sizeStruct;
    
    /*! Version of unstructured supplementary service expanded.  Ignore this
		field. */
    U32 nVersion;
    
    /*! Supplementary service handle. */
    U32 nHandle;
    
    /*! False is returned if no user response required, true otherwise. */
    bool bUserResponseReq;
    
    /*! Request response status */
    SWI_TYPE_SS_RequestStatus eRequestStatus;
    
    /*! Count of characters in the byMessage.  BZ9405 */
    U32 nCntChars;
    
    /*! Raw USSD message for user (GSM code). */
    U8 byMessage[LENGTH_USSDInputExp];
};

///////////////////////////////////////////////////////////////////////////////
///
/// SIM Toolkit (STK)
///
/// STK is not supported in this SDK
///
///////////////////////////////////////////////////////////////////////////////

enum SWI_TYPE_STK_TextType
{
	SWI_STKTEXTTTYPE_HelpData           = 0x01,
	SWI_STKTEXTTTYPE_DisplayText        = 0x02,
	SWI_STKTEXTTTYPE_DefaultDisplayText = 0x04,
	SWI_STKTEXTTTYPE_MenuTitle          = 0x08,
	SWI_STKTEXTTTYPE_MenuSelection      = 0x10
};

enum SWI_TYPE_STK_STKCommand
{
	SWI_STKCOMMANDTYPE_None,
	SWI_STKCOMMANDTYPE_MainMenu,
	SWI_STKCOMMANDTYPE_DisplayText,
	SWI_STKCOMMANDTYPE_GetInput,
	SWI_STKCOMMANDTYPE_GetInkey,
	SWI_STKCOMMANDTYPE_CallSetup,
	SWI_STKCOMMANDTYPE_SelectMenu
};

enum SWI_TYPE_STK_Operation
{
	SWI_STKOPERATIONTYPE_MainMenu,
    SWI_STKOPERATIONTYPE_Timeout,
    SWI_STKOPERATIONTYPE_UserAcknowledgement,
    SWI_STKOPERATIONTYPE_GetInput,
    SWI_STKOPERATIONTYPE_GetUserConfirmation,
    SWI_STKOPERATIONTYPE_MenuSelection
};

enum SWI_TYPE_STK_UserResponse
{
    SWI_STKUSERRESPONSE_No,
    SWI_STKUSERRESPONSE_Yes
};

enum SWI_TYPE_STK_Key
{
    SWI_STYKEY_Digit,
    SWI_STYKEY_GSMAlphabet,
    SWI_STYKEY_Unicode
};

enum SWI_TYPE_STKPriority
{
    SWI_STKPRIORITY_Normal,
    SWI_STKPRIORITY_High
};

struct SWI_STRUCT_STK_Command
{
	U32		                sizeStruct;
    U32                     nSTK_Handle;
 	SWI_TYPE_STK_TextType   eTextType;
    U32                     nMenuSelectionNumber;           ///(0x01- 0xFF)
    bool                    bMore;                          ///false-no more data available true-more data available (use another set operation to get the remainder of the string )
    U32                     cntWCHAR;                       ///Number of UCS2 characters in the following string
    WCHAR                   wText [LENGTH_STKCommand];      ///variable length string (max length 236 bytes) always coded in UCS2)
};

struct SWI_STRUCT_STK_Notif_Command
{
	U32						sizeStruct;		/// size of this structure
    U32                     nSTK_Handle;
    U32                     nTimeout;
    SWI_TYPE_STK_STKCommand eSTKCommand;
    SWI_TYPE_STK_Operation  eOperation;
    SWI_TYPE_STK_TextType   eTextType;
    U32                     nMinLengthOfInputExpected;
    U32                     nMaxLengthOfInputExpected;
    bool                    bEcho;         ///false-Don't Echo to user (present '*' characters instead) true-Echo characters to user
    SWI_TYPE_STK_Key        eKeyType;
    U32                     cntItemsInMenu;
    SWI_TYPE_STKPriority    ePriority;
};

///////////////////////////////////////////////////////////////////////////////
///
///This structure contains information for SIM authentication.
///
/// \sa SwiSetSimAuthentication
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_SimAuth 
{
	/*! The size, in bytes, of this structure.  This value must always be 
		populated by the calling application. */
	U32 sizeStruct;
	
	/*! 16 bytes random number provided by the user*/
    UCHAR RandNum[LENGTH_RandNum];
    
    /*! 32 bit SIM response */
    UINT32 SimResponse;
    
    /*! 8 bit ciphering key returned from the SIM */
    UCHAR Kc[LENGTH_Kc];
};


///////////////////////////////////////////////////////////////////////////////
///
/// This structure contains the output for the SMS store notification.
/// This notification is sent to application upon execution of SMS store
/// to report the result of a SMS store operation.
///
/// \sa SWI_TYPE_SmsStoreSendStatus
/// \sa	SwiStoreSMSMessageExp
/// \sa	SWI_NOTIFY_SmsStoreExp
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_SmsStoreExp
{
    /*!	The size, in bytes, of this structure.  This value should always be
		populated by the calling application. */
    U32	sizeStruct;

	/*! Result of the store SMS operation initiated by SwiStoreSMSMessageExp 
	    This value is returned by the API */ 
    SWI_TYPE_SmsStoreSendStatus	SmsStoreStatus;
};

///////////////////////////////////////////////////////////////////////////////
///
/// This structure contains the output for the SMS send notification.
/// This notification is sent to application upon execution of SMS send
/// to report the result of a SMS send operation.
///
/// \sa SWI_TYPE_SmsStoreSendStatus
/// \sa	SwiStoreSMSMessageExp
/// \sa	SWI_NOTIFY_SmsStoreExp
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_SmsSendExp
{
    /*!	The size, in bytes, of this structure.  This value should always be
		populated by the calling application. */
    U32 sizeStruct;

	/*! Result of the send SMS operation initiated by SwiSendSMSMessageExp 
	    This value is returned by the API */ 
    SWI_TYPE_SmsStoreSendStatus	SmsSendStatus;
};

///////////////////////////////////////////////////////////////////////////////
///
/// An enumeration of services types.
///
/// \sa SWI_STRUCT_ServiceIcon
/// \sa SWI_STRUCT_GsmSystemStatus
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_Service
{
	SWI_SERVICE_None,	/*!< No service. */
	SWI_SERVICE_Gprs,	/*!< GPRS */
	SWI_SERVICE_Edge,	/*!< EDGE */
	SWI_SERVICE_Umts,	/*!< UMTS */
	SWI_SERVICE_Hsdpa,	/*!< HSDPA */
	SWI_SERVICE_Hsupa,	/*!< HSUPA */
	SWI_SERVICE_Hspa,	/*!< HSDPA + HSUPA */
	SWI_SERVICE_HspaPlus,/*!< HSPA+ */
};

///////////////////////////////////////////////////////////////////////////////
///
/// This structure contains service state information.
///
/// \sa SWI_TYPE_Service
/// \sa SWI_NOTIFY_ServiceIcon
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_ServiceIcon
{
	/*! The size, in bytes, of this structure.  */
	U32 sizeStruct;
	
	/*! Version of this structure.  This field is obsolete and should be
		ignored. */
    U32 nVersion;
    
    /*! True is returned if the service icon should be displayed, false
		otherwise.  This was created because some carriers prefers not to 
		display the service icon even if there is service in the area. */
	bool bDisplayIcon;
	
	/*! Type of service that is available. */
	SWI_TYPE_Service eService;
	
	/*! True if the device is attached to the network, false otherwise. */
	bool bAttached;
	
	/*! True if there is an active packet session, false otherwise. */
	bool bPktSessionActive;
};

///////////////////////////////////////////////////////////////////////////////
///
/// This object is used to retrieve and set TTY (teletype) settings
///
/// \sa SwiGetTTY
/// \sa SwiSetTTY
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_TTYControl
{
	/*! The size, in bytes, of this structure.  This value must always be 
		populated by the calling application. */
	U32 sizeStruct;
	
	/*! Version of this structure.  Ignore this field. */
    U32 nVersion;
    
    /*! True if device supports TTY, false otherwise. */
	bool bSupported;
	
	/*! True if TTY icon should be displayed, false otherwise. */
	bool bDisplayIcon;
	
	/*! True if TTY enabled, false otherwise. */
	bool bEnabled;
	
	/*! 0x00 - 45.5Hz, 0x01 - 50Hz */
	U32 nBaudotRate;
	
	/*! 0x00 - never prompt, 0x01 - prompt always. */
	U32 nPromptAction;
	
	/*! True if TTY should be used for next call, false otherwise. */
	bool bUseTTYForNextCall;
};

///////////////////////////////////////////////////////////////////////////////
///
/// This structure is used in the SWI_NOTIFY_SmsReceived notification.  It 
/// indicates that a new SMS message (or segment) has been received by the 
/// modem.
///
/// \sa SWI_NOTIFY_SmsReceived
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_SMS_Received
{
	/*! The size, in bytes, of this structure. */
	U32 sizeStruct;
	
	/*! Record number of the newly received SMS message. */
	U8 nRecordNumber;
};

///////////////////////////////////////////////////////////////////////////////
///
/// This structure is used in the SWI_NOTIFY_SmsDeliver notification.
///	It delivers an SMS message (or segment) to the application.  This
///	SMS message (or segment) is not stored on the SIM.
///
/// \sa SWI_NOTIFY_SmsDeliver 
/// \sa SWI_TYPE_SMS_Address 
/// \sa SWI_TYPE_SMS_AddressNumbering 
/// \sa SWI_TYPE_SMS_Protocol
/// \sa SWI_TYPE_SMS_ProtocolId
/// \sa SWI_TYPE_SMS_CodingScheme
/// \sa SWI_TYPE_SMS_CodingClass
/// \sa SWI_TYPE_SMS_CodingCompression
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_SMS_Deliver
{
    /*!	The size, in bytes, of this structure. */
    U32	sizeStruct;

    /*! Destination Address Length
        Valid range for this field is from 0 to 20 */ 
    U32 nAddressNumLength;                     

    /*! Destination Address Type */
	SWI_TYPE_SMS_Address eAddress;                               

    /*! Destination Address Numbering Plan */ 
	SWI_TYPE_SMS_AddressNumbering eAddressNumberingPlan;                 

	/*! Destination Address
	    This field is in 8-bit binary-coded decimal. */
	U8 SME[LENGTH_SME];			

    /*! Service Centre Address Length
        Valid range for this field is from 0 to 20 */ 
    U32 nSCAddressNumLength;                  

   /*! Service Centre Address Type */
	SWI_TYPE_SMS_Address eSCAddress;                            

    /*! Service Centre Address Numbering Plan */ 
	SWI_TYPE_SMS_AddressNumbering eSCAddressNumberingPlan;                

	/*! Service Centre Address
	    This field is in 8-bit binary-coded decimal. */
	U8 SCAddressNumber[LENGTH_AddressNumber];  

    /*! Reply Path Flag */
    bool bReplyPath;

    /*! Protocol Type */
	SWI_TYPE_SMS_Protocol eProtocol;

    /*! Protocol ID */
    SWI_TYPE_SMS_ProtocolId eProtocolID;						

	/*! Data Coding Scheme */
	SWI_TYPE_SMS_CodingScheme eDataCodingScheme;					

    /*! Data Coding Class */
    SWI_TYPE_SMS_CodingClass eDataCodingClass;					

    /*! Data Coding Compression */
	SWI_TYPE_SMS_CodingCompression eDataCodingCompression;				

    /*! Message Waiting Indication flags */
    U8 byWaiting[LENGTH_MsgWaiting];           

	/*! User Data Header Present Flag */
    U8 bUserDataHeaderFlag;

	/*! Length of the SMS message in bytes */
    U8 nMessageLength;

	/*! SMS message data */
    U8 byMessage[LENGTH_MAX_SmsMsgData];	

    /*! More Messages to Send Flag */
    bool bMoreMessage;

    /*! Time of Originating SMS
	    This field is in 8-bit binary-coded decimal in the following format: 
	    yy,mm,dd,hh,mm,ss,tz.  Where tz is timezone */
    U8 Timestamp[LENGTH_SMSTimestamp];	     
};

///////////////////////////////////////////////////////////////////////////////
///
/// This structure is used in the SWI_NOTIFY_SmsSubmit notification.  This 
/// notification indicates that it is safe for the application to submit the 
/// next SMS message (or segment).
/// 
/// \sa SWI_TYPE_SMS_RequestStatus
/// \sa SWI_NOTIFY_SmsSubmit
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_SMS_Submit
{
	/*!	The size, in bytes, of this structure. */
	U32 sizeStruct;
	
	/*! Status of the request */
	SWI_TYPE_SMS_RequestStatus eRequestStatus;
	
	/*! Message reference number of the submit message */
	U8 nMessageReferenceNumber;	
};

///////////////////////////////////////////////////////////////////////////////
///
/// This enumeration contains the source status report request.
///
/// \sa SWI_STRUCT_SMS_StatusReport 
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_SMS_ReportQuality
{
    SWI_TYPE_SMSREPORTQUALITY_Submit = 0x00, /*!< SMS submit command */ 
    SWI_TYPE_SMSREPORTQUALITY_Command = 0x01 /*!< SMS status report command */ 
};

///////////////////////////////////////////////////////////////////////////////
///
/// This enumeration contains all possible SMS message states.
///
/// \sa SWI_STRUCT_SMS_StatusReport 
/// 
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_SMS_Message_Status 
{
	/*! message delivered */
    SWI_SMSMSGSTATUS_RECEIVED_OK,
    
     /*! unknown status */                     
    SWI_SMSMSGSTATUS_UNABLE_TO_CONFIRM_DELIVERY,
    
     /*! message replaced by service centre */      
    SWI_SMSMSGSTATUS_REPLACED,
    
    /*! congestion (trying to deliver) */           
    SWI_SMSMSGSTATUS_TRYING_CONGESTION = 0x20, 
    
     /*! SME busy (trying to deliver) */           
    SWI_SMSMSGSTATUS_TRYING_SME_BUSY,
    
     /*! no response (trying to deliver) */              
    SWI_SMSMSGSTATUS_TRYING_NO_RESPONSE_FROM_SME,
    
    /*! service request rejected (trying to deliver) */        
    SWI_SMSMSGSTATUS_TRYING_SERVICE_REJECTED, 
    
    /*! QOS not available (trying to deliver) */            
    SWI_SMSMSGSTATUS_TRYING_QOS_NOT_AVAILABLE,
    
     /*! SME error (trying to deliver) */          
    SWI_SMSMSGSTATUS_TRYING_SME_ERROR, 
    
    /*! remote procedure error (failed to deliver) */              
    SWI_SMSMSGSTATUS_PERM_REMOTE_PROCEDURE_ERROR = 0x40, 
    
    /*! incompatible destination (failed to deliver) */ 
    SWI_SMSMSGSTATUS_PERM_INCOMPATIBLE_DEST, 
    
    /*! rejected by SME (failed to deliver) */    
    SWI_SMSMSGSTATUS_PERM_REJECTED_BY_SME, 
    
     /*! Not Obtainable (failed to deliver) */
    SWI_SMSMSGSTATUS_PERM_NOT_OBTAINABLE,
    
    /*! QOS not available (failed to deliver) */ 
    SWI_SMSMSGSTATUS_PERM_QOS_NOT_AVAILABLE,
    
    /*! no inter-working (failed to deliver) */        
    SWI_SMSMSGSTATUS_PERM_NO_INTERWORKING, 
    
    /*! validation period expired (failed to deliver) */               
    SWI_SMSMSGSTATUS_PERM_VP_EXPIRED, 
    
    /*! deleted by SME (failed to deliver) */                    
    SWI_SMSMSGSTATUS_PERM_DELETED_BY_ORIG_SME, 
    
    /*! deleted by Service Center Admin (failed to deliver) */          
    SWI_SMSMSGSTATUS_PERM_DELETED_BY_SC_ADMIN,
    
    /*! SM does not existing (failed to deliver) */             
    SWI_SMSMSGSTATUS_PERM_SM_NO_EXISTING, 
    
     /*! congestion (failed to deliver) */          
    SWI_SMSMSGSTATUS_TEMP_CONGESTION = 0x60, 
    
    /*! SME busy (failed to deliver) */          
    SWI_SMSMSGSTATUS_TEMP_SME_BUSY,
    
    /*! no response from SME (failed to deliver) */             
    SWI_SMSMSGSTATUS_TEMP_NO_RESPONSE_FROM_SME, 
    
    /*! service request rejected (failed to deliver) */          
    SWI_SMSMSGSTATUS_TEMP_SERVICE_REJECTED, 
    
    /*! QOS not available (failed to deliver) */              
    SWI_SMSMSGSTATUS_TEMP_QOS_NOT_AVAILABLE, 
    
    /*! SME error (failed to deliver) */            
    SWI_SMSMSGSTATUS_TEMP_SME_ERROR 
};

///////////////////////////////////////////////////////////////////////////////
///
/// This structure is used in the SWI_NOTIFY_SmsStatusReport notification.
///	The notification delivers an SMS Status Report to the application.
///
/// \sa SWI_TYPE_SMS_RequestStatus 
/// \sa SWI_TYPE_SMS_Address
/// \sa SWI_TYPE_SMS_AddressNumbering
/// \sa SWI_TYPE_SMS_Message_Status
/// \sa SWI_TYPE_SMS_ReportQuality
/// \sa SWI_NOTIFY_SmsStatusReport
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_SMS_StatusReport
{
    /*!	The size, in bytes, of this structure.  */
    U32 sizeStruct;                          

    /*! Message Reference Number on which this structure is reporting.
	    The valid range is from 0 to 255.  */
	U8 nMessageReferenceNumber;	

	/*! Obsolete member */
	SWI_TYPE_SMS_RequestStatus eRequestStatus;

    /*! Service Centre Address Length
        Valid range for this field is from 0 to 20 */ 
    U32 nSCAddressNumLength;                  

    /*! Service Centre Address Type */
	SWI_TYPE_SMS_Address eSCAddress;                            

    /*! Service centre Address Numbering Plan */ 
	SWI_TYPE_SMS_AddressNumbering eSCAddressNumberingPlan;                

	/*! Service Centre Address
	    This field is in 8-bit binary-coded decimal. */
	U8 SCAddressNumber[LENGTH_AddressNumber];  

    /*! Destination Address Length
        Valid range for this field is from 0 to 20 */ 
    U32 nAddressNumLength;                     

   /*! Destination Address Type */
	SWI_TYPE_SMS_Address eAddress;                               

    /*! Destination Address Numbering Plan */ 
	SWI_TYPE_SMS_AddressNumbering eAddressNumberingPlan;                 

	/*! Destination Address
	    This field is in 8-bit binary-coded decimal. */
	U8 SME[LENGTH_SME];			       

	/*! More Messages to send flag */
	bool bMoreMessage;

    /*! Time the message was received by the service centre.
	    This field is in 8-bit binary-coded decimal in the following format: 
		yy,mm,dd,hh,mm,ss,tz.  Where tz is timezone */
	U8 SCTimestamp[LENGTH_SMSTimestamp];	    

    /*! Time the message reached its' destination.
	    This field is in 8-bit binary-coded decimal in the following format: 
	    yy,mm,dd,hh,mm,ss,tz.  Where tz is timezone */
	U8 Timestamp[LENGTH_SMSTimestamp];	    

    /*! SMS message status */
	SWI_TYPE_SMS_Message_Status	eSmsStatus;

    /*! Source of the status report request */
	SWI_TYPE_SMS_ReportQuality eSmsReportQuality;

	/*! Obsolete member */
	bool bSmsCipherFlag;
};

///////////////////////////////////////////////////////////////////////////////
///
/// This structure is used in the SWI_NOTIFY_SmsSimStatus notification.
/// It contains all the SIM information pertaining to SMS messages.
///
/// \sa SWI_TYPE_SMS_Routing
/// \sa SWI_NOTIFY_SmsSimStatus
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_SMS_SimStatus
{
	/*! The size, in bytes, of this structure. */
	U32 sizeStruct;
	
	/*! True if SMS is ready, false otherwise. */
	bool bSmsReadyFlag;
	
	/*! Number of unread records */
	U8 nUnreadRecords;
	
	/*! Number of used records */
	U8 nUsedRecords;
	
	/*! Total number of records */
	U8 nTotalRecords;
	
	/*! True if SIM is full, false otherwise. */
	bool bSimFullFlag;
	
	/*! First free record number */
	U8 nFirstFreeRecord;
	
	/*! Routing type */
	SWI_TYPE_SMS_Routing eRoutingType;
};

//////////////////////////////////////////////////////////////////////////////////
/// 
/// This structure is used to report SMS messaging parameters used by 
///	the network via the function SwiGetSMSParam. The data is needed to fill 
/// in the header for mobile-originated SMS messages.    
///
/// \sa SwiGetSmsParam 
/// \sa SwiSetSmsParam 
///
///////////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_SMS_Param
{
	/*! The size, in bytes, of this structure. */
	U32 sizeStruct;		

	/*! True if default destination address present, false otherwise. */
	bool bDesAddressPresent;			

	/*! Default destination address type */
	SWI_TYPE_SMS_Address eDesAddressType;				

	/*! Default destination address numbering plan */
	SWI_TYPE_SMS_AddressNumbering eDesAddressNumberingPlan;	

	/*! Default destination address numbering length */
	U32 nDefDesAddressLength;

	/*! Default destination address number */ 
	U8 DefDesAddress[20];

	/*! True if service centre address present, false otherwise. */
	bool bSCAddressPresent;			

	/*! Service centre address type */
	SWI_TYPE_SMS_Address eSCAddressType;				

	/*! Service center address numbering plan */ 
	SWI_TYPE_SMS_AddressNumbering eSCAddressNumberingPlan;		

	/*! Service center address numbering length */
	U32 nSCAddressLength;

	/*! Service center address number */
	U8 SCAddressNumber[20];

	/*! True if default protocol information present, false otherwise. */
	bool bDefProtocolIDPresent;		

	/*! Default protocol type */
	SWI_TYPE_SMS_Protocol eDefProtocolType;			

	/*! Default prototype id */ 
	SWI_TYPE_SMS_ProtocolId eDefProtocolID;		

	/*! True if default data coding scheme present, false otherwise. */
	bool bDefDCSPresent; 

	/*! Default data coding scheme data type */
	SWI_TYPE_SMS_CodingScheme eDefDCSDataType;				

	/*! Default data coding scheme class */ 
	SWI_TYPE_SMS_CodingClass eDefDCSClass;				

	/*! Default data coding scheme compression */ 
	SWI_TYPE_SMS_CodingCompression eDefDCSCompression;			

	/*! True if default validity period present, false otherwise. */
	bool bValidityPeriodPresent;		

	/*! default validity period.  
		This field defines the amount of time for which an outgoing message
		will be valid in the network before it is deemed obsolete and will be
		purged by the network even if the destination party does not retrieve
		the message.   

		The encoding of this field is as follows:
			- 0 to 143	(validity period + 1) x 5 minutes (ie. 5 min intervals
			  up to 12 hrs)
			- 144 to 167	12 hours + ((VP - 143) x 30 minutes)
			- 168 to 196	(VP - 166) x 1 day
			- 197 to 255	(VP - 192) x 1 week */
	U8 DefValidityPeriod;			

	/*! SMS routing option */
	SWI_TYPE_SMS_Routing eSMSRoutingOption;			
};

///////////////////////////////////////////////////////////////////////////////
///
/// This structure contains 3G packet session information.  
///
/// \sa SWI_TYPE_Precedence
/// \sa SWI_TYPE_Delay
/// \sa SWI_TYPE_Reliability
/// \sa SWI_TYPE_MeanThroughput
/// \sa SWI_TYPE_PeakThroughput
/// \sa SWI_TYPE_QOSUMTS_TrafficClass
/// \sa SWI_TYPE_QOSUMTS_Bitrate
/// \sa SWI_TYPE_QOSUMTS_DelOrder
/// \sa SWI_TYPE_QOSUMTS_DelErrSdu
/// \sa SWI_TYPE_QOSUMTS_SduErrRatio
/// \sa SWI_TYPE_QOSUMTS_ResBitErrRatio
/// \sa SWI_TYPE_QOSUMTS_TraffHandPri
/// \sa SWI_TYPE_QOSUMTS_SrcStatDesc
/// \sa SWI_TYPE_QOSUMTS_SignInd
/// \sa SWI_TYPE_InactivityReason
/// \sa SWI_NOTIFY_PktSessionCall
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_PktSessionCall
{
	/*! The size, in bytes, of this structure. */
	U32 sizeStruct;	
	
	/*! Profile ID. */	 
	U32 nProfileId;
	
	/*! True if packets session active, false otherwise. */			
    bool bPacketSessionActive;	
    
    /*! True if QoS information valid, false otherwise. */
    bool bValidQos;	
    
    /*! Negotiated QoS precedence. */			
    SWI_TYPE_Precedence ePrec;
    
    /*! Negotiated QoS delay. */					
    SWI_TYPE_Delay eDelay;	
    
    /*! Negotiated QoS reliability. */				
    SWI_TYPE_Reliability eReli;	
    
    /*! Negotiated QoS mean throughput. */				
    SWI_TYPE_MeanThroughput eMean;
    
    /*! Negotiated QoS peak throughput. */				
    SWI_TYPE_PeakThroughput ePeak;	
    
    /*! Negotiated UMTS QoS traffic class. */			
	SWI_TYPE_QOSUMTS_TrafficClass eTrafficClass;	
	
	/*! Negotiated UMTS QoS maximum upload bit rate. */		
	SWI_TYPE_QOSUMTS_Bitrate eMaxBitrateUl;	
	
	/*! Negotiated UMTS QoS maximum download bit rate. */		
	SWI_TYPE_QOSUMTS_Bitrate eMaxBitrateDl;	
	
	/*! Negotiated UMTS QoS guaranteed upload bit rate. */	
	SWI_TYPE_QOSUMTS_Bitrate eGuarBitrateUl;	
	
	/*! Negotiated UMTS QoS guaranteed download bit rate. */		
	SWI_TYPE_QOSUMTS_Bitrate eGuarBitrateDl;
	
	/*! Negotiated UMTS QoS delivery order. */			
	SWI_TYPE_QOSUMTS_DelOrder eDelOrder;
	
	/*! Negotiated UMTS QoS delivery of erroneous SDU. */			
	SWI_TYPE_QOSUMTS_DelErrSdu eDelErrSdu;
	
	/*! Negotiated UMTS QoS maximum SDU size (0-1520). */			
	U32 nMaxSdu;
	
	/*! Negotiated UMTS QoS SDU error ratio. */				
	SWI_TYPE_QOSUMTS_SduErrRatio eSduErrRatio;
	
	/*! Negotiated UMTS QoS residual bit error ratio. */			
	SWI_TYPE_QOSUMTS_ResBitErrRatio	eResBitErrRatio;
	
	/*! Negotiated UMTS QoS transfer delay (0-4000). */		
	U32 nTransDelay;
	
	/*! Negotiated UMTS QoS traffic handling priority. */			
	SWI_TYPE_QOSUMTS_TraffHandPri eTraffHandPri;
	
	/*! Negotiated UMTS QoS source statistics descriptor. */			
	SWI_TYPE_QOSUMTS_SrcStatDesc eSrcStatDesc;
	
	/*! Negotiated UMTS QoS signal indication. */			
	SWI_TYPE_QOSUMTS_SignInd eSignInd;
	
	/*! Inactivity reason.  This code is only used when bpacketSessionActive 
		is false. */
	SWI_TYPE_InactivityReason eInactivityReason;		
};

///////////////////////////////////////////////////////////////////////////////
///
/// This structure contains an IP address.
///
/// \sa SwiGetIPAddressEx
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_IpAddress
{
	/*! The size, in bytes, of this structure.  This value must always be 
		populated by the calling application. */
	U32 sizeStruct;	
	
	/*! Profile ID. */			  
	U32 nProfileId;
	
	/*! Length of the IP address  
		- 0: no IP address
		- 4: IPV4
		- 16: IPV6 */				
	U32 nIpLength;
	
	/*! IP address.  Example of an IPV4 address is 0x7F000201 which means 
		127.0.2.1. */
	BYTE byIp[LENGTH_IPAddress];	
};

///////////////////////////////////////////////////////////////////////////////
///
/// An enumeration of NV backup operation types.
///
/// \sa SWI_STRUCT_NvStore
/// \sa SWI_NOTIFY_NvStore
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_NvOperation
{
    SWI_NVOPER_BackupAll,		/*!< NV backup all operation. */
	SWI_NVOPER_RestoreAll,		/*!< NV restore all operation. */
	SWI_NVOPER_Backup,			/*!< NV backup operation. */
	SWI_NVOPER_Restore,			/*!< NV restore operation. */
};

///////////////////////////////////////////////////////////////////////////////
///
/// An enumeration of NV category types.
///
/// \sa SWI_STRUCT_NvStore
/// \sa SWI_NOTIFY_NvStore
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_NvCategory
{
    SWI_NVCAT_Factory,		/*!< Factory settings. */
	SWI_NVCAT_Oem,			/*!< OEM settings. */
	SWI_NVCAT_User,			/*!< User settings (default). */
};

///////////////////////////////////////////////////////////////////////////////
///
/// This structure contains NV back up information. 
///
/// \sa SWI_TYPE_NvOperation
/// \sa SWI_TYPE_NvCategory
/// \sa SWI_NOTIFY_NvStore
/// \sa SwiNvStore
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_NvStore
{
	/*! The size, in bytes, of this structure. */
	U32 sizeStruct;
	
	/*! This value is only valid with the SWI_NOTIFY_NvStore notification.  
		A value of "true" is returned if the back up succeed, false 
		otherwise. */
	bool bSuccess;
	
	/*! Type of operation to perform.  Must be specified when doing a 
		backup/restore. */				
	SWI_TYPE_NvOperation eOperation;	
	
	/*! NV category.  Must be specified when doing a backup/restore. */			
	SWI_TYPE_NvCategory	eCategory;
	
	/*! Items stored for backup operation or restored for restore operation,
		0 for other operations. */			
	U32 nStored;
	
	/*! Items skipped for backup operation only, 0 for other operations. */						
	U32 nSkipped;
	
	/*! Items with 0 length for backup operation only, 0 for other 
		operations. */	
	U32 nZeroLength;			
};

///////////////////////////////////////////////////////////////////////////////
///
/// This structure contains ICC ID of the SIM  
///
/// \sa SwiGetIccId
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_IccId
{
	/*! The size, in bytes, of this structure.  This value must always be 
		populated by the calling application. */
	U32 sizeStruct;
	
	/*! A binary number representing the ICC ID of the SIM. */				 
	U8 nIccId[LENGTH_IccId];	
};

///////////////////////////////////////////////////////////////////////////////
///
/// This structure contains HSDPA test channel information.
///			
/// Notes:	None
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_HSDPA_TestChan
{
	/*! The size, in bytes, of this structure. */
	U32 sizeStruct;
	
	/*! When used with SwiGetHSDPATestChannel, this returns the current
		UARFCN test channel.  When used with SwiSetHSDPATestChannel, this
		specifies the new UARFCN test channel to scan. */
    U32 CurUARFCN_TestChannel;
    
    /*! True indicates UARFCN test channel search is enabled, false 
		otherwise. */
	bool bEnable;
	
	/*! This must be specified when calling SwiSetHSDPATestChannel.  Set to 
		true to re-scan now, false otherwise. */
	bool bRescan;
	
	/*! True is returned if the request channel is valid, false otherwise. 
		This field is only applicable when returned from
		SWI_NOTIFY_HSDPA_TestChan. */
	bool bChannelStatus;
};

///////////////////////////////////////////////////////////////////////////////
///
/// This structure returns available features of the modem.
///
/// \sa SwiGetAvailableFeatures
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_AvailFeatures
{
	/*! The size, in bytes, of this structure.  This value must always be 
		populated by the calling application. */
	U32 sizeStruct;
	
	/*! True if voice is supported, false otherwise. */
	bool bVoice;
	
	/*! True if tri-band is supported, false otherwise. */
	bool bTriBand;
	
	/*! PDP type supported */
	SWI_TYPE_PDP pdpType;
};

///////////////////////////////////////////////////////////////////////////////
///
/// An enumeration of modem power status.
///
/// \sa SWI_STRUCT_GsmSystemStatus
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_ModemStatus
{
	SWI_MODEMSTATUS_Offline,	/*!< Offline */
	SWI_MODEMSTATUS_Online,		/*!< Online */
	SWI_MODEMSTATUS_Lpm			/*!< Lower power mode */
};

///////////////////////////////////////////////////////////////////////////////
///
/// An enumeration of service errors types.
///
/// \sa SWI_STRUCT_GsmSystemStatus
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_ServiceErr
{
	SWI_SERVICEERR_None,					/*!< No error */
	SWI_SERVICEERR_Unspecified = 0xFFFF,	/*!< Unspecified protocol error */
};

///////////////////////////////////////////////////////////////////////////////
///
/// An enumeration of MNC formats
///
/// \sa SWI_STRUCT_GsmSystemStatus
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_MncFormat
{
	SWI_MNCFORMAT_2Digit,	/*!< 2 digit format */
	SWI_MNCFORMAT_3Digit	/*!< 3 digit format */
};

///////////////////////////////////////////////////////////////////////////////
///
/// This structure contains system status information.
///			
/// \sa SWI_TYPE_ModemStatus
/// \sa	SWI_TYPE_ServiceStatus
/// \sa	SWI_TYPE_ServiceErr
/// \sa	SWI_TYPE_ServiceType
/// \sa	SWI_TYPE_Service
/// \sa	SWI_TYPE_ModeSelection
/// \sa	SWI_TYPE_MncFormat
/// \sa	SWI_NOTIFY_GsmSystemStatus
/// \sa SwiGetGsmSystemStatus
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_GsmSystemStatus
{
	/*! The size, in bytes, of this structure. */
	U32 sizeStruct;
	
	/*! Modem status */
	SWI_TYPE_ModemStatus eModemStatus;
	
	/*! Service status */
	SWI_TYPE_ServiceStatus eServiceStatus;
	
	/*! Service error */
	SWI_TYPE_ServiceErr	 eServiceErr;
	
	/*! Service type */
	SWI_TYPE_ServiceType eServiceType;
	
	/*! System mode */
	SWI_TYPE_Service eSystemMode;
	
	/*! Current radio band.  Values can be mapped to SWI_TYPE_RadioBand which
		is defined in SwiStructsCm.h. */
	U32 eCurrentBand;
	
	/*! True if roaming, false if on home network */
	bool bRoaming;
	
	/*! Network selection mode (either manual or automatic) */
	SWI_TYPE_ModeSelection eManualMode;
	
	/*! NULL terminated country string */
	WCHAR szCountry[LENGTH_Country];
	
	/*! NULL terminated network string */
	WCHAR szNetwork[LENGTH_Network];
	
	/*! Mobile country code */
	U32 nMcc;
	
	/*! Mobile network code */
	U32 nMnc;
	
	/*! Location area code */
	U32 nLac;
	
	/*! Routing area code */
	U32 nRac;
	
	/*! Cell ID */
	U32 nCellId;
	
	/*! Channel number */
	U32 nChannelNum;
	
	/*! Primary Scrambling Code (WCDMA only, 0 for GSM) */
	U32 nPriScramCode;
	
	/*! MNC format (either 2-digit or 3-digit) */
	SWI_TYPE_MncFormat eMncFormat;
	
	/*! PLMN service error bit mask:
		- bit 0: manual PLMN acquisition time out
		- bit 1-7: unused */
	U32 nPlmnServiceErrMask;
};

///////////////////////////////////////////////////////////////////////////////
///
/// This structure contains primary scramble code, RSCP, and Ec/Io  
/// information for an individual cell.
///			
/// \sa SWI_STRUCT_RscpEcIo
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_RscpEcIoInfo
{
	U32 nPriScramCode;	/*!< Primary scramble code */
	U32 nRscp;			/*!< Received signal code power */
	U32 nEcIo;			/*!< Energy per chip per power density */
};

///////////////////////////////////////////////////////////////////////////////
///
/// This object provides Received Signal Code Power (RSCP) and the total
/// Energy per chip per power density (Ec/Io) value of the active set's 
/// strongest cells, to a maximum of 6 (WCDMA only).  The Ec/Io value
/// will be provided as a U32 representation -dB in half step increments
/// and in order of strongest to weakest cell, which is based on the RSCP.
///
/// For example, if the value returned for Ec/Io is 0x0015, Ec/Io = -10.5dB.
///
/// These measurements are only valid for UMTS, if the current service is
/// GSM, then the number of cells will be set to 0.
///
/// The notifications, if enabled, will be sent to the host application
/// about every 3 seconds only if something changes.
///	
/// \sa SWI_STRUCT_RscpEcIoInfo	
/// \sa  SWI_NOTIFY_RscpEcIo
/// \sa SwiGetRscpEcIo
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_RscpEcIo
{
	/*! The size, in bytes, of this structure. */
	U32 sizeStruct;	
	
	/*!< Number of cells (max 6). */	
	U32 nNumOfCells;
	
	/*! Array of cell information. */
	SWI_STRUCT_RscpEcIoInfo	arCellInfo[MAX_CELLS]; 
};

///////////////////////////////////////////////////////////////////////////////
///
/// This structure contains cell measurements.
///
/// \sa SWI_TYPE_ServiceStatus
/// \sa SWI_STRUCT_GsmCellInfo
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_GsmCellMeasure
{
	/*! The size, in bytes, of this structure.  This value must always be 
		populated by the calling application. */
	U32 sizeStruct;
	
	/*! Radio band.  Values can be mapped to SWI_TYPE_RadioBand which is 
		defined in SwiStructsCm.h. */
	U32 eRadioBand;
	
	/*! ARFCN */						
	U32 nArfcn;							
	
	/*! RAC (0xFFFF if invalid) */
	U32 nRac;
	
	/*! Rx level in dBm */	
	U32 nRxLevel;
	
	/*! C1 */					
	U32 nC1;
	
	/*! C2 */						
	U32 nC2;
	
	/*! C31 */							
	U32 nC31;
	
	/*! C32 */							
	U32 nC32;							
};

///////////////////////////////////////////////////////////////////////////////
///
/// This structure contains cell information.
///
/// \sa SWI_STRUCT_GsmCellMeasure
/// \sa SWI_NOTIFY_GsmCellInfo
/// \sa SwiGetGsmCellInfo
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_GsmCellInfo
{
	/*! The size, in bytes, of this structure. */
	U32	sizeStruct;
	
	/*! True if information provided in this structure is valid, false 
		otherwise. */
	bool bValid;
	
	/*! MCC */
	U32	nMcc;
	
	/*! MNC */
	U32	nMnc;
	
	/*! LAC */
	U32	nLac;
	
	/*! Cell ID */
	U32	nCellId;
	
	/*! BSIC */
	U32	nBsic;
	
	/*! Network color code */
	U32	nNetColorCode;
	
	/*! Base station color code */
	U32	 nBsColorCode;
	
	/*! RAC */
	U32	nRac;
	
	/*! Minimum RX level to register in dBm */
	U32 nMinRxLevel;
	
	/*! Max power on RACH burst (not implemented 0xFFFF). */
	U32 nMaxRach;
	
	SWI_TYPE_ServiceStatus eServStatus;		/*!< Service status */
	
	/*! Radio band.  Values can be mapped to SWI_TYPE_RadioBand which is 
		defined in SwiStructsCm.h. */
	U32 eRadioBand;
	
	/*! ARFCN */						
	U32 nArfcn;							
	
	/*! Rx level in dBm */	
	U32 nRxLevel;
	
	/*! C1 */					
	U32 nC1;
	
	/*! C2 */						
	U32 nC2;
	
	/*! C31 */							
	U32 nC31;
	
	/*! C32 */							
	U32 nC32;							

	/*! Number of valid neighbor cells. */
	U32	nNumValidNeighborCells;
	
	/*! Neighbor cell measurements. */
	SWI_STRUCT_GsmCellMeasure arNeighborCells[MAX_CELLS];
};

///////////////////////////////////////////////////////////////////////////////
///
///	An enumeration of Radio Access Technology (RAT) mode.
///
///	\sa SWI_STRUCT_Rat
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_RatMode
{
	SWI_RATMODE_Automatic,			/*!< Automatic */
	SWI_RATMODE_UMTS3G_Only,		/*!< UMTS 3G Only */
	SWI_RATMODE_GSM2G_Only,			/*!< GSM 2G Only */
	SWI_RATMODE_UMTS3G_Preferred,	/*!< UMTS 3G Preferred */
	SWI_RATMODE_GSM2G_Preferred,	/*!< GSM 2G Preferred */
};

///////////////////////////////////////////////////////////////////////////////
///
///	This structure contains Radio Access Technology (RAT) information.
///
///	\sa SWI_TYPE_RatMode
///	\sa SwiGetRat
///	\sa SwiSetRat
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_Rat
{
	/*! The size, in bytes, of this structure. */
	U32	sizeStruct;

	/*! The returned or requested RAT mode */
	SWI_TYPE_RatMode eRatMode;
	
	/*! True is returned if request to set RAT mode is successful, 
	false otherwise. */
	bool bSuccess;
	
};


///////////////////////////////////////////////////////////////////////////////
///
///	An enumeration of PRL regions.
///
///	\sa SWI_STRUCT_PrlRegion
///
///////////////////////////////////////////////////////////////////////////////

enum SWI_TYPE_PrlRegion
{
	SWI_RRLREGION_Default,		/*!< default (internal) */
	SWI_RRLREGION_Europe,		/*!< Europe */
	SWI_RRLREGION_NorthAmerica,	/*!< North America */
	SWI_RRLREGION_Australia,	/*!< Australia */
	SWI_RRLREGION_Japan,		/*!< Japan */
	SWI_RRLREGION_Reserved,		/*!< Reserved */
	SWI_RRLREGION_Italy,		/*!< Italy */
};

///////////////////////////////////////////////////////////////////////////////
///
/// An enumeration of PRL region mode change status returned by \sa SwiSetPrl.
///
/// \sa SWI_STRUCT_PrlRegion
///	\sa SwiSetPrl
///
///////////////////////////////////////////////////////////////////////////////
enum SWI_TYPE_PrlChangeStatus
{
	SWI_PRLCHANGE_Success,			/*!< request successful */
	SWI_PRLCHANGE_InvalidPassword,	/*!< invalid password key */
	SWI_PRLCHANGE_GeneralFailure,	/*!< general failure */
};

///////////////////////////////////////////////////////////////////////////////
///
///	This structure contains PRL Region information.
///
///	\sa SWI_TYPE_PrlRegion
/// \sa SwiGetPrl
///	\sa SwiSetPrl
///
///////////////////////////////////////////////////////////////////////////////
struct SWI_STRUCT_PrlRegion
{
	/*! The size, in bytes, of this structure. */
	U32	sizeStruct;

	/*! The returned or requested PRL region */
	SWI_TYPE_PrlRegion ePrlRegion;
	
	/*! returned change status, it is only used as a return to SwiSetPrl and 
	is the actual result of the SwiSetPrl operation.*/
	SWI_TYPE_PrlChangeStatus	ePrlChangeStatus;

	/*! A NULL terminated string representing the password to unlock API */				
	WCHAR szUnlockKey[LENGTH_UnlockKey];

};

#endif ///__SWI_STRUCTS_GSM_H
